# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nidaqmx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nidaqmx._stubs import session_pb2 as session__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rnidaqmx.proto\x12\x0cnidaqmx_grpc\x1a\rsession.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"}\n\x1d\x41nalogPowerUpChannelsAndState\x12\x15\n\rchannel_names\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\x01\x12\x36\n\x0c\x63hannel_type\x18\x03 \x01(\x0e\x32 .nidaqmx_grpc.PowerUpChannelType\"_\n\x1bWatchdogExpChannelsAndState\x12\r\n\x05lines\x18\x01 \x01(\t\x12\x31\n\texp_state\x18\x02 \x01(\x0e\x32\x1e.nidaqmx_grpc.DigitalLineState\"`\n\x1c\x44igitalPowerUpTypeAndChannel\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12*\n\x05state\x18\x02 \x01(\x0e\x32\x1b.nidaqmx_grpc.PowerUpStates\"c\n\x1e\x44igitalPowerUpChannelsAndState\x12\x15\n\rchannel_names\x18\x01 \x01(\t\x12*\n\x05state\x18\x02 \x01(\x0e\x32\x1b.nidaqmx_grpc.PowerUpStates\"j\n%DigitalPullUpPullDownChannelsAndState\x12\x15\n\rchannel_names\x18\x01 \x01(\t\x12*\n\x05state\x18\x02 \x01(\x0e\x32\x1b.nidaqmx_grpc.ResistorState\"k\n\x1b\x41nalogPowerUpChannelAndType\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x36\n\x0c\x63hannel_type\x18\x02 \x01(\x0e\x32 .nidaqmx_grpc.PowerUpChannelType\"1\n\x1c\x41\x64\x64\x43\x44\x41QSyncConnectionRequest\x12\x11\n\tport_list\x18\x01 \x01(\t\"/\n\x1d\x41\x64\x64\x43\x44\x41QSyncConnectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Z\n\x1b\x41\x64\x64GlobalChansToTaskRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rchannel_names\x18\x02 \x01(\t\".\n\x1c\x41\x64\x64GlobalChansToTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n\x17\x41\x64\x64NetworkDeviceRequest\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x1b\n\x13\x61ttempt_reservation\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\"C\n\x18\x41\x64\x64NetworkDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x64\x65vice_name_out\x18\x02 \x01(\t\"_\n-AreConfiguredCDAQSyncPortsDisconnectedRequest\x12\x1d\n\x15\x63hassis_devices_ports\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"b\n.AreConfiguredCDAQSyncPortsDisconnectedResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12 \n\x18\x64isconnected_ports_exist\x18\x02 \x01(\x08\"Y\n\'AutoConfigureCDAQSyncConnectionsRequest\x12\x1d\n\x15\x63hassis_devices_ports\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\":\n(AutoConfigureCDAQSyncConnectionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9b\x01\n CalculateReversePolyCoeffRequest\x12\x16\n\x0e\x66orward_coeffs\x18\x01 \x03(\x01\x12\x11\n\tmin_val_x\x18\x02 \x01(\x01\x12\x11\n\tmax_val_x\x18\x03 \x01(\x01\x12\x1d\n\x15num_points_to_compute\x18\x04 \x01(\x05\x12\x1a\n\x12reverse_poly_order\x18\x05 \x01(\x05\"K\n!CalculateReversePolyCoeffResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x16\n\x0ereverse_coeffs\x18\x02 \x03(\x01\"\xee\x01\n\x19\x43\x66gAnlgEdgeRefTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0etrigger_source\x18\x02 \x01(\t\x12-\n\rtrigger_slope\x18\x03 \x01(\x0e\x32\x14.nidaqmx_grpc.Slope1H\x00\x12\x1b\n\x11trigger_slope_raw\x18\x04 \x01(\x05H\x00\x12\x15\n\rtrigger_level\x18\x05 \x01(\x01\x12\x1a\n\x12pretrigger_samples\x18\x06 \x01(\rB\x14\n\x12trigger_slope_enum\",\n\x1a\x43\x66gAnlgEdgeRefTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd4\x01\n\x1b\x43\x66gAnlgEdgeStartTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0etrigger_source\x18\x02 \x01(\t\x12-\n\rtrigger_slope\x18\x03 \x01(\x0e\x32\x14.nidaqmx_grpc.Slope1H\x00\x12\x1b\n\x11trigger_slope_raw\x18\x04 \x01(\x05H\x00\x12\x15\n\rtrigger_level\x18\x05 \x01(\x01\x42\x14\n\x12trigger_slope_enum\".\n\x1c\x43\x66gAnlgEdgeStartTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb5\x01\n\x1e\x43\x66gAnlgMultiEdgeRefTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0ftrigger_sources\x18\x02 \x01(\t\x12\x1b\n\x13trigger_slope_array\x18\x03 \x03(\x05\x12\x1b\n\x13trigger_level_array\x18\x04 \x03(\x01\x12\x1a\n\x12pretrigger_samples\x18\x05 \x01(\r\"1\n\x1f\x43\x66gAnlgMultiEdgeRefTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9b\x01\n CfgAnlgMultiEdgeStartTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0ftrigger_sources\x18\x02 \x01(\t\x12\x1b\n\x13trigger_slope_array\x18\x03 \x03(\x05\x12\x1b\n\x13trigger_level_array\x18\x04 \x03(\x01\"3\n!CfgAnlgMultiEdgeStartTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x92\x02\n\x1b\x43\x66gAnlgWindowRefTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0etrigger_source\x18\x02 \x01(\t\x12=\n\x0ctrigger_when\x18\x03 \x01(\x0e\x32%.nidaqmx_grpc.WindowTriggerCondition1H\x00\x12\x1a\n\x10trigger_when_raw\x18\x04 \x01(\x05H\x00\x12\x12\n\nwindow_top\x18\x05 \x01(\x01\x12\x15\n\rwindow_bottom\x18\x06 \x01(\x01\x12\x1a\n\x12pretrigger_samples\x18\x07 \x01(\rB\x13\n\x11trigger_when_enum\".\n\x1c\x43\x66gAnlgWindowRefTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf8\x01\n\x1d\x43\x66gAnlgWindowStartTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0etrigger_source\x18\x02 \x01(\t\x12=\n\x0ctrigger_when\x18\x03 \x01(\x0e\x32%.nidaqmx_grpc.WindowTriggerCondition1H\x00\x12\x1a\n\x10trigger_when_raw\x18\x04 \x01(\x05H\x00\x12\x12\n\nwindow_top\x18\x05 \x01(\x01\x12\x15\n\rwindow_bottom\x18\x06 \x01(\x01\x42\x13\n\x11trigger_when_enum\"0\n\x1e\x43\x66gAnlgWindowStartTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xef\x04\n+CfgBurstHandshakingTimingExportClockRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\x0bsample_mode\x18\x02 \x01(\x0e\x32\x1d.nidaqmx_grpc.AcquisitionTypeH\x00\x12\x19\n\x0fsample_mode_raw\x18\x03 \x01(\x05H\x00\x12\x16\n\x0esamps_per_chan\x18\x04 \x01(\x04\x12\x17\n\x0fsample_clk_rate\x18\x05 \x01(\x01\x12\x1c\n\x14sample_clk_outp_term\x18\x06 \x01(\t\x12<\n\x19sample_clk_pulse_polarity\x18\x07 \x01(\x0e\x32\x17.nidaqmx_grpc.Polarity2H\x01\x12\'\n\x1dsample_clk_pulse_polarity_raw\x18\x08 \x01(\x05H\x01\x12*\n\npause_when\x18\t \x01(\x0e\x32\x14.nidaqmx_grpc.Level1H\x02\x12\x18\n\x0epause_when_raw\x18\n \x01(\x05H\x02\x12;\n\x18ready_event_active_level\x18\x0b \x01(\x0e\x32\x17.nidaqmx_grpc.Polarity2H\x03\x12&\n\x1cready_event_active_level_raw\x18\x0c \x01(\x05H\x03\x42\x12\n\x10sample_mode_enumB \n\x1esample_clk_pulse_polarity_enumB\x11\n\x0fpause_when_enumB\x1f\n\x1dready_event_active_level_enum\">\n,CfgBurstHandshakingTimingExportClockResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdc\x04\n+CfgBurstHandshakingTimingImportClockRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\x0bsample_mode\x18\x02 \x01(\x0e\x32\x1d.nidaqmx_grpc.AcquisitionTypeH\x00\x12\x19\n\x0fsample_mode_raw\x18\x03 \x01(\x05H\x00\x12\x16\n\x0esamps_per_chan\x18\x04 \x01(\x04\x12\x17\n\x0fsample_clk_rate\x18\x05 \x01(\x01\x12\x16\n\x0esample_clk_src\x18\x06 \x01(\t\x12\x35\n\x16sample_clk_active_edge\x18\x07 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x01\x12$\n\x1asample_clk_active_edge_raw\x18\x08 \x01(\x05H\x01\x12*\n\npause_when\x18\t \x01(\x0e\x32\x14.nidaqmx_grpc.Level1H\x02\x12\x18\n\x0epause_when_raw\x18\n \x01(\x05H\x02\x12;\n\x18ready_event_active_level\x18\x0b \x01(\x0e\x32\x17.nidaqmx_grpc.Polarity2H\x03\x12&\n\x1cready_event_active_level_raw\x18\x0c \x01(\x05H\x03\x42\x12\n\x10sample_mode_enumB\x1d\n\x1bsample_clk_active_edge_enumB\x11\n\x0fpause_when_enumB\x1f\n\x1dready_event_active_level_enum\">\n,CfgBurstHandshakingTimingImportClockResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf9\x01\n\x1f\x43\x66gChangeDetectionTimingRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10rising_edge_chan\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61lling_edge_chan\x18\x03 \x01(\t\x12\x34\n\x0bsample_mode\x18\x04 \x01(\x0e\x32\x1d.nidaqmx_grpc.AcquisitionTypeH\x00\x12\x19\n\x0fsample_mode_raw\x18\x05 \x01(\x05H\x00\x12\x16\n\x0esamps_per_chan\x18\x06 \x01(\x04\x42\x12\n\x10sample_mode_enum\"2\n CfgChangeDetectionTimingResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd2\x01\n\x18\x43\x66gDigEdgeRefTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0etrigger_source\x18\x02 \x01(\t\x12+\n\x0ctrigger_edge\x18\x03 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x00\x12\x1a\n\x10trigger_edge_raw\x18\x04 \x01(\x05H\x00\x12\x1a\n\x12pretrigger_samples\x18\x05 \x01(\rB\x13\n\x11trigger_edge_enum\"+\n\x19\x43\x66gDigEdgeRefTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb8\x01\n\x1a\x43\x66gDigEdgeStartTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0etrigger_source\x18\x02 \x01(\t\x12+\n\x0ctrigger_edge\x18\x03 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x00\x12\x1a\n\x10trigger_edge_raw\x18\x04 \x01(\x05H\x00\x42\x13\n\x11trigger_edge_enum\"-\n\x1b\x43\x66gDigEdgeStartTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x81\x02\n\x1b\x43\x66gDigPatternRefTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0etrigger_source\x18\x02 \x01(\t\x12\x17\n\x0ftrigger_pattern\x18\x03 \x01(\t\x12>\n\x0ctrigger_when\x18\x04 \x01(\x0e\x32&.nidaqmx_grpc.DigitalPatternCondition1H\x00\x12\x1a\n\x10trigger_when_raw\x18\x05 \x01(\x05H\x00\x12\x1a\n\x12pretrigger_samples\x18\x06 \x01(\rB\x13\n\x11trigger_when_enum\".\n\x1c\x43\x66gDigPatternRefTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe7\x01\n\x1d\x43\x66gDigPatternStartTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0etrigger_source\x18\x02 \x01(\t\x12\x17\n\x0ftrigger_pattern\x18\x03 \x01(\t\x12>\n\x0ctrigger_when\x18\x04 \x01(\x0e\x32&.nidaqmx_grpc.DigitalPatternCondition1H\x00\x12\x1a\n\x10trigger_when_raw\x18\x05 \x01(\x05H\x00\x42\x13\n\x11trigger_when_enum\"0\n\x1e\x43\x66gDigPatternStartTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc0\x01\n\x1b\x43\x66gHandshakingTimingRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\x0bsample_mode\x18\x02 \x01(\x0e\x32\x1d.nidaqmx_grpc.AcquisitionTypeH\x00\x12\x19\n\x0fsample_mode_raw\x18\x03 \x01(\x05H\x00\x12\x16\n\x0esamps_per_chan\x18\x04 \x01(\x04\x42\x12\n\x10sample_mode_enum\".\n\x1c\x43\x66gHandshakingTimingResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbd\x01\n\x18\x43\x66gImplicitTimingRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\x0bsample_mode\x18\x02 \x01(\x0e\x32\x1d.nidaqmx_grpc.AcquisitionTypeH\x00\x12\x19\n\x0fsample_mode_raw\x18\x03 \x01(\x05H\x00\x12\x16\n\x0esamps_per_chan\x18\x04 \x01(\x04\x42\x12\n\x10sample_mode_enum\"+\n\x19\x43\x66gImplicitTimingResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Y\n\x15\x43\x66gInputBufferRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\r\"(\n\x16\x43\x66gInputBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Z\n\x16\x43\x66gOutputBufferRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\r\")\n\x17\x43\x66gOutputBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbe\x02\n CfgPipelinedSampClkTimingRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04rate\x18\x03 \x01(\x01\x12*\n\x0b\x61\x63tive_edge\x18\x04 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x00\x12\x19\n\x0f\x61\x63tive_edge_raw\x18\x05 \x01(\x05H\x00\x12\x34\n\x0bsample_mode\x18\x06 \x01(\x0e\x32\x1d.nidaqmx_grpc.AcquisitionTypeH\x01\x12\x19\n\x0fsample_mode_raw\x18\x07 \x01(\x05H\x01\x12\x16\n\x0esamps_per_chan\x18\x08 \x01(\x04\x42\x12\n\x10\x61\x63tive_edge_enumB\x12\n\x10sample_mode_enum\"3\n!CfgPipelinedSampClkTimingResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb5\x02\n\x17\x43\x66gSampClkTimingRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04rate\x18\x03 \x01(\x01\x12*\n\x0b\x61\x63tive_edge\x18\x04 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x00\x12\x19\n\x0f\x61\x63tive_edge_raw\x18\x05 \x01(\x05H\x00\x12\x34\n\x0bsample_mode\x18\x06 \x01(\x0e\x32\x1d.nidaqmx_grpc.AcquisitionTypeH\x01\x12\x19\n\x0fsample_mode_raw\x18\x07 \x01(\x05H\x01\x12\x16\n\x0esamps_per_chan\x18\x08 \x01(\x04\x42\x12\n\x10\x61\x63tive_edge_enumB\x12\n\x10sample_mode_enum\"*\n\x18\x43\x66gSampClkTimingResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc3\x01\n\x17\x43\x66gTimeStartTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12(\n\x04when\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\ttimescale\x18\x03 \x01(\x0e\x32\x18.nidaqmx_grpc.Timescale2H\x00\x12\x17\n\rtimescale_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0etimescale_enum\"*\n\x18\x43\x66gTimeStartTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb8\x01\n\x1f\x43\x66gWatchdogAOExpirStatesRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rchannel_names\x18\x02 \x01(\t\x12\x19\n\x11\x65xpir_state_array\x18\x03 \x03(\x01\x12=\n\x11output_type_array\x18\x04 \x03(\x0e\x32\".nidaqmx_grpc.WatchdogAOOutputType\"2\n CfgWatchdogAOExpirStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9d\x01\n\x1f\x43\x66gWatchdogCOExpirStatesRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rchannel_names\x18\x02 \x01(\t\x12=\n\x11\x65xpir_state_array\x18\x03 \x03(\x0e\x32\".nidaqmx_grpc.WatchdogCOExpirState\"2\n CfgWatchdogCOExpirStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x99\x01\n\x1f\x43\x66gWatchdogDOExpirStatesRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rchannel_names\x18\x02 \x01(\t\x12\x39\n\x11\x65xpir_state_array\x18\x03 \x03(\x0e\x32\x1e.nidaqmx_grpc.DigitalLineState\"2\n CfgWatchdogDOExpirStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\",\n\x10\x43learTEDSRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\"#\n\x11\x43learTEDSResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"8\n\x10\x43learTaskRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"#\n\x11\x43learTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xaa\x02\n\x17\x43onfigureLoggingRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x31\n\x0clogging_mode\x18\x03 \x01(\x0e\x32\x19.nidaqmx_grpc.LoggingModeH\x00\x12\x1a\n\x10logging_mode_raw\x18\x04 \x01(\x05H\x00\x12\x12\n\ngroup_name\x18\x05 \x01(\t\x12\x33\n\toperation\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.LoggingOperationH\x01\x12\x17\n\roperation_raw\x18\x07 \x01(\x05H\x01\x42\x13\n\x11logging_mode_enumB\x10\n\x0eoperation_enum\"*\n\x18\x43onfigureLoggingResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"C\n\x14\x43onfigureTEDSRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\"\'\n\x15\x43onfigureTEDSResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbf\x01\n\x13\x43onnectTermsRequest\x12\x17\n\x0fsource_terminal\x18\x01 \x01(\t\x12\x1c\n\x14\x64\x65stination_terminal\x18\x02 \x01(\t\x12\x38\n\x10signal_modifiers\x18\x03 \x01(\x0e\x32\x1c.nidaqmx_grpc.InvertPolarityH\x00\x12\x1e\n\x14signal_modifiers_raw\x18\x04 \x01(\x05H\x00\x42\x17\n\x15signal_modifiers_enum\"&\n\x14\x43onnectTermsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9e\x01\n\x1a\x43ontrolWatchdogTaskRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x35\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.WatchdogControlActionH\x00\x12\x14\n\naction_raw\x18\x03 \x01(\x05H\x00\x42\r\n\x0b\x61\x63tion_enum\"-\n\x1b\x43ontrolWatchdogTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xde\x05\n&CreateAIAccel4WireDCVoltageChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12*\n\x05units\x18\x08 \x01(\x0e\x32\x19.nidaqmx_grpc.AccelUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x13\n\x0bsensitivity\x18\n \x01(\x01\x12\x41\n\x11sensitivity_units\x18\x0b \x01(\x0e\x32$.nidaqmx_grpc.AccelSensitivityUnits1H\x02\x12\x1f\n\x15sensitivity_units_raw\x18\x0c \x01(\x05H\x02\x12>\n\x14voltage_excit_source\x18\r \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x03\x12\"\n\x18voltage_excit_source_raw\x18\x0e \x01(\x05H\x03\x12\x19\n\x11voltage_excit_val\x18\x0f \x01(\x01\x12\x1d\n\x15use_excit_for_scaling\x18\x10 \x01(\x08\x12\x19\n\x11\x63ustom_scale_name\x18\x11 \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x18\n\x16sensitivity_units_enumB\x1b\n\x19voltage_excit_source_enum\"9\n\'CreateAIAccel4WireDCVoltageChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb1\x05\n\x18\x43reateAIAccelChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12*\n\x05units\x18\x08 \x01(\x0e\x32\x19.nidaqmx_grpc.AccelUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x13\n\x0bsensitivity\x18\n \x01(\x01\x12\x41\n\x11sensitivity_units\x18\x0b \x01(\x0e\x32$.nidaqmx_grpc.AccelSensitivityUnits1H\x02\x12\x1f\n\x15sensitivity_units_raw\x18\x0c \x01(\x05H\x02\x12>\n\x14\x63urrent_excit_source\x18\r \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x03\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0e \x01(\x05H\x03\x12\x19\n\x11\x63urrent_excit_val\x18\x0f \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x10 \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x18\n\x16sensitivity_units_enumB\x1b\n\x19\x63urrent_excit_source_enum\"+\n\x19\x43reateAIAccelChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa0\x04\n\x1e\x43reateAIAccelChargeChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12*\n\x05units\x18\x08 \x01(\x0e\x32\x19.nidaqmx_grpc.AccelUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x13\n\x0bsensitivity\x18\n \x01(\x01\x12\x46\n\x11sensitivity_units\x18\x0b \x01(\x0e\x32).nidaqmx_grpc.AccelChargeSensitivityUnitsH\x02\x12\x1f\n\x15sensitivity_units_raw\x18\x0c \x01(\x05H\x02\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x18\n\x16sensitivity_units_enum\"1\n\x1f\x43reateAIAccelChargeChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb9\x04\n\x19\x43reateAIBridgeChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12*\n\x05units\x18\x06 \x01(\x0e\x32\x19.nidaqmx_grpc.BridgeUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0e \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enum\",\n\x1a\x43reateAIBridgeChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x83\x03\n\x19\x43reateAIChargeChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12*\n\x05units\x18\x08 \x01(\x0e\x32\x19.nidaqmx_grpc.ChargeUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11\x63ustom_scale_name\x18\n \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enum\",\n\x1a\x43reateAIChargeChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb8\x04\n\x1a\x43reateAICurrentChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12,\n\x05units\x18\x08 \x01(\x0e\x32\x1b.nidaqmx_grpc.CurrentUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12S\n\x12shunt_resistor_loc\x18\n \x01(\x0e\x32\x35.nidaqmx_grpc.CurrentShuntResistorLocationWithDefaultH\x02\x12 \n\x16shunt_resistor_loc_raw\x18\x0b \x01(\x05H\x02\x12\x1e\n\x16\x65xt_shunt_resistor_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x19\n\x17shunt_resistor_loc_enum\"-\n\x1b\x43reateAICurrentChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbb\x04\n\x1d\x43reateAICurrentRMSChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12,\n\x05units\x18\x08 \x01(\x0e\x32\x1b.nidaqmx_grpc.CurrentUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12S\n\x12shunt_resistor_loc\x18\n \x01(\x0e\x32\x35.nidaqmx_grpc.CurrentShuntResistorLocationWithDefaultH\x02\x12 \n\x16shunt_resistor_loc_raw\x18\x0b \x01(\x05H\x02\x12\x1e\n\x16\x65xt_shunt_resistor_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x19\n\x17shunt_resistor_loc_enum\"0\n\x1e\x43reateAICurrentRMSChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe3\x06\n(CreateAIForceBridgePolynomialChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12)\n\x05units\x18\x06 \x01(\x0e\x32\x18.nidaqmx_grpc.ForceUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x16\n\x0e\x66orward_coeffs\x18\x0e \x03(\x01\x12\x16\n\x0ereverse_coeffs\x18\x0f \x03(\x01\x12?\n\x10\x65lectrical_units\x18\x10 \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x11 \x01(\x05H\x03\x12;\n\x0ephysical_units\x18\x12 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x13 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x14 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\";\n)CreateAIForceBridgePolynomialChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xde\x06\n#CreateAIForceBridgeTableChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12)\n\x05units\x18\x06 \x01(\x0e\x32\x18.nidaqmx_grpc.ForceUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x17\n\x0f\x65lectrical_vals\x18\x0e \x03(\x01\x12?\n\x10\x65lectrical_units\x18\x0f \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x10 \x01(\x05H\x03\x12\x15\n\rphysical_vals\x18\x11 \x03(\x01\x12;\n\x0ephysical_units\x18\x12 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x13 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x14 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\"6\n$CreateAIForceBridgeTableChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xaa\x07\n)CreateAIForceBridgeTwoPointLinChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12)\n\x05units\x18\x06 \x01(\x0e\x32\x18.nidaqmx_grpc.ForceUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x1c\n\x14\x66irst_electrical_val\x18\x0e \x01(\x01\x12\x1d\n\x15second_electrical_val\x18\x0f \x01(\x01\x12?\n\x10\x65lectrical_units\x18\x10 \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x11 \x01(\x05H\x03\x12\x1a\n\x12\x66irst_physical_val\x18\x12 \x01(\x01\x12\x1b\n\x13second_physical_val\x18\x13 \x01(\x01\x12;\n\x0ephysical_units\x18\x14 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x15 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x16 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\"<\n*CreateAIForceBridgeTwoPointLinChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc1\x05\n\x1c\x43reateAIForceIEPEChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12-\n\x05units\x18\x08 \x01(\x0e\x32\x1c.nidaqmx_grpc.ForceIEPEUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x13\n\x0bsensitivity\x18\n \x01(\x01\x12J\n\x11sensitivity_units\x18\x0b \x01(\x0e\x32-.nidaqmx_grpc.ForceIEPESensorSensitivityUnitsH\x02\x12\x1f\n\x15sensitivity_units_raw\x18\x0c \x01(\x05H\x02\x12>\n\x14\x63urrent_excit_source\x18\r \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x03\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0e \x01(\x05H\x03\x12\x19\n\x11\x63urrent_excit_val\x18\x0f \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x10 \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x18\n\x16sensitivity_units_enumB\x1b\n\x19\x63urrent_excit_source_enum\"/\n\x1d\x43reateAIForceIEPEChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbf\x02\n\x1e\x43reateAIFreqVoltageChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12-\n\x05units\x18\x06 \x01(\x0e\x32\x1c.nidaqmx_grpc.FrequencyUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x17\n\x0fthreshold_level\x18\x08 \x01(\x01\x12\x12\n\nhysteresis\x18\t \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\n \x01(\tB\x0c\n\nunits_enum\"1\n\x1f\x43reateAIFreqVoltageChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbf\x04\n\x1d\x43reateAIMicrophoneChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x32\n\x05units\x18\x06 \x01(\x0e\x32!.nidaqmx_grpc.SoundPressureUnits1H\x01\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x01\x12\x17\n\x0fmic_sensitivity\x18\x08 \x01(\x01\x12\x1b\n\x13max_snd_press_level\x18\t \x01(\x01\x12>\n\x14\x63urrent_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x1b\n\x19\x63urrent_excit_source_enum\"0\n\x1e\x43reateAIMicrophoneChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x03\n\'CreateAIPosEddyCurrProxProbeChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12+\n\x05units\x18\x06 \x01(\x0e\x32\x1a.nidaqmx_grpc.LengthUnits2H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x13\n\x0bsensitivity\x18\x08 \x01(\x01\x12O\n\x11sensitivity_units\x18\t \x01(\x0e\x32\x32.nidaqmx_grpc.EddyCurrentProxProbeSensitivityUnitsH\x01\x12\x1f\n\x15sensitivity_units_raw\x18\n \x01(\x05H\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0b \x01(\tB\x0c\n\nunits_enumB\x18\n\x16sensitivity_units_enum\":\n(CreateAIPosEddyCurrProxProbeChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd0\x05\n\x1a\x43reateAIPosLVDTChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12+\n\x05units\x18\x06 \x01(\x0e\x32\x1a.nidaqmx_grpc.LengthUnits2H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x13\n\x0bsensitivity\x18\x08 \x01(\x01\x12@\n\x11sensitivity_units\x18\t \x01(\x0e\x32#.nidaqmx_grpc.LVDTSensitivityUnits1H\x01\x12\x1f\n\x15sensitivity_units_raw\x18\n \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\x0b \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0c \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\r \x01(\x01\x12\x1a\n\x12voltage_excit_freq\x18\x0e \x01(\x01\x12;\n\x12\x61\x63_excit_wire_mode\x18\x0f \x01(\x0e\x32\x1d.nidaqmx_grpc.ACExcitWireModeH\x03\x12 \n\x16\x61\x63_excit_wire_mode_raw\x18\x10 \x01(\x05H\x03\x12\x19\n\x11\x63ustom_scale_name\x18\x11 \x01(\tB\x0c\n\nunits_enumB\x18\n\x16sensitivity_units_enumB\x1b\n\x19voltage_excit_source_enumB\x19\n\x17\x61\x63_excit_wire_mode_enum\"-\n\x1b\x43reateAIPosLVDTChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcf\x05\n\x1a\x43reateAIPosRVDTChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12*\n\x05units\x18\x06 \x01(\x0e\x32\x19.nidaqmx_grpc.AngleUnits1H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x13\n\x0bsensitivity\x18\x08 \x01(\x01\x12@\n\x11sensitivity_units\x18\t \x01(\x0e\x32#.nidaqmx_grpc.RVDTSensitivityUnits1H\x01\x12\x1f\n\x15sensitivity_units_raw\x18\n \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\x0b \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0c \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\r \x01(\x01\x12\x1a\n\x12voltage_excit_freq\x18\x0e \x01(\x01\x12;\n\x12\x61\x63_excit_wire_mode\x18\x0f \x01(\x0e\x32\x1d.nidaqmx_grpc.ACExcitWireModeH\x03\x12 \n\x16\x61\x63_excit_wire_mode_raw\x18\x10 \x01(\x05H\x03\x12\x19\n\x11\x63ustom_scale_name\x18\x11 \x01(\tB\x0c\n\nunits_enumB\x18\n\x16sensitivity_units_enumB\x1b\n\x19voltage_excit_source_enumB\x19\n\x17\x61\x63_excit_wire_mode_enum\"-\n\x1b\x43reateAIPosRVDTChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc8\x01\n\x18\x43reateAIPowerChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x18\n\x10voltage_setpoint\x18\x04 \x01(\x01\x12\x18\n\x10\x63urrent_setpoint\x18\x05 \x01(\x01\x12\x15\n\routput_enable\x18\x06 \x01(\x08\"+\n\x19\x43reateAIPowerChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe9\x06\n+CreateAIPressureBridgePolynomialChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12,\n\x05units\x18\x06 \x01(\x0e\x32\x1b.nidaqmx_grpc.PressureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x16\n\x0e\x66orward_coeffs\x18\x0e \x03(\x01\x12\x16\n\x0ereverse_coeffs\x18\x0f \x03(\x01\x12?\n\x10\x65lectrical_units\x18\x10 \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x11 \x01(\x05H\x03\x12;\n\x0ephysical_units\x18\x12 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x13 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x14 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\">\n,CreateAIPressureBridgePolynomialChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe4\x06\n&CreateAIPressureBridgeTableChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12,\n\x05units\x18\x06 \x01(\x0e\x32\x1b.nidaqmx_grpc.PressureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x17\n\x0f\x65lectrical_vals\x18\x0e \x03(\x01\x12?\n\x10\x65lectrical_units\x18\x0f \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x10 \x01(\x05H\x03\x12\x15\n\rphysical_vals\x18\x11 \x03(\x01\x12;\n\x0ephysical_units\x18\x12 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x13 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x14 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\"9\n\'CreateAIPressureBridgeTableChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb0\x07\n,CreateAIPressureBridgeTwoPointLinChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12,\n\x05units\x18\x06 \x01(\x0e\x32\x1b.nidaqmx_grpc.PressureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x1c\n\x14\x66irst_electrical_val\x18\x0e \x01(\x01\x12\x1d\n\x15second_electrical_val\x18\x0f \x01(\x01\x12?\n\x10\x65lectrical_units\x18\x10 \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x11 \x01(\x05H\x03\x12\x1a\n\x12\x66irst_physical_val\x18\x12 \x01(\x01\x12\x1b\n\x13second_physical_val\x18\x13 \x01(\x01\x12;\n\x0ephysical_units\x18\x14 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x15 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x16 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\"?\n-CreateAIPressureBridgeTwoPointLinChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xed\x04\n\x16\x43reateAIRTDChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12*\n\x08rtd_type\x18\x08 \x01(\x0e\x32\x16.nidaqmx_grpc.RTDType1H\x01\x12\x16\n\x0crtd_type_raw\x18\t \x01(\x05H\x01\x12\x42\n\x11resistance_config\x18\n \x01(\x0e\x32%.nidaqmx_grpc.ResistanceConfigurationH\x02\x12\x1f\n\x15resistance_config_raw\x18\x0b \x01(\x05H\x02\x12>\n\x14\x63urrent_excit_source\x18\x0c \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x03\x12\"\n\x18\x63urrent_excit_source_raw\x18\r \x01(\x05H\x03\x12\x19\n\x11\x63urrent_excit_val\x18\x0e \x01(\x01\x12\n\n\x02r0\x18\x0f \x01(\x01\x42\x0c\n\nunits_enumB\x0f\n\rrtd_type_enumB\x18\n\x16resistance_config_enumB\x1b\n\x19\x63urrent_excit_source_enum\")\n\x17\x43reateAIRTDChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x04\n\x1d\x43reateAIResistanceChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.ResistanceUnits2H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x42\n\x11resistance_config\x18\x08 \x01(\x0e\x32%.nidaqmx_grpc.ResistanceConfigurationH\x01\x12\x1f\n\x15resistance_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14\x63urrent_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x0c\n\nunits_enumB\x18\n\x16resistance_config_enumB\x1b\n\x19\x63urrent_excit_source_enum\"0\n\x1e\x43reateAIResistanceChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc7\x05\n$CreateAIRosetteStrainGageChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12;\n\x0crosette_type\x18\x06 \x01(\x0e\x32#.nidaqmx_grpc.StrainGageRosetteTypeH\x00\x12\x1a\n\x10rosette_type_raw\x18\x07 \x01(\x05H\x00\x12\x18\n\x10gage_orientation\x18\x08 \x01(\x01\x12\x1a\n\x12rosette_meas_types\x18\t \x03(\x05\x12<\n\rstrain_config\x18\n \x01(\x0e\x32#.nidaqmx_grpc.StrainGageBridgeType1H\x01\x12\x1b\n\x11strain_config_raw\x18\x0b \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\x0c \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\r \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0e \x01(\x01\x12\x13\n\x0bgage_factor\x18\x0f \x01(\x01\x12\x1f\n\x17nominal_gage_resistance\x18\x10 \x01(\x01\x12\x15\n\rpoisson_ratio\x18\x11 \x01(\x01\x12\x1c\n\x14lead_wire_resistance\x18\x12 \x01(\x01\x42\x13\n\x11rosette_type_enumB\x14\n\x12strain_config_enumB\x1b\n\x19voltage_excit_source_enum\"7\n%CreateAIRosetteStrainGageChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa7\x05\n\x1d\x43reateAIStrainGageChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12+\n\x05units\x18\x06 \x01(\x0e\x32\x1a.nidaqmx_grpc.StrainUnits1H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12<\n\rstrain_config\x18\x08 \x01(\x0e\x32#.nidaqmx_grpc.StrainGageBridgeType1H\x01\x12\x1b\n\x11strain_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12\x13\n\x0bgage_factor\x18\r \x01(\x01\x12\x1e\n\x16initial_bridge_voltage\x18\x0e \x01(\x01\x12\x1f\n\x17nominal_gage_resistance\x18\x0f \x01(\x01\x12\x15\n\rpoisson_ratio\x18\x10 \x01(\x01\x12\x1c\n\x14lead_wire_resistance\x18\x11 \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x12 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12strain_config_enumB\x1b\n\x19voltage_excit_source_enum\"0\n\x1e\x43reateAIStrainGageChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdd\x01\n$CreateAITempBuiltInSensorChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12/\n\x05units\x18\x04 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x05 \x01(\x05H\x00\x42\x0c\n\nunits_enum\"7\n%CreateAITempBuiltInSensorChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf1\x03\n\x1a\x43reateAIThrmcplChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12<\n\x11thermocouple_type\x18\x08 \x01(\x0e\x32\x1f.nidaqmx_grpc.ThermocoupleType1H\x01\x12\x1f\n\x15thermocouple_type_raw\x18\t \x01(\x05H\x01\x12.\n\ncjc_source\x18\n \x01(\x0e\x32\x18.nidaqmx_grpc.CJCSource1H\x02\x12\x18\n\x0e\x63jc_source_raw\x18\x0b \x01(\x05H\x02\x12\x0f\n\x07\x63jc_val\x18\x0c \x01(\x01\x12\x13\n\x0b\x63jc_channel\x18\r \x01(\tB\x0c\n\nunits_enumB\x18\n\x16thermocouple_type_enumB\x11\n\x0f\x63jc_source_enum\"-\n\x1b\x43reateAIThrmcplChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb4\x04\n\x1d\x43reateAIThrmstrChanIexRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x42\n\x11resistance_config\x18\x08 \x01(\x0e\x32%.nidaqmx_grpc.ResistanceConfigurationH\x01\x12\x1f\n\x15resistance_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14\x63urrent_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0c \x01(\x01\x12\t\n\x01\x61\x18\r \x01(\x01\x12\t\n\x01\x62\x18\x0e \x01(\x01\x12\t\n\x01\x63\x18\x0f \x01(\x01\x42\x0c\n\nunits_enumB\x18\n\x16resistance_config_enumB\x1b\n\x19\x63urrent_excit_source_enum\"0\n\x1e\x43reateAIThrmstrChanIexResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc0\x04\n\x1d\x43reateAIThrmstrChanVexRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x42\n\x11resistance_config\x18\x08 \x01(\x0e\x32%.nidaqmx_grpc.ResistanceConfigurationH\x01\x12\x1f\n\x15resistance_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12\t\n\x01\x61\x18\r \x01(\x01\x12\t\n\x01\x62\x18\x0e \x01(\x01\x12\t\n\x01\x63\x18\x0f \x01(\x01\x12\n\n\x02r1\x18\x10 \x01(\x01\x42\x0c\n\nunits_enumB\x18\n\x16resistance_config_enumB\x1b\n\x19voltage_excit_source_enum\"0\n\x1e\x43reateAIThrmstrChanVexResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe5\x06\n)CreateAITorqueBridgePolynomialChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12*\n\x05units\x18\x06 \x01(\x0e\x32\x19.nidaqmx_grpc.TorqueUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x16\n\x0e\x66orward_coeffs\x18\x0e \x03(\x01\x12\x16\n\x0ereverse_coeffs\x18\x0f \x03(\x01\x12?\n\x10\x65lectrical_units\x18\x10 \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x11 \x01(\x05H\x03\x12;\n\x0ephysical_units\x18\x12 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x13 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x14 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\"<\n*CreateAITorqueBridgePolynomialChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe0\x06\n$CreateAITorqueBridgeTableChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12*\n\x05units\x18\x06 \x01(\x0e\x32\x19.nidaqmx_grpc.TorqueUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x17\n\x0f\x65lectrical_vals\x18\x0e \x03(\x01\x12?\n\x10\x65lectrical_units\x18\x0f \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x10 \x01(\x05H\x03\x12\x15\n\rphysical_vals\x18\x11 \x03(\x01\x12;\n\x0ephysical_units\x18\x12 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x13 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x14 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\"7\n%CreateAITorqueBridgeTableChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xac\x07\n*CreateAITorqueBridgeTwoPointLinChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12*\n\x05units\x18\x06 \x01(\x0e\x32\x19.nidaqmx_grpc.TorqueUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12;\n\rbridge_config\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x01\x12\x1b\n\x11\x62ridge_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12!\n\x19nominal_bridge_resistance\x18\r \x01(\x01\x12\x1c\n\x14\x66irst_electrical_val\x18\x0e \x01(\x01\x12\x1d\n\x15second_electrical_val\x18\x0f \x01(\x01\x12?\n\x10\x65lectrical_units\x18\x10 \x01(\x0e\x32#.nidaqmx_grpc.BridgeElectricalUnitsH\x03\x12\x1e\n\x14\x65lectrical_units_raw\x18\x11 \x01(\x05H\x03\x12\x1a\n\x12\x66irst_physical_val\x18\x12 \x01(\x01\x12\x1b\n\x13second_physical_val\x18\x13 \x01(\x01\x12;\n\x0ephysical_units\x18\x14 \x01(\x0e\x32!.nidaqmx_grpc.BridgePhysicalUnitsH\x04\x12\x1c\n\x12physical_units_raw\x18\x15 \x01(\x05H\x04\x12\x19\n\x11\x63ustom_scale_name\x18\x16 \x01(\tB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enumB\x17\n\x15\x65lectrical_units_enumB\x15\n\x13physical_units_enum\"=\n+CreateAITorqueBridgeTwoPointLinChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc6\x05\n\x1f\x43reateAIVelocityIEPEChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12,\n\x05units\x18\x08 \x01(\x0e\x32\x1b.nidaqmx_grpc.VelocityUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x13\n\x0bsensitivity\x18\n \x01(\x01\x12M\n\x11sensitivity_units\x18\x0b \x01(\x0e\x32\x30.nidaqmx_grpc.VelocityIEPESensorSensitivityUnitsH\x02\x12\x1f\n\x15sensitivity_units_raw\x18\x0c \x01(\x05H\x02\x12>\n\x14\x63urrent_excit_source\x18\r \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x03\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0e \x01(\x05H\x03\x12\x19\n\x11\x63urrent_excit_val\x18\x0f \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x10 \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x18\n\x16sensitivity_units_enumB\x1b\n\x19\x63urrent_excit_source_enum\"2\n CreateAIVelocityIEPEChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x86\x03\n\x1a\x43reateAIVoltageChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12,\n\x05units\x18\x08 \x01(\x0e\x32\x1b.nidaqmx_grpc.VoltageUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11\x63ustom_scale_name\x18\n \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enum\"-\n\x1b\x43reateAIVoltageChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x05\n#CreateAIVoltageChanWithExcitRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12,\n\x05units\x18\x08 \x01(\x0e\x32\x1b.nidaqmx_grpc.VoltageUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12;\n\rbridge_config\x18\n \x01(\x0e\x32\".nidaqmx_grpc.BridgeConfiguration1H\x02\x12\x1b\n\x11\x62ridge_config_raw\x18\x0b \x01(\x05H\x02\x12>\n\x14voltage_excit_source\x18\x0c \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x03\x12\"\n\x18voltage_excit_source_raw\x18\r \x01(\x05H\x03\x12\x19\n\x11voltage_excit_val\x18\x0e \x01(\x01\x12\x1d\n\x15use_excit_for_scaling\x18\x0f \x01(\x08\x12\x19\n\x11\x63ustom_scale_name\x18\x10 \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x14\n\x12\x62ridge_config_enumB\x1b\n\x19voltage_excit_source_enum\"6\n$CreateAIVoltageChanWithExcitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x89\x03\n\x1d\x43reateAIVoltageRMSChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12,\n\x05units\x18\x08 \x01(\x0e\x32\x1b.nidaqmx_grpc.VoltageUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11\x63ustom_scale_name\x18\n \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enum\"0\n\x1e\x43reateAIVoltageRMSChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8d\x02\n\x1a\x43reateAOCurrentChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12,\n\x05units\x18\x06 \x01(\x0e\x32\x1b.nidaqmx_grpc.CurrentUnits2H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x19\n\x11\x63ustom_scale_name\x18\x08 \x01(\tB\x0c\n\nunits_enum\"-\n\x1b\x43reateAOCurrentChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xfc\x01\n\x1a\x43reateAOFuncGenChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12)\n\x04type\x18\x04 \x01(\x0e\x32\x19.nidaqmx_grpc.FuncGenTypeH\x00\x12\x12\n\x08type_raw\x18\x05 \x01(\x05H\x00\x12\x0c\n\x04\x66req\x18\x06 \x01(\x01\x12\x11\n\tamplitude\x18\x07 \x01(\x01\x12\x0e\n\x06offset\x18\x08 \x01(\x01\x42\x0b\n\ttype_enum\"-\n\x1b\x43reateAOFuncGenChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8d\x02\n\x1a\x43reateAOVoltageChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12,\n\x05units\x18\x06 \x01(\x0e\x32\x1b.nidaqmx_grpc.VoltageUnits2H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x19\n\x11\x63ustom_scale_name\x18\x08 \x01(\tB\x0c\n\nunits_enum\"-\n\x1b\x43reateAOVoltageChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x87\x04\n\x1d\x43reateCIAngEncoderChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x33\n\rdecoding_type\x18\x04 \x01(\x0e\x32\x1a.nidaqmx_grpc.EncoderType2H\x00\x12\x1b\n\x11\x64\x65\x63oding_type_raw\x18\x05 \x01(\x05H\x00\x12\x13\n\x0bzidx_enable\x18\x06 \x01(\x08\x12\x10\n\x08zidx_val\x18\x07 \x01(\x01\x12\x37\n\nzidx_phase\x18\x08 \x01(\x0e\x32!.nidaqmx_grpc.EncoderZIndexPhase1H\x01\x12\x18\n\x0ezidx_phase_raw\x18\t \x01(\x05H\x01\x12*\n\x05units\x18\n \x01(\x0e\x32\x19.nidaqmx_grpc.AngleUnits2H\x02\x12\x13\n\tunits_raw\x18\x0b \x01(\x05H\x02\x12\x16\n\x0epulses_per_rev\x18\x0c \x01(\r\x12\x15\n\rinitial_angle\x18\r \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0e \x01(\tB\x14\n\x12\x64\x65\x63oding_type_enumB\x11\n\x0fzidx_phase_enumB\x0c\n\nunits_enum\"0\n\x1e\x43reateCIAngEncoderChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8f\x03\n\x1e\x43reateCIAngVelocityChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12\x33\n\rdecoding_type\x18\x06 \x01(\x0e\x32\x1a.nidaqmx_grpc.EncoderType2H\x00\x12\x1b\n\x11\x64\x65\x63oding_type_raw\x18\x07 \x01(\x05H\x00\x12\x33\n\x05units\x18\x08 \x01(\x0e\x32\".nidaqmx_grpc.AngularVelocityUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x16\n\x0epulses_per_rev\x18\n \x01(\r\x12\x19\n\x11\x63ustom_scale_name\x18\x0b \x01(\tB\x14\n\x12\x64\x65\x63oding_type_enumB\x0c\n\nunits_enum\"1\n\x1f\x43reateCIAngVelocityChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc7\x02\n\x1d\x43reateCICountEdgesChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12#\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x05H\x00\x12\x15\n\rinitial_count\x18\x06 \x01(\r\x12\x38\n\x0f\x63ount_direction\x18\x07 \x01(\x0e\x32\x1d.nidaqmx_grpc.CountDirection1H\x01\x12\x1d\n\x13\x63ount_direction_raw\x18\x08 \x01(\x05H\x01\x42\x0b\n\tedge_enumB\x16\n\x14\x63ount_direction_enum\"0\n\x1e\x43reateCICountEdgesChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xfd\x01\n\x1c\x43reateCIDutyCycleChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x10\n\x08min_freq\x18\x04 \x01(\x01\x12\x10\n\x08max_freq\x18\x05 \x01(\x01\x12#\n\x04\x65\x64ge\x18\x06 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x07 \x01(\x05H\x00\x12\x19\n\x11\x63ustom_scale_name\x18\x08 \x01(\tB\x0b\n\tedge_enum\"/\n\x1d\x43reateCIDutyCycleChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd9\x03\n\x17\x43reateCIFreqChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12.\n\x05units\x18\x06 \x01(\x0e\x32\x1d.nidaqmx_grpc.FrequencyUnits3H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12#\n\x04\x65\x64ge\x18\x08 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x01\x12\x12\n\x08\x65\x64ge_raw\x18\t \x01(\x05H\x01\x12;\n\x0bmeas_method\x18\n \x01(\x0e\x32$.nidaqmx_grpc.CounterFrequencyMethodH\x02\x12\x19\n\x0fmeas_method_raw\x18\x0b \x01(\x05H\x02\x12\x11\n\tmeas_time\x18\x0c \x01(\x01\x12\x0f\n\x07\x64ivisor\x18\r \x01(\r\x12\x19\n\x11\x63ustom_scale_name\x18\x0e \x01(\tB\x0c\n\nunits_enumB\x0b\n\tedge_enumB\x12\n\x10meas_method_enum\"*\n\x18\x43reateCIFreqChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc7\x02\n\x1f\x43reateCIGPSTimestampChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12(\n\x05units\x18\x04 \x01(\x0e\x32\x17.nidaqmx_grpc.TimeUnitsH\x00\x12\x13\n\tunits_raw\x18\x05 \x01(\x05H\x00\x12\x33\n\x0bsync_method\x18\x06 \x01(\x0e\x32\x1c.nidaqmx_grpc.GpsSignalType1H\x01\x12\x19\n\x0fsync_method_raw\x18\x07 \x01(\x05H\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x08 \x01(\tB\x0c\n\nunits_enumB\x12\n\x10sync_method_enum\"2\n CreateCIGPSTimestampChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x86\x04\n\x1d\x43reateCILinEncoderChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x33\n\rdecoding_type\x18\x04 \x01(\x0e\x32\x1a.nidaqmx_grpc.EncoderType2H\x00\x12\x1b\n\x11\x64\x65\x63oding_type_raw\x18\x05 \x01(\x05H\x00\x12\x13\n\x0bzidx_enable\x18\x06 \x01(\x08\x12\x10\n\x08zidx_val\x18\x07 \x01(\x01\x12\x37\n\nzidx_phase\x18\x08 \x01(\x0e\x32!.nidaqmx_grpc.EncoderZIndexPhase1H\x01\x12\x18\n\x0ezidx_phase_raw\x18\t \x01(\x05H\x01\x12+\n\x05units\x18\n \x01(\x0e\x32\x1a.nidaqmx_grpc.LengthUnits3H\x02\x12\x13\n\tunits_raw\x18\x0b \x01(\x05H\x02\x12\x16\n\x0e\x64ist_per_pulse\x18\x0c \x01(\x01\x12\x13\n\x0binitial_pos\x18\r \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0e \x01(\tB\x14\n\x12\x64\x65\x63oding_type_enumB\x11\n\x0fzidx_phase_enumB\x0c\n\nunits_enum\"0\n\x1e\x43reateCILinEncoderChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x88\x03\n\x1e\x43reateCILinVelocityChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12\x33\n\rdecoding_type\x18\x06 \x01(\x0e\x32\x1a.nidaqmx_grpc.EncoderType2H\x00\x12\x1b\n\x11\x64\x65\x63oding_type_raw\x18\x07 \x01(\x05H\x00\x12,\n\x05units\x18\x08 \x01(\x0e\x32\x1b.nidaqmx_grpc.VelocityUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x16\n\x0e\x64ist_per_pulse\x18\n \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0b \x01(\tB\x14\n\x12\x64\x65\x63oding_type_enumB\x0c\n\nunits_enum\"1\n\x1f\x43reateCILinVelocityChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd6\x03\n\x19\x43reateCIPeriodChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12)\n\x05units\x18\x06 \x01(\x0e\x32\x18.nidaqmx_grpc.TimeUnits3H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12#\n\x04\x65\x64ge\x18\x08 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x01\x12\x12\n\x08\x65\x64ge_raw\x18\t \x01(\x05H\x01\x12;\n\x0bmeas_method\x18\n \x01(\x0e\x32$.nidaqmx_grpc.CounterFrequencyMethodH\x02\x12\x19\n\x0fmeas_method_raw\x18\x0b \x01(\x05H\x02\x12\x11\n\tmeas_time\x18\x0c \x01(\x01\x12\x0f\n\x07\x64ivisor\x18\r \x01(\r\x12\x19\n\x11\x63ustom_scale_name\x18\x0e \x01(\tB\x0c\n\nunits_enumB\x0b\n\tedge_enumB\x12\n\x10meas_method_enum\",\n\x1a\x43reateCIPeriodChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xed\x01\n\x1c\x43reateCIPulseChanFreqRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12.\n\x05units\x18\x06 \x01(\x0e\x32\x1d.nidaqmx_grpc.FrequencyUnits2H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x42\x0c\n\nunits_enum\"/\n\x1d\x43reateCIPulseChanFreqResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb4\x01\n\x1d\x43reateCIPulseChanTicksRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x17\n\x0fsource_terminal\x18\x04 \x01(\t\x12\x0f\n\x07min_val\x18\x05 \x01(\x01\x12\x0f\n\x07max_val\x18\x06 \x01(\x01\"0\n\x1e\x43reateCIPulseChanTicksResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf0\x01\n\x1c\x43reateCIPulseChanTimeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12\x31\n\x05units\x18\x06 \x01(\x0e\x32 .nidaqmx_grpc.DigitalWidthUnits3H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x42\x0c\n\nunits_enum\"/\n\x1d\x43reateCIPulseChanTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe5\x02\n\x1d\x43reateCIPulseWidthChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12)\n\x05units\x18\x06 \x01(\x0e\x32\x18.nidaqmx_grpc.TimeUnits3H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12,\n\rstarting_edge\x18\x08 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x01\x12\x1b\n\x11starting_edge_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11\x63ustom_scale_name\x18\n \x01(\tB\x0c\n\nunits_enumB\x14\n\x12starting_edge_enum\"0\n\x1e\x43reateCIPulseWidthChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x84\x02\n\x1d\x43reateCISemiPeriodChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12)\n\x05units\x18\x06 \x01(\x0e\x32\x18.nidaqmx_grpc.TimeUnits3H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x19\n\x11\x63ustom_scale_name\x18\x08 \x01(\tB\x0c\n\nunits_enum\"0\n\x1e\x43reateCISemiPeriodChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x03\n\x1d\x43reateCITwoEdgeSepChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12)\n\x05units\x18\x06 \x01(\x0e\x32\x18.nidaqmx_grpc.TimeUnits3H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12)\n\nfirst_edge\x18\x08 \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x01\x12\x18\n\x0e\x66irst_edge_raw\x18\t \x01(\x05H\x01\x12*\n\x0bsecond_edge\x18\n \x01(\x0e\x32\x13.nidaqmx_grpc.Edge1H\x02\x12\x19\n\x0fsecond_edge_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63ustom_scale_name\x18\x0c \x01(\tB\x0c\n\nunits_enumB\x11\n\x0f\x66irst_edge_enumB\x12\n\x10second_edge_enum\"0\n\x1e\x43reateCITwoEdgeSepChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdd\x02\n\x1c\x43reateCOPulseChanFreqRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12.\n\x05units\x18\x04 \x01(\x0e\x32\x1d.nidaqmx_grpc.FrequencyUnits2H\x00\x12\x13\n\tunits_raw\x18\x05 \x01(\x05H\x00\x12*\n\nidle_state\x18\x06 \x01(\x0e\x32\x14.nidaqmx_grpc.Level1H\x01\x12\x18\n\x0eidle_state_raw\x18\x07 \x01(\x05H\x01\x12\x15\n\rinitial_delay\x18\x08 \x01(\x01\x12\x0c\n\x04\x66req\x18\t \x01(\x01\x12\x12\n\nduty_cycle\x18\n \x01(\x01\x42\x0c\n\nunits_enumB\x11\n\x0fidle_state_enum\"/\n\x1d\x43reateCOPulseChanFreqResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa9\x02\n\x1d\x43reateCOPulseChanTicksRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x17\n\x0fsource_terminal\x18\x04 \x01(\t\x12*\n\nidle_state\x18\x05 \x01(\x0e\x32\x14.nidaqmx_grpc.Level1H\x00\x12\x18\n\x0eidle_state_raw\x18\x06 \x01(\x05H\x00\x12\x15\n\rinitial_delay\x18\x07 \x01(\x05\x12\x11\n\tlow_ticks\x18\x08 \x01(\x05\x12\x12\n\nhigh_ticks\x18\t \x01(\x05\x42\x11\n\x0fidle_state_enum\"0\n\x1e\x43reateCOPulseChanTicksResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe3\x02\n\x1c\x43reateCOPulseChanTimeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x31\n\x05units\x18\x04 \x01(\x0e\x32 .nidaqmx_grpc.DigitalWidthUnits3H\x00\x12\x13\n\tunits_raw\x18\x05 \x01(\x05H\x00\x12*\n\nidle_state\x18\x06 \x01(\x0e\x32\x14.nidaqmx_grpc.Level1H\x01\x12\x18\n\x0eidle_state_raw\x18\x07 \x01(\x05H\x01\x12\x15\n\rinitial_delay\x18\x08 \x01(\x01\x12\x10\n\x08low_time\x18\t \x01(\x01\x12\x11\n\thigh_time\x18\n \x01(\x01\x42\x0c\n\nunits_enumB\x11\n\x0fidle_state_enum\"/\n\x1d\x43reateCOPulseChanTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd3\x01\n\x13\x43reateDIChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12\x1f\n\x17name_to_assign_to_lines\x18\x03 \x01(\t\x12\x33\n\rline_grouping\x18\x04 \x01(\x0e\x32\x1a.nidaqmx_grpc.LineGroupingH\x00\x12\x1b\n\x11line_grouping_raw\x18\x05 \x01(\x05H\x00\x42\x14\n\x12line_grouping_enum\"&\n\x14\x43reateDIChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd3\x01\n\x13\x43reateDOChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12\x1f\n\x17name_to_assign_to_lines\x18\x03 \x01(\t\x12\x33\n\rline_grouping\x18\x04 \x01(\x0e\x32\x1a.nidaqmx_grpc.LineGroupingH\x00\x12\x1b\n\x11line_grouping_raw\x18\x05 \x01(\x05H\x00\x42\x14\n\x12line_grouping_enum\"&\n\x14\x43reateDOChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd2\x01\n\x15\x43reateLinScaleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05slope\x18\x02 \x01(\x01\x12\x13\n\x0by_intercept\x18\x03 \x01(\x01\x12\x38\n\x10pre_scaled_units\x18\x04 \x01(\x0e\x32\x1c.nidaqmx_grpc.UnitsPreScaledH\x00\x12\x1e\n\x14pre_scaled_units_raw\x18\x05 \x01(\x05H\x00\x12\x14\n\x0cscaled_units\x18\x06 \x01(\tB\x17\n\x15pre_scaled_units_enum\"(\n\x16\x43reateLinScaleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x84\x02\n\x15\x43reateMapScaleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rprescaled_min\x18\x02 \x01(\x01\x12\x15\n\rprescaled_max\x18\x03 \x01(\x01\x12\x12\n\nscaled_min\x18\x04 \x01(\x01\x12\x12\n\nscaled_max\x18\x05 \x01(\x01\x12\x38\n\x10pre_scaled_units\x18\x06 \x01(\x0e\x32\x1c.nidaqmx_grpc.UnitsPreScaledH\x00\x12\x1e\n\x14pre_scaled_units_raw\x18\x07 \x01(\x05H\x00\x12\x14\n\x0cscaled_units\x18\x08 \x01(\tB\x17\n\x15pre_scaled_units_enum\"(\n\x16\x43reateMapScaleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe5\x01\n\x1c\x43reatePolynomialScaleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x66orward_coeffs\x18\x02 \x03(\x01\x12\x16\n\x0ereverse_coeffs\x18\x03 \x03(\x01\x12\x38\n\x10pre_scaled_units\x18\x04 \x01(\x0e\x32\x1c.nidaqmx_grpc.UnitsPreScaledH\x00\x12\x1e\n\x14pre_scaled_units_raw\x18\x05 \x01(\x05H\x00\x12\x14\n\x0cscaled_units\x18\x06 \x01(\tB\x17\n\x15pre_scaled_units_enum\"/\n\x1d\x43reatePolynomialScaleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa2\x04\n\x1c\x43reateTEDSAIAccelChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12*\n\x05units\x18\x08 \x01(\x0e\x32\x19.nidaqmx_grpc.AccelUnits2H\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12>\n\x14\x63urrent_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x1b\n\x19\x63urrent_excit_source_enum\"/\n\x1d\x43reateTEDSAIAccelChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa8\x03\n\x1d\x43reateTEDSAIBridgeChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12(\n\x05units\x18\x06 \x01(\x0e\x32\x17.nidaqmx_grpc.TEDSUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12>\n\x14voltage_excit_source\x18\x08 \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x01\x12\"\n\x18voltage_excit_source_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11voltage_excit_val\x18\n \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0b \x01(\tB\x0c\n\nunits_enumB\x1b\n\x19voltage_excit_source_enum\"0\n\x1e\x43reateTEDSAIBridgeChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb8\x04\n\x1e\x43reateTEDSAICurrentChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12(\n\x05units\x18\x08 \x01(\x0e\x32\x17.nidaqmx_grpc.TEDSUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12S\n\x12shunt_resistor_loc\x18\n \x01(\x0e\x32\x35.nidaqmx_grpc.CurrentShuntResistorLocationWithDefaultH\x02\x12 \n\x16shunt_resistor_loc_raw\x18\x0b \x01(\x05H\x02\x12\x1e\n\x16\x65xt_shunt_resistor_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x19\n\x17shunt_resistor_loc_enum\"1\n\x1f\x43reateTEDSAICurrentChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x03\n\"CreateTEDSAIForceBridgeChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12)\n\x05units\x18\x06 \x01(\x0e\x32\x18.nidaqmx_grpc.ForceUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12>\n\x14voltage_excit_source\x18\x08 \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x01\x12\"\n\x18voltage_excit_source_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11voltage_excit_val\x18\n \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0b \x01(\tB\x0c\n\nunits_enumB\x1b\n\x19voltage_excit_source_enum\"5\n#CreateTEDSAIForceBridgeChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa9\x04\n CreateTEDSAIForceIEPEChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12-\n\x05units\x18\x08 \x01(\x0e\x32\x1c.nidaqmx_grpc.ForceIEPEUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12>\n\x14\x63urrent_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x1b\n\x19\x63urrent_excit_source_enum\"3\n!CreateTEDSAIForceIEPEChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xaa\x04\n!CreateTEDSAIMicrophoneChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x32\n\x05units\x18\x06 \x01(\x0e\x32!.nidaqmx_grpc.SoundPressureUnits1H\x01\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x01\x12\x1b\n\x13max_snd_press_level\x18\x08 \x01(\x01\x12>\n\x14\x63urrent_excit_source\x18\t \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\n \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0b \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0c \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x1b\n\x19\x63urrent_excit_source_enum\"4\n\"CreateTEDSAIMicrophoneChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc2\x04\n\x1e\x43reateTEDSAIPosLVDTChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12+\n\x05units\x18\x06 \x01(\x0e\x32\x1a.nidaqmx_grpc.LengthUnits2H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12>\n\x14voltage_excit_source\x18\x08 \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x01\x12\"\n\x18voltage_excit_source_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11voltage_excit_val\x18\n \x01(\x01\x12\x1a\n\x12voltage_excit_freq\x18\x0b \x01(\x01\x12;\n\x12\x61\x63_excit_wire_mode\x18\x0c \x01(\x0e\x32\x1d.nidaqmx_grpc.ACExcitWireModeH\x02\x12 \n\x16\x61\x63_excit_wire_mode_raw\x18\r \x01(\x05H\x02\x12\x19\n\x11\x63ustom_scale_name\x18\x0e \x01(\tB\x0c\n\nunits_enumB\x1b\n\x19voltage_excit_source_enumB\x19\n\x17\x61\x63_excit_wire_mode_enum\"1\n\x1f\x43reateTEDSAIPosLVDTChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc1\x04\n\x1e\x43reateTEDSAIPosRVDTChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12*\n\x05units\x18\x06 \x01(\x0e\x32\x19.nidaqmx_grpc.AngleUnits1H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12>\n\x14voltage_excit_source\x18\x08 \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x01\x12\"\n\x18voltage_excit_source_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11voltage_excit_val\x18\n \x01(\x01\x12\x1a\n\x12voltage_excit_freq\x18\x0b \x01(\x01\x12;\n\x12\x61\x63_excit_wire_mode\x18\x0c \x01(\x0e\x32\x1d.nidaqmx_grpc.ACExcitWireModeH\x02\x12 \n\x16\x61\x63_excit_wire_mode_raw\x18\r \x01(\x05H\x02\x12\x19\n\x11\x63ustom_scale_name\x18\x0e \x01(\tB\x0c\n\nunits_enumB\x1b\n\x19voltage_excit_source_enumB\x19\n\x17\x61\x63_excit_wire_mode_enum\"1\n\x1f\x43reateTEDSAIPosRVDTChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb4\x03\n%CreateTEDSAIPressureBridgeChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12,\n\x05units\x18\x06 \x01(\x0e\x32\x1b.nidaqmx_grpc.PressureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12>\n\x14voltage_excit_source\x18\x08 \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x01\x12\"\n\x18voltage_excit_source_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11voltage_excit_val\x18\n \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0b \x01(\tB\x0c\n\nunits_enumB\x1b\n\x19voltage_excit_source_enum\"8\n&CreateTEDSAIPressureBridgeChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x90\x04\n\x1a\x43reateTEDSAIRTDChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x42\n\x11resistance_config\x18\x08 \x01(\x0e\x32%.nidaqmx_grpc.ResistanceConfigurationH\x01\x12\x1f\n\x15resistance_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14\x63urrent_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0c \x01(\x01\x42\x0c\n\nunits_enumB\x18\n\x16resistance_config_enumB\x1b\n\x19\x63urrent_excit_source_enum\"-\n\x1b\x43reateTEDSAIRTDChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xab\x04\n!CreateTEDSAIResistanceChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12(\n\x05units\x18\x06 \x01(\x0e\x32\x17.nidaqmx_grpc.TEDSUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x42\n\x11resistance_config\x18\x08 \x01(\x0e\x32%.nidaqmx_grpc.ResistanceConfigurationH\x01\x12\x1f\n\x15resistance_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14\x63urrent_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x0c\n\nunits_enumB\x18\n\x16resistance_config_enumB\x1b\n\x19\x63urrent_excit_source_enum\"4\n\"CreateTEDSAIResistanceChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xed\x03\n!CreateTEDSAIStrainGageChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12+\n\x05units\x18\x06 \x01(\x0e\x32\x1a.nidaqmx_grpc.StrainUnits1H\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12>\n\x14voltage_excit_source\x18\x08 \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x01\x12\"\n\x18voltage_excit_source_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11voltage_excit_val\x18\n \x01(\x01\x12\x1e\n\x16initial_bridge_voltage\x18\x0b \x01(\x01\x12\x1c\n\x14lead_wire_resistance\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x0c\n\nunits_enumB\x1b\n\x19voltage_excit_source_enum\"4\n\"CreateTEDSAIStrainGageChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xfc\x02\n\x1e\x43reateTEDSAIThrmcplChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12.\n\ncjc_source\x18\x08 \x01(\x0e\x32\x18.nidaqmx_grpc.CJCSource1H\x01\x12\x18\n\x0e\x63jc_source_raw\x18\t \x01(\x05H\x01\x12\x0f\n\x07\x63jc_val\x18\n \x01(\x01\x12\x13\n\x0b\x63jc_channel\x18\x0b \x01(\tB\x0c\n\nunits_enumB\x11\n\x0f\x63jc_source_enum\"1\n\x1f\x43reateTEDSAIThrmcplChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x97\x04\n!CreateTEDSAIThrmstrChanIexRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x42\n\x11resistance_config\x18\x08 \x01(\x0e\x32%.nidaqmx_grpc.ResistanceConfigurationH\x01\x12\x1f\n\x15resistance_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14\x63urrent_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18\x63urrent_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11\x63urrent_excit_val\x18\x0c \x01(\x01\x42\x0c\n\nunits_enumB\x18\n\x16resistance_config_enumB\x1b\n\x19\x63urrent_excit_source_enum\"4\n\"CreateTEDSAIThrmstrChanIexResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa3\x04\n!CreateTEDSAIThrmstrChanVexRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12/\n\x05units\x18\x06 \x01(\x0e\x32\x1e.nidaqmx_grpc.TemperatureUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12\x42\n\x11resistance_config\x18\x08 \x01(\x0e\x32%.nidaqmx_grpc.ResistanceConfigurationH\x01\x12\x1f\n\x15resistance_config_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12\n\n\x02r1\x18\r \x01(\x01\x42\x0c\n\nunits_enumB\x18\n\x16resistance_config_enumB\x1b\n\x19voltage_excit_source_enum\"4\n\"CreateTEDSAIThrmstrChanVexResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb0\x03\n#CreateTEDSAITorqueBridgeChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12\x0f\n\x07min_val\x18\x04 \x01(\x01\x12\x0f\n\x07max_val\x18\x05 \x01(\x01\x12*\n\x05units\x18\x06 \x01(\x0e\x32\x19.nidaqmx_grpc.TorqueUnitsH\x00\x12\x13\n\tunits_raw\x18\x07 \x01(\x05H\x00\x12>\n\x14voltage_excit_source\x18\x08 \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x01\x12\"\n\x18voltage_excit_source_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11voltage_excit_val\x18\n \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\x0b \x01(\tB\x0c\n\nunits_enumB\x1b\n\x19voltage_excit_source_enum\"6\n$CreateTEDSAITorqueBridgeChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x86\x03\n\x1e\x43reateTEDSAIVoltageChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12(\n\x05units\x18\x08 \x01(\x0e\x32\x17.nidaqmx_grpc.TEDSUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12\x19\n\x11\x63ustom_scale_name\x18\n \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enum\"1\n\x1f\x43reateTEDSAIVoltageChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xab\x04\n\'CreateTEDSAIVoltageChanWithExcitRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x18\n\x10physical_channel\x18\x02 \x01(\t\x12!\n\x19name_to_assign_to_channel\x18\x03 \x01(\t\x12@\n\x0fterminal_config\x18\x04 \x01(\x0e\x32%.nidaqmx_grpc.InputTermCfgWithDefaultH\x00\x12\x1d\n\x13terminal_config_raw\x18\x05 \x01(\x05H\x00\x12\x0f\n\x07min_val\x18\x06 \x01(\x01\x12\x0f\n\x07max_val\x18\x07 \x01(\x01\x12(\n\x05units\x18\x08 \x01(\x0e\x32\x17.nidaqmx_grpc.TEDSUnitsH\x01\x12\x13\n\tunits_raw\x18\t \x01(\x05H\x01\x12>\n\x14voltage_excit_source\x18\n \x01(\x0e\x32\x1e.nidaqmx_grpc.ExcitationSourceH\x02\x12\"\n\x18voltage_excit_source_raw\x18\x0b \x01(\x05H\x02\x12\x19\n\x11voltage_excit_val\x18\x0c \x01(\x01\x12\x19\n\x11\x63ustom_scale_name\x18\r \x01(\tB\x16\n\x14terminal_config_enumB\x0c\n\nunits_enumB\x1b\n\x19voltage_excit_source_enum\":\n(CreateTEDSAIVoltageChanWithExcitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdd\x01\n\x17\x43reateTableScaleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0eprescaled_vals\x18\x02 \x03(\x01\x12\x13\n\x0bscaled_vals\x18\x03 \x03(\x01\x12\x38\n\x10pre_scaled_units\x18\x04 \x01(\x0e\x32\x1c.nidaqmx_grpc.UnitsPreScaledH\x00\x12\x1e\n\x14pre_scaled_units_raw\x18\x05 \x01(\x05H\x00\x12\x14\n\x0cscaled_units\x18\x06 \x01(\tB\x17\n\x15pre_scaled_units_enum\"*\n\x18\x43reateTableScaleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"x\n\x11\x43reateTaskRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12M\n\x17initialization_behavior\x18\x02 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"k\n\x12\x43reateTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12$\n\x04task\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1f\n\x17new_session_initialized\x18\x03 \x01(\x08\"\xea\x01\n\x1e\x43reateWatchdogTimerTaskRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x14\n\x0csession_name\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12=\n\nexp_states\x18\x04 \x03(\x0b\x32).nidaqmx_grpc.WatchdogExpChannelsAndState\x12M\n\x17initialization_behavior\x18\x05 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"x\n\x1f\x43reateWatchdogTimerTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12$\n\x04task\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1f\n\x17new_session_initialized\x18\x03 \x01(\x08\"\xad\x01\n CreateWatchdogTimerTaskExRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x14\n\x0csession_name\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12M\n\x17initialization_behavior\x18\x04 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"z\n!CreateWatchdogTimerTaskExResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12$\n\x04task\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1f\n\x17new_session_initialized\x18\x03 \x01(\x08\"1\n\x1a\x44\x65leteNetworkDeviceRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"-\n\x1b\x44\x65leteNetworkDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x1c\x44\x65leteSavedGlobalChanRequest\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\"/\n\x1d\x44\x65leteSavedGlobalChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"-\n\x17\x44\x65leteSavedScaleRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\"*\n\x18\x44\x65leteSavedScaleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"+\n\x16\x44\x65leteSavedTaskRequest\x12\x11\n\ttask_name\x18\x01 \x01(\t\")\n\x17\x44\x65leteSavedTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"/\n\x18\x44\x65viceSupportsCalRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"B\n\x19\x44\x65viceSupportsCalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rcal_supported\x18\x02 \x01(\x08\"=\n\x15\x44isableRefTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"(\n\x16\x44isableRefTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"?\n\x17\x44isableStartTrigRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"*\n\x18\x44isableStartTrigResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"O\n\x16\x44isconnectTermsRequest\x12\x17\n\x0fsource_terminal\x18\x01 \x01(\t\x12\x1c\n\x14\x64\x65stination_terminal\x18\x02 \x01(\t\")\n\x17\x44isconnectTermsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xaa\x01\n\x13\x45xportSignalRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12)\n\tsignal_id\x18\x02 \x01(\x0e\x32\x14.nidaqmx_grpc.SignalH\x00\x12\x17\n\rsignal_id_raw\x18\x03 \x01(\x05H\x00\x12\x17\n\x0foutput_terminal\x18\x04 \x01(\tB\x10\n\x0esignal_id_enum\"&\n\x14\x45xportSignalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"X\n\x1aGetAIChanCalCalDateRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"u\n\x1bGetAIChanCalCalDateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\r\n\x05month\x18\x03 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\r\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0e\n\x06minute\x18\x06 \x01(\r\"X\n\x1aGetAIChanCalExpDateRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"u\n\x1bGetAIChanCalExpDateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\r\n\x05month\x18\x03 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\r\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0e\n\x06minute\x18\x06 \x01(\r\"q\n\x1dGetAnalogPowerUpStatesRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12;\n\x08\x63hannels\x18\x02 \x03(\x0b\x32).nidaqmx_grpc.AnalogPowerUpChannelAndType\"I\n\x1eGetAnalogPowerUpStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fpower_up_states\x18\x02 \x03(\x01\"X\n+GetAnalogPowerUpStatesWithOutputTypeRequest\x12\x15\n\rchannel_names\x18\x01 \x01(\t\x12\x12\n\narray_size\x18\x02 \x01(\r\"\xb1\x01\n,GetAnalogPowerUpStatesWithOutputTypeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0bstate_array\x18\x02 \x03(\x01\x12<\n\x12\x63hannel_type_array\x18\x03 \x03(\x0e\x32 .nidaqmx_grpc.PowerUpChannelType\x12\x1e\n\x16\x63hannel_type_array_raw\x18\x04 \x03(\x05\"J\n\"GetArmStartTrigTimestampValRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"_\n#GetArmStartTrigTimestampValResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"F\n\x1eGetArmStartTrigTrigWhenRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"[\n\x1fGetArmStartTrigTrigWhenResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"-\n+GetAutoConfiguredCDAQSyncConnectionsRequest\"Q\n,GetAutoConfiguredCDAQSyncConnectionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tport_list\x18\x02 \x01(\t\"\xac\x01\n\x1fGetBufferAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.BufferUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetBufferAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xa1\x01\n\x1eGetCalInfoAttributeBoolRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12?\n\tattribute\x18\x02 \x01(\x0e\x32*.nidaqmx_grpc.CalibrationInfoBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"@\n\x1fGetCalInfoAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xa5\x01\n GetCalInfoAttributeDoubleRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.CalibrationInfoDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"B\n!GetCalInfoAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xa5\x01\n GetCalInfoAttributeStringRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.CalibrationInfoStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"B\n!GetCalInfoAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xa5\x01\n GetCalInfoAttributeUInt32Request\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.CalibrationInfoUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"B\n!GetCalInfoAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xb8\x01\n\x1bGetChanAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x37\n\tattribute\x18\x03 \x01(\x0e\x32\".nidaqmx_grpc.ChannelBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"=\n\x1cGetChanAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xbc\x01\n\x1dGetChanAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.ChannelDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetChanAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xc6\x01\n\"GetChanAttributeDoubleArrayRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12>\n\tattribute\x18\x03 \x01(\x0e\x32).nidaqmx_grpc.ChannelDoubleArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"D\n#GetChanAttributeDoubleArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x03(\x01\"\xba\x01\n\x1cGetChanAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.ChannelInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"|\n\x1dGetChanAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x38\n\x05value\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.ChannelInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xbc\x01\n\x1dGetChanAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.ChannelStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetChanAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xbc\x01\n\x1dGetChanAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.ChannelUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetChanAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\x97\x01\n\x1dGetDeviceAttributeBoolRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.DeviceBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetDeviceAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\x9b\x01\n\x1fGetDeviceAttributeDoubleRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.DeviceDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetDeviceAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xa5\x01\n$GetDeviceAttributeDoubleArrayRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12=\n\tattribute\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.DeviceDoubleArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"F\n%GetDeviceAttributeDoubleArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x03(\x01\"\x99\x01\n\x1eGetDeviceAttributeInt32Request\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.DeviceInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"}\n\x1fGetDeviceAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x37\n\x05value\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.DeviceInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xa3\x01\n#GetDeviceAttributeInt32ArrayRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12<\n\tattribute\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.DeviceInt32ArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"\x82\x01\n$GetDeviceAttributeInt32ArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x37\n\x05value\x18\x02 \x03(\x0e\x32(.nidaqmx_grpc.DeviceInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x03(\x05\"\x9b\x01\n\x1fGetDeviceAttributeStringRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.DeviceStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetDeviceAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\x9b\x01\n\x1fGetDeviceAttributeUInt32Request\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.DeviceUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetDeviceAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xa5\x01\n$GetDeviceAttributeUInt32ArrayRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12=\n\tattribute\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.DeviceUInt32ArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"F\n%GetDeviceAttributeUInt32ArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x03(\r\"?\n(GetDigitalLogicFamilyPowerUpStateRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"Q\n)GetDigitalLogicFamilyPowerUpStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0clogic_family\x18\x02 \x01(\x05\"K\n\x1eGetDigitalPowerUpStatesRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x02 \x03(\t\"g\n\x1fGetDigitalPowerUpStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x34\n\x0fpower_up_states\x18\x02 \x03(\x0e\x32\x1b.nidaqmx_grpc.PowerUpStates\"R\n%GetDigitalPullUpPullDownStatesRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x02 \x03(\t\"w\n&GetDigitalPullUpPullDownStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12=\n\x18pull_up_pull_down_states\x18\x02 \x03(\x0e\x32\x1b.nidaqmx_grpc.ResistorState\"%\n#GetDisconnectedCDAQSyncPortsRequest\"I\n$GetDisconnectedCDAQSyncPortsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tport_list\x18\x02 \x01(\t\"+\n\x15GetErrorStringRequest\x12\x12\n\nerror_code\x18\x01 \x01(\x05\">\n\x16GetErrorStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0c\x65rror_string\x18\x02 \x01(\t\"\xb6\x01\n%GetExportedSignalAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12<\n\tattribute\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.ExportSignalBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"G\n&GetExportedSignalAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xba\x01\n\'GetExportedSignalAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.ExportSignalDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"I\n(GetExportedSignalAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xb8\x01\n&GetExportedSignalAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12=\n\tattribute\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.ExportSignalInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"\x8b\x01\n\'GetExportedSignalAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12=\n\x05value\x18\x02 \x01(\x0e\x32..nidaqmx_grpc.ExportSignalInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xba\x01\n\'GetExportedSignalAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.ExportSignalStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"I\n(GetExportedSignalAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xba\x01\n\'GetExportedSignalAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.ExportSignalUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"I\n(GetExportedSignalAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"6\n\x1fGetExtCalLastDateAndTimeRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"z\n GetExtCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\r\n\x05month\x18\x03 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\r\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0e\n\x06minute\x18\x06 \x01(\r\"B\n\x1aGetFirstSampClkWhenRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"W\n\x1bGetFirstSampClkWhenResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"G\n\x1fGetFirstSampTimestampValRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\\\n GetFirstSampTimestampValResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\x18GetNthTaskChannelRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\r\";\n\x19GetNthTaskChannelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06\x62uffer\x18\x02 \x01(\t\"N\n\x17GetNthTaskDeviceRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\r\":\n\x18GetNthTaskDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06\x62uffer\x18\x02 \x01(\t\"S\n\x1cGetNthTaskReadChannelRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\r\"?\n\x1dGetNthTaskReadChannelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06\x62uffer\x18\x02 \x01(\t\"\xa4\x01\n$GetPersistedChanAttributeBoolRequest\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12@\n\tattribute\x18\x02 \x01(\x0e\x32+.nidaqmx_grpc.PersistedChannelBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"F\n%GetPersistedChanAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xa8\x01\n&GetPersistedChanAttributeStringRequest\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12\x42\n\tattribute\x18\x02 \x01(\x0e\x32-.nidaqmx_grpc.PersistedChannelStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"H\n\'GetPersistedChanAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xa6\x01\n%GetPersistedScaleAttributeBoolRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.PersistedScaleBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"G\n&GetPersistedScaleAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xaa\x01\n\'GetPersistedScaleAttributeStringRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12@\n\tattribute\x18\x02 \x01(\x0e\x32+.nidaqmx_grpc.PersistedScaleStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"I\n(GetPersistedScaleAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xa3\x01\n$GetPersistedTaskAttributeBoolRequest\x12\x11\n\ttask_name\x18\x01 \x01(\t\x12=\n\tattribute\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.PersistedTaskBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"F\n%GetPersistedTaskAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xa7\x01\n&GetPersistedTaskAttributeStringRequest\x12\x11\n\ttask_name\x18\x01 \x01(\t\x12?\n\tattribute\x18\x02 \x01(\x0e\x32*.nidaqmx_grpc.PersistedTaskStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"H\n\'GetPersistedTaskAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xab\x01\n#GetPhysicalChanAttributeBoolRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12?\n\tattribute\x18\x02 \x01(\x0e\x32*.nidaqmx_grpc.PhysicalChannelBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"E\n$GetPhysicalChanAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xad\x01\n$GetPhysicalChanAttributeBytesRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12@\n\tattribute\x18\x02 \x01(\x0e\x32+.nidaqmx_grpc.PhysicalChannelBytesAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"F\n%GetPhysicalChanAttributeBytesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x0c\"\xaf\x01\n%GetPhysicalChanAttributeDoubleRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.PhysicalChannelDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"G\n&GetPhysicalChanAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xb9\x01\n*GetPhysicalChanAttributeDoubleArrayRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x46\n\tattribute\x18\x02 \x01(\x0e\x32\x31.nidaqmx_grpc.PhysicalChannelDoubleArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"L\n+GetPhysicalChanAttributeDoubleArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x03(\x01\"\xad\x01\n$GetPhysicalChanAttributeInt32Request\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12@\n\tattribute\x18\x02 \x01(\x0e\x32+.nidaqmx_grpc.PhysicalChannelInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"\x8c\x01\n%GetPhysicalChanAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12@\n\x05value\x18\x02 \x01(\x0e\x32\x31.nidaqmx_grpc.PhysicalChannelInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xb7\x01\n)GetPhysicalChanAttributeInt32ArrayRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x45\n\tattribute\x18\x02 \x01(\x0e\x32\x30.nidaqmx_grpc.PhysicalChannelInt32ArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"\x91\x01\n*GetPhysicalChanAttributeInt32ArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12@\n\x05value\x18\x02 \x03(\x0e\x32\x31.nidaqmx_grpc.PhysicalChannelInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x03(\x05\"\xaf\x01\n%GetPhysicalChanAttributeStringRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.PhysicalChannelStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"G\n&GetPhysicalChanAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xaf\x01\n%GetPhysicalChanAttributeUInt32Request\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.PhysicalChannelUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"G\n&GetPhysicalChanAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xb9\x01\n*GetPhysicalChanAttributeUInt32ArrayRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x46\n\tattribute\x18\x02 \x01(\x0e\x32\x31.nidaqmx_grpc.PhysicalChannelUInt32ArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"L\n+GetPhysicalChanAttributeUInt32ArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x03(\r\"\xa4\x01\n\x1bGetReadAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\tattribute\x18\x02 \x01(\x0e\x32\x1f.nidaqmx_grpc.ReadBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"=\n\x1cGetReadAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xa8\x01\n\x1dGetReadAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ReadDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetReadAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xa6\x01\n\x1cGetReadAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x35\n\tattribute\x18\x02 \x01(\x0e\x32 .nidaqmx_grpc.ReadInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"y\n\x1dGetReadAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x35\n\x05value\x18\x02 \x01(\x0e\x32&.nidaqmx_grpc.ReadInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xa8\x01\n\x1dGetReadAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ReadStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetReadAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xa8\x01\n\x1dGetReadAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ReadUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetReadAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xa8\x01\n\x1dGetReadAttributeUInt64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ReadUInt64AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetReadAttributeUInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x04\"\xac\x01\n\x1fGetRealTimeAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.RealTimeBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetRealTimeAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xae\x01\n GetRealTimeAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.RealTimeInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"\x81\x01\n!GetRealTimeAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x39\n\x05value\x18\x02 \x01(\x0e\x32*.nidaqmx_grpc.RealTimeInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xb0\x01\n!GetRealTimeAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12:\n\tattribute\x18\x02 \x01(\x0e\x32%.nidaqmx_grpc.RealTimeUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"C\n\"GetRealTimeAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"E\n\x1dGetRefTrigTimestampValRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"Z\n\x1eGetRefTrigTimestampValResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x98\x01\n\x1eGetScaleAttributeDoubleRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.ScaleDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"@\n\x1fGetScaleAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xa2\x01\n#GetScaleAttributeDoubleArrayRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12<\n\tattribute\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.ScaleDoubleArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"E\n$GetScaleAttributeDoubleArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x03(\x01\"\x96\x01\n\x1dGetScaleAttributeInt32Request\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ScaleInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"{\n\x1eGetScaleAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x36\n\x05value\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.ScaleInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\x98\x01\n\x1eGetScaleAttributeStringRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.ScaleStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"@\n\x1fGetScaleAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"7\n GetSelfCalLastDateAndTimeRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"{\n!GetSelfCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\r\n\x05month\x18\x03 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\r\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0e\n\x06minute\x18\x06 \x01(\r\"G\n\x1fGetStartTrigTimestampValRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\\\n GetStartTrigTimestampValResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\x1bGetStartTrigTrigWhenRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"X\n\x1cGetStartTrigTrigWhenResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\x1bGetSyncPulseTimeWhenRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"X\n\x1cGetSyncPulseTimeWhenResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8a\x01\n#GetSystemInfoAttributeStringRequest\x12\x38\n\tattribute\x18\x01 \x01(\x0e\x32#.nidaqmx_grpc.SystemStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x02 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"E\n$GetSystemInfoAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\x8a\x01\n#GetSystemInfoAttributeUInt32Request\x12\x38\n\tattribute\x18\x01 \x01(\x0e\x32#.nidaqmx_grpc.SystemUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x02 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"E\n$GetSystemInfoAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xa4\x01\n\x1bGetTaskAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\tattribute\x18\x02 \x01(\x0e\x32\x1f.nidaqmx_grpc.TaskBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"=\n\x1cGetTaskAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xa8\x01\n\x1dGetTaskAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.TaskStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetTaskAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xa8\x01\n\x1dGetTaskAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.TaskUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetTaskAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xa8\x01\n\x1dGetTimingAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.TimingBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetTimingAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xac\x01\n\x1fGetTimingAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TimingDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetTimingAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xc0\x01\n\x1fGetTimingAttributeExBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x36\n\tattribute\x18\x03 \x01(\x0e\x32!.nidaqmx_grpc.TimingBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetTimingAttributeExBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xc4\x01\n!GetTimingAttributeExDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.TimingDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"C\n\"GetTimingAttributeExDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xc2\x01\n GetTimingAttributeExInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x37\n\tattribute\x18\x03 \x01(\x0e\x32\".nidaqmx_grpc.TimingInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"\x7f\n!GetTimingAttributeExInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x37\n\x05value\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.TimingInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xc4\x01\n!GetTimingAttributeExStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.TimingStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"C\n\"GetTimingAttributeExStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xca\x01\n$GetTimingAttributeExTimestampRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12;\n\tattribute\x18\x03 \x01(\x0e\x32&.nidaqmx_grpc.TimingTimestampAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"b\n%GetTimingAttributeExTimestampResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc4\x01\n!GetTimingAttributeExUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.TimingUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"C\n\"GetTimingAttributeExUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xc4\x01\n!GetTimingAttributeExUInt64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.TimingUInt64AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"C\n\"GetTimingAttributeExUInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x04\"\xaa\x01\n\x1eGetTimingAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.TimingInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"}\n\x1fGetTimingAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x37\n\x05value\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.TimingInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xac\x01\n\x1fGetTimingAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TimingStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetTimingAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xb2\x01\n\"GetTimingAttributeTimestampRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12;\n\tattribute\x18\x02 \x01(\x0e\x32&.nidaqmx_grpc.TimingTimestampAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"`\n#GetTimingAttributeTimestampResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xac\x01\n\x1fGetTimingAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TimingUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetTimingAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xac\x01\n\x1fGetTimingAttributeUInt64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TimingUInt64AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetTimingAttributeUInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x04\"\xa7\x01\n\x1bGetTrigAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.TriggerBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"=\n\x1cGetTrigAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xab\x01\n\x1dGetTrigAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.TriggerDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetTrigAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xb5\x01\n\"GetTrigAttributeDoubleArrayRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.TriggerDoubleArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"D\n#GetTrigAttributeDoubleArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x03(\x01\"\xa9\x01\n\x1cGetTrigAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TriggerInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"|\n\x1dGetTrigAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x38\n\x05value\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.TriggerInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xb3\x01\n!GetTrigAttributeInt32ArrayRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12=\n\tattribute\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.TriggerInt32ArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"\x81\x01\n\"GetTrigAttributeInt32ArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x38\n\x05value\x18\x02 \x03(\x0e\x32).nidaqmx_grpc.TriggerInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x03(\x05\"\xab\x01\n\x1dGetTrigAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.TriggerStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetTrigAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xb1\x01\n GetTrigAttributeTimestampRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12<\n\tattribute\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.TriggerTimestampAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"^\n!GetTrigAttributeTimestampResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xab\x01\n\x1dGetTrigAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.TriggerUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"?\n\x1eGetTrigAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xbb\x01\n\x1fGetWatchdogAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.WatchdogBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"A\n GetWatchdogAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xbf\x01\n!GetWatchdogAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12:\n\tattribute\x18\x03 \x01(\x0e\x32%.nidaqmx_grpc.WatchdogDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"C\n\"GetWatchdogAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xbd\x01\n GetWatchdogAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.WatchdogInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"\x81\x01\n!GetWatchdogAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x39\n\x05value\x18\x02 \x01(\x0e\x32*.nidaqmx_grpc.WatchdogInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xbf\x01\n!GetWatchdogAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12:\n\tattribute\x18\x03 \x01(\x0e\x32%.nidaqmx_grpc.WatchdogStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"C\n\"GetWatchdogAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xa6\x01\n\x1cGetWriteAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x35\n\tattribute\x18\x02 \x01(\x0e\x32 .nidaqmx_grpc.WriteBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\">\n\x1dGetWriteAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08\"\xaa\x01\n\x1eGetWriteAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.WriteDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"@\n\x1fGetWriteAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xa8\x01\n\x1dGetWriteAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.WriteInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"{\n\x1eGetWriteAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x36\n\x05value\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.WriteInt32AttributeValues\x12\x11\n\tvalue_raw\x18\x03 \x01(\x05\"\xaa\x01\n\x1eGetWriteAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.WriteStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"@\n\x1fGetWriteAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\"\xaa\x01\n\x1eGetWriteAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.WriteUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"@\n\x1fGetWriteAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xaa\x01\n\x1eGetWriteAttributeUInt64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.WriteUInt64AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"@\n\x1fGetWriteAttributeUInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x04\"9\n\x11IsTaskDoneRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\":\n\x12IsTaskDoneResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0cis_task_done\x18\x02 \x01(\x08\"v\n\x0fLoadTaskRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12M\n\x17initialization_behavior\x18\x02 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"i\n\x10LoadTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12$\n\x04task\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1f\n\x17new_session_initialized\x18\x03 \x01(\x08\"\x82\x01\n&PerformBridgeOffsetNullingCalExRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12!\n\x19skip_unsupported_channels\x18\x03 \x01(\x08\"9\n\'PerformBridgeOffsetNullingCalExResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc5\x04\n\x1ePerformBridgeShuntCalExRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x1c\n\x14shunt_resistor_value\x18\x03 \x01(\x01\x12\x45\n\x17shunt_resistor_location\x18\x04 \x01(\x0e\x32\".nidaqmx_grpc.ShuntElementLocationH\x00\x12%\n\x1bshunt_resistor_location_raw\x18\x05 \x01(\x05H\x00\x12=\n\x15shunt_resistor_select\x18\x06 \x01(\x0e\x32\x1c.nidaqmx_grpc.ShuntCalSelectH\x01\x12#\n\x19shunt_resistor_select_raw\x18\x07 \x01(\x05H\x01\x12=\n\x15shunt_resistor_source\x18\x08 \x01(\x0e\x32\x1c.nidaqmx_grpc.ShuntCalSourceH\x02\x12#\n\x19shunt_resistor_source_raw\x18\t \x01(\x05H\x02\x12\x19\n\x11\x62ridge_resistance\x18\n \x01(\x01\x12!\n\x19skip_unsupported_channels\x18\x0b \x01(\x08\x42\x1e\n\x1cshunt_resistor_location_enumB\x1c\n\x1ashunt_resistor_select_enumB\x1c\n\x1ashunt_resistor_source_enum\"1\n\x1fPerformBridgeShuntCalExResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xaa\x04\n\x1ePerformStrainShuntCalExRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x1c\n\x14shunt_resistor_value\x18\x03 \x01(\x01\x12\x45\n\x17shunt_resistor_location\x18\x04 \x01(\x0e\x32\".nidaqmx_grpc.ShuntElementLocationH\x00\x12%\n\x1bshunt_resistor_location_raw\x18\x05 \x01(\x05H\x00\x12=\n\x15shunt_resistor_select\x18\x06 \x01(\x0e\x32\x1c.nidaqmx_grpc.ShuntCalSelectH\x01\x12#\n\x19shunt_resistor_select_raw\x18\x07 \x01(\x05H\x01\x12=\n\x15shunt_resistor_source\x18\x08 \x01(\x0e\x32\x1c.nidaqmx_grpc.ShuntCalSourceH\x02\x12#\n\x19shunt_resistor_source_raw\x18\t \x01(\x05H\x02\x12!\n\x19skip_unsupported_channels\x18\n \x01(\x08\x42\x1e\n\x1cshunt_resistor_location_enumB\x1c\n\x1ashunt_resistor_select_enumB\x1c\n\x1ashunt_resistor_source_enum\"1\n\x1fPerformStrainShuntCalExResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x85\x01\n)PerformThrmcplLeadOffsetNullingCalRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12!\n\x19skip_unsupported_channels\x18\x03 \x01(\x08\"<\n*PerformThrmcplLeadOffsetNullingCalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdd\x01\n\x14ReadAnalogF64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"X\n\x15ReadAnalogF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\x01\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"S\n\x1aReadAnalogScalarF64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"<\n\x1bReadAnalogScalarF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\xdd\x01\n\x14ReadBinaryI16Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"X\n\x15ReadBinaryI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\x05\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xdd\x01\n\x14ReadBinaryI32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"X\n\x15ReadBinaryI32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\x05\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xdd\x01\n\x14ReadBinaryU16Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"X\n\x15ReadBinaryU16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\r\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xdd\x01\n\x14ReadBinaryU32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"X\n\x15ReadBinaryU32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\r\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\x87\x01\n\x15ReadCounterF64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x1b\n\x13\x61rray_size_in_samps\x18\x04 \x01(\r\"Y\n\x16ReadCounterF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\x01\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xe0\x01\n\x17ReadCounterF64ExRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"[\n\x18ReadCounterF64ExResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\x01\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"T\n\x1bReadCounterScalarF64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"=\n\x1cReadCounterScalarF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"T\n\x1bReadCounterScalarU32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"=\n\x1cReadCounterScalarU32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\x87\x01\n\x15ReadCounterU32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x1b\n\x13\x61rray_size_in_samps\x18\x04 \x01(\r\"Y\n\x16ReadCounterU32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\r\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xe0\x01\n\x17ReadCounterU32ExRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"[\n\x18ReadCounterU32ExResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\r\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xe1\x01\n\x12ReadCtrFreqRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12,\n\x0binterleaved\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0finterleaved_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x12\n\x10interleaved_enum\"\x7f\n\x13ReadCtrFreqResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1c\n\x14read_array_frequency\x18\x02 \x03(\x01\x12\x1d\n\x15read_array_duty_cycle\x18\x03 \x03(\x01\x12\x1b\n\x13samps_per_chan_read\x18\x04 \x01(\x05\"Q\n\x18ReadCtrFreqScalarRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"R\n\x19ReadCtrFreqScalarResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tfrequency\x18\x02 \x01(\x01\x12\x12\n\nduty_cycle\x18\x03 \x01(\x01\"\xe2\x01\n\x13ReadCtrTicksRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12,\n\x0binterleaved\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0finterleaved_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x12\n\x10interleaved_enum\"\x80\x01\n\x14ReadCtrTicksResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1d\n\x15read_array_high_ticks\x18\x02 \x03(\r\x12\x1c\n\x14read_array_low_ticks\x18\x03 \x03(\r\x12\x1b\n\x13samps_per_chan_read\x18\x04 \x01(\x05\"R\n\x19ReadCtrTicksScalarRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"S\n\x1aReadCtrTicksScalarResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nhigh_ticks\x18\x02 \x01(\r\x12\x11\n\tlow_ticks\x18\x03 \x01(\r\"\xe1\x01\n\x12ReadCtrTimeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12,\n\x0binterleaved\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0finterleaved_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x12\n\x10interleaved_enum\"}\n\x13ReadCtrTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1c\n\x14read_array_high_time\x18\x02 \x03(\x01\x12\x1b\n\x13read_array_low_time\x18\x03 \x03(\x01\x12\x1b\n\x13samps_per_chan_read\x18\x04 \x01(\x05\"Q\n\x18ReadCtrTimeScalarRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"P\n\x19ReadCtrTimeScalarResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\thigh_time\x18\x02 \x01(\x01\x12\x10\n\x08low_time\x18\x03 \x01(\x01\"\xe0\x01\n\x17ReadDigitalLinesRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_bytes\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"w\n\x18ReadDigitalLinesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x01(\x0c\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\x12\x1a\n\x12num_bytes_per_samp\x18\x04 \x01(\x05\"T\n\x1bReadDigitalScalarU32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"=\n\x1cReadDigitalScalarU32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\r\"\xde\x01\n\x15ReadDigitalU16Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"Y\n\x16ReadDigitalU16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\r\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xde\x01\n\x15ReadDigitalU32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"Y\n\x16ReadDigitalU32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x03(\r\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xdd\x01\n\x14ReadDigitalU8Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"X\n\x15ReadDigitalU8Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x01(\x0c\x12\x1b\n\x13samps_per_chan_read\x18\x03 \x01(\x05\"\xe2\x01\n\x19ReadPowerBinaryI16Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"\x81\x01\n\x1aReadPowerBinaryI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1a\n\x12read_array_voltage\x18\x02 \x03(\x05\x12\x1a\n\x12read_array_current\x18\x03 \x03(\x05\x12\x1b\n\x13samps_per_chan_read\x18\x04 \x01(\x05\"\xdc\x01\n\x13ReadPowerF64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12*\n\tfill_mode\x18\x04 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x17\n\rfill_mode_raw\x18\x05 \x01(\x05H\x00\x12\x1b\n\x13\x61rray_size_in_samps\x18\x06 \x01(\rB\x10\n\x0e\x66ill_mode_enum\"{\n\x14ReadPowerF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1a\n\x12read_array_voltage\x18\x02 \x03(\x01\x12\x1a\n\x12read_array_current\x18\x03 \x03(\x01\x12\x1b\n\x13samps_per_chan_read\x18\x04 \x01(\x05\"R\n\x19ReadPowerScalarF64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"N\n\x1aReadPowerScalarF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07voltage\x18\x02 \x01(\x01\x12\x0f\n\x07\x63urrent\x18\x03 \x01(\x01\"\x80\x01\n\x0eReadRawRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x1b\n\x13\x61rray_size_in_bytes\x18\x04 \x01(\r\"e\n\x0fReadRawResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nread_array\x18\x02 \x01(\x0c\x12\x12\n\nsamps_read\x18\x03 \x01(\x05\x12\x1a\n\x12num_bytes_per_samp\x18\x04 \x01(\x05\"@\n\x18RegisterDoneEventRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"+\n\x19RegisterDoneEventResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf5\x01\n!RegisterEveryNSamplesEventRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12J\n\x1a\x65very_n_samples_event_type\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.EveryNSamplesEventTypeH\x00\x12(\n\x1e\x65very_n_samples_event_type_raw\x18\x03 \x01(\x05H\x00\x12\x11\n\tn_samples\x18\x04 \x01(\rB!\n\x1f\x65very_n_samples_event_type_enum\"\xb9\x01\n\"RegisterEveryNSamplesEventResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12H\n\x1a\x65very_n_samples_event_type\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.EveryNSamplesEventType\x12&\n\x1e\x65very_n_samples_event_type_raw\x18\x03 \x01(\x05\x12\x11\n\tn_samples\x18\x04 \x01(\r\"\x99\x01\n\x1aRegisterSignalEventRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12*\n\tsignal_id\x18\x02 \x01(\x0e\x32\x15.nidaqmx_grpc.Signal2H\x00\x12\x17\n\rsignal_id_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0esignal_id_enum\"@\n\x1bRegisterSignalEventResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tsignal_id\x18\x02 \x01(\x05\"4\n\x1fRemoveCDAQSyncConnectionRequest\x12\x11\n\tport_list\x18\x01 \x01(\t\"2\n RemoveCDAQSyncConnectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"P\n\x1bReserveNetworkDeviceRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x1c\n\x14override_reservation\x18\x02 \x01(\x08\".\n\x1cReserveNetworkDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa7\x01\n\x1bResetBufferAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.BufferResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\".\n\x1cResetBufferAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x01\n\x19ResetChanAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.ChannelResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\",\n\x1aResetChanAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\")\n\x12ResetDeviceRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"%\n\x13ResetDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb5\x01\n#ResetExportedSignalAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12=\n\tattribute\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.ExportSignalResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"6\n$ResetExportedSignalAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa3\x01\n\x19ResetReadAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x35\n\tattribute\x18\x02 \x01(\x0e\x32 .nidaqmx_grpc.ReadResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\",\n\x1aResetReadAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xab\x01\n\x1dResetRealTimeAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.RealTimeResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"0\n\x1eResetRealTimeAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa7\x01\n\x1bResetTimingAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.TimingResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\".\n\x1cResetTimingAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbf\x01\n\x1dResetTimingAttributeExRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x37\n\tattribute\x18\x03 \x01(\x0e\x32\".nidaqmx_grpc.TimingResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"0\n\x1eResetTimingAttributeExResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa6\x01\n\x19ResetTrigAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TriggerResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\",\n\x1aResetTrigAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x01\n\x1dResetWatchdogAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.WatchdogResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"0\n\x1eResetWatchdogAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa5\x01\n\x1aResetWriteAttributeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.WriteResetAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0e\x61ttribute_enum\"-\n\x1bResetWriteAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x1dRestoreLastExtCalConstRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"0\n\x1eRestoreLastExtCalConstResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc9\x01\n\x15SaveGlobalChanRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07save_as\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12,\n\x07options\x18\x05 \x01(\x0e\x32\x19.nidaqmx_grpc.SaveOptionsH\x00\x12\x15\n\x0boptions_raw\x18\x06 \x01(\rH\x00\x42\x0e\n\x0coptions_enum\"(\n\x16SaveGlobalChanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9c\x01\n\x10SaveScaleRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12\x0f\n\x07save_as\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12,\n\x07options\x18\x04 \x01(\x0e\x32\x19.nidaqmx_grpc.SaveOptionsH\x00\x12\x15\n\x0boptions_raw\x18\x05 \x01(\rH\x00\x42\x0e\n\x0coptions_enum\"#\n\x11SaveScaleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xad\x01\n\x0fSaveTaskRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07save_as\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12,\n\x07options\x18\x04 \x01(\x0e\x32\x19.nidaqmx_grpc.SaveOptionsH\x00\x12\x15\n\x0boptions_raw\x18\x05 \x01(\rH\x00\x42\x0e\n\x0coptions_enum\"\"\n\x10SaveTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"%\n\x0eSelfCalRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"!\n\x0fSelfCalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\",\n\x15SelfTestDeviceRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"(\n\x16SelfTestDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa0\x01\n\x1aSetAIChanCalCalDateRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0c\n\x04year\x18\x03 \x01(\r\x12\r\n\x05month\x18\x04 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x05 \x01(\r\x12\x0c\n\x04hour\x18\x06 \x01(\r\x12\x0e\n\x06minute\x18\x07 \x01(\r\"-\n\x1bSetAIChanCalCalDateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa0\x01\n\x1aSetAIChanCalExpDateRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0c\n\x04year\x18\x03 \x01(\r\x12\r\n\x05month\x18\x04 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x05 \x01(\r\x12\x0c\n\x04hour\x18\x06 \x01(\r\x12\x0e\n\x06minute\x18\x07 \x01(\r\"-\n\x1bSetAIChanCalExpDateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"z\n\x1dSetAnalogPowerUpStatesRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x44\n\x0fpower_up_states\x18\x02 \x03(\x0b\x32+.nidaqmx_grpc.AnalogPowerUpChannelsAndState\"0\n\x1eSetAnalogPowerUpStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x97\x01\n+SetAnalogPowerUpStatesWithOutputTypeRequest\x12\x15\n\rchannel_names\x18\x01 \x01(\t\x12\x13\n\x0bstate_array\x18\x02 \x03(\x01\x12<\n\x12\x63hannel_type_array\x18\x03 \x03(\x0e\x32 .nidaqmx_grpc.PowerUpChannelType\">\n,SetAnalogPowerUpStatesWithOutputTypeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n\x1eSetArmStartTrigTrigWhenRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x1fSetArmStartTrigTrigWhenResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbb\x01\n\x1fSetBufferAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.BufferUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\rB\x10\n\x0e\x61ttribute_enum\"2\n SetBufferAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb0\x01\n\x1eSetCalInfoAttributeBoolRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12?\n\tattribute\x18\x02 \x01(\x0e\x32*.nidaqmx_grpc.CalibrationInfoBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\"1\n\x1fSetCalInfoAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb4\x01\n SetCalInfoAttributeDoubleRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.CalibrationInfoDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"3\n!SetCalInfoAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb4\x01\n SetCalInfoAttributeStringRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.CalibrationInfoStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\tB\x10\n\x0e\x61ttribute_enum\"3\n!SetCalInfoAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb4\x01\n SetCalInfoAttributeUInt32Request\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x41\n\tattribute\x18\x02 \x01(\x0e\x32,.nidaqmx_grpc.CalibrationInfoUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\rB\x10\n\x0e\x61ttribute_enum\"3\n!SetCalInfoAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc7\x01\n\x1bSetChanAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x37\n\tattribute\x18\x03 \x01(\x0e\x32\".nidaqmx_grpc.ChannelBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\".\n\x1cSetChanAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcb\x01\n\x1dSetChanAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.ChannelDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetChanAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd5\x01\n\"SetChanAttributeDoubleArrayRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12>\n\tattribute\x18\x03 \x01(\x0e\x32).nidaqmx_grpc.ChannelDoubleArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x03(\x01\x42\x10\n\x0e\x61ttribute_enum\"5\n#SetChanAttributeDoubleArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x99\x02\n\x1cSetChanAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.ChannelInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12:\n\x05value\x18\x05 \x01(\x0e\x32).nidaqmx_grpc.ChannelInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x06 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"/\n\x1dSetChanAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcb\x01\n\x1dSetChanAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.ChannelStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\tB\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetChanAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcb\x01\n\x1dSetChanAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.ChannelUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\rB\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetChanAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa3\x01\n(SetDigitalLogicFamilyPowerUpStateRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x31\n\x0clogic_family\x18\x02 \x01(\x0e\x32\x19.nidaqmx_grpc.LogicFamilyH\x00\x12\x1a\n\x10logic_family_raw\x18\x03 \x01(\x05H\x00\x42\x13\n\x11logic_family_enum\";\n)SetDigitalLogicFamilyPowerUpStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"|\n\x1eSetDigitalPowerUpStatesRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x45\n\x0fpower_up_states\x18\x02 \x03(\x0b\x32,.nidaqmx_grpc.DigitalPowerUpChannelsAndState\"1\n\x1fSetDigitalPowerUpStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x93\x01\n%SetDigitalPullUpPullDownStatesRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12U\n\x18pull_up_pull_down_states\x18\x02 \x03(\x0b\x32\x33.nidaqmx_grpc.DigitalPullUpPullDownChannelsAndState\"8\n&SetDigitalPullUpPullDownStatesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc5\x01\n%SetExportedSignalAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12<\n\tattribute\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.ExportSignalBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\"8\n&SetExportedSignalAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc9\x01\n\'SetExportedSignalAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.ExportSignalDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\":\n(SetExportedSignalAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9c\x02\n&SetExportedSignalAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12=\n\tattribute\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.ExportSignalInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12?\n\x05value\x18\x04 \x01(\x0e\x32..nidaqmx_grpc.ExportSignalInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x05 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"9\n\'SetExportedSignalAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc9\x01\n\'SetExportedSignalAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.ExportSignalStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\tB\x10\n\x0e\x61ttribute_enum\":\n(SetExportedSignalAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc9\x01\n\'SetExportedSignalAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.ExportSignalUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\rB\x10\n\x0e\x61ttribute_enum\":\n(SetExportedSignalAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n\x1aSetFirstSampClkWhenRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"-\n\x1bSetFirstSampClkWhenResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb3\x01\n\x1bSetReadAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x34\n\tattribute\x18\x02 \x01(\x0e\x32\x1f.nidaqmx_grpc.ReadBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\".\n\x1cSetReadAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x01\n\x1dSetReadAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ReadDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetReadAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x82\x02\n\x1cSetReadAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x35\n\tattribute\x18\x02 \x01(\x0e\x32 .nidaqmx_grpc.ReadInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\x37\n\x05value\x18\x04 \x01(\x0e\x32&.nidaqmx_grpc.ReadInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x05 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"/\n\x1dSetReadAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x01\n\x1dSetReadAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ReadStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\tB\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetReadAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x01\n\x1dSetReadAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ReadUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\rB\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetReadAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x01\n\x1dSetReadAttributeUInt64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ReadUInt64AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x04\x42\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetReadAttributeUInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbb\x01\n\x1fSetRealTimeAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.RealTimeBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\"2\n SetRealTimeAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8e\x02\n SetRealTimeAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.RealTimeInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12;\n\x05value\x18\x04 \x01(\x0e\x32*.nidaqmx_grpc.RealTimeInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x05 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"3\n!SetRealTimeAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbf\x01\n!SetRealTimeAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12:\n\tattribute\x18\x02 \x01(\x0e\x32%.nidaqmx_grpc.RealTimeUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\rB\x10\n\x0e\x61ttribute_enum\"4\n\"SetRealTimeAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa7\x01\n\x1eSetScaleAttributeDoubleRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.ScaleDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"1\n\x1fSetScaleAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb1\x01\n#SetScaleAttributeDoubleArrayRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12<\n\tattribute\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.ScaleDoubleArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x03(\x01\x42\x10\n\x0e\x61ttribute_enum\"6\n$SetScaleAttributeDoubleArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf3\x01\n\x1dSetScaleAttributeInt32Request\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.ScaleInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\x38\n\x05value\x18\x04 \x01(\x0e\x32\'.nidaqmx_grpc.ScaleInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x05 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"0\n\x1eSetScaleAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa7\x01\n\x1eSetScaleAttributeStringRequest\x12\x12\n\nscale_name\x18\x01 \x01(\t\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.ScaleStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\tB\x10\n\x0e\x61ttribute_enum\"1\n\x1fSetScaleAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"m\n\x1bSetStartTrigTrigWhenRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\".\n\x1cSetStartTrigTrigWhenResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"m\n\x1bSetSyncPulseTimeWhenRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\".\n\x1cSetSyncPulseTimeWhenResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x01\n\x1dSetTimingAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.TimingBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetTimingAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbb\x01\n\x1fSetTimingAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TimingDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"2\n SetTimingAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcf\x01\n\x1fSetTimingAttributeExBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x36\n\tattribute\x18\x03 \x01(\x0e\x32!.nidaqmx_grpc.TimingBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\"2\n SetTimingAttributeExBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd3\x01\n!SetTimingAttributeExDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.TimingDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"4\n\"SetTimingAttributeExDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa0\x02\n SetTimingAttributeExInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x37\n\tattribute\x18\x03 \x01(\x0e\x32\".nidaqmx_grpc.TimingInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\x39\n\x05value\x18\x05 \x01(\x0e\x32(.nidaqmx_grpc.TimingInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x06 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"3\n!SetTimingAttributeExInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd3\x01\n!SetTimingAttributeExStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.TimingStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\tB\x10\n\x0e\x61ttribute_enum\"4\n\"SetTimingAttributeExStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf5\x01\n$SetTimingAttributeExTimestampRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12;\n\tattribute\x18\x03 \x01(\x0e\x32&.nidaqmx_grpc.TimingTimestampAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12)\n\x05value\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x10\n\x0e\x61ttribute_enum\"7\n%SetTimingAttributeExTimestampResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd3\x01\n!SetTimingAttributeExUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.TimingUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\rB\x10\n\x0e\x61ttribute_enum\"4\n\"SetTimingAttributeExUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd3\x01\n!SetTimingAttributeExUInt64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x64\x65vice_names\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.TimingUInt64AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\x04\x42\x10\n\x0e\x61ttribute_enum\"4\n\"SetTimingAttributeExUInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x88\x02\n\x1eSetTimingAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.TimingInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\x39\n\x05value\x18\x04 \x01(\x0e\x32(.nidaqmx_grpc.TimingInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x05 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"1\n\x1fSetTimingAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbb\x01\n\x1fSetTimingAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TimingStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\tB\x10\n\x0e\x61ttribute_enum\"2\n SetTimingAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdd\x01\n\"SetTimingAttributeTimestampRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12;\n\tattribute\x18\x02 \x01(\x0e\x32&.nidaqmx_grpc.TimingTimestampAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12)\n\x05value\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x10\n\x0e\x61ttribute_enum\"5\n#SetTimingAttributeTimestampResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbb\x01\n\x1fSetTimingAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TimingUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\rB\x10\n\x0e\x61ttribute_enum\"2\n SetTimingAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbb\x01\n\x1fSetTimingAttributeUInt64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TimingUInt64AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x04\x42\x10\n\x0e\x61ttribute_enum\"2\n SetTimingAttributeUInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb6\x01\n\x1bSetTrigAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.TriggerBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\".\n\x1cSetTrigAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x01\n\x1dSetTrigAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.TriggerDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetTrigAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc4\x01\n\"SetTrigAttributeDoubleArrayRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\tattribute\x18\x02 \x01(\x0e\x32).nidaqmx_grpc.TriggerDoubleArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x03(\x01\x42\x10\n\x0e\x61ttribute_enum\"5\n#SetTrigAttributeDoubleArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x88\x02\n\x1cSetTrigAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x38\n\tattribute\x18\x02 \x01(\x0e\x32#.nidaqmx_grpc.TriggerInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12:\n\x05value\x18\x04 \x01(\x0e\x32).nidaqmx_grpc.TriggerInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x05 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"/\n\x1dSetTrigAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc2\x01\n!SetTrigAttributeInt32ArrayRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12=\n\tattribute\x18\x02 \x01(\x0e\x32(.nidaqmx_grpc.TriggerInt32ArrayAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x03(\x05\x42\x10\n\x0e\x61ttribute_enum\"4\n\"SetTrigAttributeInt32ArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x01\n\x1dSetTrigAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.TriggerStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\tB\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetTrigAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdc\x01\n SetTrigAttributeTimestampRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12<\n\tattribute\x18\x02 \x01(\x0e\x32\'.nidaqmx_grpc.TriggerTimestampAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12)\n\x05value\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x10\n\x0e\x61ttribute_enum\"3\n!SetTrigAttributeTimestampResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x01\n\x1dSetTrigAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x39\n\tattribute\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.TriggerUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\rB\x10\n\x0e\x61ttribute_enum\"0\n\x1eSetTrigAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xca\x01\n\x1fSetWatchdogAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12\x38\n\tattribute\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.WatchdogBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\"2\n SetWatchdogAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xce\x01\n!SetWatchdogAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12:\n\tattribute\x18\x03 \x01(\x0e\x32%.nidaqmx_grpc.WatchdogDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"4\n\"SetWatchdogAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9d\x02\n SetWatchdogAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12\x39\n\tattribute\x18\x03 \x01(\x0e\x32$.nidaqmx_grpc.WatchdogInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12;\n\x05value\x18\x05 \x01(\x0e\x32*.nidaqmx_grpc.WatchdogInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x06 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"3\n!SetWatchdogAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xce\x01\n!SetWatchdogAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05lines\x18\x02 \x01(\t\x12:\n\tattribute\x18\x03 \x01(\x0e\x32%.nidaqmx_grpc.WatchdogStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x04 \x01(\x05H\x00\x12\r\n\x05value\x18\x05 \x01(\tB\x10\n\x0e\x61ttribute_enum\"4\n\"SetWatchdogAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb5\x01\n\x1cSetWriteAttributeBoolRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x35\n\tattribute\x18\x02 \x01(\x0e\x32 .nidaqmx_grpc.WriteBoolAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x08\x42\x10\n\x0e\x61ttribute_enum\"/\n\x1dSetWriteAttributeBoolResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb9\x01\n\x1eSetWriteAttributeDoubleRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.WriteDoubleAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x01\x42\x10\n\x0e\x61ttribute_enum\"1\n\x1fSetWriteAttributeDoubleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x85\x02\n\x1dSetWriteAttributeInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\tattribute\x18\x02 \x01(\x0e\x32!.nidaqmx_grpc.WriteInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\x38\n\x05value\x18\x04 \x01(\x0e\x32\'.nidaqmx_grpc.WriteInt32AttributeValuesH\x01\x12\x13\n\tvalue_raw\x18\x05 \x01(\x05H\x01\x42\x10\n\x0e\x61ttribute_enumB\x0c\n\nvalue_enum\"0\n\x1eSetWriteAttributeInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb9\x01\n\x1eSetWriteAttributeStringRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.WriteStringAttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\tB\x10\n\x0e\x61ttribute_enum\"1\n\x1fSetWriteAttributeStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb9\x01\n\x1eSetWriteAttributeUInt32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.WriteUInt32AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\rB\x10\n\x0e\x61ttribute_enum\"1\n\x1fSetWriteAttributeUInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb9\x01\n\x1eSetWriteAttributeUInt64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\tattribute\x18\x02 \x01(\x0e\x32\".nidaqmx_grpc.WriteUInt64AttributeH\x00\x12\x17\n\rattribute_raw\x18\x03 \x01(\x05H\x00\x12\r\n\x05value\x18\x04 \x01(\x04\x42\x10\n\x0e\x61ttribute_enum\"1\n\x1fSetWriteAttributeUInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"N\n\x13StartNewFileRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\"&\n\x14StartNewFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"8\n\x10StartTaskRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"#\n\x11StartTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"7\n\x0fStopTaskRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\"\n\x10StopTaskResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x92\x01\n\x12TaskControlRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x31\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1f.nidaqmx_grpc.TaskControlActionH\x00\x12\x14\n\naction_raw\x18\x03 \x01(\x05H\x00\x42\r\n\x0b\x61\x63tion_enum\"%\n\x13TaskControlResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x19TristateOutputTermRequest\x12\x17\n\x0foutput_terminal\x18\x01 \x01(\t\",\n\x1aTristateOutputTermResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"B\n\x1aUnregisterDoneEventRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1bUnregisterDoneEventResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe4\x01\n#UnregisterEveryNSamplesEventRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12J\n\x1a\x65very_n_samples_event_type\x18\x02 \x01(\x0e\x32$.nidaqmx_grpc.EveryNSamplesEventTypeH\x00\x12(\n\x1e\x65very_n_samples_event_type_raw\x18\x03 \x01(\x05H\x00\x42!\n\x1f\x65very_n_samples_event_type_enum\"6\n$UnregisterEveryNSamplesEventResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9b\x01\n\x1cUnregisterSignalEventRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12*\n\tsignal_id\x18\x02 \x01(\x0e\x32\x15.nidaqmx_grpc.Signal2H\x00\x12\x17\n\rsignal_id_raw\x18\x03 \x01(\x05H\x00\x42\x10\n\x0esignal_id_enum\"/\n\x1dUnregisterSignalEventResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x1dUnreserveNetworkDeviceRequest\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\"0\n\x1eUnreserveNetworkDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"V\n\x1dWaitForNextSampleClockRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0f\n\x07timeout\x18\x02 \x01(\x01\"A\n\x1eWaitForNextSampleClockResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07is_late\x18\x02 \x01(\x08\"\xc5\x01\n\x1cWaitForValidTimestampRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x37\n\x0ftimestamp_event\x18\x02 \x01(\x0e\x32\x1c.nidaqmx_grpc.TimestampEventH\x00\x12\x1d\n\x13timestamp_event_raw\x18\x03 \x01(\x05H\x00\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x42\x16\n\x14timestamp_event_enum\"^\n\x1dWaitForValidTimestampResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"V\n\x18WaitUntilTaskDoneRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0ctime_to_wait\x18\x02 \x01(\x01\"+\n\x19WaitUntilTaskDoneResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf0\x01\n\x15WriteAnalogF64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x03(\x01\x42\x12\n\x10\x64\x61ta_layout_enum\"H\n\x16WriteAnalogF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"w\n\x1bWriteAnalogScalarF64Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nauto_start\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\r\n\x05value\x18\x04 \x01(\x01\".\n\x1cWriteAnalogScalarF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf0\x01\n\x15WriteBinaryI16Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x03(\x05\x42\x12\n\x10\x64\x61ta_layout_enum\"H\n\x16WriteBinaryI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"\xf0\x01\n\x15WriteBinaryI32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x03(\x05\x42\x12\n\x10\x64\x61ta_layout_enum\"H\n\x16WriteBinaryI32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"\xf0\x01\n\x15WriteBinaryU16Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x03(\rB\x12\n\x10\x64\x61ta_layout_enum\"H\n\x16WriteBinaryU16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"\xf0\x01\n\x15WriteBinaryU32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x03(\rB\x12\n\x10\x64\x61ta_layout_enum\"H\n\x16WriteBinaryU32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"\x80\x02\n\x13WriteCtrFreqRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x11\n\tfrequency\x18\x07 \x03(\x01\x12\x12\n\nduty_cycle\x18\x08 \x03(\x01\x42\x12\n\x10\x64\x61ta_layout_enum\"J\n\x14WriteCtrFreqResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1anum_samps_per_chan_written\x18\x02 \x01(\x05\"\x8d\x01\n\x19WriteCtrFreqScalarRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nauto_start\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x11\n\tfrequency\x18\x04 \x01(\x01\x12\x12\n\nduty_cycle\x18\x05 \x01(\x01\",\n\x1aWriteCtrFreqScalarResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x81\x02\n\x14WriteCtrTicksRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x12\n\nhigh_ticks\x18\x07 \x03(\r\x12\x11\n\tlow_ticks\x18\x08 \x03(\rB\x12\n\x10\x64\x61ta_layout_enum\"K\n\x15WriteCtrTicksResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1anum_samps_per_chan_written\x18\x02 \x01(\x05\"\x8e\x01\n\x1aWriteCtrTicksScalarRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nauto_start\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x12\n\nhigh_ticks\x18\x04 \x01(\r\x12\x11\n\tlow_ticks\x18\x05 \x01(\r\"-\n\x1bWriteCtrTicksScalarResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xfe\x01\n\x13WriteCtrTimeRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x11\n\thigh_time\x18\x07 \x03(\x01\x12\x10\n\x08low_time\x18\x08 \x03(\x01\x42\x12\n\x10\x64\x61ta_layout_enum\"J\n\x14WriteCtrTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1anum_samps_per_chan_written\x18\x02 \x01(\x05\"\x8b\x01\n\x19WriteCtrTimeScalarRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nauto_start\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x11\n\thigh_time\x18\x04 \x01(\x01\x12\x10\n\x08low_time\x18\x05 \x01(\x01\",\n\x1aWriteCtrTimeScalarResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf3\x01\n\x18WriteDigitalLinesRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x01(\x0c\x42\x12\n\x10\x64\x61ta_layout_enum\"K\n\x19WriteDigitalLinesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"x\n\x1cWriteDigitalScalarU32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nauto_start\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\r\n\x05value\x18\x04 \x01(\r\"/\n\x1dWriteDigitalScalarU32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xf1\x01\n\x16WriteDigitalU16Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x03(\rB\x12\n\x10\x64\x61ta_layout_enum\"I\n\x17WriteDigitalU16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"\xf1\x01\n\x16WriteDigitalU32Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x03(\rB\x12\n\x10\x64\x61ta_layout_enum\"I\n\x17WriteDigitalU32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"\xf0\x01\n\x15WriteDigitalU8Request\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12num_samps_per_chan\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12,\n\x0b\x64\x61ta_layout\x18\x05 \x01(\x0e\x32\x15.nidaqmx_grpc.GroupByH\x00\x12\x19\n\x0f\x64\x61ta_layout_raw\x18\x06 \x01(\x05H\x00\x12\x13\n\x0bwrite_array\x18\x07 \x01(\x0c\x42\x12\n\x10\x64\x61ta_layout_enum\"H\n\x16WriteDigitalU8Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"\x84\x01\n\x0fWriteRawRequest\x12$\n\x04task\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tnum_samps\x18\x02 \x01(\x05\x12\x12\n\nauto_start\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x12\x13\n\x0bwrite_array\x18\x05 \x01(\x0c\"B\n\x10WriteRawResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1e\n\x16samps_per_chan_written\x18\x02 \x01(\x05\"\xcb\x01\n\x1bWriteToTEDSFromArrayRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x12\n\nbit_stream\x18\x02 \x01(\x0c\x12\x41\n\x12\x62\x61sic_teds_options\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.WriteBasicTEDSOptionsH\x00\x12 \n\x16\x62\x61sic_teds_options_raw\x18\x04 \x01(\x05H\x00\x42\x19\n\x17\x62\x61sic_teds_options_enum\".\n\x1cWriteToTEDSFromArrayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc9\x01\n\x1aWriteToTEDSFromFileRequest\x12\x18\n\x10physical_channel\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x41\n\x12\x62\x61sic_teds_options\x18\x03 \x01(\x0e\x32#.nidaqmx_grpc.WriteBasicTEDSOptionsH\x00\x12 \n\x16\x62\x61sic_teds_options_raw\x18\x04 \x01(\x05H\x00\x42\x19\n\x17\x62\x61sic_teds_options_enum\"-\n\x1bWriteToTEDSFromFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05*\xe6\x01\n\x15\x42ufferUInt32Attribute\x12\'\n#BUFFER_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12$\n\x1f\x42UFFER_ATTRIBUTE_INPUT_BUF_SIZE\x10\xec\x30\x12%\n BUFFER_ATTRIBUTE_OUTPUT_BUF_SIZE\x10\xed\x30\x12*\n%BUFFER_ATTRIBUTE_INPUT_ONBRD_BUF_SIZE\x10\x8a\x46\x12+\n&BUFFER_ATTRIBUTE_OUTPUT_ONBRD_BUF_SIZE\x10\x8b\x46*\xca\x01\n\x14\x42ufferResetAttribute\x12&\n\"BUFFER_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12*\n%BUFFER_RESET_ATTRIBUTE_INPUT_BUF_SIZE\x10\xec\x30\x12+\n&BUFFER_RESET_ATTRIBUTE_OUTPUT_BUF_SIZE\x10\xed\x30\x12\x31\n,BUFFER_RESET_ATTRIBUTE_OUTPUT_ONBRD_BUF_SIZE\x10\x8b\x46*\x81\x01\n\x1c\x43\x61librationInfoBoolAttribute\x12.\n*CALIBRATIONINFO_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x31\n,CALIBRATIONINFO_ATTRIBUTE_SELF_CAL_SUPPORTED\x10\xe0\x30*\x88\x01\n\x1e\x43\x61librationInfoStringAttribute\x12\x30\n,CALIBRATIONINFO_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x34\n/CALIBRATIONINFO_ATTRIBUTE_CAL_USER_DEFINED_INFO\x10\xe1\x30*\xe4\x01\n\x1e\x43\x61librationInfoDoubleAttribute\x12\x30\n,CALIBRATIONINFO_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x31\n,CALIBRATIONINFO_ATTRIBUTE_SELF_CAL_LAST_TEMP\x10\xe4\x30\x12\x30\n+CALIBRATIONINFO_ATTRIBUTE_EXT_CAL_LAST_TEMP\x10\xe7\x30\x12+\n&CALIBRATIONINFO_ATTRIBUTE_CAL_DEV_TEMP\x10\xbb\x44*\xd2\x02\n\x1e\x43\x61librationInfoUInt32Attribute\x12\x30\n,CALIBRATIONINFO_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12;\n6CALIBRATIONINFO_ATTRIBUTE_EXT_CAL_RECOMMENDED_INTERVAL\x10\xe8\x30\x12=\n8CALIBRATIONINFO_ATTRIBUTE_CAL_USER_DEFINED_INFO_MAX_SIZE\x10\x9c\x32\x12\x37\n2CALIBRATIONINFO_ATTRIBUTE_CAL_ACC_CONNECTION_COUNT\x10\xeb_\x12I\nDCALIBRATIONINFO_ATTRIBUTE_CAL_RECOMMENDED_ACC_CONNECTION_COUNT_LIMIT\x10\xec_*\xc8K\n\x15\x43hannelInt32Attribute\x12\'\n#CHANNEL_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12/\n+CHANNEL_ATTRIBUTE_AI_RAW_SAMP_JUSTIFICATION\x10P\x12!\n\x1d\x43HANNEL_ATTRIBUTE_AI_COUPLING\x10\x64\x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_BRIDGE_CFG\x10\x87\x01\x12%\n CHANNEL_ATTRIBUTE_AO_DAC_REF_SRC\x10\xb2\x02\x12(\n#CHANNEL_ATTRIBUTE_AO_DATA_XFER_MECH\x10\xb4\x02\x12\x32\n-CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_ACTIVE_EDGE\x10\xc2\x02\x12(\n#CHANNEL_ATTRIBUTE_CI_FREQ_MEAS_METH\x10\xc4\x02\x12&\n!CHANNEL_ATTRIBUTE_CI_OUTPUT_STATE\x10\xc9\x02\x12(\n#CHANNEL_ATTRIBUTE_CI_DATA_XFER_MECH\x10\x80\x04\x12&\n!CHANNEL_ATTRIBUTE_CO_OUTPUT_STATE\x10\x94\x05\x12\x32\n-CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_ACTIVE_EDGE\x10\xc1\x06\x12%\n CHANNEL_ATTRIBUTE_AI_ACCEL_UNITS\x10\xf3\x0c\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_MEAS_TYPE\x10\x95\r\x12)\n$CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIR\x10\x96\r\x12\x31\n,CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_ACTIVE_EDGE\x10\x97\r\x12\'\n\"CHANNEL_ATTRIBUTE_AI_CURRENT_UNITS\x10\x81\x0e\x12,\n\'CHANNEL_ATTRIBUTE_CI_FREQ_STARTING_EDGE\x10\x99\x0f\x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_FREQ_UNITS\x10\x86\x10\x12+\n&CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_UNITS\x10\xa3\x10\x12\x33\n.CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_STARTING_EDGE\x10\xa5\x10\x12\x31\n,CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_EDGE\x10\xb3\x10\x12\x32\n-CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_EDGE\x10\xb4\x10\x12.\n)CHANNEL_ATTRIBUTE_CI_PERIOD_STARTING_EDGE\x10\xd2\x10\x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_RVDT_UNITS\x10\xf7\x10\x12/\n*CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_PHASE\x10\x89\x11\x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_LVDT_UNITS\x10\x90\x12\x12*\n%CHANNEL_ATTRIBUTE_AI_RESISTANCE_UNITS\x10\xd5\x12\x12&\n!CHANNEL_ATTRIBUTE_AI_STRAIN_UNITS\x10\x81\x13\x12)\n$CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_CFG\x10\x82\x13\x12\"\n\x1d\x43HANNEL_ATTRIBUTE_AI_RTD_TYPE\x10\xb2 \x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_TEMP_UNITS\x10\xb3 \x12)\n$CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_SRC\x10\xb5 \x12&\n!CHANNEL_ATTRIBUTE_AI_THRMCPL_TYPE\x10\xd0 \x12)\n$CHANNEL_ATTRIBUTE_CI_GPS_SYNC_METHOD\x10\x92!\x12\'\n\"CHANNEL_ATTRIBUTE_AI_VOLTAGE_UNITS\x10\x94!\x12\"\n\x1d\x43HANNEL_ATTRIBUTE_AI_TERM_CFG\x10\x97!\x12%\n CHANNEL_ATTRIBUTE_AO_OUTPUT_TYPE\x10\x88\"\x12\'\n\"CHANNEL_ATTRIBUTE_AO_CURRENT_UNITS\x10\x89\"\x12+\n&CHANNEL_ATTRIBUTE_DO_OUTPUT_DRIVE_TYPE\x10\xb7\"\x12*\n%CHANNEL_ATTRIBUTE_CO_PULSE_IDLE_STATE\x10\xf0\"\x12\'\n\"CHANNEL_ATTRIBUTE_AO_VOLTAGE_UNITS\x10\x84#\x12.\n)CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_UNITS\x10\xa8*\x12(\n#CHANNEL_ATTRIBUTE_AI_AUTO_ZERO_MODE\x10\xe0.\x12*\n%CHANNEL_ATTRIBUTE_AI_RESOLUTION_UNITS\x10\xe4.\x12-\n(CHANNEL_ATTRIBUTE_AI_VOLTAGE_ACRMS_UNITS\x10\xe2/\x12-\n(CHANNEL_ATTRIBUTE_AI_CURRENT_ACRMS_UNITS\x10\xe3/\x12\x33\n.CHANNEL_ATTRIBUTE_AI_BRIDGE_BALANCE_COARSE_POT\x10\xf1/\x12+\n&CHANNEL_ATTRIBUTE_AI_CURRENT_SHUNT_LOC\x10\xf2/\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_EXCIT_SRC\x10\xf4/\x12\x32\n-CHANNEL_ATTRIBUTE_AI_EXCIT_VOLTAGE_OR_CURRENT\x10\xf6/\x12(\n#CHANNEL_ATTRIBUTE_AI_EXCIT_D_COR_AC\x10\xfb/\x12\'\n\"CHANNEL_ATTRIBUTE_AI_HIGHPASS_TYPE\x10\x88\x30\x12\'\n\"CHANNEL_ATTRIBUTE_AI_BANDPASS_TYPE\x10\x8d\x30\x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_NOTCH_TYPE\x10\x91\x30\x12(\n#CHANNEL_ATTRIBUTE_AI_DATA_XFER_MECH\x10\xa1\x30\x12*\n%CHANNEL_ATTRIBUTE_AO_RESOLUTION_UNITS\x10\xab\x30\x12,\n\'CHANNEL_ATTRIBUTE_AO_DATA_XFER_REQ_COND\x10\xbc\x30\x12 \n\x1b\x43HANNEL_ATTRIBUTE_CHAN_TYPE\x10\xff\x30\x12(\n#CHANNEL_ATTRIBUTE_AI_RESISTANCE_CFG\x10\x81\x31\x12\x34\n/CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_CLK_SRC\x10\x84\x31\x12,\n\'CHANNEL_ATTRIBUTE_AI_DATA_XFER_REQ_COND\x10\x8b\x31\x12\"\n\x1d\x43HANNEL_ATTRIBUTE_AO_TERM_CFG\x10\x8e\x31\x12#\n\x1e\x43HANNEL_ATTRIBUTE_CI_MEAS_TYPE\x10\xa0\x31\x12$\n\x1f\x43HANNEL_ATTRIBUTE_CI_FREQ_UNITS\x10\xa1\x31\x12&\n!CHANNEL_ATTRIBUTE_CI_PERIOD_UNITS\x10\xa3\x31\x12+\n&CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_UNITS\x10\xa6\x31\x12+\n&CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_UNITS\x10\xa9\x31\x12,\n\'CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_UNITS\x10\xac\x31\x12+\n&CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_UNITS\x10\xaf\x31\x12%\n CHANNEL_ATTRIBUTE_CO_OUTPUT_TYPE\x10\xb5\x31\x12,\n\'CHANNEL_ATTRIBUTE_AI_AC_EXCIT_WIRE_MODE\x10\xcd\x31\x12*\n%CHANNEL_ATTRIBUTE_CO_PULSE_FREQ_UNITS\x10\xd5\x31\x12*\n%CHANNEL_ATTRIBUTE_CO_PULSE_TIME_UNITS\x10\xd6\x31\x12\x31\n,CHANNEL_ATTRIBUTE_AI_BRIDGE_BALANCE_FINE_POT\x10\xf4\x31\x12*\n%CHANNEL_ATTRIBUTE_CI_PERIOD_MEAS_METH\x10\xac\x32\x12\x30\n+CHANNEL_ATTRIBUTE_AI_LVDT_SENSITIVITY_UNITS\x10\x9a\x43\x12\x30\n+CHANNEL_ATTRIBUTE_AI_RVDT_SENSITIVITY_UNITS\x10\x9b\x43\x12\x31\n,CHANNEL_ATTRIBUTE_AI_ACCEL_SENSITIVITY_UNITS\x10\x9c\x43\x12\x31\n,CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SELECT\x10\xd5\x43\x12/\n*CHANNEL_ATTRIBUTE_CI_ENCODER_DECODING_TYPE\x10\xe6\x43\x12.\n)CHANNEL_ATTRIBUTE_AO_IDLE_OUTPUT_BEHAVIOR\x10\xc0\x44\x12(\n#CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_SRC\x10\xd3\x44\x12(\n#CHANNEL_ATTRIBUTE_DI_DATA_XFER_MECH\x10\xe3\x44\x12,\n\'CHANNEL_ATTRIBUTE_DI_DATA_XFER_REQ_COND\x10\xe4\x44\x12(\n#CHANNEL_ATTRIBUTE_DO_DATA_XFER_MECH\x10\xe6\x44\x12,\n\'CHANNEL_ATTRIBUTE_DO_DATA_XFER_REQ_COND\x10\xe7\x44\x12-\n(CHANNEL_ATTRIBUTE_AI_CHAN_CAL_SCALE_TYPE\x10\x9c\x45\x12)\n$CHANNEL_ATTRIBUTE_CI_TIMESTAMP_UNITS\x10\xb3\x45\x12\x33\n.CHANNEL_ATTRIBUTE_AI_RAW_DATA_COMPRESSION_TYPE\x10\xd8\x45\x12\x33\n.CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_STARTING_EDGE\x10\xfe\x45\x12$\n\x1f\x43HANNEL_ATTRIBUTE_DI_ACQUIRE_ON\x10\xe6R\x12\x32\n-CHANNEL_ATTRIBUTE_DO_LINE_STATES_PAUSED_STATE\x10\xe7R\x12\x30\n+CHANNEL_ATTRIBUTE_DO_LINE_STATES_DONE_STATE\x10\xe8R\x12%\n CHANNEL_ATTRIBUTE_DO_GENERATE_ON\x10\xe9R\x12&\n!CHANNEL_ATTRIBUTE_DI_LOGIC_FAMILY\x10\xedR\x12&\n!CHANNEL_ATTRIBUTE_DO_LOGIC_FAMILY\x10\xeeR\x12\x31\n,CHANNEL_ATTRIBUTE_DO_LINE_STATES_START_STATE\x10\xf2R\x12,\n\'CHANNEL_ATTRIBUTE_AI_THRMCPL_SCALE_TYPE\x10\xd0S\x12.\n)CHANNEL_ATTRIBUTE_CO_CONSTRAINED_GEN_MODE\x10\xf2S\x12)\n$CHANNEL_ATTRIBUTE_AI_ADC_TIMING_MODE\x10\xf9S\x12\'\n\"CHANNEL_ATTRIBUTE_AO_FUNC_GEN_TYPE\x10\x98T\x12\x32\n-CHANNEL_ATTRIBUTE_AO_FUNC_GEN_MODULATION_TYPE\x10\xa2T\x12\x43\n>CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS\x10\xbfU\x12\x37\n2CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_UNITS\x10\xc0U\x12(\n#CHANNEL_ATTRIBUTE_CO_DATA_XFER_MECH\x10\xcc]\x12,\n\'CHANNEL_ATTRIBUTE_CO_DATA_XFER_REQ_COND\x10\xcd]\x12,\n\'CHANNEL_ATTRIBUTE_CI_DATA_XFER_REQ_COND\x10\xfb]\x12/\n*CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_START_EDGE\x10\x85^\x12*\n%CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_UNITS\x10\x8b^\x12/\n*CHANNEL_ATTRIBUTE_CI_PULSE_TIME_START_EDGE\x10\x8d^\x12*\n%CHANNEL_ATTRIBUTE_CI_PULSE_TIME_UNITS\x10\x93^\x12\x30\n+CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_START_EDGE\x10\x95^\x12%\n CHANNEL_ATTRIBUTE_AI_FORCE_UNITS\x10\xf5^\x12(\n#CHANNEL_ATTRIBUTE_AI_PRESSURE_UNITS\x10\xf6^\x12&\n!CHANNEL_ATTRIBUTE_AI_TORQUE_UNITS\x10\xf7^\x12=\n8CHANNEL_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS\x10\x82_\x12\x31\n,CHANNEL_ATTRIBUTE_AI_BRIDGE_ELECTRICAL_UNITS\x10\x87_\x12/\n*CHANNEL_ATTRIBUTE_AI_BRIDGE_PHYSICAL_UNITS\x10\x88_\x12+\n&CHANNEL_ATTRIBUTE_AI_BRIDGE_SCALE_TYPE\x10\x89_\x12&\n!CHANNEL_ATTRIBUTE_AI_BRIDGE_UNITS\x10\x92_\x12=\n8CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ACTIVE_EDGE\x10\xb2_\x12(\n#CHANNEL_ATTRIBUTE_AI_VELOCITY_UNITS\x10\xf4_\x12@\n;CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS\x10\xf7_\x12?\n:CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_MEAS_TYPE\x10\xfd_\x12:\n5CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_TYPE\x10\xfe_\x12(\n#CHANNEL_ATTRIBUTE_CI_TIMESTAMP_EDGE\x10\xba`\x12-\n(CHANNEL_ATTRIBUTE_CI_TIMESTAMP_TIMESCALE\x10\xbb`\x12$\n\x1f\x43HANNEL_ATTRIBUTE_NAV_MEAS_TYPE\x10\xbd`\x12$\n\x1f\x43HANNEL_ATTRIBUTE_NAV_ALT_UNITS\x10\xbe`\x12$\n\x1f\x43HANNEL_ATTRIBUTE_NAV_LAT_UNITS\x10\xbf`\x12%\n CHANNEL_ATTRIBUTE_NAV_LONG_UNITS\x10\xc0`\x12\x32\n-CHANNEL_ATTRIBUTE_NAV_SPEED_OVER_GROUND_UNITS\x10\xc1`\x12&\n!CHANNEL_ATTRIBUTE_NAV_TRACK_UNITS\x10\xc2`\x12.\n)CHANNEL_ATTRIBUTE_NAV_VERT_VELOCITY_UNITS\x10\xc3`\x12*\n%CHANNEL_ATTRIBUTE_NAV_TIMESTAMP_UNITS\x10\xc4`\x12.\n)CHANNEL_ATTRIBUTE_NAV_TIMESTAMP_TIMESCALE\x10\xc5`\x12,\n\'CHANNEL_ATTRIBUTE_AI_FILTER_DELAY_UNITS\x10\xf1`\x12,\n\'CHANNEL_ATTRIBUTE_AO_FILTER_DELAY_UNITS\x10\xf6`\x12\x32\n-CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_STARTING_EDGE\x10\x92\x61\x12\x33\n.CHANNEL_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_BEHAVIOR\x10\x93\x61\x12\x37\n2CHANNEL_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_SENTINEL_VAL\x10\x94\x61\x12\'\n\"CHANNEL_ATTRIBUTE_CI_FREQ_TERM_CFG\x10\x97\x61\x12\x31\n,CHANNEL_ATTRIBUTE_CI_FREQ_LOGIC_LVL_BEHAVIOR\x10\x98\x61\x12)\n$CHANNEL_ATTRIBUTE_CI_PERIOD_TERM_CFG\x10\x99\x61\x12\x33\n.CHANNEL_ATTRIBUTE_CI_PERIOD_LOGIC_LVL_BEHAVIOR\x10\x9a\x61\x12.\n)CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_TERM_CFG\x10\x9b\x61\x12\x38\n3CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_LOGIC_LVL_BEHAVIOR\x10\x9c\x61\x12\x38\n3CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_TERM_CFG\x10\x9d\x61\x12\x42\n=CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_LOGIC_LVL_BEHAVIOR\x10\x9e\x61\x12:\n5CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM_CFG\x10\x9f\x61\x12\x44\n?CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_LOGIC_LVL_BEHAVIOR\x10\xa0\x61\x12-\n(CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_TERM_CFG\x10\xa1\x61\x12\x37\n2CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_LOGIC_LVL_BEHAVIOR\x10\xa2\x61\x12\x32\n-CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM_CFG\x10\xa3\x61\x12<\n7CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR\x10\xa4\x61\x12\x32\n-CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM_CFG\x10\xa5\x61\x12<\n7CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR\x10\xa6\x61\x12\x32\n-CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM_CFG\x10\xa7\x61\x12<\n7CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_LOGIC_LVL_BEHAVIOR\x10\xa8\x61\x12.\n)CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_TERM_CFG\x10\xa9\x61\x12\x38\n3CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_LOGIC_LVL_BEHAVIOR\x10\xaa\x61\x12\x35\n0CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM_CFG\x10\xab\x61\x12?\n:CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_LOGIC_LVL_BEHAVIOR\x10\xac\x61\x12\x36\n1CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM_CFG\x10\xad\x61\x12@\n;CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_LOGIC_LVL_BEHAVIOR\x10\xae\x61\x12.\n)CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_TERM_CFG\x10\xaf\x61\x12\x38\n3CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_LOGIC_LVL_BEHAVIOR\x10\xb0\x61\x12-\n(CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_TERM_CFG\x10\xb1\x61\x12\x37\n2CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_LOGIC_LVL_BEHAVIOR\x10\xb2\x61\x12-\n(CHANNEL_ATTRIBUTE_CI_PULSE_TIME_TERM_CFG\x10\xb3\x61\x12\x37\n2CHANNEL_ATTRIBUTE_CI_PULSE_TIME_LOGIC_LVL_BEHAVIOR\x10\xb4\x61\x12.\n)CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_TERM_CFG\x10\xb5\x61\x12\x38\n3CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_LOGIC_LVL_BEHAVIOR\x10\xb6\x61\x12\x34\n/CHANNEL_ATTRIBUTE_AI_EXCIT_IDLE_OUTPUT_BEHAVIOR\x10\xb8\x61\x12\'\n\"CHANNEL_ATTRIBUTE_AI_DIG_FLTR_TYPE\x10\xbe\x61\x12+\n&CHANNEL_ATTRIBUTE_AI_DIG_FLTR_RESPONSE\x10\xbf\x61\x12:\n5CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_SRC\x10\xca\x61\x12\x34\n/CHANNEL_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_UNITS\x10\xd8\x61\x12\x34\n/CHANNEL_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_UNITS\x10\xda\x61\x12\x38\n3CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_DECODING_TYPE\x10\xdc\x61\x12;\n6CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM_CFG\x10\xde\x61\x12\x45\n@CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR\x10\xdf\x61\x12;\n6CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM_CFG\x10\xe5\x61\x12\x45\n@CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR\x10\xe6\x61\x12\x33\n.CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM_CFG\x10\xef\x61\x12=\n8CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_LOGIC_LVL_BEHAVIOR\x10\xf0\x61\x12/\n*CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_WHEN\x10\xf5\x61\x12:\n5CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_SRC\x10\xf7\x61\x12%\n CHANNEL_ATTRIBUTE_AI_EXCIT_SENSE\x10\xfd\x61\x12&\n!CHANNEL_ATTRIBUTE_AI_CHARGE_UNITS\x10\x92\x62\x12\x38\n3CHANNEL_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY_UNITS\x10\x94\x62\x12\x43\n>CHANNEL_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY_UNITS\x10\x96\x62\x12\x30\n+CHANNEL_ATTRIBUTE_CHAN_SYNC_UNLOCK_BEHAVIOR\x10\xbc\x62\x12*\n%CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_CFG\x10\xea\x62\x12+\n&CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_TYPE\x10\xeb\x62\x12)\n$CHANNEL_ATTRIBUTE_AI_FILTER_RESPONSE\x10\xf5\x62\x12)\n$CHANNEL_ATTRIBUTE_CI_FILTER_RESPONSE\x10\xb9\x63\x12,\n\'CHANNEL_ATTRIBUTE_CI_FILTER_DELAY_UNITS\x10\xbc\x63\x12\'\n\"CHANNEL_ATTRIBUTE_PWR_OUTPUT_STATE\x10\xd7\x63\x12/\n*CHANNEL_ATTRIBUTE_PWR_IDLE_OUTPUT_BEHAVIOR\x10\xd8\x63\x12\'\n\"CHANNEL_ATTRIBUTE_PWR_REMOTE_SENSE\x10\xdb\x63*\xbcH\n\x16\x43hannelDoubleAttribute\x12(\n$CHANNEL_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\"\n\x1e\x43HANNEL_ATTRIBUTE_AI_IMPEDANCE\x10\x62\x12\'\n\"CHANNEL_ATTRIBUTE_AI_AC_EXCIT_FREQ\x10\x81\x02\x12\x1e\n\x19\x43HANNEL_ATTRIBUTE_AO_GAIN\x10\x98\x02\x12(\n#CHANNEL_ATTRIBUTE_AO_LOAD_IMPEDANCE\x10\xa1\x02\x12(\n#CHANNEL_ATTRIBUTE_CI_FREQ_MEAS_TIME\x10\xc5\x02\x12\x32\n-CHANNEL_ATTRIBUTE_CO_PULSE_FREQ_INITIAL_DELAY\x10\x99\x05\x12+\n&CHANNEL_ATTRIBUTE_AI_ACCEL_SENSITIVITY\x10\x92\r\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_FREQ_HYST\x10\x94\x10\x12-\n(CHANNEL_ATTRIBUTE_AI_FREQ_THRESH_VOLTAGE\x10\x95\x10\x12\x33\n.CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_INITIAL_ANGLE\x10\x81\x11\x12-\n(CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_VAL\x10\x88\x11\x12*\n%CHANNEL_ATTRIBUTE_AI_RVDT_SENSITIVITY\x10\x83\x12\x12\x34\n/CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_DIST_PER_PULSE\x10\x91\x12\x12\x31\n,CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_INITIAL_POS\x10\x95\x12\x12*\n%CHANNEL_ATTRIBUTE_AI_LVDT_SENSITIVITY\x10\xb9\x12\x12\x31\n,CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_GAGE_FACTOR\x10\x94\x13\x12\x33\n.CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_POISSON_RATIO\x10\x98\x13\x12\x1f\n\x1a\x43HANNEL_ATTRIBUTE_AI_RTD_A\x10\x90 \x12\x1f\n\x1a\x43HANNEL_ATTRIBUTE_AI_RTD_B\x10\x91 \x12\x1f\n\x1a\x43HANNEL_ATTRIBUTE_AI_RTD_C\x10\x93 \x12 \n\x1b\x43HANNEL_ATTRIBUTE_AI_RTD_R0\x10\xb0 \x12)\n$CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_VAL\x10\xb6 \x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_THRMSTR_R1\x10\xe1 \x12(\n#CHANNEL_ATTRIBUTE_CO_PULSE_DUTY_CYC\x10\xf6\"\x12$\n\x1f\x43HANNEL_ATTRIBUTE_CO_PULSE_FREQ\x10\xf8\"\x12\x1d\n\x18\x43HANNEL_ATTRIBUTE_AO_MAX\x10\x86#\x12\x1d\n\x18\x43HANNEL_ATTRIBUTE_AO_MIN\x10\x87#\x12*\n%CHANNEL_ATTRIBUTE_AO_OUTPUT_IMPEDANCE\x10\x90)\x12\x30\n+CHANNEL_ATTRIBUTE_AI_MICROPHONE_SENSITIVITY\x10\xb6*\x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_RESOLUTION\x10\xe5.\x12\x1d\n\x18\x43HANNEL_ATTRIBUTE_AI_MAX\x10\xdd/\x12\x1d\n\x18\x43HANNEL_ATTRIBUTE_AI_MIN\x10\xde/\x12/\n*CHANNEL_ATTRIBUTE_AI_BRIDGE_NOM_RESISTANCE\x10\xec/\x12\x30\n+CHANNEL_ATTRIBUTE_AI_BRIDGE_INITIAL_VOLTAGE\x10\xed/\x12.\n)CHANNEL_ATTRIBUTE_AI_LEAD_WIRE_RESISTANCE\x10\xee/\x12\x32\n-CHANNEL_ATTRIBUTE_AI_CURRENT_SHUNT_RESISTANCE\x10\xf3/\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_EXCIT_VAL\x10\xf5/\x12\x1f\n\x1a\x43HANNEL_ATTRIBUTE_AI_ATTEN\x10\x81\x30\x12-\n(CHANNEL_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ\x10\x83\x30\x12.\n)CHANNEL_ATTRIBUTE_AI_HIGHPASS_CUTOFF_FREQ\x10\x87\x30\x12.\n)CHANNEL_ATTRIBUTE_AI_BANDPASS_CENTER_FREQ\x10\x8c\x30\x12(\n#CHANNEL_ATTRIBUTE_AI_BANDPASS_WIDTH\x10\x8e\x30\x12+\n&CHANNEL_ATTRIBUTE_AI_NOTCH_CENTER_FREQ\x10\x90\x30\x12%\n CHANNEL_ATTRIBUTE_AI_NOTCH_WIDTH\x10\x92\x30\x12\"\n\x1d\x43HANNEL_ATTRIBUTE_AI_RNG_HIGH\x10\x95\x30\x12!\n\x1c\x43HANNEL_ATTRIBUTE_AI_RNG_LOW\x10\x96\x30\x12\x1e\n\x19\x43HANNEL_ATTRIBUTE_AI_GAIN\x10\x98\x30\x12$\n\x1f\x43HANNEL_ATTRIBUTE_AO_RESOLUTION\x10\xac\x30\x12%\n CHANNEL_ATTRIBUTE_AO_DAC_RNG_LOW\x10\xad\x30\x12&\n!CHANNEL_ATTRIBUTE_AO_DAC_RNG_HIGH\x10\xae\x30\x12%\n CHANNEL_ATTRIBUTE_AO_DAC_REF_VAL\x10\xb2\x30\x12*\n%CHANNEL_ATTRIBUTE_AI_EXCIT_ACTUAL_VAL\x10\x83\x31\x12\x39\n4CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_FREQ\x10\x85\x31\x12\x1d\n\x18\x43HANNEL_ATTRIBUTE_CI_MAX\x10\x9c\x31\x12\x1d\n\x18\x43HANNEL_ATTRIBUTE_CI_MIN\x10\x9d\x31\x12+\n&CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_RATE\x10\xb2\x31\x12)\n$CHANNEL_ATTRIBUTE_CO_PULSE_HIGH_TIME\x10\xba\x31\x12(\n#CHANNEL_ATTRIBUTE_CO_PULSE_LOW_TIME\x10\xbb\x31\x12\x32\n-CHANNEL_ATTRIBUTE_CO_PULSE_TIME_INITIAL_DELAY\x10\xbc\x31\x12+\n&CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_RATE\x10\xc2\x31\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_THRMSTR_A\x10\xc9\x31\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_THRMSTR_C\x10\xca\x31\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_THRMSTR_B\x10\xcb\x31\x12*\n%CHANNEL_ATTRIBUTE_CI_PERIOD_MEAS_TIME\x10\xad\x32\x12\x36\n1CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_GAIN_ADJUST\x10\xbf\x32\x12\x32\n-CHANNEL_ATTRIBUTE_DI_DIG_FLTR_MIN_PULSE_WIDTH\x10\xd7\x43\x12\x37\n2CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe8\x43\x12\x35\n0CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_RATE\x10\xea\x43\x12\x39\n4CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH\x10\xed\x43\x12\x37\n2CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_RATE\x10\xef\x43\x12H\nCCHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf2\x43\x12\x46\nACHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_RATE\x10\xf4\x43\x12>\n9CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf7\x43\x12<\n7CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_RATE\x10\xf9\x43\x12\x42\n=CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\xfc\x43\x12@\n;CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\xfe\x43\x12\x42\n=CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\x81\x44\x12@\n;CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\x83\x44\x12\x42\n=CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\x86\x44\x12@\n;CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\x88\x44\x12>\n9CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_MIN_PULSE_WIDTH\x10\x8b\x44\x12<\n7CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_RATE\x10\x8d\x44\x12\x45\n@CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_MIN_PULSE_WIDTH\x10\x90\x44\x12\x43\n>CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_RATE\x10\x92\x44\x12\x46\nACHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_MIN_PULSE_WIDTH\x10\x95\x44\x12\x44\n?CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_RATE\x10\x97\x44\x12>\n9CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH\x10\x9a\x44\x12<\n7CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_RATE\x10\x9c\x44\x12?\n:CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_MAX_SOUND_PRESSURE_LVL\x10\xba\x44\x12(\n#CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_VAL\x10\xd5\x44\x12?\n:CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf2\x44\x12=\n8CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE\x10\xf4\x44\x12?\n:CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf7\x44\x12=\n8CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE\x10\xf9\x44\x12(\n#CHANNEL_ATTRIBUTE_AI_VOLTAGE_DB_REF\x10\xb0S\x12/\n*CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_DB_REF\x10\xb1S\x12&\n!CHANNEL_ATTRIBUTE_AI_ACCEL_DB_REF\x10\xb2S\x12\'\n\"CHANNEL_ATTRIBUTE_AO_FUNC_GEN_FREQ\x10\x99T\x12,\n\'CHANNEL_ATTRIBUTE_AO_FUNC_GEN_AMPLITUDE\x10\x9aT\x12)\n$CHANNEL_ATTRIBUTE_AO_FUNC_GEN_OFFSET\x10\x9bT\x12\x34\n/CHANNEL_ATTRIBUTE_AO_FUNC_GEN_SQUARE_DUTY_CYCLE\x10\x9cT\x12/\n*CHANNEL_ATTRIBUTE_AO_VOLTAGE_CURRENT_LIMIT\x10\x9dT\x12/\n*CHANNEL_ATTRIBUTE_AO_FUNC_GEN_FM_DEVIATION\x10\xa3T\x12+\n&CHANNEL_ATTRIBUTE_DO_OVERCURRENT_LIMIT\x10\x85U\x12\x35\n0CHANNEL_ATTRIBUTE_DO_OVERCURRENT_REENABLE_PERIOD\x10\x87U\x12%\n CHANNEL_ATTRIBUTE_AI_PROBE_ATTEN\x10\x88U\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_DC_OFFSET\x10\x89U\x12=\n8CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY\x10\xbeU\x12\x30\n+CHANNEL_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_RATE\x10\xd5]\x12=\n8CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_MIN_PULSE_WIDTH\x10\x87^\x12;\n6CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_RATE\x10\x89^\x12=\n8CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_MIN_PULSE_WIDTH\x10\x8f^\x12;\n6CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_RATE\x10\x91^\x12>\n9CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_MIN_PULSE_WIDTH\x10\x97^\x12<\n7CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_RATE\x10\x99^\x12\x41\n<CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_RESISTANCE\x10\xf8^\x12H\nCCHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_ACTUAL_RESISTANCE\x10\xf9^\x12\x41\n<CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_RESISTANCE\x10\xfa^\x12H\nCCHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_ACTUAL_RESISTANCE\x10\xfb^\x12\x37\n2CHANNEL_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY\x10\x81_\x12.\n)CHANNEL_ATTRIBUTE_AI_BRIDGE_INITIAL_RATIO\x10\x86_\x12\x43\n>CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_ELECTRICAL_VAL\x10\x8a_\x12\x41\n<CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_PHYSICAL_VAL\x10\x8b_\x12\x44\n?CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_ELECTRICAL_VAL\x10\x8c_\x12\x42\n=CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_PHYSICAL_VAL\x10\x8d_\x12J\nECHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_MIN_PULSE_WIDTH\x10\xb4_\x12H\nCCHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_RATE\x10\xb6_\x12\x35\n0CHANNEL_ATTRIBUTE_AI_THRMCPL_LEAD_OFFSET_VOLTAGE\x10\xb8_\x12&\n!CHANNEL_ATTRIBUTE_AI_FILTER_DELAY\x10\xed_\x12\x35\n0CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_DB_REF\x10\xf5_\x12:\n5CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY\x10\xf6_\x12\x39\n4CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ORIENTATION\x10\xfc_\x12\x31\n,CHANNEL_ATTRIBUTE_AO_FILTER_DELAY_ADJUSTMENT\x10\xf2`\x12\x31\n,CHANNEL_ATTRIBUTE_AI_FILTER_DELAY_ADJUSTMENT\x10\xf4`\x12&\n!CHANNEL_ATTRIBUTE_AO_FILTER_DELAY\x10\xf5`\x12=\n8CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_MIN_PULSE_WIDTH\x10\x8f\x61\x12;\n6CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_RATE\x10\x91\x61\x12)\n$CHANNEL_ATTRIBUTE_CI_MAX_MEAS_PERIOD\x10\x95\x61\x12(\n#CHANNEL_ATTRIBUTE_CI_THRESH_VOLTAGE\x10\xb7\x61\x12\x36\n1CHANNEL_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ\x10\xc1\x61\x12\x37\n2CHANNEL_ATTRIBUTE_AI_DIG_FLTR_HIGHPASS_CUTOFF_FREQ\x10\xc2\x61\x12\x37\n2CHANNEL_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_CENTER_FREQ\x10\xc3\x61\x12\x31\n,CHANNEL_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_WIDTH\x10\xc4\x61\x12\x34\n/CHANNEL_ATTRIBUTE_AI_DIG_FLTR_NOTCH_CENTER_FREQ\x10\xc5\x61\x12.\n)CHANNEL_ATTRIBUTE_AI_DIG_FLTR_NOTCH_WIDTH\x10\xc6\x61\x12=\n8CHANNEL_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_DIST_PER_PULSE\x10\xdb\x61\x12K\nFCHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe1\x61\x12I\nDCHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\xe3\x61\x12K\nFCHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe8\x61\x12I\nDCHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\xea\x61\x12,\n\'CHANNEL_ATTRIBUTE_CI_VELOCITY_MEAS_TIME\x10\xeb\x61\x12\x43\n>CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf2\x61\x12\x41\n<CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_RATE\x10\xf4\x61\x12\x32\n-CHANNEL_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY\x10\x93\x62\x12=\n8CHANNEL_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY\x10\x95\x62\x12,\n\'CHANNEL_ATTRIBUTE_AI_DATA_XFER_MAX_RATE\x10\x97\x62\x12.\n)CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_VOLTAGE\x10\xe9\x62\x12%\n CHANNEL_ATTRIBUTE_AI_FILTER_FREQ\x10\xf4\x62\x12?\n:CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_UPPER_LIMIT\x10\x8c\x63\x12?\n:CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_LOWER_LIMIT\x10\x8d\x63\x12-\n(CHANNEL_ATTRIBUTE_CI_FREQ_THRESH_VOLTAGE\x10\xab\x63\x12#\n\x1e\x43HANNEL_ATTRIBUTE_CI_FREQ_HYST\x10\xac\x63\x12/\n*CHANNEL_ATTRIBUTE_CI_PERIOD_THRESH_VOLTAGE\x10\xad\x63\x12%\n CHANNEL_ATTRIBUTE_CI_PERIOD_HYST\x10\xae\x63\x12\x34\n/CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_THRESH_VOLTAGE\x10\xaf\x63\x12*\n%CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_HYST\x10\xb0\x63\x12>\n9CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_THRESH_VOLTAGE\x10\xb1\x63\x12\x34\n/CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_HYST\x10\xb2\x63\x12@\n;CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_THRESH_VOLTAGE\x10\xb3\x63\x12\x36\n1CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_HYST\x10\xb4\x63\x12\x39\n4CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_THRESH_VOLTAGE\x10\xb5\x63\x12/\n*CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_HYST\x10\xb6\x63\x12%\n CHANNEL_ATTRIBUTE_CI_FILTER_FREQ\x10\xb8\x63\x12&\n!CHANNEL_ATTRIBUTE_CI_FILTER_DELAY\x10\xbb\x63\x12.\n)CHANNEL_ATTRIBUTE_AO_FUNC_GEN_START_PHASE\x10\xc4\x63\x12,\n\'CHANNEL_ATTRIBUTE_AO_COMMON_MODE_OFFSET\x10\xcc\x63\x12+\n&CHANNEL_ATTRIBUTE_PWR_VOLTAGE_SETPOINT\x10\xd4\x63\x12+\n&CHANNEL_ATTRIBUTE_PWR_CURRENT_SETPOINT\x10\xd5\x63*\xd3\xf6\x01\n\x15\x43hannelResetAttribute\x12\'\n#CHANNEL_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12(\n$CHANNEL_RESET_ATTRIBUTE_AI_IMPEDANCE\x10\x62\x12\'\n#CHANNEL_RESET_ATTRIBUTE_AI_COUPLING\x10\x64\x12,\n(CHANNEL_RESET_ATTRIBUTE_AI_DITHER_ENABLE\x10h\x12*\n%CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_CFG\x10\x87\x01\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_ENABLE\x10\x94\x01\x12-\n(CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_FREQ\x10\x81\x02\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_SYNC_ENABLE\x10\x82\x02\x12$\n\x1f\x43HANNEL_RESET_ATTRIBUTE_AO_GAIN\x10\x98\x02\x12.\n)CHANNEL_RESET_ATTRIBUTE_AO_LOAD_IMPEDANCE\x10\xa1\x02\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_CONN_TO_GND\x10\xb0\x02\x12+\n&CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_SRC\x10\xb2\x02\x12/\n*CHANNEL_RESET_ATTRIBUTE_AO_REGLITCH_ENABLE\x10\xb3\x02\x12.\n)CHANNEL_RESET_ATTRIBUTE_AO_DATA_XFER_MECH\x10\xb4\x02\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_ACTIVE_EDGE\x10\xc2\x02\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_SRC\x10\xc3\x02\x12.\n)CHANNEL_RESET_ATTRIBUTE_CI_FREQ_MEAS_METH\x10\xc4\x02\x12.\n)CHANNEL_RESET_ATTRIBUTE_CI_FREQ_MEAS_TIME\x10\xc5\x02\x12(\n#CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIV\x10\xc7\x02\x12.\n)CHANNEL_RESET_ATTRIBUTE_CI_DATA_XFER_MECH\x10\x80\x04\x12-\n(CHANNEL_RESET_ATTRIBUTE_CO_AUTO_INCR_CNT\x10\x95\x05\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TICKS_INITIAL_DELAY\x10\x98\x05\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ_INITIAL_DELAY\x10\x99\x05\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_SRC\x10\xb9\x06\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_ACTIVE_EDGE\x10\xc1\x06\x12+\n&CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_UNITS\x10\xf3\x0c\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_SENSITIVITY\x10\x92\r\x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIR\x10\x96\r\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_ACTIVE_EDGE\x10\x97\r\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_INITIAL_CNT\x10\x98\r\x12-\n(CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_UNITS\x10\x81\x0e\x12,\n\'CHANNEL_RESET_ATTRIBUTE_DI_INVERT_LINES\x10\x93\x0f\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_CI_FREQ_STARTING_EDGE\x10\x99\x0f\x12*\n%CHANNEL_RESET_ATTRIBUTE_AI_FREQ_UNITS\x10\x86\x10\x12)\n$CHANNEL_RESET_ATTRIBUTE_AI_FREQ_HYST\x10\x94\x10\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AI_FREQ_THRESH_VOLTAGE\x10\x95\x10\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_UNITS\x10\xa3\x10\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_STARTING_EDGE\x10\xa5\x10\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_EDGE\x10\xb3\x10\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_EDGE\x10\xb4\x10\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_STARTING_EDGE\x10\xd2\x10\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_PULSES_PER_REV\x10\xf5\x10\x12*\n%CHANNEL_RESET_ATTRIBUTE_AI_RVDT_UNITS\x10\xf7\x10\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_INITIAL_ANGLE\x10\x81\x11\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_VAL\x10\x88\x11\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_PHASE\x10\x89\x11\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_ENABLE\x10\x90\x11\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_AI_RVDT_SENSITIVITY\x10\x83\x12\x12*\n%CHANNEL_RESET_ATTRIBUTE_AI_LVDT_UNITS\x10\x90\x12\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_DIST_PER_PULSE\x10\x91\x12\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_INITIAL_POS\x10\x95\x12\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_AI_LVDT_SENSITIVITY\x10\xb9\x12\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_AI_RESISTANCE_UNITS\x10\xd5\x12\x12,\n\'CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_UNITS\x10\x81\x13\x12/\n*CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_CFG\x10\x82\x13\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_GAGE_FACTOR\x10\x94\x13\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_POISSON_RATIO\x10\x98\x13\x12%\n CHANNEL_RESET_ATTRIBUTE_AI_RTD_A\x10\x90 \x12%\n CHANNEL_RESET_ATTRIBUTE_AI_RTD_B\x10\x91 \x12%\n CHANNEL_RESET_ATTRIBUTE_AI_RTD_C\x10\x93 \x12&\n!CHANNEL_RESET_ATTRIBUTE_AI_RTD_R0\x10\xb0 \x12(\n#CHANNEL_RESET_ATTRIBUTE_AI_RTD_TYPE\x10\xb2 \x12*\n%CHANNEL_RESET_ATTRIBUTE_AI_TEMP_UNITS\x10\xb3 \x12/\n*CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_CJC_VAL\x10\xb6 \x12,\n\'CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_TYPE\x10\xd0 \x12*\n%CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_R1\x10\xe1 \x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_GPS_SYNC_METHOD\x10\x92!\x12,\n\'CHANNEL_RESET_ATTRIBUTE_CI_GPS_SYNC_SRC\x10\x93!\x12-\n(CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_UNITS\x10\x94!\x12(\n#CHANNEL_RESET_ATTRIBUTE_AI_TERM_CFG\x10\x97!\x12-\n(CHANNEL_RESET_ATTRIBUTE_AO_CURRENT_UNITS\x10\x89\"\x12,\n\'CHANNEL_RESET_ATTRIBUTE_DO_INVERT_LINES\x10\xb3\"\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_DO_OUTPUT_DRIVE_TYPE\x10\xb7\"\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CO_PULSE_HIGH_TICKS\x10\xe9\"\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CO_PULSE_IDLE_STATE\x10\xf0\"\x12/\n*CHANNEL_RESET_ATTRIBUTE_CO_PULSE_LOW_TICKS\x10\xf1\"\x12.\n)CHANNEL_RESET_ATTRIBUTE_CO_PULSE_DUTY_CYC\x10\xf6\"\x12*\n%CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ\x10\xf8\"\x12-\n(CHANNEL_RESET_ATTRIBUTE_AO_VOLTAGE_UNITS\x10\x84#\x12#\n\x1e\x43HANNEL_RESET_ATTRIBUTE_AO_MAX\x10\x86#\x12#\n\x1e\x43HANNEL_RESET_ATTRIBUTE_AO_MIN\x10\x87#\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AO_CUSTOM_SCALE_NAME\x10\x88#\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_AO_OUTPUT_IMPEDANCE\x10\x90)\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_UNITS\x10\xa8*\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_AI_MICROPHONE_SENSITIVITY\x10\xb6*\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_AUTO_ZERO_MODE\x10\xe0.\x12#\n\x1e\x43HANNEL_RESET_ATTRIBUTE_AI_MAX\x10\xdd/\x12#\n\x1e\x43HANNEL_RESET_ATTRIBUTE_AI_MIN\x10\xde/\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AI_CUSTOM_SCALE_NAME\x10\xe0/\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_ACRMS_UNITS\x10\xe2/\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_ACRMS_UNITS\x10\xe3/\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_NOM_RESISTANCE\x10\xec/\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_INITIAL_VOLTAGE\x10\xed/\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_LEAD_WIRE_RESISTANCE\x10\xee/\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_BALANCE_COARSE_POT\x10\xf1/\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_SHUNT_LOC\x10\xf2/\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_SHUNT_RESISTANCE\x10\xf3/\x12)\n$CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_SRC\x10\xf4/\x12)\n$CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_VAL\x10\xf5/\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_VOLTAGE_OR_CURRENT\x10\xf6/\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_D_COR_AC\x10\xfb/\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_USE_FOR_SCALING\x10\xfc/\x12%\n CHANNEL_RESET_ATTRIBUTE_AI_ATTEN\x10\x81\x30\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_ENABLE\x10\x82\x30\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ\x10\x83\x30\x12/\n*CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_ENABLE\x10\x86\x30\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_CUTOFF_FREQ\x10\x87\x30\x12-\n(CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_TYPE\x10\x88\x30\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_ORDER\x10\x89\x30\x12/\n*CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_ENABLE\x10\x8b\x30\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_CENTER_FREQ\x10\x8c\x30\x12-\n(CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_TYPE\x10\x8d\x30\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_WIDTH\x10\x8e\x30\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_CENTER_FREQ\x10\x90\x30\x12*\n%CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_TYPE\x10\x91\x30\x12+\n&CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_WIDTH\x10\x92\x30\x12(\n#CHANNEL_RESET_ATTRIBUTE_AI_RNG_HIGH\x10\x95\x30\x12\'\n\"CHANNEL_RESET_ATTRIBUTE_AI_RNG_LOW\x10\x96\x30\x12$\n\x1f\x43HANNEL_RESET_ATTRIBUTE_AI_GAIN\x10\x98\x30\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_SAMP_AND_HOLD_ENABLE\x10\x9a\x30\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_MECH\x10\xa1\x30\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_AO_RESOLUTION_UNITS\x10\xab\x30\x12+\n&CHANNEL_RESET_ATTRIBUTE_AO_DAC_RNG_LOW\x10\xad\x30\x12,\n\'CHANNEL_RESET_ATTRIBUTE_AO_DAC_RNG_HIGH\x10\xae\x30\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_ALLOW_CONN_TO_GND\x10\xb0\x30\x12+\n&CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_VAL\x10\xb2\x30\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AO_USE_ONLY_ON_BRD_MEM\x10\xba\x30\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AO_DATA_XFER_REQ_COND\x10\xbc\x30\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_RESISTANCE_CFG\x10\x81\x31\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_ACTUAL_VAL\x10\x83\x31\x12:\n5CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_CLK_SRC\x10\x84\x31\x12?\n:CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_FREQ\x10\x85\x31\x12>\n9CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_DIV\x10\x86\x31\x12>\n9CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_OUT_CLK_DIV\x10\x87\x31\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_REQ_COND\x10\x8b\x31\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_MEM_MAP_ENABLE\x10\x8c\x31\x12(\n#CHANNEL_RESET_ATTRIBUTE_AO_TERM_CFG\x10\x8e\x31\x12.\n)CHANNEL_RESET_ATTRIBUTE_AO_MEM_MAP_ENABLE\x10\x8f\x31\x12(\n#CHANNEL_RESET_ATTRIBUTE_DI_TRISTATE\x10\x90\x31\x12#\n\x1e\x43HANNEL_RESET_ATTRIBUTE_CI_MAX\x10\x9c\x31\x12#\n\x1e\x43HANNEL_RESET_ATTRIBUTE_CI_MIN\x10\x9d\x31\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CI_CUSTOM_SCALE_NAME\x10\x9e\x31\x12*\n%CHANNEL_RESET_ATTRIBUTE_CI_FREQ_UNITS\x10\xa1\x31\x12)\n$CHANNEL_RESET_ATTRIBUTE_CI_FREQ_TERM\x10\xa2\x31\x12,\n\'CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_UNITS\x10\xa3\x31\x12+\n&CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_TERM\x10\xa4\x31\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_UNITS\x10\xa6\x31\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_UNITS\x10\xa9\x31\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_TERM\x10\xaa\x31\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_UNITS\x10\xac\x31\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM\x10\xad\x31\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM\x10\xae\x31\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_UNITS\x10\xaf\x31\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_TERM\x10\xb0\x31\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_RATE\x10\xb2\x31\x12@\n;CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_MASTER_TIMEBASE_DIV\x10\xb3\x31\x12/\n*CHANNEL_RESET_ATTRIBUTE_CO_PULSE_HIGH_TIME\x10\xba\x31\x12.\n)CHANNEL_RESET_ATTRIBUTE_CO_PULSE_LOW_TIME\x10\xbb\x31\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TIME_INITIAL_DELAY\x10\xbc\x31\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_RATE\x10\xc2\x31\x12@\n;CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_MASTER_TIMEBASE_DIV\x10\xc3\x31\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_TERM\x10\xc7\x31\x12)\n$CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_A\x10\xc9\x31\x12)\n$CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_C\x10\xca\x31\x12)\n$CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_B\x10\xcb\x31\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_WIRE_MODE\x10\xcd\x31\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ_UNITS\x10\xd5\x31\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TIME_UNITS\x10\xd6\x31\x12*\n%CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TERM\x10\xe1\x31\x12(\n#CHANNEL_RESET_ATTRIBUTE_DO_TRISTATE\x10\xf3\x31\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_BALANCE_FINE_POT\x10\xf4\x31\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_FORCE_READ_FROM_CHAN\x10\xf8\x31\x12\'\n\"CHANNEL_RESET_ATTRIBUTE_CHAN_DESCR\x10\xa6\x32\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_MEAS_METH\x10\xac\x32\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_MEAS_TIME\x10\xad\x32\x12*\n%CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIV\x10\xae\x32\x12<\n7CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_GAIN_ADJUST\x10\xbf\x32\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_USE_MULTIPLEXED\x10\x80\x43\x12)\n$CHANNEL_RESET_ATTRIBUTE_AI_INPUT_SRC\x10\x98\x43\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_AI_LVDT_SENSITIVITY_UNITS\x10\x9a\x43\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_AI_RVDT_SENSITIVITY_UNITS\x10\x9b\x43\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_SENSITIVITY_UNITS\x10\x9c\x43\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM\x10\x9d\x43\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM\x10\x9e\x43\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM\x10\x9f\x43\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CI_DUP_COUNT_PREVENT\x10\xac\x43\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SELECT\x10\xd5\x43\x12/\n*CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_ENABLE\x10\xd6\x43\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_MIN_PULSE_WIDTH\x10\xd7\x43\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIR_TERM\x10\xe1\x43\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_DECODING_TYPE\x10\xe6\x43\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_ENABLE\x10\xe7\x43\x12=\n8CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe8\x43\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_SRC\x10\xe9\x43\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_RATE\x10\xea\x43\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_SYNC_ENABLE\x10\xeb\x43\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_ENABLE\x10\xec\x43\x12?\n:CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH\x10\xed\x43\x12<\n7CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_SRC\x10\xee\x43\x12=\n8CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_RATE\x10\xef\x43\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_SYNC_ENABLE\x10\xf0\x43\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_ENABLE\x10\xf1\x43\x12N\nICHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf2\x43\x12K\nFCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_SRC\x10\xf3\x43\x12L\nGCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_RATE\x10\xf4\x43\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_SYNC_ENABLE\x10\xf5\x43\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_ENABLE\x10\xf6\x43\x12\x44\n?CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf7\x43\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_SRC\x10\xf8\x43\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_RATE\x10\xf9\x43\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_SYNC_ENABLE\x10\xfa\x43\x12?\n:CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_ENABLE\x10\xfb\x43\x12H\nCCHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\xfc\x43\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\xfd\x43\x12\x46\nACHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\xfe\x43\x12?\n:CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_SYNC_ENABLE\x10\xff\x43\x12?\n:CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_ENABLE\x10\x80\x44\x12H\nCCHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\x81\x44\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\x82\x44\x12\x46\nACHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\x83\x44\x12?\n:CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_SYNC_ENABLE\x10\x84\x44\x12?\n:CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_ENABLE\x10\x85\x44\x12H\nCCHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\x86\x44\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\x87\x44\x12\x46\nACHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\x88\x44\x12?\n:CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_SYNC_ENABLE\x10\x89\x44\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_ENABLE\x10\x8a\x44\x12\x44\n?CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_MIN_PULSE_WIDTH\x10\x8b\x44\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_SRC\x10\x8c\x44\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_RATE\x10\x8d\x44\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_SYNC_ENABLE\x10\x8e\x44\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_ENABLE\x10\x8f\x44\x12K\nFCHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_MIN_PULSE_WIDTH\x10\x90\x44\x12H\nCCHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_SRC\x10\x91\x44\x12I\nDCHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_RATE\x10\x92\x44\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_SYNC_ENABLE\x10\x93\x44\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_ENABLE\x10\x94\x44\x12L\nGCHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_MIN_PULSE_WIDTH\x10\x95\x44\x12I\nDCHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_SRC\x10\x96\x44\x12J\nECHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_RATE\x10\x97\x44\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_SYNC_ENABLE\x10\x98\x44\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_ENABLE\x10\x99\x44\x12\x44\n?CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH\x10\x9a\x44\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_SRC\x10\x9b\x44\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_RATE\x10\x9c\x44\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_SYNC_ENABLE\x10\x9d\x44\x12)\n$CHANNEL_RESET_ATTRIBUTE_CI_PRESCALER\x10\xb9\x44\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_MAX_SOUND_PRESSURE_LVL\x10\xba\x44\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AO_IDLE_OUTPUT_BEHAVIOR\x10\xc0\x44\x12?\n:CHANNEL_RESET_ATTRIBUTE_AO_ENHANCED_IMAGE_REJECTION_ENABLE\x10\xc1\x44\x12/\n*CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_EXT_SRC\x10\xd2\x44\x12.\n)CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_SRC\x10\xd3\x44\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_EXT_SRC\x10\xd4\x44\x12.\n)CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_VAL\x10\xd5\x44\x12.\n)CHANNEL_RESET_ATTRIBUTE_DI_DATA_XFER_MECH\x10\xe3\x44\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_DI_DATA_XFER_REQ_COND\x10\xe4\x44\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_DO_USE_ONLY_ON_BRD_MEM\x10\xe5\x44\x12.\n)CHANNEL_RESET_ATTRIBUTE_DO_DATA_XFER_MECH\x10\xe6\x44\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_DO_DATA_XFER_REQ_COND\x10\xe7\x44\x12)\n$CHANNEL_RESET_ATTRIBUTE_CO_PRESCALER\x10\xed\x44\x12<\n7CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_ENABLE\x10\xf1\x44\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf2\x44\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC\x10\xf3\x44\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE\x10\xf4\x44\x12<\n7CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_SYNC_ENABLE\x10\xf5\x44\x12<\n7CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_ENABLE\x10\xf6\x44\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf7\x44\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC\x10\xf8\x44\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE\x10\xf9\x44\x12<\n7CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_SYNC_ENABLE\x10\xfa\x44\x12?\n:CHANNEL_RESET_ATTRIBUTE_AI_ENHANCED_ALIAS_REJECTION_ENABLE\x10\x94\x45\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_ENABLE_CAL\x10\x98\x45\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_APPLY_CAL_IF_EXP\x10\x99\x45\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_SCALE_TYPE\x10\x9c\x45\x12>\n9CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_TABLE_PRE_SCALED_VALS\x10\x9d\x45\x12:\n5CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_TABLE_SCALED_VALS\x10\x9e\x45\x12;\n6CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_POLY_FORWARD_COEFF\x10\x9f\x45\x12;\n6CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_POLY_REVERSE_COEFF\x10\xa0\x45\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_VERIF_REF_VALS\x10\xa1\x45\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_VERIF_ACQ_VALS\x10\xa2\x45\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_OPERATOR_NAME\x10\xa3\x45\x12-\n(CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_DESC\x10\xa4\x45\x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_UNITS\x10\xb3\x45\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_INITIAL_SECONDS\x10\xb4\x45\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_AI_RAW_DATA_COMPRESSION_TYPE\x10\xd8\x45\x12\x46\nACHANNEL_RESET_ATTRIBUTE_AI_LOSSY_LSB_REMOVAL_COMPRESSED_SAMP_SIZE\x10\xd9\x45\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_STARTING_EDGE\x10\xfe\x45\x12:\n5CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_CUSTOM_THRESHOLD\x10\x8c\x46\x12*\n%CHANNEL_RESET_ATTRIBUTE_DI_ACQUIRE_ON\x10\xe6R\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_PAUSED_STATE\x10\xe7R\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_DONE_STATE\x10\xe8R\x12+\n&CHANNEL_RESET_ATTRIBUTE_DO_GENERATE_ON\x10\xe9R\x12.\n)CHANNEL_RESET_ATTRIBUTE_DI_MEM_MAP_ENABLE\x10\xeaR\x12.\n)CHANNEL_RESET_ATTRIBUTE_DO_MEM_MAP_ENABLE\x10\xebR\x12,\n\'CHANNEL_RESET_ATTRIBUTE_DI_LOGIC_FAMILY\x10\xedR\x12,\n\'CHANNEL_RESET_ATTRIBUTE_DO_LOGIC_FAMILY\x10\xeeR\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_START_STATE\x10\xf2R\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_DB_REF\x10\xb0S\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_DB_REF\x10\xb1S\x12,\n\'CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_DB_REF\x10\xb2S\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_SCALE_TYPE\x10\xd0S\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CO_CONSTRAINED_GEN_MODE\x10\xf2S\x12/\n*CHANNEL_RESET_ATTRIBUTE_AI_ADC_TIMING_MODE\x10\xf9S\x12-\n(CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_TYPE\x10\x98T\x12-\n(CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_FREQ\x10\x99T\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_AMPLITUDE\x10\x9aT\x12/\n*CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_OFFSET\x10\x9bT\x12:\n5CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_SQUARE_DUTY_CYCLE\x10\x9cT\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_AO_VOLTAGE_CURRENT_LIMIT\x10\x9dT\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_MODULATION_TYPE\x10\xa2T\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_FM_DEVIATION\x10\xa3T\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_LIMIT\x10\x85U\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_AUTO_REENABLE\x10\x86U\x12;\n6CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_REENABLE_PERIOD\x10\x87U\x12+\n&CHANNEL_RESET_ATTRIBUTE_AI_PROBE_ATTEN\x10\x88U\x12)\n$CHANNEL_RESET_ATTRIBUTE_AI_DC_OFFSET\x10\x89U\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AI_USB_XFER_REQ_SIZE\x10\x8eU\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AO_USB_XFER_REQ_SIZE\x10\x8fU\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_DI_USB_XFER_REQ_SIZE\x10\x90U\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_DO_USB_XFER_REQ_SIZE\x10\x91U\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CI_USB_XFER_REQ_SIZE\x10\x92U\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_CO_USB_XFER_REQ_SIZE\x10\x93U\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY\x10\xbeU\x12I\nDCHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS\x10\xbfU\x12=\n8CHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_UNITS\x10\xc0U\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CO_ENABLE_INITIAL_DELAY_ON_RETRIGGER\x10\xc9]\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_CO_USE_ONLY_ON_BRD_MEM\x10\xcb]\x12.\n)CHANNEL_RESET_ATTRIBUTE_CO_DATA_XFER_MECH\x10\xcc]\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_CO_DATA_XFER_REQ_COND\x10\xcd]\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_FREQ_ENABLE_AVERAGING\x10\xd0]\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_ENABLE_AVERAGING\x10\xd1]\x12.\n)CHANNEL_RESET_ATTRIBUTE_CI_MEM_MAP_ENABLE\x10\xd2]\x12.\n)CHANNEL_RESET_ATTRIBUTE_CO_MEM_MAP_ENABLE\x10\xd3]\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_SRC\x10\xd4]\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_RATE\x10\xd5]\x12/\n*CHANNEL_RESET_ATTRIBUTE_DI_DIG_SYNC_ENABLE\x10\xd6]\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_CI_DATA_XFER_REQ_COND\x10\xfb]\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_ENABLE_BUS_MODE\x10\xfe]\x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_TERM\x10\x84^\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_START_EDGE\x10\x85^\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_ENABLE\x10\x86^\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_MIN_PULSE_WIDTH\x10\x87^\x12@\n;CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_SRC\x10\x88^\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_RATE\x10\x89^\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_SYNC_ENABLE\x10\x8a^\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_UNITS\x10\x8b^\x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_TERM\x10\x8c^\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_START_EDGE\x10\x8d^\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_ENABLE\x10\x8e^\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_MIN_PULSE_WIDTH\x10\x8f^\x12@\n;CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_SRC\x10\x90^\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_RATE\x10\x91^\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_SYNC_ENABLE\x10\x92^\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_UNITS\x10\x93^\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_TERM\x10\x94^\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_START_EDGE\x10\x95^\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_ENABLE\x10\x96^\x12\x44\n?CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_MIN_PULSE_WIDTH\x10\x97^\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_SRC\x10\x98^\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_RATE\x10\x99^\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_SYNC_ENABLE\x10\x9a^\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_AI_ADC_CUSTOM_TIMING_MODE\x10\xeb^\x12:\n5CHANNEL_RESET_ATTRIBUTE_AI_OPEN_THRMCPL_DETECT_ENABLE\x10\xf2^\x12+\n&CHANNEL_RESET_ATTRIBUTE_AI_FORCE_UNITS\x10\xf5^\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_PRESSURE_UNITS\x10\xf6^\x12,\n\'CHANNEL_RESET_ATTRIBUTE_AI_TORQUE_UNITS\x10\xf7^\x12G\nBCHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_RESISTANCE\x10\xf8^\x12N\nICHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_ACTUAL_RESISTANCE\x10\xf9^\x12G\nBCHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_RESISTANCE\x10\xfa^\x12N\nICHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_ACTUAL_RESISTANCE\x10\xfb^\x12=\n8CHANNEL_RESET_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY\x10\x81_\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS\x10\x82_\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_INITIAL_RATIO\x10\x86_\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_ELECTRICAL_UNITS\x10\x87_\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_PHYSICAL_UNITS\x10\x88_\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SCALE_TYPE\x10\x89_\x12I\nDCHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_ELECTRICAL_VAL\x10\x8a_\x12G\nBCHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_PHYSICAL_VAL\x10\x8b_\x12J\nECHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_ELECTRICAL_VAL\x10\x8c_\x12H\nCCHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_PHYSICAL_VAL\x10\x8d_\x12<\n7CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TABLE_ELECTRICAL_VALS\x10\x8e_\x12:\n5CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TABLE_PHYSICAL_VALS\x10\x8f_\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_POLY_FORWARD_COEFF\x10\x90_\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_POLY_REVERSE_COEFF\x10\x91_\x12,\n\'CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_UNITS\x10\x92_\x12>\n9CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ENABLE\x10\xaf_\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_RESET_COUNT\x10\xb0_\x12<\n7CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM\x10\xb1_\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ACTIVE_EDGE\x10\xb2_\x12G\nBCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_ENABLE\x10\xb3_\x12P\nKCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_MIN_PULSE_WIDTH\x10\xb4_\x12M\nHCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_SRC\x10\xb5_\x12N\nICHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_RATE\x10\xb6_\x12G\nBCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_SYNC_ENABLE\x10\xb7_\x12;\n6CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_LEAD_OFFSET_VOLTAGE\x10\xb8_\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_AI_REMOVE_FILTER_DELAY\x10\xbd_\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AI_AVERAGING_WIN_SIZE\x10\xee_\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_UNITS\x10\xf4_\x12;\n6CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_DB_REF\x10\xf5_\x12@\n;CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY\x10\xf6_\x12\x46\nACHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS\x10\xf7_\x12@\n;CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_FORCE_READ_FROM_CHAN\x10\xfa_\x12?\n:CHANNEL_RESET_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ORIENTATION\x10\xfc_\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_MEAS_TYPE\x10\xfd_\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AI_USB_XFER_REQ_COUNT\x10\x80`\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AO_USB_XFER_REQ_COUNT\x10\x81`\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_DI_USB_XFER_REQ_COUNT\x10\x82`\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_DO_USB_XFER_REQ_COUNT\x10\x83`\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_CI_USB_XFER_REQ_COUNT\x10\x84`\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_CO_USB_XFER_REQ_COUNT\x10\x85`\x12.\n)CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_TERM\x10\xb9`\x12.\n)CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_EDGE\x10\xba`\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_TIMESCALE\x10\xbb`\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_NAV_CUSTOM_SCALE_NAME\x10\xbc`\x12*\n%CHANNEL_RESET_ATTRIBUTE_NAV_ALT_UNITS\x10\xbe`\x12*\n%CHANNEL_RESET_ATTRIBUTE_NAV_LAT_UNITS\x10\xbf`\x12+\n&CHANNEL_RESET_ATTRIBUTE_NAV_LONG_UNITS\x10\xc0`\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_NAV_SPEED_OVER_GROUND_UNITS\x10\xc1`\x12,\n\'CHANNEL_RESET_ATTRIBUTE_NAV_TRACK_UNITS\x10\xc2`\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_NAV_VERT_VELOCITY_UNITS\x10\xc3`\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_NAV_TIMESTAMP_UNITS\x10\xc4`\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_NAV_TIMESTAMP_TIMESCALE\x10\xc5`\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AI_FILTER_DELAY_UNITS\x10\xf1`\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY_ADJUSTMENT\x10\xf2`\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_FILTER_DELAY_ADJUSTMENT\x10\xf4`\x12,\n\'CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY\x10\xf5`\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY_UNITS\x10\xf6`\x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_TERM\x10\x8d\x61\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_ENABLE\x10\x8e\x61\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_MIN_PULSE_WIDTH\x10\x8f\x61\x12@\n;CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_SRC\x10\x90\x61\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_RATE\x10\x91\x61\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_STARTING_EDGE\x10\x92\x61\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_BEHAVIOR\x10\x93\x61\x12=\n8CHANNEL_RESET_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_SENTINEL_VAL\x10\x94\x61\x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_MAX_MEAS_PERIOD\x10\x95\x61\x12-\n(CHANNEL_RESET_ATTRIBUTE_CI_FREQ_TERM_CFG\x10\x97\x61\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_CI_FREQ_LOGIC_LVL_BEHAVIOR\x10\x98\x61\x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_TERM_CFG\x10\x99\x61\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_LOGIC_LVL_BEHAVIOR\x10\x9a\x61\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_TERM_CFG\x10\x9b\x61\x12>\n9CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_LOGIC_LVL_BEHAVIOR\x10\x9c\x61\x12>\n9CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_TERM_CFG\x10\x9d\x61\x12H\nCCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_LOGIC_LVL_BEHAVIOR\x10\x9e\x61\x12@\n;CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM_CFG\x10\x9f\x61\x12J\nECHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_LOGIC_LVL_BEHAVIOR\x10\xa0\x61\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_TERM_CFG\x10\xa1\x61\x12=\n8CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_LOGIC_LVL_BEHAVIOR\x10\xa2\x61\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM_CFG\x10\xa3\x61\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR\x10\xa4\x61\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM_CFG\x10\xa5\x61\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR\x10\xa6\x61\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM_CFG\x10\xa7\x61\x12\x42\n=CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_LOGIC_LVL_BEHAVIOR\x10\xa8\x61\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_TERM_CFG\x10\xa9\x61\x12>\n9CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_LOGIC_LVL_BEHAVIOR\x10\xaa\x61\x12;\n6CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM_CFG\x10\xab\x61\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_LOGIC_LVL_BEHAVIOR\x10\xac\x61\x12<\n7CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM_CFG\x10\xad\x61\x12\x46\nACHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_LOGIC_LVL_BEHAVIOR\x10\xae\x61\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_TERM_CFG\x10\xaf\x61\x12>\n9CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_LOGIC_LVL_BEHAVIOR\x10\xb0\x61\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_TERM_CFG\x10\xb1\x61\x12=\n8CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_LOGIC_LVL_BEHAVIOR\x10\xb2\x61\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_TERM_CFG\x10\xb3\x61\x12=\n8CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_LOGIC_LVL_BEHAVIOR\x10\xb4\x61\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_TERM_CFG\x10\xb5\x61\x12>\n9CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_LOGIC_LVL_BEHAVIOR\x10\xb6\x61\x12.\n)CHANNEL_RESET_ATTRIBUTE_CI_THRESH_VOLTAGE\x10\xb7\x61\x12:\n5CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_IDLE_OUTPUT_BEHAVIOR\x10\xb8\x61\x12/\n*CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_ENABLE\x10\xbd\x61\x12-\n(CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_TYPE\x10\xbe\x61\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_RESPONSE\x10\xbf\x61\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_ORDER\x10\xc0\x61\x12<\n7CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ\x10\xc1\x61\x12=\n8CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_HIGHPASS_CUTOFF_FREQ\x10\xc2\x61\x12=\n8CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_CENTER_FREQ\x10\xc3\x61\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_WIDTH\x10\xc4\x61\x12:\n5CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_NOTCH_CENTER_FREQ\x10\xc5\x61\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_NOTCH_WIDTH\x10\xc6\x61\x12.\n)CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_COEFF\x10\xc7\x61\x12@\n;CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_SRC\x10\xca\x61\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_UNITS\x10\xd8\x61\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_PULSES_PER_REV\x10\xd9\x61\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_UNITS\x10\xda\x61\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_DIST_PER_PULSE\x10\xdb\x61\x12>\n9CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_DECODING_TYPE\x10\xdc\x61\x12=\n8CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM\x10\xdd\x61\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM_CFG\x10\xde\x61\x12K\nFCHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR\x10\xdf\x61\x12H\nCCHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_ENABLE\x10\xe0\x61\x12Q\nLCHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe1\x61\x12N\nICHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\xe2\x61\x12O\nJCHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\xe3\x61\x12=\n8CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM\x10\xe4\x61\x12\x41\n<CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM_CFG\x10\xe5\x61\x12K\nFCHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR\x10\xe6\x61\x12H\nCCHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_ENABLE\x10\xe7\x61\x12Q\nLCHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe8\x61\x12N\nICHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\xe9\x61\x12O\nJCHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE\x10\xea\x61\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_MEAS_TIME\x10\xeb\x61\x12,\n\'CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_DIV\x10\xec\x61\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_ENABLE\x10\xed\x61\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM\x10\xee\x61\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM_CFG\x10\xef\x61\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_LOGIC_LVL_BEHAVIOR\x10\xf0\x61\x12@\n;CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_ENABLE\x10\xf1\x61\x12I\nDCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf2\x61\x12\x46\nACHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_SRC\x10\xf3\x61\x12G\nBCHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_RATE\x10\xf4\x61\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_WHEN\x10\xf5\x61\x12@\n;CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_SRC\x10\xf7\x61\x12+\n&CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_SENSE\x10\xfd\x61\x12\x37\n2CHANNEL_RESET_ATTRIBUTE_AI_OPEN_CHAN_DETECT_ENABLE\x10\xff\x61\x12,\n\'CHANNEL_RESET_ATTRIBUTE_AI_CHARGE_UNITS\x10\x92\x62\x12\x38\n3CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY\x10\x93\x62\x12>\n9CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY_UNITS\x10\x94\x62\x12\x43\n>CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY\x10\x95\x62\x12I\nDCHANNEL_RESET_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY_UNITS\x10\x96\x62\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_MAX_RATE\x10\x97\x62\x12\x36\n1CHANNEL_RESET_ATTRIBUTE_CHAN_SYNC_UNLOCK_BEHAVIOR\x10\xbc\x62\x12+\n&CHANNEL_RESET_ATTRIBUTE_AI_CHOP_ENABLE\x10\xc3\x62\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_VOLTAGE\x10\xe9\x62\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_CFG\x10\xea\x62\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_TYPE\x10\xeb\x62\x12-\n(CHANNEL_RESET_ATTRIBUTE_AI_FILTER_ENABLE\x10\xf3\x62\x12+\n&CHANNEL_RESET_ATTRIBUTE_AI_FILTER_FREQ\x10\xf4\x62\x12/\n*CHANNEL_RESET_ATTRIBUTE_AI_FILTER_RESPONSE\x10\xf5\x62\x12,\n\'CHANNEL_RESET_ATTRIBUTE_AI_FILTER_ORDER\x10\xf6\x62\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_UPPER_LIMIT\x10\x8c\x63\x12\x45\n@CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_LOWER_LIMIT\x10\x8d\x63\x12@\n;CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_ENABLE\x10\x8e\x63\x12@\n;CHANNEL_RESET_ATTRIBUTE_AI_POWER_SUPPLY_FAULT_DETECT_ENABLE\x10\x91\x63\x12\x39\n4CHANNEL_RESET_ATTRIBUTE_AI_OVERCURRENT_DETECT_ENABLE\x10\x94\x63\x12\x33\n.CHANNEL_RESET_ATTRIBUTE_CI_FREQ_THRESH_VOLTAGE\x10\xab\x63\x12)\n$CHANNEL_RESET_ATTRIBUTE_CI_FREQ_HYST\x10\xac\x63\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_THRESH_VOLTAGE\x10\xad\x63\x12+\n&CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_HYST\x10\xae\x63\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_THRESH_VOLTAGE\x10\xaf\x63\x12\x30\n+CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_HYST\x10\xb0\x63\x12\x44\n?CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_THRESH_VOLTAGE\x10\xb1\x63\x12:\n5CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_HYST\x10\xb2\x63\x12\x46\nACHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_THRESH_VOLTAGE\x10\xb3\x63\x12<\n7CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_HYST\x10\xb4\x63\x12?\n:CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_THRESH_VOLTAGE\x10\xb5\x63\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_HYST\x10\xb6\x63\x12-\n(CHANNEL_RESET_ATTRIBUTE_CI_FILTER_ENABLE\x10\xb7\x63\x12+\n&CHANNEL_RESET_ATTRIBUTE_CI_FILTER_FREQ\x10\xb8\x63\x12/\n*CHANNEL_RESET_ATTRIBUTE_CI_FILTER_RESPONSE\x10\xb9\x63\x12,\n\'CHANNEL_RESET_ATTRIBUTE_CI_FILTER_ORDER\x10\xba\x63\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_CI_FILTER_DELAY_UNITS\x10\xbc\x63\x12\x34\n/CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_START_PHASE\x10\xc4\x63\x12\x32\n-CHANNEL_RESET_ATTRIBUTE_AO_COMMON_MODE_OFFSET\x10\xcc\x63\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_PWR_VOLTAGE_SETPOINT\x10\xd4\x63\x12\x31\n,CHANNEL_RESET_ATTRIBUTE_PWR_CURRENT_SETPOINT\x10\xd5\x63\x12.\n)CHANNEL_RESET_ATTRIBUTE_PWR_OUTPUT_ENABLE\x10\xd6\x63\x12\x35\n0CHANNEL_RESET_ATTRIBUTE_PWR_IDLE_OUTPUT_BEHAVIOR\x10\xd8\x63\x12-\n(CHANNEL_RESET_ATTRIBUTE_PWR_REMOTE_SENSE\x10\xdb\x63*\x9a\'\n\x14\x43hannelBoolAttribute\x12&\n\"CHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12&\n\"CHANNEL_ATTRIBUTE_AI_DITHER_ENABLE\x10h\x12\x31\n,CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_ENABLE\x10\x94\x01\x12.\n)CHANNEL_ATTRIBUTE_AI_AC_EXCIT_SYNC_ENABLE\x10\x82\x02\x12-\n(CHANNEL_ATTRIBUTE_AO_DAC_REF_CONN_TO_GND\x10\xb0\x02\x12)\n$CHANNEL_ATTRIBUTE_AO_REGLITCH_ENABLE\x10\xb3\x02\x12$\n\x1f\x43HANNEL_ATTRIBUTE_CI_TC_REACHED\x10\xd0\x02\x12&\n!CHANNEL_ATTRIBUTE_DI_INVERT_LINES\x10\x93\x0f\x12\x30\n+CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_ENABLE\x10\x90\x11\x12&\n!CHANNEL_ATTRIBUTE_DO_INVERT_LINES\x10\xb3\"\x12/\n*CHANNEL_ATTRIBUTE_AI_EXCIT_USE_FOR_SCALING\x10\xfc/\x12(\n#CHANNEL_ATTRIBUTE_AI_LOWPASS_ENABLE\x10\x82\x30\x12)\n$CHANNEL_ATTRIBUTE_AI_HIGHPASS_ENABLE\x10\x86\x30\x12)\n$CHANNEL_ATTRIBUTE_AI_BANDPASS_ENABLE\x10\x8b\x30\x12.\n)CHANNEL_ATTRIBUTE_AI_SAMP_AND_HOLD_ENABLE\x10\x9a\x30\x12\x33\n.CHANNEL_ATTRIBUTE_AO_DAC_REF_ALLOW_CONN_TO_GND\x10\xb0\x30\x12-\n(CHANNEL_ATTRIBUTE_AO_USE_ONLY_ON_BRD_MEM\x10\xba\x30\x12(\n#CHANNEL_ATTRIBUTE_AI_MEM_MAP_ENABLE\x10\x8c\x31\x12(\n#CHANNEL_ATTRIBUTE_AO_MEM_MAP_ENABLE\x10\x8f\x31\x12\"\n\x1d\x43HANNEL_ATTRIBUTE_DI_TRISTATE\x10\x90\x31\x12\"\n\x1d\x43HANNEL_ATTRIBUTE_DO_TRISTATE\x10\xf3\x31\x12.\n)CHANNEL_ATTRIBUTE_AI_FORCE_READ_FROM_CHAN\x10\xf8\x31\x12$\n\x1f\x43HANNEL_ATTRIBUTE_CO_PULSE_DONE\x10\x8e\x32\x12/\n*CHANNEL_ATTRIBUTE_AI_EXCIT_USE_MULTIPLEXED\x10\x80\x43\x12+\n&CHANNEL_ATTRIBUTE_CI_DUP_COUNT_PREVENT\x10\xac\x43\x12)\n$CHANNEL_ATTRIBUTE_DI_DIG_FLTR_ENABLE\x10\xd6\x43\x12.\n)CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_ENABLE\x10\xe7\x43\x12.\n)CHANNEL_ATTRIBUTE_CI_FREQ_DIG_SYNC_ENABLE\x10\xeb\x43\x12\x30\n+CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_ENABLE\x10\xec\x43\x12\x30\n+CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_SYNC_ENABLE\x10\xf0\x43\x12?\n:CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_ENABLE\x10\xf1\x43\x12?\n:CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_SYNC_ENABLE\x10\xf5\x43\x12\x35\n0CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_ENABLE\x10\xf6\x43\x12\x35\n0CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_SYNC_ENABLE\x10\xfa\x43\x12\x39\n4CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_ENABLE\x10\xfb\x43\x12\x39\n4CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_SYNC_ENABLE\x10\xff\x43\x12\x39\n4CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_ENABLE\x10\x80\x44\x12\x39\n4CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_SYNC_ENABLE\x10\x84\x44\x12\x39\n4CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_ENABLE\x10\x85\x44\x12\x39\n4CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_SYNC_ENABLE\x10\x89\x44\x12\x35\n0CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_ENABLE\x10\x8a\x44\x12\x35\n0CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_SYNC_ENABLE\x10\x8e\x44\x12<\n7CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_ENABLE\x10\x8f\x44\x12<\n7CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_SYNC_ENABLE\x10\x93\x44\x12=\n8CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_ENABLE\x10\x94\x44\x12=\n8CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_SYNC_ENABLE\x10\x98\x44\x12\x35\n0CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_ENABLE\x10\x99\x44\x12\x35\n0CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_SYNC_ENABLE\x10\x9d\x44\x12\x39\n4CHANNEL_ATTRIBUTE_AO_ENHANCED_IMAGE_REJECTION_ENABLE\x10\xc1\x44\x12-\n(CHANNEL_ATTRIBUTE_DO_USE_ONLY_ON_BRD_MEM\x10\xe5\x44\x12\x36\n1CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_ENABLE\x10\xf1\x44\x12\x36\n1CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_SYNC_ENABLE\x10\xf5\x44\x12\x36\n1CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_ENABLE\x10\xf6\x44\x12\x36\n1CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_SYNC_ENABLE\x10\xfa\x44\x12\x39\n4CHANNEL_ATTRIBUTE_AI_ENHANCED_ALIAS_REJECTION_ENABLE\x10\x94\x45\x12\x35\n0CHANNEL_ATTRIBUTE_AI_CHAN_CAL_HAS_VALID_CAL_INFO\x10\x97\x45\x12-\n(CHANNEL_ATTRIBUTE_AI_CHAN_CAL_ENABLE_CAL\x10\x98\x45\x12\x33\n.CHANNEL_ATTRIBUTE_AI_CHAN_CAL_APPLY_CAL_IF_EXP\x10\x99\x45\x12)\n$CHANNEL_ATTRIBUTE_CO_RDY_FOR_NEW_VAL\x10\xff\x45\x12%\n CHANNEL_ATTRIBUTE_CHAN_IS_GLOBAL\x10\x84\x46\x12(\n#CHANNEL_ATTRIBUTE_DI_MEM_MAP_ENABLE\x10\xeaR\x12(\n#CHANNEL_ATTRIBUTE_DO_MEM_MAP_ENABLE\x10\xebR\x12!\n\x1c\x43HANNEL_ATTRIBUTE_AI_IS_TEDS\x10\x83S\x12\x33\n.CHANNEL_ATTRIBUTE_DO_OVERCURRENT_AUTO_REENABLE\x10\x86U\x12;\n6CHANNEL_ATTRIBUTE_CO_ENABLE_INITIAL_DELAY_ON_RETRIGGER\x10\xc9]\x12-\n(CHANNEL_ATTRIBUTE_CO_USE_ONLY_ON_BRD_MEM\x10\xcb]\x12/\n*CHANNEL_ATTRIBUTE_CI_FREQ_ENABLE_AVERAGING\x10\xd0]\x12\x31\n,CHANNEL_ATTRIBUTE_CI_PERIOD_ENABLE_AVERAGING\x10\xd1]\x12(\n#CHANNEL_ATTRIBUTE_CI_MEM_MAP_ENABLE\x10\xd2]\x12(\n#CHANNEL_ATTRIBUTE_CO_MEM_MAP_ENABLE\x10\xd3]\x12)\n$CHANNEL_ATTRIBUTE_DI_DIG_SYNC_ENABLE\x10\xd6]\x12\x32\n-CHANNEL_ATTRIBUTE_DI_DIG_FLTR_ENABLE_BUS_MODE\x10\xfe]\x12\x34\n/CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_ENABLE\x10\x86^\x12\x34\n/CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_SYNC_ENABLE\x10\x8a^\x12\x34\n/CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_ENABLE\x10\x8e^\x12\x34\n/CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_SYNC_ENABLE\x10\x92^\x12\x35\n0CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_ENABLE\x10\x96^\x12\x35\n0CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_SYNC_ENABLE\x10\x9a^\x12\x34\n/CHANNEL_ATTRIBUTE_AI_OPEN_THRMCPL_DETECT_ENABLE\x10\xf2^\x12\x38\n3CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ENABLE\x10\xaf_\x12\x41\n<CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_ENABLE\x10\xb3_\x12\x41\n<CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_SYNC_ENABLE\x10\xb7_\x12-\n(CHANNEL_ATTRIBUTE_AI_REMOVE_FILTER_DELAY\x10\xbd_\x12:\n5CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_FORCE_READ_FROM_CHAN\x10\xfa_\x12\x34\n/CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_ENABLE\x10\x8e\x61\x12)\n$CHANNEL_ATTRIBUTE_AI_DIG_FLTR_ENABLE\x10\xbd\x61\x12\x42\n=CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_ENABLE\x10\xe0\x61\x12\x42\n=CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_ENABLE\x10\xe7\x61\x12\x31\n,CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_ENABLE\x10\xed\x61\x12:\n5CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_ENABLE\x10\xf1\x61\x12\x31\n,CHANNEL_ATTRIBUTE_AI_OPEN_CHAN_DETECT_ENABLE\x10\xff\x61\x12%\n CHANNEL_ATTRIBUTE_AI_CHOP_ENABLE\x10\xc3\x62\x12\'\n\"CHANNEL_ATTRIBUTE_AI_FILTER_ENABLE\x10\xf3\x62\x12:\n5CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_ENABLE\x10\x8e\x63\x12:\n5CHANNEL_ATTRIBUTE_AI_POWER_SUPPLY_FAULT_DETECT_ENABLE\x10\x91\x63\x12\x33\n.CHANNEL_ATTRIBUTE_AI_OVERCURRENT_DETECT_ENABLE\x10\x94\x63\x12\'\n\"CHANNEL_ATTRIBUTE_CI_FILTER_ENABLE\x10\xb7\x63\x12(\n#CHANNEL_ATTRIBUTE_PWR_OUTPUT_ENABLE\x10\xd6\x63*\xf0\x18\n\x16\x43hannelStringAttribute\x12(\n$CHANNEL_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12*\n%CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_SRC\x10\xc3\x02\x12*\n%CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_SRC\x10\xb9\x06\x12*\n%CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_CHAN\x10\xb4 \x12&\n!CHANNEL_ATTRIBUTE_CI_GPS_SYNC_SRC\x10\x93!\x12+\n&CHANNEL_ATTRIBUTE_AO_CUSTOM_SCALE_NAME\x10\x88#\x12+\n&CHANNEL_ATTRIBUTE_AI_CUSTOM_SCALE_NAME\x10\xe0/\x12+\n&CHANNEL_ATTRIBUTE_CI_CUSTOM_SCALE_NAME\x10\x9e\x31\x12#\n\x1e\x43HANNEL_ATTRIBUTE_CI_FREQ_TERM\x10\xa2\x31\x12%\n CHANNEL_ATTRIBUTE_CI_PERIOD_TERM\x10\xa4\x31\x12*\n%CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_TERM\x10\xaa\x31\x12\x31\n,CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM\x10\xad\x31\x12\x32\n-CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM\x10\xae\x31\x12*\n%CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_TERM\x10\xb0\x31\x12*\n%CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_TERM\x10\xc7\x31\x12$\n\x1f\x43HANNEL_ATTRIBUTE_CO_PULSE_TERM\x10\xe1\x31\x12)\n$CHANNEL_ATTRIBUTE_PHYSICAL_CHAN_NAME\x10\xf5\x31\x12!\n\x1c\x43HANNEL_ATTRIBUTE_CHAN_DESCR\x10\xa6\x32\x12#\n\x1e\x43HANNEL_ATTRIBUTE_AI_INPUT_SRC\x10\x98\x43\x12.\n)CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM\x10\x9d\x43\x12.\n)CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM\x10\x9e\x43\x12.\n)CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM\x10\x9f\x43\x12$\n\x1f\x43HANNEL_ATTRIBUTE_AI_TEDS_UNITS\x10\xe0\x43\x12.\n)CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIR_TERM\x10\xe1\x43\x12\x34\n/CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_SRC\x10\xe9\x43\x12\x36\n1CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_SRC\x10\xee\x43\x12\x45\n@CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_SRC\x10\xf3\x43\x12;\n6CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_SRC\x10\xf8\x43\x12?\n:CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\xfd\x43\x12?\n:CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\x82\x44\x12?\n:CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\x87\x44\x12;\n6CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_SRC\x10\x8c\x44\x12\x42\n=CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_SRC\x10\x91\x44\x12\x43\n>CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_SRC\x10\x96\x44\x12;\n6CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_SRC\x10\x9b\x44\x12)\n$CHANNEL_ATTRIBUTE_AO_DAC_REF_EXT_SRC\x10\xd2\x44\x12,\n\'CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_EXT_SRC\x10\xd4\x44\x12<\n7CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC\x10\xf3\x44\x12<\n7CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC\x10\xf8\x44\x12\x30\n+CHANNEL_ATTRIBUTE_AI_CHAN_CAL_OPERATOR_NAME\x10\xa3\x45\x12\'\n\"CHANNEL_ATTRIBUTE_AI_CHAN_CAL_DESC\x10\xa4\x45\x12/\n*CHANNEL_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_SRC\x10\xd4]\x12)\n$CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_TERM\x10\x84^\x12:\n5CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_SRC\x10\x88^\x12)\n$CHANNEL_ATTRIBUTE_CI_PULSE_TIME_TERM\x10\x8c^\x12:\n5CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_SRC\x10\x90^\x12*\n%CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_TERM\x10\x94^\x12;\n6CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_SRC\x10\x98^\x12\x36\n1CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM\x10\xb1_\x12G\nBCHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_SRC\x10\xb5_\x12:\n5CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_STRAIN_CHANS\x10\xfb_\x12(\n#CHANNEL_ATTRIBUTE_CI_TIMESTAMP_TERM\x10\xb9`\x12,\n\'CHANNEL_ATTRIBUTE_NAV_CUSTOM_SCALE_NAME\x10\xbc`\x12)\n$CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_TERM\x10\x8d\x61\x12:\n5CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_SRC\x10\x90\x61\x12\x37\n2CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM\x10\xdd\x61\x12H\nCCHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\xe2\x61\x12\x37\n2CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM\x10\xe4\x61\x12H\nCCHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC\x10\xe9\x61\x12/\n*CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM\x10\xee\x61\x12@\n;CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_SRC\x10\xf3\x61*\xc4\x10\n\x16\x43hannelUInt32Attribute\x12(\n$CHANNEL_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\"\n\x1d\x43HANNEL_ATTRIBUTE_CI_FREQ_DIV\x10\xc7\x02\x12\x1f\n\x1a\x43HANNEL_ATTRIBUTE_CI_COUNT\x10\xc8\x02\x12\x1f\n\x1a\x43HANNEL_ATTRIBUTE_CO_COUNT\x10\x93\x05\x12\'\n\"CHANNEL_ATTRIBUTE_CO_AUTO_INCR_CNT\x10\x95\x05\x12\x33\n.CHANNEL_ATTRIBUTE_CO_PULSE_TICKS_INITIAL_DELAY\x10\x98\x05\x12\x31\n,CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_INITIAL_CNT\x10\x98\r\x12\x34\n/CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_PULSES_PER_REV\x10\xf5\x10\x12*\n%CHANNEL_ATTRIBUTE_CO_PULSE_HIGH_TICKS\x10\xe9\"\x12)\n$CHANNEL_ATTRIBUTE_CO_PULSE_LOW_TICKS\x10\xf1\"\x12(\n#CHANNEL_ATTRIBUTE_AI_HIGHPASS_ORDER\x10\x89\x30\x12\x38\n3CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_DIV\x10\x86\x31\x12\x38\n3CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_OUT_CLK_DIV\x10\x87\x31\x12:\n5CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_MASTER_TIMEBASE_DIV\x10\xb3\x31\x12:\n5CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_MASTER_TIMEBASE_DIV\x10\xc3\x31\x12$\n\x1f\x43HANNEL_ATTRIBUTE_CI_PERIOD_DIV\x10\xae\x32\x12\x34\n/CHANNEL_ATTRIBUTE_CI_NUM_POSSIBLY_INVALID_SAMPS\x10\xbc\x32\x12#\n\x1e\x43HANNEL_ATTRIBUTE_DI_NUM_LINES\x10\xf8\x42\x12#\n\x1e\x43HANNEL_ATTRIBUTE_DO_NUM_LINES\x10\xf9\x42\x12#\n\x1e\x43HANNEL_ATTRIBUTE_CI_PRESCALER\x10\xb9\x44\x12#\n\x1e\x43HANNEL_ATTRIBUTE_CO_PRESCALER\x10\xed\x44\x12\x33\n.CHANNEL_ATTRIBUTE_CI_TIMESTAMP_INITIAL_SECONDS\x10\xb4\x45\x12@\n;CHANNEL_ATTRIBUTE_AI_LOSSY_LSB_REMOVAL_COMPRESSED_SAMP_SIZE\x10\xd9\x45\x12\'\n\"CHANNEL_ATTRIBUTE_AI_RAW_SAMP_SIZE\x10\xda\x45\x12\x34\n/CHANNEL_ATTRIBUTE_AI_DATA_XFER_CUSTOM_THRESHOLD\x10\x8c\x46\x12+\n&CHANNEL_ATTRIBUTE_AI_USB_XFER_REQ_SIZE\x10\x8eU\x12+\n&CHANNEL_ATTRIBUTE_AO_USB_XFER_REQ_SIZE\x10\x8fU\x12+\n&CHANNEL_ATTRIBUTE_DI_USB_XFER_REQ_SIZE\x10\x90U\x12+\n&CHANNEL_ATTRIBUTE_DO_USB_XFER_REQ_SIZE\x10\x91U\x12+\n&CHANNEL_ATTRIBUTE_CI_USB_XFER_REQ_SIZE\x10\x92U\x12+\n&CHANNEL_ATTRIBUTE_CO_USB_XFER_REQ_SIZE\x10\x93U\x12\x30\n+CHANNEL_ATTRIBUTE_AI_ADC_CUSTOM_TIMING_MODE\x10\xeb^\x12=\n8CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_RESET_COUNT\x10\xb0_\x12,\n\'CHANNEL_ATTRIBUTE_AI_AVERAGING_WIN_SIZE\x10\xee_\x12,\n\'CHANNEL_ATTRIBUTE_AI_USB_XFER_REQ_COUNT\x10\x80`\x12,\n\'CHANNEL_ATTRIBUTE_AO_USB_XFER_REQ_COUNT\x10\x81`\x12,\n\'CHANNEL_ATTRIBUTE_DI_USB_XFER_REQ_COUNT\x10\x82`\x12,\n\'CHANNEL_ATTRIBUTE_DO_USB_XFER_REQ_COUNT\x10\x83`\x12,\n\'CHANNEL_ATTRIBUTE_CI_USB_XFER_REQ_COUNT\x10\x84`\x12,\n\'CHANNEL_ATTRIBUTE_CO_USB_XFER_REQ_COUNT\x10\x85`\x12(\n#CHANNEL_ATTRIBUTE_AI_DIG_FLTR_ORDER\x10\xc0\x61\x12=\n8CHANNEL_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_PULSES_PER_REV\x10\xd9\x61\x12&\n!CHANNEL_ATTRIBUTE_CI_VELOCITY_DIV\x10\xec\x61\x12&\n!CHANNEL_ATTRIBUTE_AI_FILTER_ORDER\x10\xf6\x62\x12&\n!CHANNEL_ATTRIBUTE_CI_FILTER_ORDER\x10\xba\x63*\xd9\x06\n\x1b\x43hannelDoubleArrayAttribute\x12.\n*CHANNEL_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12+\n&CHANNEL_ATTRIBUTE_AI_DEV_SCALING_COEFF\x10\xb0\x32\x12+\n&CHANNEL_ATTRIBUTE_AO_DEV_SCALING_COEFF\x10\xb1\x32\x12\x38\n3CHANNEL_ATTRIBUTE_AI_CHAN_CAL_TABLE_PRE_SCALED_VALS\x10\x9d\x45\x12\x34\n/CHANNEL_ATTRIBUTE_AI_CHAN_CAL_TABLE_SCALED_VALS\x10\x9e\x45\x12\x35\n0CHANNEL_ATTRIBUTE_AI_CHAN_CAL_POLY_FORWARD_COEFF\x10\x9f\x45\x12\x35\n0CHANNEL_ATTRIBUTE_AI_CHAN_CAL_POLY_REVERSE_COEFF\x10\xa0\x45\x12\x31\n,CHANNEL_ATTRIBUTE_AI_CHAN_CAL_VERIF_REF_VALS\x10\xa1\x45\x12\x31\n,CHANNEL_ATTRIBUTE_AI_CHAN_CAL_VERIF_ACQ_VALS\x10\xa2\x45\x12\x36\n1CHANNEL_ATTRIBUTE_AI_BRIDGE_TABLE_ELECTRICAL_VALS\x10\x8e_\x12\x34\n/CHANNEL_ATTRIBUTE_AI_BRIDGE_TABLE_PHYSICAL_VALS\x10\x8f_\x12\x33\n.CHANNEL_ATTRIBUTE_AI_BRIDGE_POLY_FORWARD_COEFF\x10\x90_\x12\x33\n.CHANNEL_ATTRIBUTE_AI_BRIDGE_POLY_REVERSE_COEFF\x10\x91_\x12(\n#CHANNEL_ATTRIBUTE_AI_DIG_FLTR_COEFF\x10\xc7\x61\x12\x34\n/CHANNEL_ATTRIBUTE_PWR_VOLTAGE_DEV_SCALING_COEFF\x10\xd9\x63\x12\x34\n/CHANNEL_ATTRIBUTE_PWR_CURRENT_DEV_SCALING_COEFF\x10\xda\x63*\xec\x06\n\x15\x44\x65viceStringAttribute\x12\'\n#DEVICE_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\"\n\x1d\x44\x45VICE_ATTRIBUTE_PRODUCT_TYPE\x10\xb1\x0c\x12\'\n\"DEVICE_ATTRIBUTE_AI_PHYSICAL_CHANS\x10\x9e\x46\x12\'\n\"DEVICE_ATTRIBUTE_AO_PHYSICAL_CHANS\x10\x9f\x46\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_DI_LINES\x10\xa0\x46\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_DI_PORTS\x10\xa1\x46\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_DO_LINES\x10\xa2\x46\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_DO_PORTS\x10\xa3\x46\x12\'\n\"DEVICE_ATTRIBUTE_CI_PHYSICAL_CHANS\x10\xa4\x46\x12\'\n\"DEVICE_ATTRIBUTE_CO_PHYSICAL_CHANS\x10\xa5\x46\x12.\n)DEVICE_ATTRIBUTE_CHASSIS_MODULE_DEV_NAMES\x10\xb6S\x12\x32\n-DEVICE_ATTRIBUTE_COMPACT_DAQ_CHASSIS_DEV_NAME\x10\xb7S\x12\x1f\n\x1a\x44\x45VICE_ATTRIBUTE_TERMINALS\x10\xc0T\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_TCPIP_HOSTNAME\x10\x8bU\x12\'\n\"DEVICE_ATTRIBUTE_TCPIP_ETHERNET_IP\x10\x8cU\x12\'\n\"DEVICE_ATTRIBUTE_TCPIP_WIRELESS_IP\x10\x8dU\x12-\n(DEVICE_ATTRIBUTE_ACCESSORY_PRODUCT_TYPES\x10\xed^\x12(\n#DEVICE_ATTRIBUTE_NAV_PHYSICAL_CHANS\x10\xa2`\x12\x32\n-DEVICE_ATTRIBUTE_COMPACT_RIO_CHASSIS_DEV_NAME\x10\xe1\x62\x12(\n#DEVICE_ATTRIBUTE_FIELD_DAQ_DEV_NAME\x10\xf1\x62\x12.\n)DEVICE_ATTRIBUTE_FIELD_DAQ_BANK_DEV_NAMES\x10\xf8\x62*\xfc\x07\n\x15\x44\x65viceUInt32Attribute\x12\'\n#DEVICE_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12 \n\x1b\x44\x45VICE_ATTRIBUTE_SERIAL_NUM\x10\xb2\x0c\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_PRODUCT_NUM\x10\x9d\x46\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_PCI_BUS_NUM\x10\xa7\x46\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_PCI_DEV_NUM\x10\xa8\x46\x12%\n DEVICE_ATTRIBUTE_PXI_CHASSIS_NUM\x10\xa9\x46\x12\"\n\x1d\x44\x45VICE_ATTRIBUTE_PXI_SLOT_NUM\x10\xaa\x46\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_NUM_DMA_CHANS\x10\xbc\x46\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_CI_MAX_SIZE\x10\x9fS\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_CO_MAX_SIZE\x10\xa1S\x12*\n%DEVICE_ATTRIBUTE_COMPACT_DAQ_SLOT_NUM\x10\xb8S\x12(\n#DEVICE_ATTRIBUTE_CARRIER_SERIAL_NUM\x10\x8aU\x12*\n%DEVICE_ATTRIBUTE_NAV_NUM_SURVEY_FIXES\x10\xab`\x12\x30\n+DEVICE_ATTRIBUTE_NAV_REMAINING_SURVEY_FIXES\x10\xac`\x12\"\n\x1d\x44\x45VICE_ATTRIBUTE_NAV_NUM_SATS\x10\xb1`\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_NUM_TIME_TRIGS\x10\xc1\x62\x12+\n&DEVICE_ATTRIBUTE_NUM_TIMESTAMP_ENGINES\x10\xc2\x62\x12*\n%DEVICE_ATTRIBUTE_COMPACT_RIO_SLOT_NUM\x10\xe2\x62\x12\x30\n+DEVICE_ATTRIBUTE_AI_NUM_SAMP_TIMING_ENGINES\x10\xe3\x62\x12,\n\'DEVICE_ATTRIBUTE_AI_NUM_SYNC_PULSE_SRCS\x10\xe4\x62\x12\x30\n+DEVICE_ATTRIBUTE_AO_NUM_SAMP_TIMING_ENGINES\x10\xe5\x62\x12,\n\'DEVICE_ATTRIBUTE_AO_NUM_SYNC_PULSE_SRCS\x10\xe6\x62\x12\x30\n+DEVICE_ATTRIBUTE_DI_NUM_SAMP_TIMING_ENGINES\x10\xe7\x62\x12\x30\n+DEVICE_ATTRIBUTE_DO_NUM_SAMP_TIMING_ENGINES\x10\xe8\x62*\xc8\x04\n\x13\x44\x65viceBoolAttribute\x12%\n!DEVICE_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\"\n\x1d\x44\x45VICE_ATTRIBUTE_IS_SIMULATED\x10\xca\x45\x12)\n$DEVICE_ATTRIBUTE_ANLG_TRIG_SUPPORTED\x10\x84S\x12(\n#DEVICE_ATTRIBUTE_DIG_TRIG_SUPPORTED\x10\x85S\x12\x38\n3DEVICE_ATTRIBUTE_AI_SIMULTANEOUS_SAMPLING_SUPPORTED\x10\x8fS\x12+\n&DEVICE_ATTRIBUTE_AO_SAMP_CLK_SUPPORTED\x10\x96S\x12+\n&DEVICE_ATTRIBUTE_CI_SAMP_CLK_SUPPORTED\x10\x9eS\x12+\n&DEVICE_ATTRIBUTE_CO_SAMP_CLK_SUPPORTED\x10\xdb^\x12+\n&DEVICE_ATTRIBUTE_TEDS_HWTEDS_SUPPORTED\x10\xd6_\x12)\n$DEVICE_ATTRIBUTE_TIME_TRIG_SUPPORTED\x10\x9f`\x12)\n$DEVICE_ATTRIBUTE_CI_UTC_OFFSET_READY\x10\xa1`\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_NAV_HAS_FIX\x10\xad`\x12*\n%DEVICE_ATTRIBUTE_NAV_UTC_OFFSET_READY\x10\xaf`*\xcc\x04\n\x14\x44\x65viceInt32Attribute\x12&\n\"DEVICE_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_BUS_TYPE\x10\xa6\x46\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_AI_TRIG_USAGE\x10\x86S\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_AO_TRIG_USAGE\x10\x87S\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_DI_TRIG_USAGE\x10\x88S\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_DO_TRIG_USAGE\x10\x89S\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_CI_TRIG_USAGE\x10\x8aS\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_CO_TRIG_USAGE\x10\x8bS\x12\"\n\x1d\x44\x45VICE_ATTRIBUTE_AI_COUPLINGS\x10\x94S\x12&\n!DEVICE_ATTRIBUTE_PRODUCT_CATEGORY\x10\xa9S\x12+\n&DEVICE_ATTRIBUTE_CI_CURRENT_UTC_OFFSET\x10\xa0`\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_NAV_MODE\x10\xa5`\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_NAV_ALT_REF\x10\xa9`\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_NAV_ANT_STATUS\x10\xae`\x12,\n\'DEVICE_ATTRIBUTE_NAV_CURRENT_UTC_OFFSET\x10\xb0`*\x93\x05\n\x15\x44\x65viceDoubleAttribute\x12\'\n#DEVICE_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12-\n(DEVICE_ATTRIBUTE_AI_MAX_SINGLE_CHAN_RATE\x10\x8cS\x12,\n\'DEVICE_ATTRIBUTE_AI_MAX_MULTI_CHAN_RATE\x10\x8dS\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_AI_MIN_RATE\x10\x8eS\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_AO_MAX_RATE\x10\x97S\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_AO_MIN_RATE\x10\x98S\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_DI_MAX_RATE\x10\x99S\x12!\n\x1c\x44\x45VICE_ATTRIBUTE_DO_MAX_RATE\x10\x9aS\x12%\n DEVICE_ATTRIBUTE_CI_MAX_TIMEBASE\x10\xa0S\x12%\n DEVICE_ATTRIBUTE_CO_MAX_TIMEBASE\x10\xa2S\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_NAV_PRESET_LAT\x10\xa6`\x12%\n DEVICE_ATTRIBUTE_NAV_PRESET_LONG\x10\xa7`\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_NAV_PRESET_ALT\x10\xa8`\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_NAV_PPS_COMPEN\x10\xaa`\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_NAV_PDOP\x10\xb2`\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_NAV_HDOP\x10\xb3`\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_NAV_VDOP\x10\xb4`*\xe8\x06\n\x1a\x44\x65viceDoubleArrayAttribute\x12-\n)DEVICE_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12%\n DEVICE_ATTRIBUTE_AI_VOLTAGE_RNGS\x10\x90S\x12%\n DEVICE_ATTRIBUTE_AI_CURRENT_RNGS\x10\x91S\x12\"\n\x1d\x44\x45VICE_ATTRIBUTE_AI_FREQ_RNGS\x10\x92S\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_AI_GAINS\x10\x93S\x12:\n5DEVICE_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ_DISCRETE_VALS\x10\x95S\x12%\n DEVICE_ATTRIBUTE_AO_VOLTAGE_RNGS\x10\x9bS\x12%\n DEVICE_ATTRIBUTE_AO_CURRENT_RNGS\x10\x9cS\x12\x1e\n\x19\x44\x45VICE_ATTRIBUTE_AO_GAINS\x10\x9dS\x12\x38\n3DEVICE_ATTRIBUTE_AI_VOLTAGE_INT_EXCIT_DISCRETE_VALS\x10\xc9S\x12\x35\n0DEVICE_ATTRIBUTE_AI_VOLTAGE_INT_EXCIT_RANGE_VALS\x10\xcaS\x12\x38\n3DEVICE_ATTRIBUTE_AI_CURRENT_INT_EXCIT_DISCRETE_VALS\x10\xcbS\x12\x37\n2DEVICE_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ_RANGE_VALS\x10\xcfS\x12(\n#DEVICE_ATTRIBUTE_AI_RESISTANCE_RNGS\x10\x95T\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_AI_BRIDGE_RNGS\x10\xd0_\x12\x43\n>DEVICE_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ_DISCRETE_VALS\x10\xc8\x61\x12@\n;DEVICE_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ_RANGE_VALS\x10\xc9\x61\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_AI_CHARGE_RNGS\x10\x91\x62*\xa6\x01\n\x1a\x44\x65viceUInt32ArrayAttribute\x12-\n)DEVICE_UINT32_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12,\n\'DEVICE_ATTRIBUTE_ACCESSORY_PRODUCT_NUMS\x10\xee^\x12+\n&DEVICE_ATTRIBUTE_ACCESSORY_SERIAL_NUMS\x10\xef^*\x9c\x04\n\x19\x44\x65viceInt32ArrayAttribute\x12,\n(DEVICE_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12-\n(DEVICE_ATTRIBUTE_AI_SUPPORTED_MEAS_TYPES\x10\xd2_\x12/\n*DEVICE_ATTRIBUTE_AO_SUPPORTED_OUTPUT_TYPES\x10\xd3_\x12-\n(DEVICE_ATTRIBUTE_CI_SUPPORTED_MEAS_TYPES\x10\xd4_\x12/\n*DEVICE_ATTRIBUTE_CO_SUPPORTED_OUTPUT_TYPES\x10\xd5_\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_AI_SAMP_MODES\x10\xdc_\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_AO_SAMP_MODES\x10\xdd_\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_CI_SAMP_MODES\x10\xde_\x12#\n\x1e\x44\x45VICE_ATTRIBUTE_CO_SAMP_MODES\x10\xdf_\x12.\n)DEVICE_ATTRIBUTE_NAV_SUPPORTED_MEAS_TYPES\x10\xa3`\x12$\n\x1f\x44\x45VICE_ATTRIBUTE_NAV_TRIG_USAGE\x10\xa4`\x12\'\n\"DEVICE_ATTRIBUTE_AI_DIG_FLTR_TYPES\x10\x87\x62*\x9d\x07\n\x1b\x45xportSignalDoubleAttribute\x12-\n)EXPORTSIGNAL_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12,\n\'EXPORTSIGNAL_ATTRIBUTE_START_TRIG_DELAY\x10\x81\x0b\x12\x32\n-EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_WIDTH\x10\x86\x0b\x12\x39\n4EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH\x10\xa4,\x12\x30\n+EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH\x10\xc8,\x12\x37\n2EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH\x10\xd4,\x12\x37\n2EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH\x10\xe0,\x12\x30\n+EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH\x10\xe6,\x12\x33\n.EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH\x10\x90-\x12\x34\n/EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH\x10\x94.\x12\x35\n0EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH\x10\xa0.\x12/\n*EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_WIDTH\x10\xb8.\x12\x31\n,EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_DELAY\x10\xd7.\x12\x31\n,EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_DELAY_OFFSET\x10\xc4\x43\x12,\n\'EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_DELAY\x10\xbc\x45\x12\x41\n<EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_DEASSERT_DELAY\x10\xbf\x45\x12\x32\n-EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_PULSE_WIDTH\x10\xc1\x45*\xba\t\n\x1b\x45xportSignalStringAttribute\x12-\n)EXPORTSIGNAL_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x32\n-EXPORTSIGNAL_ATTRIBUTE_START_TRIG_OUTPUT_TERM\x10\x84\x0b\x12\x30\n+EXPORTSIGNAL_ATTRIBUTE_REF_TRIG_OUTPUT_TERM\x10\x90\x0b\x12;\n6EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_START_EVENT_OUTPUT_TERM\x10\x89,\x12\x32\n-EXPORTSIGNAL_ATTRIBUTE_PAUSE_TRIG_OUTPUT_TERM\x10\x95,\x12\x39\n4EXPORTSIGNAL_ATTRIBUTE_DATA_ACTIVE_EVENT_OUTPUT_TERM\x10\xb3,\x12\x30\n+EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_OUTPUT_TERM\x10\xc5,\x12\x37\n2EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_OUTPUT_TERM\x10\xd1,\x12\x37\n2EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_OUTPUT_TERM\x10\xd7,\x12\x30\n+EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_OUTPUT_TERM\x10\xe3,\x12\x33\n.EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_OUTPUT_TERM\x10\x87-\x12\x35\n0EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_TERM\x10\x97.\x12;\n6EXPORTSIGNAL_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_OUTPUT_TERM\x10\xed\x31\x12\x39\n4EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_TIMEBASE_OUTPUT_TERM\x10\xf9\x31\x12;\n6EXPORTSIGNAL_ATTRIBUTE_CHANGE_DETECT_EVENT_OUTPUT_TERM\x10\x97\x43\x12\x41\n<EXPORTSIGNAL_ATTRIBUTE_DIVIDED_SAMP_CLK_TIMEBASE_OUTPUT_TERM\x10\xa1\x43\x12>\n9EXPORTSIGNAL_ATTRIBUTE_WATCHDOG_EXPIRED_EVENT_OUTPUT_TERM\x10\xaa\x43\x12\x38\n3EXPORTSIGNAL_ATTRIBUTE_SYNC_PULSE_EVENT_OUTPUT_TERM\x10\xbc\x44\x12\x36\n1EXPORTSIGNAL_ATTRIBUTE_10_MHZ_REF_CLK_OUTPUT_TERM\x10\xee\x44\x12:\n5EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_OUTPUT_TERM\x10\xb5\x45\x12\x32\n-EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_OUTPUT_TERM\x10\xba\x45*\xcb\x1f\n\x1a\x45xportSignalResetAttribute\x12,\n(EXPORTSIGNAL_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x38\n3EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_OUTPUT_TERM\x10\x84\x0b\x12;\n6EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_PULSE_POLARITY\x10\x85\x0b\x12\x36\n1EXPORTSIGNAL_RESET_ATTRIBUTE_REF_TRIG_OUTPUT_TERM\x10\x90\x0b\x12\x39\n4EXPORTSIGNAL_RESET_ATTRIBUTE_REF_TRIG_PULSE_POLARITY\x10\x91\x0b\x12>\n9EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_PULSE_WIDTH_UNITS\x10\x82,\x12\x41\n<EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_START_EVENT_OUTPUT_TERM\x10\x89,\x12\x38\n3EXPORTSIGNAL_RESET_ATTRIBUTE_PAUSE_TRIG_OUTPUT_TERM\x10\x95,\x12;\n6EXPORTSIGNAL_RESET_ATTRIBUTE_PAUSE_TRIG_LVL_ACTIVE_LVL\x10\x96,\x12\x45\n@EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH_UNITS\x10\xa3,\x12?\n:EXPORTSIGNAL_RESET_ATTRIBUTE_DATA_ACTIVE_EVENT_OUTPUT_TERM\x10\xb3,\x12\x42\n=EXPORTSIGNAL_RESET_ATTRIBUTE_DATA_ACTIVE_EVENT_LVL_ACTIVE_LVL\x10\xb4,\x12\x36\n1EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_OUTPUT_TERM\x10\xc5,\x12<\n7EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH_UNITS\x10\xc7,\x12\x36\n1EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH\x10\xc8,\x12\x38\n3EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_ENABLE\x10\xca,\x12=\n8EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_OUTPUT_TERM\x10\xd1,\x12@\n;EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_POLARITY\x10\xd2,\x12\x43\n>EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH_UNITS\x10\xd3,\x12=\n8EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH\x10\xd4,\x12\x42\n=EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_DIVIDE_DOWN_BY_N\x10\xd6,\x12=\n8EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_OUTPUT_TERM\x10\xd7,\x12\x43\n>EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH_UNITS\x10\xd9,\x12\x36\n1EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_OUTPUT_TERM\x10\xe3,\x12\x39\n4EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_PULSE_POLARITY\x10\xe4,\x12<\n7EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH_UNITS\x10\xe5,\x12\x39\n4EXPORTSIGNAL_RESET_ATTRIBUTE_AI_CONV_CLK_OUTPUT_TERM\x10\x87-\x12?\n:EXPORTSIGNAL_RESET_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH_UNITS\x10\x89-\x12@\n;EXPORTSIGNAL_RESET_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH_UNITS\x10\x93.\x12;\n6EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_TERM\x10\x97.\x12>\n9EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_PULSE_POLARITY\x10\x98.\x12\x41\n<EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH_UNITS\x10\x99.\x12;\n6EXPORTSIGNAL_RESET_ATTRIBUTE_REF_CLK_PULSE_WIDTH_UNITS\x10\xb7.\x12<\n7EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_OUTPUT_BEHAVIOR\x10\xc3.\x12\x41\n<EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_TOGGLE_INITIAL_STATE\x10\xc4.\x12\x38\n3EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_DELAY_UNITS\x10\xcd.\x12?\n:EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_BEHAVIOR\x10\xcf.\x12\x44\n?EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_START_EVENT_LVL_ACTIVE_LVL\x10\xd1.\x12\x37\n2EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_DELAY\x10\xd7.\x12\x41\n<EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_TOGGLE_IDLE_STATE\x10\xea\x30\x12:\n5EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_OUTPUT_BEHAVIOR\x10\xeb\x30\x12\x41\n<EXPORTSIGNAL_RESET_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_OUTPUT_TERM\x10\xed\x31\x12\x44\n?EXPORTSIGNAL_RESET_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_PULSE_POLARITY\x10\xee\x31\x12?\n:EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_OUTPUT_TERM\x10\xf9\x31\x12\x41\n<EXPORTSIGNAL_RESET_ATTRIBUTE_CHANGE_DETECT_EVENT_OUTPUT_TERM\x10\x97\x43\x12G\nBEXPORTSIGNAL_RESET_ATTRIBUTE_DIVIDED_SAMP_CLK_TIMEBASE_OUTPUT_TERM\x10\xa1\x43\x12\x44\n?EXPORTSIGNAL_RESET_ATTRIBUTE_WATCHDOG_EXPIRED_EVENT_OUTPUT_TERM\x10\xaa\x43\x12\x37\n2EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_DELAY_OFFSET\x10\xc4\x43\x12>\n9EXPORTSIGNAL_RESET_ATTRIBUTE_SYNC_PULSE_EVENT_OUTPUT_TERM\x10\xbc\x44\x12<\n7EXPORTSIGNAL_RESET_ATTRIBUTE_10_MHZ_REF_CLK_OUTPUT_TERM\x10\xee\x44\x12@\n;EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_OUTPUT_TERM\x10\xb5\x45\x12\x43\n>EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_LVL_ACTIVE_LVL\x10\xb6\x45\x12\x38\n3EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_OUTPUT_TERM\x10\xba\x45\x12<\n7EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_OUTPUT_BEHAVIOR\x10\xbb\x45\x12\x32\n-EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_DELAY\x10\xbc\x45\x12\x45\n@EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERTED_LVL\x10\xbd\x45\x12H\nCEXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERT_ON_START\x10\xbe\x45\x12G\nBEXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_DEASSERT_DELAY\x10\xbf\x45\x12;\n6EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_PULSE_POLARITY\x10\xc0\x45\x12\x38\n3EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_PULSE_WIDTH\x10\xc1\x45\x12\x44\n?EXPORTSIGNAL_RESET_ATTRIBUTE_CHANGE_DETECT_EVENT_PULSE_POLARITY\x10\x83\x46\x12\x42\n=EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND\x10\xe3R\x12S\nNEXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND_CUSTOM_THRESHOLD\x10\xe4R*\xfa\x11\n\x1a\x45xportSignalInt32Attribute\x12,\n(EXPORTSIGNAL_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x35\n0EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_POLARITY\x10\x85\x0b\x12\x33\n.EXPORTSIGNAL_ATTRIBUTE_REF_TRIG_PULSE_POLARITY\x10\x91\x0b\x12\x38\n3EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_WIDTH_UNITS\x10\x82,\x12\x35\n0EXPORTSIGNAL_ATTRIBUTE_PAUSE_TRIG_LVL_ACTIVE_LVL\x10\x96,\x12<\n7EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_POLARITY\x10\xa2,\x12?\n:EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH_UNITS\x10\xa3,\x12<\n7EXPORTSIGNAL_ATTRIBUTE_DATA_ACTIVE_EVENT_LVL_ACTIVE_LVL\x10\xb4,\x12\x33\n.EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_POLARITY\x10\xc6,\x12\x36\n1EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH_UNITS\x10\xc7,\x12:\n5EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_POLARITY\x10\xd2,\x12=\n8EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH_UNITS\x10\xd3,\x12:\n5EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_POLARITY\x10\xd8,\x12=\n8EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH_UNITS\x10\xd9,\x12\x33\n.EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_POLARITY\x10\xe4,\x12\x36\n1EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH_UNITS\x10\xe5,\x12\x36\n1EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_POLARITY\x10\x88-\x12\x39\n4EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH_UNITS\x10\x89-\x12\x37\n2EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_POLARITY\x10\x92.\x12:\n5EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH_UNITS\x10\x93.\x12\x38\n3EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_POLARITY\x10\x98.\x12;\n6EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH_UNITS\x10\x99.\x12\x32\n-EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_POLARITY\x10\xb6.\x12\x35\n0EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_WIDTH_UNITS\x10\xb7.\x12\x36\n1EXPORTSIGNAL_ATTRIBUTE_START_TRIG_OUTPUT_BEHAVIOR\x10\xc3.\x12;\n6EXPORTSIGNAL_ATTRIBUTE_START_TRIG_TOGGLE_INITIAL_STATE\x10\xc4.\x12\x32\n-EXPORTSIGNAL_ATTRIBUTE_START_TRIG_DELAY_UNITS\x10\xcd.\x12\x39\n4EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_BEHAVIOR\x10\xcf.\x12\x36\n1EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_LVL_POLARITY\x10\xd0.\x12>\n9EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_START_EVENT_LVL_ACTIVE_LVL\x10\xd1.\x12;\n6EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_TOGGLE_IDLE_STATE\x10\xea\x30\x12\x34\n/EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_OUTPUT_BEHAVIOR\x10\xeb\x30\x12>\n9EXPORTSIGNAL_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_PULSE_POLARITY\x10\xee\x31\x12=\n8EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_LVL_ACTIVE_LVL\x10\xb6\x45\x12\x36\n1EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_OUTPUT_BEHAVIOR\x10\xbb\x45\x12?\n:EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERTED_LVL\x10\xbd\x45\x12\x35\n0EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_PULSE_POLARITY\x10\xc0\x45\x12>\n9EXPORTSIGNAL_ATTRIBUTE_CHANGE_DETECT_EVENT_PULSE_POLARITY\x10\x83\x46\x12<\n7EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND\x10\xe3R*\xc0\x01\n\x19\x45xportSignalBoolAttribute\x12+\n\'EXPORTSIGNAL_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x32\n-EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_ENABLE\x10\xca,\x12\x42\n=EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERT_ON_START\x10\xbe\x45*\xd9\x01\n\x1b\x45xportSignalUInt32Attribute\x12-\n)EXPORTSIGNAL_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12<\n7EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_DIVIDE_DOWN_BY_N\x10\xd6,\x12M\nHEXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND_CUSTOM_THRESHOLD\x10\xe4R*\xa9\x01\n\x1fPersistedChannelStringAttribute\x12\x31\n-PERSISTEDCHANNEL_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12+\n&PERSISTEDCHANNEL_ATTRIBUTE_ACTIVE_CHAN\x10\xcf\x45\x12&\n!PERSISTEDCHANNEL_ATTRIBUTE_AUTHOR\x10\xd0\x45*\xc7\x01\n\x1dPersistedChannelBoolAttribute\x12/\n+PERSISTEDCHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x39\n4PERSISTEDCHANNEL_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING\x10\xd1\x45\x12:\n5PERSISTEDCHANNEL_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION\x10\xd2\x45*\xa2\x01\n\x1dPersistedScaleStringAttribute\x12/\n+PERSISTEDSCALE_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12*\n%PERSISTEDSCALE_ATTRIBUTE_ACTIVE_SCALE\x10\xd3\x45\x12$\n\x1fPERSISTEDSCALE_ATTRIBUTE_AUTHOR\x10\xd4\x45*\xbf\x01\n\x1bPersistedScaleBoolAttribute\x12-\n)PERSISTEDSCALE_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x37\n2PERSISTEDSCALE_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING\x10\xd5\x45\x12\x38\n3PERSISTEDSCALE_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION\x10\xd6\x45*\x9d\x01\n\x1cPersistedTaskStringAttribute\x12.\n*PERSISTEDTASK_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12(\n#PERSISTEDTASK_ATTRIBUTE_ACTIVE_TASK\x10\xcb\x45\x12#\n\x1ePERSISTEDTASK_ATTRIBUTE_AUTHOR\x10\xcc\x45*\xbb\x01\n\x1aPersistedTaskBoolAttribute\x12,\n(PERSISTEDTASK_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x36\n1PERSISTEDTASK_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING\x10\xcd\x45\x12\x37\n2PERSISTEDTASK_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION\x10\xce\x45*\xbe\x03\n\x1ePhysicalChannelUInt32Attribute\x12\x30\n,PHYSICALCHANNEL_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x38\n3PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_MFG_ID\x10\xda\x43\x12;\n6PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_MODEL_NUM\x10\xdb\x43\x12<\n7PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_SERIAL_NUM\x10\xdc\x43\x12=\n8PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_VERSION_NUM\x10\xdd\x43\x12:\n5PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_PORT_WIDTH\x10\xa4S\x12:\n5PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_PORT_WIDTH\x10\xa7S*\xd0\x01\n\x1ePhysicalChannelStringAttribute\x12\x30\n,PHYSICALCHANNEL_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12@\n;PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_VERSION_LETTER\x10\xde\x43\x12:\n5PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_INPUT_SRCS\x10\xd8_*\x8e\x01\n\x1dPhysicalChannelBytesAttribute\x12/\n+PHYSICALCHANNEL_BYTES_ATTRIBUTE_UNSPECIFIED\x10\x00\x12<\n7PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_BIT_STREAM\x10\xdf\x43*\x9e\x01\n#PhysicalChannelUInt32ArrayAttribute\x12\x36\n2PHYSICALCHANNEL_UINT32_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12?\n:PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_TEMPLATE_I_DS\x10\x8f\x45*\x8a\x02\n\x1dPhysicalChannelInt32Attribute\x12/\n+PHYSICALCHANNEL_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x39\n4PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_TERM_CFGS\x10\xc2\x46\x12\x39\n4PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_TERM_CFGS\x10\xa3S\x12\x42\n=PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_TYPE\x10\xee\x62*\x82\x06\n\x1cPhysicalChannelBoolAttribute\x12.\n*PHYSICALCHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x42\n=PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_SAMP_CLK_SUPPORTED\x10\xa5S\x12G\nBPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_CHANGE_DETECT_SUPPORTED\x10\xa6S\x12\x42\n=PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_SAMP_CLK_SUPPORTED\x10\xa8S\x12\x45\n@PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_ENABLE\x10\x9eT\x12M\nHPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_SHORT_DETECTED\x10\xc3]\x12:\n5PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_CHANNEL_ENABLE\x10\xe2`\x12\x37\n2PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_OVERCURRENT\x10\xe4`\x12\x44\n?PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_ENABLE\x10\xed\x62\x12\x46\nAPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_OPEN_CHAN\x10\xfc\x62\x12H\nCPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_OVERCURRENT\x10\xfd\x62*\xc2\x03\n\x1dPhysicalChannelResetAttribute\x12/\n+PHYSICALCHANNEL_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12K\nFPHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_ENABLE\x10\x9eT\x12@\n;PHYSICALCHANNEL_RESET_ATTRIBUTE_AO_POWER_AMP_CHANNEL_ENABLE\x10\xe2`\x12K\nFPHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_VOLTAGE\x10\xec\x62\x12J\nEPHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_ENABLE\x10\xed\x62\x12H\nCPHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_TYPE\x10\xee\x62*\x8e\x03\n\x1ePhysicalChannelDoubleAttribute\x12\x30\n,PHYSICALCHANNEL_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12H\nCPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_AMPLITUDE\x10\x9fT\x12\x43\n>PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_FREQ\x10\xa0T\x12\x30\n+PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_GAIN\x10\xe5`\x12\x32\n-PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_OFFSET\x10\xe6`\x12\x45\n@PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_VOLTAGE\x10\xec\x62*\xcb\x05\n\"PhysicalChannelInt32ArrayAttribute\x12\x35\n1PHYSICALCHANNEL_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x44\n?PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SUPPORTED_MEAS_TYPES\x10\xd7_\x12\x46\nAPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_SUPPORTED_OUTPUT_TYPES\x10\xd9_\x12\x44\n?PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_CI_SUPPORTED_MEAS_TYPES\x10\xda_\x12\x46\nAPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_CO_SUPPORTED_OUTPUT_TYPES\x10\xdb_\x12:\n5PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_SAMP_MODES\x10\xe0_\x12:\n5PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_SAMP_MODES\x10\xe1_\x12\x45\n@PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_NAV_SUPPORTED_MEAS_TYPES\x10\xb7`\x12O\nJPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_SUPPORTED_POWER_UP_OUTPUT_TYPES\x10\xce`\x12\x42\n=PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_TYPES\x10\xf9\x62*\xe9\x01\n#PhysicalChannelDoubleArrayAttribute\x12\x36\n2PHYSICALCHANNEL_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x39\n4PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_SCALING_COEFF\x10\xe3`\x12O\nJPHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_VOLTAGE_RANGE_VALS\x10\xfa\x62*\x83\x02\n\x12ReadInt32Attribute\x12$\n READ_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1d\n\x18READ_ATTRIBUTE_OVERWRITE\x10\x91$\x12\x1f\n\x1aREAD_ATTRIBUTE_RELATIVE_TO\x10\x8a\x32\x12\x1a\n\x15READ_ATTRIBUTE_OFFSET\x10\x8b\x32\x12\x1d\n\x18READ_ATTRIBUTE_WAIT_MODE\x10\xb2\x44\x12 \n\x1bREAD_ATTRIBUTE_LOGGING_MODE\x10\xc5]\x12*\n%READ_ATTRIBUTE_LOGGING_TDMS_OPERATION\x10\xc7]*\xf7\x05\n\x12ReadResetAttribute\x12$\n READ_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12#\n\x1eREAD_RESET_ATTRIBUTE_OVERWRITE\x10\x91$\x12-\n(READ_RESET_ATTRIBUTE_READ_ALL_AVAIL_SAMP\x10\x95$\x12*\n%READ_RESET_ATTRIBUTE_CHANNELS_TO_READ\x10\xa3\x30\x12$\n\x1fREAD_RESET_ATTRIBUTE_AUTO_START\x10\xa6\x30\x12%\n READ_RESET_ATTRIBUTE_RELATIVE_TO\x10\x8a\x32\x12 \n\x1bREAD_RESET_ATTRIBUTE_OFFSET\x10\x8b\x32\x12#\n\x1eREAD_RESET_ATTRIBUTE_WAIT_MODE\x10\xb2\x44\x12$\n\x1fREAD_RESET_ATTRIBUTE_SLEEP_TIME\x10\xb0\x45\x12+\n&READ_RESET_ATTRIBUTE_LOGGING_FILE_PATH\x10\xc4]\x12&\n!READ_RESET_ATTRIBUTE_LOGGING_MODE\x10\xc5]\x12\x31\n,READ_RESET_ATTRIBUTE_LOGGING_TDMS_GROUP_NAME\x10\xc6]\x12\x30\n+READ_RESET_ATTRIBUTE_LOGGING_TDMS_OPERATION\x10\xc7]\x12\x31\n,READ_RESET_ATTRIBUTE_LOGGING_FILE_WRITE_SIZE\x10\xc3_\x12\x39\n4READ_RESET_ATTRIBUTE_LOGGING_FILE_PREALLOCATION_SIZE\x10\xc6_\x12\'\n\"READ_RESET_ATTRIBUTE_LOGGING_PAUSE\x10\xe3_\x12\x30\n+READ_RESET_ATTRIBUTE_LOGGING_SAMPS_PER_FILE\x10\xe4_*\x8d\x08\n\x11ReadBoolAttribute\x12#\n\x1fREAD_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\'\n\"READ_ATTRIBUTE_READ_ALL_AVAIL_SAMP\x10\x95$\x12\x1e\n\x19READ_ATTRIBUTE_AUTO_START\x10\xa6\x30\x12*\n%READ_ATTRIBUTE_OVERLOADED_CHANS_EXIST\x10\xf4\x42\x12\x30\n+READ_ATTRIBUTE_CHANGE_DETECT_HAS_OVERFLOWED\x10\x94\x43\x12+\n&READ_ATTRIBUTE_OVERCURRENT_CHANS_EXIST\x10\xe6S\x12\x31\n,READ_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS_EXIST\x10\x89T\x12,\n\'READ_ATTRIBUTE_OPEN_THRMCPL_CHANS_EXIST\x10\x96U\x12\x37\n2READ_ATTRIBUTE_COMMON_MODE_RANGE_ERROR_CHANS_EXIST\x10\x98U\x12;\n6READ_ATTRIBUTE_ACCESSORY_INSERTION_OR_REMOVAL_DETECTED\x10\xf0^\x12!\n\x1cREAD_ATTRIBUTE_LOGGING_PAUSE\x10\xe3_\x12 \n\x1bREAD_ATTRIBUTE_NAV_FIX_LOST\x10\xb5`\x12/\n*READ_ATTRIBUTE_OVERTEMPERATURE_CHANS_EXIST\x10\x81\x61\x12+\n&READ_ATTRIBUTE_EXCIT_FAULT_CHANS_EXIST\x10\x88\x61\x12$\n\x1fREAD_ATTRIBUTE_OPEN_CHANS_EXIST\x10\x80\x62\x12,\n\'READ_ATTRIBUTE_PLL_UNLOCKED_CHANS_EXIST\x10\x98\x62\x12-\n(READ_ATTRIBUTE_SYNC_UNLOCKED_CHANS_EXIST\x10\xbd\x62\x12\x32\n-READ_ATTRIBUTE_INPUT_LIMITS_FAULT_CHANS_EXIST\x10\x8f\x63\x12\x32\n-READ_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS_EXIST\x10\x92\x63\x12\x32\n-READ_ATTRIBUTE_REMOTE_SENSE_ERROR_CHANS_EXIST\x10\xdd\x63\x12/\n*READ_ATTRIBUTE_AUX_POWER_ERROR_CHANS_EXIST\x10\xdf\x63\x12\x35\n0READ_ATTRIBUTE_REVERSE_VOLTAGE_ERROR_CHANS_EXIST\x10\xe6\x63*\xf2\x01\n\x13ReadUInt64Attribute\x12%\n!READ_UINT64_ATTRIBUTE_UNSPECIFIED\x10\x00\x12!\n\x1cREAD_ATTRIBUTE_CURR_READ_POS\x10\xa1$\x12\x30\n+READ_ATTRIBUTE_TOTAL_SAMP_PER_CHAN_ACQUIRED\x10\xaa\x32\x12\x33\n.READ_ATTRIBUTE_LOGGING_FILE_PREALLOCATION_SIZE\x10\xc6_\x12*\n%READ_ATTRIBUTE_LOGGING_SAMPS_PER_FILE\x10\xe4_*\x87\x02\n\x13ReadUInt32Attribute\x12%\n!READ_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\'\n\"READ_ATTRIBUTE_AVAIL_SAMP_PER_CHAN\x10\xa3$\x12\"\n\x1dREAD_ATTRIBUTE_RAW_DATA_WIDTH\x10\xfa\x42\x12\x1d\n\x18READ_ATTRIBUTE_NUM_CHANS\x10\xfb\x42\x12\x30\n+READ_ATTRIBUTE_DIGITAL_LINES_BYTES_PER_CHAN\x10\xfc\x42\x12+\n&READ_ATTRIBUTE_LOGGING_FILE_WRITE_SIZE\x10\xc3_*\x9b\x07\n\x13ReadStringAttribute\x12%\n!READ_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12$\n\x1fREAD_ATTRIBUTE_CHANNELS_TO_READ\x10\xa3\x30\x12$\n\x1fREAD_ATTRIBUTE_OVERLOADED_CHANS\x10\xf5\x42\x12%\n READ_ATTRIBUTE_OVERCURRENT_CHANS\x10\xe7S\x12+\n&READ_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS\x10\x8aT\x12&\n!READ_ATTRIBUTE_OPEN_THRMCPL_CHANS\x10\x97U\x12\x31\n,READ_ATTRIBUTE_COMMON_MODE_RANGE_ERROR_CHANS\x10\x99U\x12%\n READ_ATTRIBUTE_LOGGING_FILE_PATH\x10\xc4]\x12+\n&READ_ATTRIBUTE_LOGGING_TDMS_GROUP_NAME\x10\xc6]\x12=\n8READ_ATTRIBUTE_DEVS_WITH_INSERTED_OR_REMOVED_ACCESSORIES\x10\xf1^\x12)\n$READ_ATTRIBUTE_OVERTEMPERATURE_CHANS\x10\x82\x61\x12%\n READ_ATTRIBUTE_EXCIT_FAULT_CHANS\x10\x89\x61\x12\x1e\n\x19READ_ATTRIBUTE_OPEN_CHANS\x10\x81\x62\x12&\n!READ_ATTRIBUTE_OPEN_CHANS_DETAILS\x10\x82\x62\x12&\n!READ_ATTRIBUTE_PLL_UNLOCKED_CHANS\x10\x99\x62\x12\'\n\"READ_ATTRIBUTE_SYNC_UNLOCKED_CHANS\x10\xbe\x62\x12,\n\'READ_ATTRIBUTE_INPUT_LIMITS_FAULT_CHANS\x10\x90\x63\x12,\n\'READ_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS\x10\x93\x63\x12,\n\'READ_ATTRIBUTE_REMOTE_SENSE_ERROR_CHANS\x10\xde\x63\x12)\n$READ_ATTRIBUTE_AUX_POWER_ERROR_CHANS\x10\xe0\x63\x12/\n*READ_ATTRIBUTE_REVERSE_VOLTAGE_ERROR_CHANS\x10\xe7\x63*\\\n\x13ReadDoubleAttribute\x12%\n!READ_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1e\n\x19READ_ATTRIBUTE_SLEEP_TIME\x10\xb0\x45*q\n\x17RealTimeUInt32Attribute\x12)\n%REALTIME_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12+\n&REALTIME_ATTRIBUTE_NUM_OF_WARMUP_ITERS\x10\xed\x45*\xd6\x02\n\x16RealTimeResetAttribute\x12(\n$REALTIME_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x31\n,REALTIME_RESET_ATTRIBUTE_NUM_OF_WARMUP_ITERS\x10\xed\x45\x12:\n5REALTIME_RESET_ATTRIBUTE_CONV_LATE_ERRORS_TO_WARNINGS\x10\xee\x45\x12>\n9REALTIME_RESET_ATTRIBUTE_WAIT_FOR_NEXT_SAMP_CLK_WAIT_MODE\x10\xef\x45\x12\x30\n+REALTIME_RESET_ATTRIBUTE_REPORT_MISSED_SAMP\x10\x99\x46\x12\x31\n,REALTIME_RESET_ATTRIBUTE_WRITE_RECOVERY_MODE\x10\x9a\x46*\xa2\x01\n\x15RealTimeBoolAttribute\x12\'\n#REALTIME_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x34\n/REALTIME_ATTRIBUTE_CONV_LATE_ERRORS_TO_WARNINGS\x10\xee\x45\x12*\n%REALTIME_ATTRIBUTE_REPORT_MISSED_SAMP\x10\x99\x46*\xa9\x01\n\x16RealTimeInt32Attribute\x12(\n$REALTIME_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x38\n3REALTIME_ATTRIBUTE_WAIT_FOR_NEXT_SAMP_CLK_WAIT_MODE\x10\xef\x45\x12+\n&REALTIME_ATTRIBUTE_WRITE_RECOVERY_MODE\x10\x9a\x46*}\n\x14ScaleStringAttribute\x12&\n\"SCALE_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1a\n\x15SCALE_ATTRIBUTE_DESCR\x10\xa6$\x12!\n\x1cSCALE_ATTRIBUTE_SCALED_UNITS\x10\x9b\x32*\xa0\x02\n\x14ScaleDoubleAttribute\x12&\n\"SCALE_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1e\n\x19SCALE_ATTRIBUTE_LIN_SLOPE\x10\xa7$\x12$\n\x1fSCALE_ATTRIBUTE_LIN_Y_INTERCEPT\x10\xa8$\x12#\n\x1eSCALE_ATTRIBUTE_MAP_SCALED_MAX\x10\xa9$\x12#\n\x1eSCALE_ATTRIBUTE_MAP_SCALED_MIN\x10\xb0$\x12\'\n\"SCALE_ATTRIBUTE_MAP_PRE_SCALED_MAX\x10\xb1$\x12\'\n\"SCALE_ATTRIBUTE_MAP_PRE_SCALED_MIN\x10\xb2$*\xef\x01\n\x19ScaleDoubleArrayAttribute\x12,\n(SCALE_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\'\n\"SCALE_ATTRIBUTE_POLY_FORWARD_COEFF\x10\xb4$\x12\'\n\"SCALE_ATTRIBUTE_POLY_REVERSE_COEFF\x10\xb5$\x12&\n!SCALE_ATTRIBUTE_TABLE_SCALED_VALS\x10\xb6$\x12*\n%SCALE_ATTRIBUTE_TABLE_PRE_SCALED_VALS\x10\xb7$*~\n\x13ScaleInt32Attribute\x12%\n!SCALE_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12%\n SCALE_ATTRIBUTE_PRE_SCALED_UNITS\x10\xf7\x31\x12\x19\n\x14SCALE_ATTRIBUTE_TYPE\x10\xa9\x32*\xc0\x01\n\x15SystemStringAttribute\x12\'\n#SYSTEM_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\"\n\x1dSYSTEM_ATTRIBUTE_GLOBAL_CHANS\x10\xe5$\x12\x1c\n\x17SYSTEM_ATTRIBUTE_SCALES\x10\xe6$\x12\x1b\n\x16SYSTEM_ATTRIBUTE_TASKS\x10\xe7$\x12\x1f\n\x1aSYSTEM_ATTRIBUTE_DEV_NAMES\x10\xbb\x32*\xc2\x01\n\x15SystemUInt32Attribute\x12\'\n#SYSTEM_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12)\n$SYSTEM_ATTRIBUTE_NIDAQ_MAJOR_VERSION\x10\xf2$\x12)\n$SYSTEM_ATTRIBUTE_NIDAQ_MINOR_VERSION\x10\xa3\x32\x12*\n%SYSTEM_ATTRIBUTE_NIDAQ_UPDATE_VERSION\x10\xa2^*\x91\x01\n\x13TaskStringAttribute\x12%\n!TASK_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1c\n\x17TASK_ATTRIBUTE_CHANNELS\x10\xf3$\x12\x18\n\x13TASK_ATTRIBUTE_NAME\x10\xf6$\x12\x1b\n\x16TASK_ATTRIBUTE_DEVICES\x10\x8e\x46*V\n\x11TaskBoolAttribute\x12#\n\x1fTASK_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1c\n\x17TASK_ATTRIBUTE_COMPLETE\x10\xf4$*|\n\x13TaskUInt32Attribute\x12%\n!TASK_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1d\n\x18TASK_ATTRIBUTE_NUM_CHANS\x10\x81\x43\x12\x1f\n\x1aTASK_ATTRIBUTE_NUM_DEVICES\x10\xbaS*\xb0\x06\n\x14TimingInt32Attribute\x12&\n\"TIMING_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12*\n%TIMING_ATTRIBUTE_SAMP_QUANT_SAMP_MODE\x10\x80&\x12*\n%TIMING_ATTRIBUTE_SAMP_CLK_ACTIVE_EDGE\x10\x81&\x12\x35\n0TIMING_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY_UNITS\x10\x84&\x12*\n%TIMING_ATTRIBUTE_AI_CONV_TIMEBASE_SRC\x10\xb9&\x12&\n!TIMING_ATTRIBUTE_SAMP_TIMING_TYPE\x10\xc7&\x12)\n$TIMING_ATTRIBUTE_AI_CONV_ACTIVE_EDGE\x10\xd3\x30\x12\x33\n.TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_ACTIVE_EDGE\x10\xec\x31\x12%\n TIMING_ATTRIBUTE_HSHK_START_COND\x10\xc3\x45\x12\x31\n,TIMING_ATTRIBUTE_HSHK_SAMPLE_INPUT_DATA_WHEN\x10\xc4\x45\x12\x31\n,TIMING_ATTRIBUTE_SAMP_CLK_UNDERFLOW_BEHAVIOR\x10\xe1R\x12/\n*TIMING_ATTRIBUTE_SAMP_CLK_OVERRUN_BEHAVIOR\x10\xfc]\x12\x31\n,TIMING_ATTRIBUTE_IMPLICIT_UNDERFLOW_BEHAVIOR\x10\xfd]\x12%\n TIMING_ATTRIBUTE_SYNC_PULSE_TYPE\x10\xb6\x62\x12/\n*TIMING_ATTRIBUTE_SYNC_PULSE_TIME_TIMESCALE\x10\xb8\x62\x12\x34\n/TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_TIMESCALE\x10\xbb\x62\x12.\n)TIMING_ATTRIBUTE_FIRST_SAMP_CLK_TIMESCALE\x10\x83\x63*\xa9\x18\n\x14TimingResetAttribute\x12&\n\"TIMING_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x30\n+TIMING_RESET_ATTRIBUTE_SAMP_QUANT_SAMP_MODE\x10\x80&\x12\x30\n+TIMING_RESET_ATTRIBUTE_SAMP_CLK_ACTIVE_EDGE\x10\x81&\x12\x32\n-TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_RATE\x10\x83&\x12;\n6TIMING_RESET_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY_UNITS\x10\x84&\x12\x41\n<TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_MASTER_TIMEBASE_DIV\x10\x85&\x12\x31\n,TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_SRC\x10\x88&\x12\x34\n/TIMING_RESET_ATTRIBUTE_SAMP_QUANT_SAMP_PER_CHAN\x10\x90&\x12(\n#TIMING_RESET_ATTRIBUTE_REF_CLK_RATE\x10\x95&\x12\'\n\"TIMING_RESET_ATTRIBUTE_REF_CLK_SRC\x10\x96&\x12\x35\n0TIMING_RESET_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY\x10\x97&\x12\x30\n+TIMING_RESET_ATTRIBUTE_AI_CONV_TIMEBASE_DIV\x10\xb5&\x12\x30\n+TIMING_RESET_ATTRIBUTE_AI_CONV_TIMEBASE_SRC\x10\xb9&\x12/\n*TIMING_RESET_ATTRIBUTE_MASTER_TIMEBASE_SRC\x10\xc3&\x12)\n$TIMING_RESET_ATTRIBUTE_SAMP_CLK_RATE\x10\xc4&\x12,\n\'TIMING_RESET_ATTRIBUTE_SAMP_TIMING_TYPE\x10\xc7&\x12\x30\n+TIMING_RESET_ATTRIBUTE_MASTER_TIMEBASE_RATE\x10\x95)\x12\'\n\"TIMING_RESET_ATTRIBUTE_AI_CONV_SRC\x10\x82*\x12(\n#TIMING_RESET_ATTRIBUTE_AI_CONV_RATE\x10\xc8\x30\x12(\n#TIMING_RESET_ATTRIBUTE_SAMP_CLK_SRC\x10\xd2\x30\x12/\n*TIMING_RESET_ATTRIBUTE_AI_CONV_ACTIVE_EDGE\x10\xd3\x30\x12\x31\n,TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_DIV\x10\xeb\x31\x12\x39\n4TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_ACTIVE_EDGE\x10\xec\x31\x12G\nBTIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_RISING_EDGE_PHYSICAL_CHANS\x10\x95\x43\x12H\nCTIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_FALLING_EDGE_PHYSICAL_CHANS\x10\x96\x43\x12<\n7TIMING_RESET_ATTRIBUTE_ON_DEMAND_SIMULTANEOUS_AO_ENABLE\x10\xa0\x43\x12\x34\n/TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_ENABLE\x10\x9e\x44\x12=\n8TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_MIN_PULSE_WIDTH\x10\x9f\x44\x12:\n5TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_SRC\x10\xa0\x44\x12;\n6TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_RATE\x10\xa1\x44\x12\x34\n/TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_SYNC_ENABLE\x10\xa2\x44\x12*\n%TIMING_RESET_ATTRIBUTE_SYNC_PULSE_SRC\x10\xbd\x44\x12\x39\n4TIMING_RESET_ATTRIBUTE_SYNC_PULSE_MIN_DELAY_TO_START\x10\xbf\x44\x12\x31\n,TIMING_RESET_ATTRIBUTE_HSHK_DELAY_AFTER_XFER\x10\xc2\x45\x12+\n&TIMING_RESET_ATTRIBUTE_HSHK_START_COND\x10\xc3\x45\x12\x37\n2TIMING_RESET_ATTRIBUTE_HSHK_SAMPLE_INPUT_DATA_WHEN\x10\xc4\x45\x12\x37\n2TIMING_RESET_ATTRIBUTE_SAMP_CLK_UNDERFLOW_BEHAVIOR\x10\xe1R\x12.\n)TIMING_RESET_ATTRIBUTE_SAMP_TIMING_ENGINE\x10\xa6T\x12\x33\n.TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_ENABLE\x10\xdc]\x12<\n7TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_MIN_PULSE_WIDTH\x10\xdd]\x12\x39\n4TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_SRC\x10\xde]\x12:\n5TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_RATE\x10\xdf]\x12\x33\n.TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_SYNC_ENABLE\x10\xe0]\x12\x35\n0TIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_TRISTATE\x10\xfa]\x12\x35\n0TIMING_RESET_ATTRIBUTE_SAMP_CLK_OVERRUN_BEHAVIOR\x10\xfc]\x12\x37\n2TIMING_RESET_ATTRIBUTE_IMPLICIT_UNDERFLOW_BEHAVIOR\x10\xfd]\x12\x32\n-TIMING_RESET_ATTRIBUTE_SYNC_PULSE_RESET_DELAY\x10\xfd^\x12-\n(TIMING_RESET_ATTRIBUTE_SYNC_CLK_INTERVAL\x10\xfe^\x12\x33\n.TIMING_RESET_ATTRIBUTE_TIMING_SYNC_PULSE_FORCE\x10\xba\x61\x12\x41\n<TIMING_RESET_ATTRIBUTE_SAMP_CLK_WRITE_WFM_USE_INITIAL_WFM_DT\x10\xfc\x61\x12+\n&TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TYPE\x10\xb6\x62\x12\x30\n+TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TIME_WHEN\x10\xb7\x62\x12\x35\n0TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TIME_TIMESCALE\x10\xb8\x62\x12\x37\n2TIMING_RESET_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_ENABLE\x10\xb9\x62\x12:\n5TIMING_RESET_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_TIMESCALE\x10\xbb\x62\x12/\n*TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_WHEN\x10\x82\x63\x12\x34\n/TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_TIMESCALE\x10\x83\x63\x12\x31\n,TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_OFFSET\x10\xaa\x63*\xfd\x06\n\x15TimingDoubleAttribute\x12\'\n#TIMING_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12,\n\'TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_RATE\x10\x83&\x12\"\n\x1dTIMING_ATTRIBUTE_REF_CLK_RATE\x10\x95&\x12/\n*TIMING_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY\x10\x97&\x12#\n\x1eTIMING_ATTRIBUTE_SAMP_CLK_RATE\x10\xc4&\x12*\n%TIMING_ATTRIBUTE_MASTER_TIMEBASE_RATE\x10\x95)\x12\"\n\x1dTIMING_ATTRIBUTE_AI_CONV_RATE\x10\xc8\x30\x12\x37\n2TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_MIN_PULSE_WIDTH\x10\x9f\x44\x12\x35\n0TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_RATE\x10\xa1\x44\x12*\n%TIMING_ATTRIBUTE_SYNC_PULSE_SYNC_TIME\x10\xbe\x44\x12\x33\n.TIMING_ATTRIBUTE_SYNC_PULSE_MIN_DELAY_TO_START\x10\xbf\x44\x12+\n&TIMING_ATTRIBUTE_HSHK_DELAY_AFTER_XFER\x10\xc2\x45\x12\'\n\"TIMING_ATTRIBUTE_SAMP_CLK_MAX_RATE\x10\xc8\x45\x12&\n!TIMING_ATTRIBUTE_AI_CONV_MAX_RATE\x10\xc9\x45\x12\x36\n1TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_MIN_PULSE_WIDTH\x10\xdd]\x12\x34\n/TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_RATE\x10\xdf]\x12+\n&TIMING_ATTRIBUTE_SYNC_PULSE_RESET_TIME\x10\xfc^\x12,\n\'TIMING_ATTRIBUTE_SYNC_PULSE_RESET_DELAY\x10\xfd^\x12+\n&TIMING_ATTRIBUTE_FIRST_SAMP_CLK_OFFSET\x10\xaa\x63*\xa9\x02\n\x15TimingUInt32Attribute\x12\'\n#TIMING_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12;\n6TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_MASTER_TIMEBASE_DIV\x10\x85&\x12*\n%TIMING_ATTRIBUTE_AI_CONV_TIMEBASE_DIV\x10\xb5&\x12+\n&TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_DIV\x10\xeb\x31\x12(\n#TIMING_ATTRIBUTE_SAMP_TIMING_ENGINE\x10\xa6T\x12\'\n\"TIMING_ATTRIBUTE_SYNC_CLK_INTERVAL\x10\xfe^*\x94\x05\n\x15TimingStringAttribute\x12\'\n#TIMING_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12+\n&TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_SRC\x10\x88&\x12!\n\x1cTIMING_ATTRIBUTE_REF_CLK_SRC\x10\x96&\x12)\n$TIMING_ATTRIBUTE_MASTER_TIMEBASE_SRC\x10\xc3&\x12!\n\x1cTIMING_ATTRIBUTE_AI_CONV_SRC\x10\x82*\x12\"\n\x1dTIMING_ATTRIBUTE_SAMP_CLK_SRC\x10\xd2\x30\x12\x41\n<TIMING_ATTRIBUTE_CHANGE_DETECT_DI_RISING_EDGE_PHYSICAL_CHANS\x10\x95\x43\x12\x42\n=TIMING_ATTRIBUTE_CHANGE_DETECT_DI_FALLING_EDGE_PHYSICAL_CHANS\x10\x96\x43\x12\x34\n/TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_SRC\x10\xa0\x44\x12$\n\x1fTIMING_ATTRIBUTE_SYNC_PULSE_SRC\x10\xbd\x44\x12\x33\n.TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_SRC\x10\xde]\x12#\n\x1eTIMING_ATTRIBUTE_SAMP_CLK_TERM\x10\x9b^\x12,\n\'TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_TERM\x10\x9c^\x12%\n TIMING_ATTRIBUTE_SYNC_PULSE_TERM\x10\x85_*p\n\x15TimingUInt64Attribute\x12\'\n#TIMING_UINT64_ATTRIBUTE_UNSPECIFIED\x10\x00\x12.\n)TIMING_ATTRIBUTE_SAMP_QUANT_SAMP_PER_CHAN\x10\x90&*\x82\x04\n\x13TimingBoolAttribute\x12%\n!TIMING_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x36\n1TIMING_ATTRIBUTE_ON_DEMAND_SIMULTANEOUS_AO_ENABLE\x10\xa0\x43\x12.\n)TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_ENABLE\x10\x9e\x44\x12.\n)TIMING_ATTRIBUTE_SAMP_CLK_DIG_SYNC_ENABLE\x10\xa2\x44\x12-\n(TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_ENABLE\x10\xdc]\x12-\n(TIMING_ATTRIBUTE_AI_CONV_DIG_SYNC_ENABLE\x10\xe0]\x12/\n*TIMING_ATTRIBUTE_CHANGE_DETECT_DI_TRISTATE\x10\xfa]\x12-\n(TIMING_ATTRIBUTE_TIMING_SYNC_PULSE_FORCE\x10\xba\x61\x12;\n6TIMING_ATTRIBUTE_SAMP_CLK_WRITE_WFM_USE_INITIAL_WFM_DT\x10\xfc\x61\x12\x31\n,TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_ENABLE\x10\xb9\x62*\xcd\x01\n\x18TimingTimestampAttribute\x12*\n&TIMING_TIMESTAMP_ATTRIBUTE_UNSPECIFIED\x10\x00\x12*\n%TIMING_ATTRIBUTE_SYNC_PULSE_TIME_WHEN\x10\xb7\x62\x12.\n)TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_VAL\x10\xba\x62\x12)\n$TIMING_ATTRIBUTE_FIRST_SAMP_CLK_WHEN\x10\x82\x63*\xb8\r\n\x15TriggerInt32Attribute\x12\'\n#TRIGGER_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12-\n(TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_EDGE\x10\xe0&\x12$\n\x1fTRIGGER_ATTRIBUTE_ADV_TRIG_TYPE\x10\xe5&\x12&\n!TRIGGER_ATTRIBUTE_PAUSE_TRIG_TYPE\x10\xe6&\x12/\n*TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_WHEN\x10\xf1&\x12/\n*TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_WHEN\x10\xf4&\x12.\n)TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_WHEN\x10\x80\'\x12&\n!TRIGGER_ATTRIBUTE_START_TRIG_TYPE\x10\x93\'\x12\x31\n,TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_SLOPE\x10\x97\'\x12/\n*TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_WHEN\x10\x81(\x12/\n*TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_EDGE\x10\x84(\x12\x32\n-TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_WHEN\x10\x91(\x12*\n%TRIGGER_ATTRIBUTE_ARM_START_TRIG_TYPE\x10\x94(\x12\x33\n.TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_EDGE\x10\x95(\x12$\n\x1fTRIGGER_ATTRIBUTE_REF_TRIG_TYPE\x10\x99(\x12/\n*TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SLOPE\x10\xa3(\x12-\n(TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_WHEN\x10\xa7(\x12-\n(TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_EDGE\x10\xb0(\x12\x30\n+TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_WHEN\x10\xb8(\x12\x31\n,TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_COUPLING\x10\xd7\x30\x12-\n(TRIGGER_ATTRIBUTE_START_TRIG_DELAY_UNITS\x10\xc8\x31\x12\x32\n-TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_WHEN\x10\xf0\x42\x12\x34\n/TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_COUPLING\x10\xb3\x44\x12\x33\n.TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_COUPLING\x10\xb4\x44\x12\x32\n-TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_COUPLING\x10\xb5\x44\x12\x33\n.TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_COUPLING\x10\xb6\x44\x12\x33\n.TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_COUPLING\x10\xb7\x44\x12%\n TRIGGER_ATTRIBUTE_HSHK_TRIG_TYPE\x10\xb7\x45\x12\x39\n4TRIGGER_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_ASSERTED_LVL\x10\xb9\x45\x12(\n#TRIGGER_ATTRIBUTE_TRIGGER_SYNC_TYPE\x10\x80_\x12+\n&TRIGGER_ATTRIBUTE_START_TRIG_TIMESCALE\x10\xb6`\x12\x35\n0TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_TIMESCALE\x10\xad\x62\x12\x33\n.TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_TIMESCALE\x10\xb0\x62\x12/\n*TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESCALE\x10\xb2\x62\x12\x39\n4TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_TIMESCALE\x10\xb5\x62*\xae\x44\n\x15TriggerResetAttribute\x12\'\n#TRIGGER_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_EDGE\x10\xe0&\x12\x32\n-TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_SRC\x10\xe2&\x12*\n%TRIGGER_RESET_ATTRIBUTE_ADV_TRIG_TYPE\x10\xe5&\x12,\n\'TRIGGER_RESET_ATTRIBUTE_PAUSE_TRIG_TYPE\x10\xe6&\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_HYST\x10\xe8&\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_LVL\x10\xe9&\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_SRC\x10\xf0&\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_WHEN\x10\xf1&\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_SRC\x10\xf3&\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_WHEN\x10\xf4&\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_BTM\x10\xf5&\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_TOP\x10\xf6&\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_SRC\x10\xf9&\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_WHEN\x10\x80\'\x12,\n\'TRIGGER_RESET_ATTRIBUTE_START_TRIG_TYPE\x10\x93\'\x12\x36\n1TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_HYST\x10\x95\'\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_LVL\x10\x96\'\x12\x37\n2TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_SLOPE\x10\x97\'\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_SRC\x10\x98\'\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_SRC\x10\x80(\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_WHEN\x10\x81(\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_BTM\x10\x82(\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_TOP\x10\x83(\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_EDGE\x10\x84(\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_SRC\x10\x87(\x12\x37\n2TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_SRC\x10\x90(\x12\x38\n3TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_WHEN\x10\x91(\x12\x30\n+TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TYPE\x10\x94(\x12\x39\n4TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_EDGE\x10\x95(\x12\x38\n3TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_SRC\x10\x97(\x12*\n%TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TYPE\x10\x99(\x12\x34\n/TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_HYST\x10\xa1(\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_LVL\x10\xa2(\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SLOPE\x10\xa3(\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SRC\x10\xa4(\x12\x32\n-TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_SRC\x10\xa6(\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_WHEN\x10\xa7(\x12\x32\n-TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_BTM\x10\xa8(\x12\x32\n-TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_TOP\x10\xa9(\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_EDGE\x10\xb0(\x12\x32\n-TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_SRC\x10\xb4(\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_SRC\x10\xb7(\x12\x36\n1TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_WHEN\x10\xb8(\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_REF_TRIG_PRETRIG_SAMPLES\x10\xc5(\x12+\n&TRIGGER_RESET_ATTRIBUTE_REF_TRIG_DELAY\x10\x83)\x12-\n(TRIGGER_RESET_ATTRIBUTE_START_TRIG_DELAY\x10\xd6\x30\x12\x37\n2TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_COUPLING\x10\xd7\x30\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_START_TRIG_DELAY_UNITS\x10\xc8\x31\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_START_TRIG_RETRIGGERABLE\x10\x8f\x32\x12\x37\n2TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_SRC\x10\xef\x42\x12\x38\n3TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_WHEN\x10\xf0\x42\x12;\n6TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_PATTERN\x10\x86\x43\x12\x39\n4TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_PATTERN\x10\x87\x43\x12;\n6TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_PATTERN\x10\x88\x43\x12@\n;TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_ENABLE\x10\xa3\x44\x12I\nDTRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xa4\x44\x12\x46\nATRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xa5\x44\x12G\nBTRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xa6\x44\x12@\n;TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_SYNC_ENABLE\x10\xa7\x44\x12?\n:TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE\x10\xa8\x44\x12H\nCTRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xa9\x44\x12\x45\n@TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xaa\x44\x12\x46\nATRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xab\x44\x12?\n:TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE\x10\xac\x44\x12\x44\n?TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_ENABLE\x10\xad\x44\x12M\nHTRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xae\x44\x12J\nETRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xaf\x44\x12K\nFTRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xb0\x44\x12\x44\n?TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_SYNC_ENABLE\x10\xb1\x44\x12:\n5TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_COUPLING\x10\xb3\x44\x12\x39\n4TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_COUPLING\x10\xb4\x44\x12\x38\n3TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_COUPLING\x10\xb5\x44\x12\x39\n4TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_COUPLING\x10\xb6\x44\x12\x39\n4TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_COUPLING\x10\xb7\x44\x12>\n9TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_DIG_FLTR_ENABLE\x10\xb8\x44\x12+\n&TRIGGER_RESET_ATTRIBUTE_HSHK_TRIG_TYPE\x10\xb7\x45\x12\x36\n1TRIGGER_RESET_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_SRC\x10\xb8\x45\x12?\n:TRIGGER_RESET_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_ASSERTED_LVL\x10\xb9\x45\x12\x36\n1TRIGGER_RESET_ATTRIBUTE_REF_TRIG_AUTO_TRIG_ENABLE\x10\xc1]\x12>\n9TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_ENABLE\x10\xd7]\x12G\nBTRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xd8]\x12\x44\n?TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xd9]\x12\x45\n@TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xda]\x12>\n9TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_SYNC_ENABLE\x10\xdb]\x12\x41\n<TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_ENABLE\x10\xe1]\x12J\nETRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe2]\x12G\nBTRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xe3]\x12H\nCTRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xe4]\x12\x41\n<TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_SYNC_ENABLE\x10\xe5]\x12?\n:TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_ENABLE\x10\xe6]\x12H\nCTRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe7]\x12\x45\n@TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xe8]\x12\x46\nATRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xe9]\x12?\n:TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_SYNC_ENABLE\x10\xea]\x12>\n9TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_ENABLE\x10\xeb]\x12G\nBTRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xec]\x12\x44\n?TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xed]\x12\x45\n@TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xee]\x12>\n9TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_SYNC_ENABLE\x10\xef]\x12@\n;TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE\x10\xf0]\x12I\nDTRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf1]\x12\x46\nATRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xf2]\x12G\nBTRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xf3]\x12@\n;TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE\x10\xf4]\x12@\n;TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_ENABLE\x10\xf5]\x12I\nDTRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf6]\x12\x46\nATRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xf7]\x12G\nBTRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xf8]\x12@\n;TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_SYNC_ENABLE\x10\xf9]\x12@\n;TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_ENABLE\x10\xff]\x12I\nDTRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\x80^\x12\x46\nATRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\x81^\x12G\nBTRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\x82^\x12@\n;TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_SYNC_ENABLE\x10\x83^\x12.\n)TRIGGER_RESET_ATTRIBUTE_TRIGGER_SYNC_TYPE\x10\x80_\x12\x30\n+TRIGGER_RESET_ATTRIBUTE_TIME_START_TRIG_SRC\x10\x9d`\x12\x31\n,TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESCALE\x10\xb6`\x12\x31\n,TRIGGER_RESET_ATTRIBUTE_START_TRIG_TRIG_WHEN\x10\xcd`\x12\x30\n+TRIGGER_RESET_ATTRIBUTE_START_TRIG_TRIG_WIN\x10\x9a\x62\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_START_TRIG_RETRIGGER_WIN\x10\x9b\x62\x12?\n:TRIGGER_RESET_ATTRIBUTE_START_TRIG_MAX_NUM_TRIGS_TO_DETECT\x10\x9c\x62\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_REF_TRIG_RETRIGGERABLE\x10\x9d\x62\x12.\n)TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TRIG_WIN\x10\x9e\x62\x12\x33\n.TRIGGER_RESET_ATTRIBUTE_REF_TRIG_RETRIGGER_WIN\x10\x9f\x62\x12=\n8TRIGGER_RESET_ATTRIBUTE_REF_TRIG_MAX_NUM_TRIGS_TO_DETECT\x10\xa0\x62\x12<\n7TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SRCS\x10\xa1\x62\x12>\n9TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SLOPES\x10\xa2\x62\x12<\n7TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_LVLS\x10\xa3\x62\x12=\n8TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_HYSTS\x10\xa4\x62\x12\x41\n<TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_COUPLINGS\x10\xa5\x62\x12:\n5TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SRCS\x10\xa6\x62\x12<\n7TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SLOPES\x10\xa7\x62\x12:\n5TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_LVLS\x10\xa8\x62\x12;\n6TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_HYSTS\x10\xa9\x62\x12?\n:TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_COUPLINGS\x10\xaa\x62\x12;\n6TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESTAMP_TIMESCALE\x10\xad\x62\x12\x36\n1TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TIMESTAMP_ENABLE\x10\xae\x62\x12\x39\n4TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TIMESTAMP_TIMESCALE\x10\xb0\x62\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TRIG_WHEN\x10\xb1\x62\x12\x35\n0TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESCALE\x10\xb2\x62\x12<\n7TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_ENABLE\x10\xb3\x62\x12?\n:TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_TIMESCALE\x10\xb5\x62\x12\x38\n3TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESTAMP_ENABLE\x10\xca\x62*\x85\x0f\n\x16TriggerStringAttribute\x12(\n$TRIGGER_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12,\n\'TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_SRC\x10\xe2&\x12.\n)TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_SRC\x10\xf0&\x12.\n)TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_SRC\x10\xf3&\x12-\n(TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_SRC\x10\xf9&\x12/\n*TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_SRC\x10\x98\'\x12.\n)TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_SRC\x10\x80(\x12.\n)TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_SRC\x10\x87(\x12\x31\n,TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_SRC\x10\x90(\x12\x32\n-TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_SRC\x10\x97(\x12-\n(TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SRC\x10\xa4(\x12,\n\'TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_SRC\x10\xa6(\x12,\n\'TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_SRC\x10\xb4(\x12/\n*TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_SRC\x10\xb7(\x12\x31\n,TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_SRC\x10\xef\x42\x12\x35\n0TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_PATTERN\x10\x86\x43\x12\x33\n.TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_PATTERN\x10\x87\x43\x12\x35\n0TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_PATTERN\x10\x88\x43\x12@\n;TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xa5\x44\x12?\n:TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xaa\x44\x12\x44\n?TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xaf\x44\x12\x30\n+TRIGGER_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_SRC\x10\xb8\x45\x12>\n9TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xd9]\x12\x41\n<TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xe3]\x12?\n:TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xe8]\x12>\n9TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xed]\x12@\n;TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xf2]\x12@\n;TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\xf7]\x12@\n;TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_SRC\x10\x81^\x12&\n!TRIGGER_ATTRIBUTE_START_TRIG_TERM\x10\x9e^\x12$\n\x1fTRIGGER_ATTRIBUTE_REF_TRIG_TERM\x10\x9f^\x12&\n!TRIGGER_ATTRIBUTE_PAUSE_TRIG_TERM\x10\xa0^\x12%\n TRIGGER_ATTRIBUTE_ARM_START_TERM\x10\xff^\x12*\n%TRIGGER_ATTRIBUTE_TIME_START_TRIG_SRC\x10\x9d`\x12\x36\n1TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SRCS\x10\xa1\x62\x12\x34\n/TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SRCS\x10\xa6\x62*\xd5\x11\n\x16TriggerDoubleAttribute\x12(\n$TRIGGER_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12/\n*TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_HYST\x10\xe8&\x12.\n)TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_LVL\x10\xe9&\x12.\n)TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_BTM\x10\xf5&\x12.\n)TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_TOP\x10\xf6&\x12\x30\n+TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_HYST\x10\x95\'\x12/\n*TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_LVL\x10\x96\'\x12.\n)TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_BTM\x10\x82(\x12.\n)TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_TOP\x10\x83(\x12.\n)TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_HYST\x10\xa1(\x12-\n(TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_LVL\x10\xa2(\x12,\n\'TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_BTM\x10\xa8(\x12,\n\'TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_TOP\x10\xa9(\x12%\n TRIGGER_ATTRIBUTE_REF_TRIG_DELAY\x10\x83)\x12\'\n\"TRIGGER_ATTRIBUTE_START_TRIG_DELAY\x10\xd6\x30\x12\x43\n>TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xa4\x44\x12\x41\n<TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xa6\x44\x12\x42\n=TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xa9\x44\x12@\n;TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xab\x44\x12G\nBTRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xae\x44\x12\x45\n@TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xb0\x44\x12\x41\n<TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xd8]\x12?\n:TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xda]\x12\x44\n?TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe2]\x12\x42\n=TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xe4]\x12\x42\n=TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xe7]\x12@\n;TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xe9]\x12\x41\n<TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xec]\x12?\n:TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xee]\x12\x43\n>TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf1]\x12\x41\n<TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xf3]\x12\x43\n>TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\xf6]\x12\x41\n<TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\xf8]\x12\x43\n>TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH\x10\x80^\x12\x41\n<TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_RATE\x10\x82^\x12*\n%TRIGGER_ATTRIBUTE_START_TRIG_TRIG_WIN\x10\x9a\x62\x12/\n*TRIGGER_ATTRIBUTE_START_TRIG_RETRIGGER_WIN\x10\x9b\x62\x12(\n#TRIGGER_ATTRIBUTE_REF_TRIG_TRIG_WIN\x10\x9e\x62\x12-\n(TRIGGER_ATTRIBUTE_REF_TRIG_RETRIGGER_WIN\x10\x9f\x62*\xe7\x01\n\x16TriggerUInt32Attribute\x12(\n$TRIGGER_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12/\n*TRIGGER_ATTRIBUTE_REF_TRIG_PRETRIG_SAMPLES\x10\xc5(\x12\x39\n4TRIGGER_ATTRIBUTE_START_TRIG_MAX_NUM_TRIGS_TO_DETECT\x10\x9c\x62\x12\x37\n2TRIGGER_ATTRIBUTE_REF_TRIG_MAX_NUM_TRIGS_TO_DETECT\x10\xa0\x62*\x86\r\n\x14TriggerBoolAttribute\x12&\n\"TRIGGER_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12/\n*TRIGGER_ATTRIBUTE_START_TRIG_RETRIGGERABLE\x10\x8f\x32\x12:\n5TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_ENABLE\x10\xa3\x44\x12:\n5TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_SYNC_ENABLE\x10\xa7\x44\x12\x39\n4TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE\x10\xa8\x44\x12\x39\n4TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE\x10\xac\x44\x12>\n9TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_ENABLE\x10\xad\x44\x12>\n9TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_SYNC_ENABLE\x10\xb1\x44\x12\x38\n3TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_DIG_FLTR_ENABLE\x10\xb8\x44\x12\x30\n+TRIGGER_ATTRIBUTE_REF_TRIG_AUTO_TRIG_ENABLE\x10\xc1]\x12.\n)TRIGGER_ATTRIBUTE_REF_TRIG_AUTO_TRIGGERED\x10\xc2]\x12\x38\n3TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_ENABLE\x10\xd7]\x12\x38\n3TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_SYNC_ENABLE\x10\xdb]\x12;\n6TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_ENABLE\x10\xe1]\x12;\n6TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_SYNC_ENABLE\x10\xe5]\x12\x39\n4TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_ENABLE\x10\xe6]\x12\x39\n4TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_SYNC_ENABLE\x10\xea]\x12\x38\n3TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_ENABLE\x10\xeb]\x12\x38\n3TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_SYNC_ENABLE\x10\xef]\x12:\n5TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE\x10\xf0]\x12:\n5TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE\x10\xf4]\x12:\n5TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_ENABLE\x10\xf5]\x12:\n5TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_SYNC_ENABLE\x10\xf9]\x12:\n5TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_ENABLE\x10\xff]\x12:\n5TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_SYNC_ENABLE\x10\x83^\x12-\n(TRIGGER_ATTRIBUTE_REF_TRIG_RETRIGGERABLE\x10\x9d\x62\x12\x30\n+TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_ENABLE\x10\xae\x62\x12\x36\n1TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_ENABLE\x10\xb3\x62\x12\x32\n-TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_ENABLE\x10\xca\x62*\xbb\x02\n\x19TriggerTimestampAttribute\x12+\n\'TRIGGER_TIMESTAMP_ATTRIBUTE_UNSPECIFIED\x10\x00\x12+\n&TRIGGER_ATTRIBUTE_START_TRIG_TRIG_WHEN\x10\xcd`\x12-\n(TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_VAL\x10\xaf\x62\x12/\n*TRIGGER_ATTRIBUTE_ARM_START_TRIG_TRIG_WHEN\x10\xb1\x62\x12\x33\n.TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_VAL\x10\xb4\x62\x12/\n*TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_VAL\x10\xcb\x62*\xb5\x02\n\x1aTriggerInt32ArrayAttribute\x12-\n)TRIGGER_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x38\n3TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SLOPES\x10\xa2\x62\x12;\n6TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_COUPLINGS\x10\xa5\x62\x12\x36\n1TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SLOPES\x10\xa7\x62\x12\x39\n4TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_COUPLINGS\x10\xaa\x62*\xab\x02\n\x1bTriggerDoubleArrayAttribute\x12.\n*TRIGGER_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x36\n1TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_LVLS\x10\xa3\x62\x12\x37\n2TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_HYSTS\x10\xa4\x62\x12\x34\n/TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_LVLS\x10\xa8\x62\x12\x35\n0TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_HYSTS\x10\xa9\x62*\x9e\x02\n\x16WatchdogInt32Attribute\x12(\n$WATCHDOG_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\'\n\"WATCHDOG_ATTRIBUTE_EXPIR_TRIG_TYPE\x10\xa3\x43\x12\x39\n4WATCHDOG_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_EDGE\x10\xa5\x43\x12&\n!WATCHDOG_ATTRIBUTE_DO_EXPIR_STATE\x10\xa7\x43\x12&\n!WATCHDOG_ATTRIBUTE_AO_OUTPUT_TYPE\x10\xde`\x12&\n!WATCHDOG_ATTRIBUTE_CO_EXPIR_STATE\x10\xe0`*\x95\x04\n\x16WatchdogResetAttribute\x12(\n$WATCHDOG_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12-\n(WATCHDOG_RESET_ATTRIBUTE_EXPIR_TRIG_TYPE\x10\xa3\x43\x12>\n9WATCHDOG_RESET_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_SRC\x10\xa4\x43\x12?\n:WATCHDOG_RESET_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_EDGE\x10\xa5\x43\x12,\n\'WATCHDOG_RESET_ATTRIBUTE_DO_EXPIR_STATE\x10\xa7\x43\x12%\n WATCHDOG_RESET_ATTRIBUTE_TIMEOUT\x10\xa9\x43\x12\x42\n=WATCHDOG_RESET_ATTRIBUTE_EXPIR_TRIG_TRIG_ON_NETWORK_CONN_LOSS\x10\xdd`\x12,\n\'WATCHDOG_RESET_ATTRIBUTE_AO_OUTPUT_TYPE\x10\xde`\x12,\n\'WATCHDOG_RESET_ATTRIBUTE_AO_EXPIR_STATE\x10\xdf`\x12,\n\'WATCHDOG_RESET_ATTRIBUTE_CO_EXPIR_STATE\x10\xe0`*~\n\x17WatchdogStringAttribute\x12)\n%WATCHDOG_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x38\n3WATCHDOG_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_SRC\x10\xa4\x43*\xa3\x01\n\x15WatchdogBoolAttribute\x12\'\n#WATCHDOG_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12#\n\x1eWATCHDOG_ATTRIBUTE_HAS_EXPIRED\x10\xa8\x43\x12<\n7WATCHDOG_ATTRIBUTE_EXPIR_TRIG_TRIG_ON_NETWORK_CONN_LOSS\x10\xdd`*\x8d\x01\n\x17WatchdogDoubleAttribute\x12)\n%WATCHDOG_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1f\n\x1aWATCHDOG_ATTRIBUTE_TIMEOUT\x10\xa9\x43\x12&\n!WATCHDOG_ATTRIBUTE_AO_EXPIR_STATE\x10\xdf`*\xbc\x01\n\x13WriteInt32Attribute\x12%\n!WRITE_INT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1f\n\x1aWRITE_ATTRIBUTE_REGEN_MODE\x10\xd3(\x12 \n\x1bWRITE_ATTRIBUTE_RELATIVE_TO\x10\x8c\x32\x12\x1b\n\x16WRITE_ATTRIBUTE_OFFSET\x10\x8d\x32\x12\x1e\n\x19WRITE_ATTRIBUTE_WAIT_MODE\x10\xb1\x45*\xaa\x02\n\x13WriteResetAttribute\x12%\n!WRITE_RESET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12%\n WRITE_RESET_ATTRIBUTE_REGEN_MODE\x10\xd3(\x12&\n!WRITE_RESET_ATTRIBUTE_RELATIVE_TO\x10\x8c\x32\x12!\n\x1cWRITE_RESET_ATTRIBUTE_OFFSET\x10\x8d\x32\x12$\n\x1fWRITE_RESET_ATTRIBUTE_WAIT_MODE\x10\xb1\x45\x12%\n WRITE_RESET_ATTRIBUTE_SLEEP_TIME\x10\xb2\x45\x12-\n(WRITE_RESET_ATTRIBUTE_NEXT_WRITE_IS_LAST\x10\xecR*\x97\x01\n\x14WriteUInt64Attribute\x12&\n\"WRITE_UINT64_ATTRIBUTE_UNSPECIFIED\x10\x00\x12#\n\x1eWRITE_ATTRIBUTE_CURR_WRITE_POS\x10\xd8(\x12\x32\n-WRITE_ATTRIBUTE_TOTAL_SAMP_PER_CHAN_GENERATED\x10\xab\x32*\xd8\x01\n\x14WriteUInt32Attribute\x12&\n\"WRITE_UINT32_ATTRIBUTE_UNSPECIFIED\x10\x00\x12 \n\x1bWRITE_ATTRIBUTE_SPACE_AVAIL\x10\xe0(\x12#\n\x1eWRITE_ATTRIBUTE_RAW_DATA_WIDTH\x10\xfd\x42\x12\x1e\n\x19WRITE_ATTRIBUTE_NUM_CHANS\x10\xfe\x42\x12\x31\n,WRITE_ATTRIBUTE_DIGITAL_LINES_BYTES_PER_CHAN\x10\xff\x42*_\n\x14WriteDoubleAttribute\x12&\n\"WRITE_DOUBLE_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x1f\n\x1aWRITE_ATTRIBUTE_SLEEP_TIME\x10\xb2\x45*\xfe\x03\n\x12WriteBoolAttribute\x12$\n WRITE_BOOL_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\'\n\"WRITE_ATTRIBUTE_NEXT_WRITE_IS_LAST\x10\xecR\x12,\n\'WRITE_ATTRIBUTE_OVERCURRENT_CHANS_EXIST\x10\xe8S\x12\x32\n-WRITE_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS_EXIST\x10\xeaS\x12\x33\n.WRITE_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS_EXIST\x10\xecS\x12\x30\n+WRITE_ATTRIBUTE_OVERTEMPERATURE_CHANS_EXIST\x10\x84U\x12<\n7WRITE_ATTRIBUTE_ACCESSORY_INSERTION_OR_REMOVAL_DETECTED\x10\xd3`\x12+\n&WRITE_ATTRIBUTE_OVERLOADED_CHANS_EXIST\x10\x84\x61\x12\x35\n0WRITE_ATTRIBUTE_EXTERNAL_OVERVOLTAGE_CHANS_EXIST\x10\xbb\x61\x12.\n)WRITE_ATTRIBUTE_SYNC_UNLOCKED_CHANS_EXIST\x10\xbf\x62*\xb1\x03\n\x14WriteStringAttribute\x12&\n\"WRITE_STRING_ATTRIBUTE_UNSPECIFIED\x10\x00\x12&\n!WRITE_ATTRIBUTE_OVERCURRENT_CHANS\x10\xe9S\x12,\n\'WRITE_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS\x10\xebS\x12-\n(WRITE_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS\x10\xedS\x12>\n9WRITE_ATTRIBUTE_DEVS_WITH_INSERTED_OR_REMOVED_ACCESSORIES\x10\xd4`\x12*\n%WRITE_ATTRIBUTE_OVERTEMPERATURE_CHANS\x10\x83\x61\x12%\n WRITE_ATTRIBUTE_OVERLOADED_CHANS\x10\x85\x61\x12/\n*WRITE_ATTRIBUTE_EXTERNAL_OVERVOLTAGE_CHANS\x10\xbc\x61\x12(\n#WRITE_ATTRIBUTE_SYNC_UNLOCKED_CHANS\x10\xc0\x62*\x92\x01\n\x0f\x41\x43\x45xcitWireMode\x12\"\n\x1e\x41\x43_EXCIT_WIRE_MODE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x41\x43_EXCIT_WIRE_MODE_4_WIRE\x10\x04\x12\x1d\n\x19\x41\x43_EXCIT_WIRE_MODE_5_WIRE\x10\x05\x12\x1d\n\x19\x41\x43_EXCIT_WIRE_MODE_6_WIRE\x10\x06*\xa8\x02\n\x1b\x41\x63\x63\x65lChargeSensitivityUnits\x12.\n*ACCEL_CHARGE_SENSITIVITY_UNITS_UNSPECIFIED\x10\x00\x12\x37\n2ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_G\x10\xe3}\x12O\nJACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_METERS_PER_SECOND_SQUARED\x10\xe4}\x12O\nJACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_INCHES_PER_SECOND_SQUARED\x10\xe5}*\x9a\x01\n\x16\x41\x63\x63\x65lSensitivityUnits1\x12(\n$ACCEL_SENSITIVITY_UNITS1_UNSPECIFIED\x10\x00\x12+\n&ACCEL_SENSITIVITY_UNITS1_M_VOLTS_PER_G\x10\xdd\x61\x12)\n$ACCEL_SENSITIVITY_UNITS1_VOLTS_PER_G\x10\xde\x61*\xca\x01\n\x0b\x41\x63\x63\x65lUnits2\x12\x1c\n\x18\x41\x43\x43\x45L_UNITS2_UNSPECIFIED\x10\x00\x12\x1e\n\x19\x41\x43\x43\x45L_UNITS2_ACCEL_UNIT_G\x10\xcaO\x12+\n&ACCEL_UNITS2_METERS_PER_SECOND_SQUARED\x10\xb6\x61\x12+\n&ACCEL_UNITS2_INCHES_PER_SECOND_SQUARED\x10\xb7\x61\x12#\n\x1e\x41\x43\x43\x45L_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N*\xa6\x01\n\x0f\x41\x63quisitionType\x12 \n\x1c\x41\x43QUISITION_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1d\x41\x43QUISITION_TYPE_FINITE_SAMPS\x10\xc2O\x12 \n\x1b\x41\x43QUISITION_TYPE_CONT_SAMPS\x10\x8bO\x12+\n&ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT\x10\xea\x61*\x86\x01\n\x0b\x41ngleUnits1\x12\x1c\n\x18\x41NGLE_UNITS1_UNSPECIFIED\x10\x00\x12\x19\n\x14\x41NGLE_UNITS1_DEGREES\x10\xa2O\x12\x19\n\x14\x41NGLE_UNITS1_RADIANS\x10\xa1P\x12#\n\x1e\x41NGLE_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N*\x9f\x01\n\x0b\x41ngleUnits2\x12\x1c\n\x18\x41NGLE_UNITS2_UNSPECIFIED\x10\x00\x12\x19\n\x14\x41NGLE_UNITS2_DEGREES\x10\xa2O\x12\x19\n\x14\x41NGLE_UNITS2_RADIANS\x10\xa1P\x12\x17\n\x12\x41NGLE_UNITS2_TICKS\x10\xc0P\x12#\n\x1e\x41NGLE_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N*\xee\x01\n\x14\x41ngularVelocityUnits\x12&\n\"ANGULAR_VELOCITY_UNITS_UNSPECIFIED\x10\x00\x12\x1f\n\x1a\x41NGULAR_VELOCITY_UNITS_RPM\x10\xd0}\x12.\n)ANGULAR_VELOCITY_UNITS_RADIANS_PER_SECOND\x10\xd1}\x12.\n)ANGULAR_VELOCITY_UNITS_DEGREES_PER_SECOND\x10\xd2}\x12-\n(ANGULAR_VELOCITY_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*\xde\x01\n\x14\x42ridgeConfiguration1\x12%\n!BRIDGE_CONFIGURATION1_UNSPECIFIED\x10\x00\x12&\n!BRIDGE_CONFIGURATION1_FULL_BRIDGE\x10\xc6O\x12&\n!BRIDGE_CONFIGURATION1_HALF_BRIDGE\x10\xcbO\x12)\n$BRIDGE_CONFIGURATION1_QUARTER_BRIDGE\x10\x9eP\x12$\n\x1f\x42RIDGE_CONFIGURATION1_NO_BRIDGE\x10\xf4O*\x9c\x01\n\x15\x42ridgeElectricalUnits\x12\'\n#BRIDGE_ELECTRICAL_UNITS_UNSPECIFIED\x10\x00\x12+\n&BRIDGE_ELECTRICAL_UNITS_VOLTS_PER_VOLT\x10\x98|\x12-\n(BRIDGE_ELECTRICAL_UNITS_M_VOLTS_PER_VOLT\x10\x99|*\xc7\x03\n\x13\x42ridgePhysicalUnits\x12%\n!BRIDGE_PHYSICAL_UNITS_UNSPECIFIED\x10\x00\x12\"\n\x1d\x42RIDGE_PHYSICAL_UNITS_NEWTONS\x10\x83|\x12!\n\x1c\x42RIDGE_PHYSICAL_UNITS_POUNDS\x10\x84|\x12)\n$BRIDGE_PHYSICAL_UNITS_KILOGRAM_FORCE\x10\x85|\x12\"\n\x1d\x42RIDGE_PHYSICAL_UNITS_PASCALS\x10\xe1N\x12\x31\n,BRIDGE_PHYSICAL_UNITS_POUNDS_PER_SQUARE_INCH\x10\x87|\x12\x1e\n\x19\x42RIDGE_PHYSICAL_UNITS_BAR\x10\x88|\x12(\n#BRIDGE_PHYSICAL_UNITS_NEWTON_METERS\x10\x89|\x12&\n!BRIDGE_PHYSICAL_UNITS_INCH_OUNCES\x10\x8a|\x12&\n!BRIDGE_PHYSICAL_UNITS_INCH_POUNDS\x10\x8b|\x12&\n!BRIDGE_PHYSICAL_UNITS_FOOT_POUNDS\x10\x8c|*\xb3\x01\n\x0b\x42ridgeUnits\x12\x1c\n\x18\x42RIDGE_UNITS_UNSPECIFIED\x10\x00\x12 \n\x1b\x42RIDGE_UNITS_VOLTS_PER_VOLT\x10\x98|\x12\"\n\x1d\x42RIDGE_UNITS_M_VOLTS_PER_VOLT\x10\x99|\x12#\n\x1e\x42RIDGE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12\x1b\n\x16\x42RIDGE_UNITS_FROM_TEDS\x10\xe4\x61*w\n\nCJCSource1\x12\x1b\n\x17\x43JC_SOURCE1_UNSPECIFIED\x10\x00\x12\x19\n\x14\x43JC_SOURCE1_BUILT_IN\x10\xd8O\x12\x1a\n\x15\x43JC_SOURCE1_CONST_VAL\x10\x84O\x12\x15\n\x10\x43JC_SOURCE1_CHAN\x10\x81O*\x8d\x01\n\x0b\x43hargeUnits\x12\x1c\n\x18\x43HARGE_UNITS_UNSPECIFIED\x10\x00\x12\x1a\n\x15\x43HARGE_UNITS_COULOMBS\x10\xe6}\x12\x1f\n\x1a\x43HARGE_UNITS_PICO_COULOMBS\x10\xe7}\x12#\n\x1e\x43HARGE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*\x9b\x01\n\x0f\x43ountDirection1\x12 \n\x1c\x43OUNT_DIRECTION1_UNSPECIFIED\x10\x00\x12\x1e\n\x19\x43OUNT_DIRECTION1_COUNT_UP\x10\x90O\x12 \n\x1b\x43OUNT_DIRECTION1_COUNT_DOWN\x10\x8cO\x12$\n\x1f\x43OUNT_DIRECTION1_EXT_CONTROLLED\x10\xd6P*\xf5\x01\n\x16\x43ounterFrequencyMethod\x12(\n$COUNTER_FREQUENCY_METHOD_UNSPECIFIED\x10\x00\x12,\n\'COUNTER_FREQUENCY_METHOD_LOW_FREQ_1_CTR\x10\xf9N\x12-\n(COUNTER_FREQUENCY_METHOD_HIGH_FREQ_2_CTR\x10\xadO\x12-\n(COUNTER_FREQUENCY_METHOD_LARGE_RNG_2_CTR\x10\xddO\x12%\n COUNTER_FREQUENCY_METHOD_DYN_AVG\x10\xc1}*\xa2\x02\n\'CurrentShuntResistorLocationWithDefault\x12<\n8CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_UNSPECIFIED\x10\x00\x12\x41\n4CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_DEFAULT\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n5CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_INTERNAL\x10\xd8O\x12:\n5CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_EXTERNAL\x10\xb7O*p\n\rCurrentUnits2\x12\x1e\n\x1a\x43URRENT_UNITS2_UNSPECIFIED\x10\x00\x12\x18\n\x13\x43URRENT_UNITS2_AMPS\x10\xe6P\x12%\n CURRENT_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N*\xb6\x01\n\x10\x44igitalLineState\x12\"\n\x1e\x44IGITAL_LINE_STATE_UNSPECIFIED\x10\x00\x12\x1c\n\x17\x44IGITAL_LINE_STATE_HIGH\x10\xd0O\x12\x1b\n\x16\x44IGITAL_LINE_STATE_LOW\x10\xe6O\x12 \n\x1b\x44IGITAL_LINE_STATE_TRISTATE\x10\xc6P\x12!\n\x1c\x44IGITAL_LINE_STATE_NO_CHANGE\x10\xb0O*\xaf\x01\n\x18\x44igitalPatternCondition1\x12*\n&DIGITAL_PATTERN_CONDITION1_UNSPECIFIED\x10\x00\x12/\n*DIGITAL_PATTERN_CONDITION1_PATTERN_MATCHES\x10\x8eP\x12\x36\n1DIGITAL_PATTERN_CONDITION1_PATTERN_DOES_NOT_MATCH\x10\x8dP*]\n\x12\x44igitalWidthUnits3\x12$\n DIGITAL_WIDTH_UNITS3_UNSPECIFIED\x10\x00\x12!\n\x1c\x44IGITAL_WIDTH_UNITS3_SECONDS\x10\xfcP*\xae\x03\n$EddyCurrentProxProbeSensitivityUnits\x12\x39\n5EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_UNSPECIFIED\x10\x00\x12>\n9EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MIL\x10\xf4s\x12<\n7EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MIL\x10\xf5s\x12\x45\n@EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MILLIMETER\x10\xf6s\x12\x43\n>EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MILLIMETER\x10\xf7s\x12\x41\n<EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MICRON\x10\xf8s*E\n\x05\x45\x64ge1\x12\x15\n\x11\x45\x44GE1_UNSPECIFIED\x10\x00\x12\x11\n\x0c\x45\x44GE1_RISING\x10\xa8P\x12\x12\n\rEDGE1_FALLING\x10\xbbO*\x99\x01\n\x0c\x45ncoderType2\x12\x1d\n\x19\x45NCODER_TYPE2_UNSPECIFIED\x10\x00\x12\x15\n\x10\x45NCODER_TYPE2_X1\x10\xeaN\x12\x15\n\x10\x45NCODER_TYPE2_X2\x10\xebN\x12\x15\n\x10\x45NCODER_TYPE2_X4\x10\xecN\x12%\n ENCODER_TYPE2_TWO_PULSE_COUNTING\x10\xc9P*\xe5\x01\n\x13\x45ncoderZIndexPhase1\x12&\n\"ENCODER_Z_INDEX_PHASE1_UNSPECIFIED\x10\x00\x12)\n$ENCODER_Z_INDEX_PHASE1_A_HIGH_B_HIGH\x10\xb8N\x12(\n#ENCODER_Z_INDEX_PHASE1_A_HIGH_B_LOW\x10\xb9N\x12(\n#ENCODER_Z_INDEX_PHASE1_A_LOW_B_HIGH\x10\xbaN\x12\'\n\"ENCODER_Z_INDEX_PHASE1_A_LOW_B_LOW\x10\xbbN*\xb1\x01\n\x16\x45veryNSamplesEventType\x12*\n&EVERY_N_SAMPLES_EVENT_TYPE_UNSPECIFIED\x10\x00\x12\x33\n/EVERY_N_SAMPLES_EVENT_TYPE_ACQUIRED_INTO_BUFFER\x10\x01\x12\x36\n2EVERY_N_SAMPLES_EVENT_TYPE_TRANSFERRED_FROM_BUFFER\x10\x02*\x94\x01\n\x10\x45xcitationSource\x12!\n\x1d\x45XCITATION_SOURCE_UNSPECIFIED\x10\x00\x12\x1f\n\x1a\x45XCITATION_SOURCE_INTERNAL\x10\xd8O\x12\x1f\n\x1a\x45XCITATION_SOURCE_EXTERNAL\x10\xb7O\x12\x1b\n\x16\x45XCITATION_SOURCE_NONE\x10\xf6O*\xcf\x01\n\x1f\x46orceIEPESensorSensitivityUnits\x12\x33\n/FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_UNSPECIFIED\x10\x00\x12;\n6FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_NEWTON\x10\x93|\x12:\n5FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_POUND\x10\x94|*\x98\x01\n\x0e\x46orceIEPEUnits\x12 \n\x1c\x46ORCE_IEPE_UNITS_UNSPECIFIED\x10\x00\x12\x1d\n\x18\x46ORCE_IEPE_UNITS_NEWTONS\x10\x83|\x12\x1c\n\x17\x46ORCE_IEPE_UNITS_POUNDS\x10\x84|\x12\'\n\"FORCE_IEPE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*\xa1\x01\n\nForceUnits\x12\x1b\n\x17\x46ORCE_UNITS_UNSPECIFIED\x10\x00\x12\x18\n\x13\x46ORCE_UNITS_NEWTONS\x10\x83|\x12\x17\n\x12\x46ORCE_UNITS_POUNDS\x10\x84|\x12\x1f\n\x1a\x46ORCE_UNITS_KILOGRAM_FORCE\x10\x85|\x12\"\n\x1d\x46ORCE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*r\n\x0e\x46requencyUnits\x12\x1f\n\x1b\x46REQUENCY_UNITS_UNSPECIFIED\x10\x00\x12\x17\n\x12\x46REQUENCY_UNITS_HZ\x10\x85Q\x12&\n!FREQUENCY_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*M\n\x0f\x46requencyUnits2\x12 \n\x1c\x46REQUENCY_UNITS2_UNSPECIFIED\x10\x00\x12\x18\n\x13\x46REQUENCY_UNITS2_HZ\x10\x85Q*\x93\x01\n\x0f\x46requencyUnits3\x12 \n\x1c\x46REQUENCY_UNITS3_UNSPECIFIED\x10\x00\x12\x18\n\x13\x46REQUENCY_UNITS3_HZ\x10\x85Q\x12\x1b\n\x16\x46REQUENCY_UNITS3_TICKS\x10\xc0P\x12\'\n\"FREQUENCY_UNITS3_FROM_CUSTOM_SCALE\x10\xd1N*\x9a\x01\n\x0b\x46uncGenType\x12\x1d\n\x19\x46UNC_GEN_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x12\x46UNC_GEN_TYPE_SINE\x10\x9fs\x12\x1b\n\x16\x46UNC_GEN_TYPE_TRIANGLE\x10\xa0s\x12\x19\n\x14\x46UNC_GEN_TYPE_SQUARE\x10\xa1s\x12\x1b\n\x16\x46UNC_GEN_TYPE_SAWTOOTH\x10\xa2s*\x86\x01\n\x0eGpsSignalType1\x12 \n\x1cGPS_SIGNAL_TYPE1_UNSPECIFIED\x10\x00\x12\x1b\n\x16GPS_SIGNAL_TYPE1_IRIGB\x10\xd6N\x12\x19\n\x14GPS_SIGNAL_TYPE1_PPS\x10\xe0N\x12\x1a\n\x15GPS_SIGNAL_TYPE1_NONE\x10\xf6O*K\n\x07GroupBy\x12\x1d\n\x19GROUP_BY_GROUP_BY_CHANNEL\x10\x00\x12!\n\x1dGROUP_BY_GROUP_BY_SCAN_NUMBER\x10\x01*\x9e\x02\n\x17InputTermCfgWithDefault\x12+\n\'INPUT_TERM_CFG_WITH_DEFAULT_UNSPECIFIED\x10\x00\x12\x34\n\'INPUT_TERM_CFG_WITH_DEFAULT_CFG_DEFAULT\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12$\n\x1fINPUT_TERM_CFG_WITH_DEFAULT_RSE\x10\xe3N\x12%\n INPUT_TERM_CFG_WITH_DEFAULT_NRSE\x10\xdeN\x12%\n INPUT_TERM_CFG_WITH_DEFAULT_DIFF\x10\xfaN\x12,\n\'INPUT_TERM_CFG_WITH_DEFAULT_PSEUDO_DIFF\x10\xf1\x61*a\n\x0eInvertPolarity\x12*\n&INVERT_POLARITY_DO_NOT_INVERT_POLARITY\x10\x00\x12#\n\x1fINVERT_POLARITY_INVERT_POLARITY\x10\x01*\xbc\x01\n\x15LVDTSensitivityUnits1\x12\'\n#LVDT_SENSITIVITY_UNITS1_UNSPECIFIED\x10\x00\x12<\n7LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLIMETER\x10\xda\x61\x12<\n7LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLI_INCH\x10\xd9\x61*\x89\x01\n\x0cLengthUnits2\x12\x1d\n\x19LENGTH_UNITS2_UNSPECIFIED\x10\x00\x12\x19\n\x14LENGTH_UNITS2_METERS\x10\xebO\x12\x19\n\x14LENGTH_UNITS2_INCHES\x10\x8bQ\x12$\n\x1fLENGTH_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N*\xa3\x01\n\x0cLengthUnits3\x12\x1d\n\x19LENGTH_UNITS3_UNSPECIFIED\x10\x00\x12\x19\n\x14LENGTH_UNITS3_METERS\x10\xebO\x12\x19\n\x14LENGTH_UNITS3_INCHES\x10\x8bQ\x12\x18\n\x13LENGTH_UNITS3_TICKS\x10\xc0P\x12$\n\x1fLENGTH_UNITS3_FROM_CUSTOM_SCALE\x10\xd1N*C\n\x06Level1\x12\x16\n\x12LEVEL1_UNSPECIFIED\x10\x00\x12\x10\n\x0bLEVEL1_HIGH\x10\xd0O\x12\x0f\n\nLEVEL1_LOW\x10\xe6O*U\n\x0cLineGrouping\x12\x1f\n\x1bLINE_GROUPING_CHAN_PER_LINE\x10\x00\x12$\n LINE_GROUPING_CHAN_FOR_ALL_LINES\x10\x01*y\n\x0bLoggingMode\x12\x1c\n\x18LOGGING_MODE_UNSPECIFIED\x10\x00\x12\x15\n\x10LOGGING_MODE_OFF\x10\xf7O\x12\x15\n\x10LOGGING_MODE_LOG\x10\xe4{\x12\x1e\n\x19LOGGING_MODE_LOG_AND_READ\x10\xe2{*\xc2\x01\n\x10LoggingOperation\x12!\n\x1dLOGGING_OPERATION_UNSPECIFIED\x10\x00\x12\x1b\n\x16LOGGING_OPERATION_OPEN\x10\xc5Q\x12%\n LOGGING_OPERATION_OPEN_OR_CREATE\x10\xe6{\x12(\n#LOGGING_OPERATION_CREATE_OR_REPLACE\x10\xe7{\x12\x1d\n\x18LOGGING_OPERATION_CREATE\x10\xe8{*~\n\x0bLogicFamily\x12\x1c\n\x18LOGIC_FAMILY_UNSPECIFIED\x10\x00\x12\x1c\n\x17LOGIC_FAMILY_2POINT_5_V\x10\x9cr\x12\x1c\n\x17LOGIC_FAMILY_3POINT_3_V\x10\x9dr\x12\x15\n\x10LOGIC_FAMILY_5_V\x10\x9br*]\n\tPolarity2\x12\x19\n\x15POLARITY2_UNSPECIFIED\x10\x00\x12\x1a\n\x15POLARITY2_ACTIVE_HIGH\x10\xefN\x12\x19\n\x14POLARITY2_ACTIVE_LOW\x10\xf0N*\x9c\x01\n\x12PowerUpChannelType\x12)\n%POWER_UP_CHANNEL_TYPE_CHANNEL_VOLTAGE\x10\x00\x12)\n%POWER_UP_CHANNEL_TYPE_CHANNEL_CURRENT\x10\x01\x12\x30\n,POWER_UP_CHANNEL_TYPE_CHANNEL_HIGH_IMPEDANCE\x10\x02*\x84\x01\n\rPowerUpStates\x12\x1f\n\x1bPOWER_UP_STATES_UNSPECIFIED\x10\x00\x12\x19\n\x14POWER_UP_STATES_HIGH\x10\xd0O\x12\x18\n\x13POWER_UP_STATES_LOW\x10\xe6O\x12\x1d\n\x18POWER_UP_STATES_TRISTATE\x10\xc6P*\xb8\x01\n\rPressureUnits\x12\x1e\n\x1aPRESSURE_UNITS_UNSPECIFIED\x10\x00\x12\x1b\n\x16PRESSURE_UNITS_PASCALS\x10\xe1N\x12*\n%PRESSURE_UNITS_POUNDS_PER_SQUARE_INCH\x10\x87|\x12\x17\n\x12PRESSURE_UNITS_BAR\x10\x88|\x12%\n PRESSURE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*\xcc\x01\n\x08RTDType1\x12\x19\n\x15RTD_TYPE1_UNSPECIFIED\x10\x00\x12\x16\n\x11RTD_TYPE1_PT_3750\x10\xc1\x61\x12\x16\n\x11RTD_TYPE1_PT_3851\x10\xd7N\x12\x16\n\x11RTD_TYPE1_PT_3911\x10\xc2\x61\x12\x16\n\x11RTD_TYPE1_PT_3916\x10\xd5N\x12\x16\n\x11RTD_TYPE1_PT_3920\x10\xc5N\x12\x16\n\x11RTD_TYPE1_PT_3928\x10\xc3\x61\x12\x15\n\x10RTD_TYPE1_CUSTOM\x10\x99O*\xb4\x01\n\x15RVDTSensitivityUnits1\x12\'\n#RVDT_SENSITIVITY_UNITS1_UNSPECIFIED\x10\x00\x12\x38\n3RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_DEGREE\x10\xdb\x61\x12\x38\n3RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_RADIAN\x10\xdc\x61*\xb2\x01\n\x17ResistanceConfiguration\x12(\n$RESISTANCE_CONFIGURATION_UNSPECIFIED\x10\x00\x12#\n\x1fRESISTANCE_CONFIGURATION_2_WIRE\x10\x02\x12#\n\x1fRESISTANCE_CONFIGURATION_3_WIRE\x10\x03\x12#\n\x1fRESISTANCE_CONFIGURATION_4_WIRE\x10\x04*|\n\x10ResistanceUnits2\x12!\n\x1dRESISTANCE_UNITS2_UNSPECIFIED\x10\x00\x12\x1b\n\x16RESISTANCE_UNITS2_OHMS\x10\x90Q\x12(\n#RESISTANCE_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N*k\n\rResistorState\x12\x1e\n\x1aRESISTOR_STATE_UNSPECIFIED\x10\x00\x12\x1b\n\x16RESISTOR_STATE_PULL_UP\x10\xce|\x12\x1d\n\x18RESISTOR_STATE_PULL_DOWN\x10\xcf|*\xa0\x01\n\x0bSaveOptions\x12\x1c\n\x18SAVE_OPTIONS_UNSPECIFIED\x10\x00\x12\x1a\n\x16SAVE_OPTIONS_OVERWRITE\x10\x01\x12*\n&SAVE_OPTIONS_ALLOW_INTERACTIVE_EDITING\x10\x02\x12+\n\'SAVE_OPTIONS_ALLOW_INTERACTIVE_DELETION\x10\x04*\x83\x01\n\x0eShuntCalSelect\x12 \n\x1cSHUNT_CAL_SELECT_UNSPECIFIED\x10\x00\x12\x17\n\x12SHUNT_CAL_SELECT_A\x10\xe1\x61\x12\x17\n\x12SHUNT_CAL_SELECT_B\x10\xe2\x61\x12\x1d\n\x18SHUNT_CAL_SELECT_A_AND_B\x10\xe3\x61*\x9e\x01\n\x0eShuntCalSource\x12 \n\x1cSHUNT_CAL_SOURCE_UNSPECIFIED\x10\x00\x12%\n\x18SHUNT_CAL_SOURCE_DEFAULT\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1e\n\x19SHUNT_CAL_SOURCE_BUILT_IN\x10\xd8O\x12#\n\x1eSHUNT_CAL_SOURCE_USER_PROVIDED\x10\xb7O*\xe0\x01\n\x14ShuntElementLocation\x12&\n\"SHUNT_ELEMENT_LOCATION_UNSPECIFIED\x10\x00\x12\x1e\n\x19SHUNT_ELEMENT_LOCATION_R1\x10\xb1\x61\x12\x1e\n\x19SHUNT_ELEMENT_LOCATION_R2\x10\xb2\x61\x12\x1e\n\x19SHUNT_ELEMENT_LOCATION_R3\x10\xb3\x61\x12\x1e\n\x19SHUNT_ELEMENT_LOCATION_R4\x10\xdds\x12 \n\x1bSHUNT_ELEMENT_LOCATION_NONE\x10\xf6O*\x93\x03\n\x06Signal\x12\x16\n\x12SIGNAL_UNSPECIFIED\x10\x00\x12\x1c\n\x17SIGNAL_AI_CONVERT_CLOCK\x10\xc4\x61\x12\x1c\n\x17SIGNAL_10_MHZ_REF_CLOCK\x10\xf8\x61\x12!\n\x1cSIGNAL_20_MHZ_TIMEBASE_CLOCK\x10\xc6\x61\x12\x18\n\x13SIGNAL_SAMPLE_CLOCK\x10\xc7\x61\x12\x1b\n\x16SIGNAL_ADVANCE_TRIGGER\x10\xc8\x61\x12\x1d\n\x18SIGNAL_REFERENCE_TRIGGER\x10\xca\x61\x12\x19\n\x14SIGNAL_START_TRIGGER\x10\xcb\x61\x12\x1b\n\x16SIGNAL_ADV_CMPLT_EVENT\x10\xcc\x61\x12\x1f\n\x1aSIGNAL_AI_HOLD_CMPLT_EVENT\x10\xcd\x61\x12 \n\x1bSIGNAL_COUNTER_OUTPUT_EVENT\x10\xce\x61\x12\"\n\x1dSIGNAL_CHANGE_DETECTION_EVENT\x10\xdf\x61\x12\x1d\n\x18SIGNAL_WDT_EXPIRED_EVENT\x10\xe0\x61*\xa9\x01\n\x07Signal2\x12\x17\n\x13SIGNAL2_UNSPECIFIED\x10\x00\x12\"\n\x1dSIGNAL2_SAMPLE_COMPLETE_EVENT\x10\xf2\x61\x12!\n\x1cSIGNAL2_COUNTER_OUTPUT_EVENT\x10\xce\x61\x12#\n\x1eSIGNAL2_CHANGE_DETECTION_EVENT\x10\xdf\x61\x12\x19\n\x14SIGNAL2_SAMPLE_CLOCK\x10\xc7\x61*U\n\x06Slope1\x12\x16\n\x12SLOPE1_UNSPECIFIED\x10\x00\x12\x18\n\x13SLOPE1_RISING_SLOPE\x10\xa8P\x12\x19\n\x14SLOPE1_FALLING_SLOPE\x10\xbbO*\x8e\x01\n\x13SoundPressureUnits1\x12%\n!SOUND_PRESSURE_UNITS1_UNSPECIFIED\x10\x00\x12\"\n\x1dSOUND_PRESSURE_UNITS1_PASCALS\x10\xe1N\x12,\n\'SOUND_PRESSURE_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N*\x87\x03\n\x15StrainGageBridgeType1\x12(\n$STRAIN_GAGE_BRIDGE_TYPE1_UNSPECIFIED\x10\x00\x12+\n&STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_I\x10\xc7O\x12,\n\'STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_II\x10\xc8O\x12-\n(STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_III\x10\xc9O\x12+\n&STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_I\x10\xccO\x12,\n\'STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_II\x10\xcdO\x12.\n)STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_I\x10\x9fP\x12/\n*STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_II\x10\xa0P*\xcc\x01\n\x15StrainGageRosetteType\x12(\n$STRAIN_GAGE_ROSETTE_TYPE_UNSPECIFIED\x10\x00\x12\x31\n,STRAIN_GAGE_ROSETTE_TYPE_RECTANGULAR_ROSETTE\x10\xe0|\x12+\n&STRAIN_GAGE_ROSETTE_TYPE_DELTA_ROSETTE\x10\xe1|\x12)\n$STRAIN_GAGE_ROSETTE_TYPE_TEE_ROSETTE\x10\xe2|*n\n\x0cStrainUnits1\x12\x1d\n\x19STRAIN_UNITS1_UNSPECIFIED\x10\x00\x12\x19\n\x14STRAIN_UNITS1_STRAIN\x10\xbbP\x12$\n\x1fSTRAIN_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N*e\n\tTEDSUnits\x12\x1a\n\x16TEDS_UNITS_UNSPECIFIED\x10\x00\x12!\n\x1cTEDS_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12\x19\n\x14TEDS_UNITS_FROM_TEDS\x10\xe4\x61*\x96\x02\n\x11TaskControlAction\x12\"\n\x1eTASK_CONTROL_ACTION_TASK_START\x10\x00\x12!\n\x1dTASK_CONTROL_ACTION_TASK_STOP\x10\x01\x12#\n\x1fTASK_CONTROL_ACTION_TASK_VERIFY\x10\x02\x12#\n\x1fTASK_CONTROL_ACTION_TASK_COMMIT\x10\x03\x12$\n TASK_CONTROL_ACTION_TASK_RESERVE\x10\x04\x12&\n\"TASK_CONTROL_ACTION_TASK_UNRESERVE\x10\x05\x12\"\n\x1eTASK_CONTROL_ACTION_TASK_ABORT\x10\x06*\xaf\x01\n\x10TemperatureUnits\x12!\n\x1dTEMPERATURE_UNITS_UNSPECIFIED\x10\x00\x12\x1c\n\x17TEMPERATURE_UNITS_DEG_C\x10\x9fO\x12\x1c\n\x17TEMPERATURE_UNITS_DEG_F\x10\xa0O\x12\x1e\n\x19TEMPERATURE_UNITS_KELVINS\x10\xd5P\x12\x1c\n\x17TEMPERATURE_UNITS_DEG_R\x10\xa1O*\xcf\x02\n\x11ThermocoupleType1\x12\"\n\x1eTHERMOCOUPLE_TYPE1_UNSPECIFIED\x10\x00\x12!\n\x1cTHERMOCOUPLE_TYPE1_J_TYPE_TC\x10\xd8N\x12!\n\x1cTHERMOCOUPLE_TYPE1_K_TYPE_TC\x10\xd9N\x12!\n\x1cTHERMOCOUPLE_TYPE1_N_TYPE_TC\x10\xddN\x12!\n\x1cTHERMOCOUPLE_TYPE1_R_TYPE_TC\x10\xe2N\x12!\n\x1cTHERMOCOUPLE_TYPE1_S_TYPE_TC\x10\xe5N\x12!\n\x1cTHERMOCOUPLE_TYPE1_T_TYPE_TC\x10\xe6N\x12!\n\x1cTHERMOCOUPLE_TYPE1_B_TYPE_TC\x10\xbfN\x12!\n\x1cTHERMOCOUPLE_TYPE1_E_TYPE_TC\x10\xc7N*c\n\tTimeUnits\x12\x1a\n\x16TIME_UNITS_UNSPECIFIED\x10\x00\x12\x17\n\x12TIME_UNITS_SECONDS\x10\xfcP\x12!\n\x1cTIME_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*\x7f\n\nTimeUnits3\x12\x1b\n\x17TIME_UNITS3_UNSPECIFIED\x10\x00\x12\x18\n\x13TIME_UNITS3_SECONDS\x10\xfcP\x12\x16\n\x11TIME_UNITS3_TICKS\x10\xc0P\x12\"\n\x1dTIME_UNITS3_FROM_CUSTOM_SCALE\x10\xd1N*c\n\nTimescale2\x12\x1a\n\x16TIMESCALE2_UNSPECIFIED\x10\x00\x12\x19\n\x14TIMESCALE2_HOST_TIME\x10\xfe}\x12\x1e\n\x19TIMESCALE2_IO_DEVICE_TIME\x10\xff}*\xd2\x01\n\x0eTimestampEvent\x12\x1f\n\x1bTIMESTAMP_EVENT_UNSPECIFIED\x10\x00\x12\"\n\x1dTIMESTAMP_EVENT_START_TRIGGER\x10\xcb\x61\x12&\n!TIMESTAMP_EVENT_REFERENCE_TRIGGER\x10\xca\x61\x12&\n!TIMESTAMP_EVENT_ARM_START_TRIGGER\x10\xb1r\x12+\n&TIMESTAMP_EVENT_FIRST_SAMPLE_TIMESTAMP\x10\x82~*\xce\x01\n\x0bTorqueUnits\x12\x1c\n\x18TORQUE_UNITS_UNSPECIFIED\x10\x00\x12\x1f\n\x1aTORQUE_UNITS_NEWTON_METERS\x10\x89|\x12\x1d\n\x18TORQUE_UNITS_INCH_OUNCES\x10\x8a|\x12\x1d\n\x18TORQUE_UNITS_INCH_POUNDS\x10\x8b|\x12\x1d\n\x18TORQUE_UNITS_FOOT_POUNDS\x10\x8c|\x12#\n\x1eTORQUE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*\xb4\n\n\x0eUnitsPreScaled\x12 \n\x1cUNITS_PRE_SCALED_UNSPECIFIED\x10\x00\x12\x1b\n\x16UNITS_PRE_SCALED_VOLTS\x10\xecP\x12\x1a\n\x15UNITS_PRE_SCALED_AMPS\x10\xe6P\x12\x1b\n\x16UNITS_PRE_SCALED_DEG_F\x10\xa0O\x12\x1b\n\x16UNITS_PRE_SCALED_DEG_C\x10\x9fO\x12\x1b\n\x16UNITS_PRE_SCALED_DEG_R\x10\xa1O\x12\x1d\n\x18UNITS_PRE_SCALED_KELVINS\x10\xd5P\x12\x1c\n\x17UNITS_PRE_SCALED_STRAIN\x10\xbbP\x12\x1a\n\x15UNITS_PRE_SCALED_OHMS\x10\x90Q\x12\x18\n\x13UNITS_PRE_SCALED_HZ\x10\x85Q\x12\x1d\n\x18UNITS_PRE_SCALED_SECONDS\x10\xfcP\x12\x1c\n\x17UNITS_PRE_SCALED_METERS\x10\xebO\x12\x1c\n\x17UNITS_PRE_SCALED_INCHES\x10\x8bQ\x12\x1d\n\x18UNITS_PRE_SCALED_DEGREES\x10\xa2O\x12\x1d\n\x18UNITS_PRE_SCALED_RADIANS\x10\xa1P\x12\x1b\n\x16UNITS_PRE_SCALED_TICKS\x10\xc0P\x12\x19\n\x14UNITS_PRE_SCALED_RPM\x10\xd0}\x12(\n#UNITS_PRE_SCALED_RADIANS_PER_SECOND\x10\xd1}\x12(\n#UNITS_PRE_SCALED_DEGREES_PER_SECOND\x10\xd2}\x12\x17\n\x12UNITS_PRE_SCALED_G\x10\xcaO\x12/\n*UNITS_PRE_SCALED_METERS_PER_SECOND_SQUARED\x10\xb6\x61\x12/\n*UNITS_PRE_SCALED_INCHES_PER_SECOND_SQUARED\x10\xb7\x61\x12\'\n\"UNITS_PRE_SCALED_METERS_PER_SECOND\x10\xd7|\x12\'\n\"UNITS_PRE_SCALED_INCHES_PER_SECOND\x10\xd8|\x12\x1d\n\x18UNITS_PRE_SCALED_PASCALS\x10\xe1N\x12\x1d\n\x18UNITS_PRE_SCALED_NEWTONS\x10\x83|\x12\x1c\n\x17UNITS_PRE_SCALED_POUNDS\x10\x84|\x12$\n\x1fUNITS_PRE_SCALED_KILOGRAM_FORCE\x10\x85|\x12,\n\'UNITS_PRE_SCALED_POUNDS_PER_SQUARE_INCH\x10\x87|\x12\x19\n\x14UNITS_PRE_SCALED_BAR\x10\x88|\x12#\n\x1eUNITS_PRE_SCALED_NEWTON_METERS\x10\x89|\x12!\n\x1cUNITS_PRE_SCALED_INCH_OUNCES\x10\x8a|\x12!\n\x1cUNITS_PRE_SCALED_INCH_POUNDS\x10\x8b|\x12!\n\x1cUNITS_PRE_SCALED_FOOT_POUNDS\x10\x8c|\x12$\n\x1fUNITS_PRE_SCALED_VOLTS_PER_VOLT\x10\x98|\x12&\n!UNITS_PRE_SCALED_M_VOLTS_PER_VOLT\x10\x99|\x12\x1e\n\x19UNITS_PRE_SCALED_COULOMBS\x10\xe6}\x12#\n\x1eUNITS_PRE_SCALED_PICO_COULOMBS\x10\xe7}\x12\x1f\n\x1aUNITS_PRE_SCALED_FROM_TEDS\x10\xe4\x61*\xfb\x01\n\"VelocityIEPESensorSensitivityUnits\x12\x36\n2VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_UNSPECIFIED\x10\x00\x12P\nKVELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLIVOLTS_PER_MILLIMETER_PER_SECOND\x10\xdb|\x12K\nFVELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLI_VOLTS_PER_INCH_PER_SECOND\x10\xdc|*\xa4\x01\n\rVelocityUnits\x12\x1e\n\x1aVELOCITY_UNITS_UNSPECIFIED\x10\x00\x12%\n VELOCITY_UNITS_METERS_PER_SECOND\x10\xd7|\x12%\n VELOCITY_UNITS_INCHES_PER_SECOND\x10\xd8|\x12%\n VELOCITY_UNITS_FROM_CUSTOM_SCALE\x10\xd1N*q\n\rVoltageUnits2\x12\x1e\n\x1aVOLTAGE_UNITS2_UNSPECIFIED\x10\x00\x12\x19\n\x14VOLTAGE_UNITS2_VOLTS\x10\xecP\x12%\n VOLTAGE_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N*\xb3\x01\n\x14WatchdogAOOutputType\x12\'\n#WATCHDOG_AO_OUTPUT_TYPE_UNSPECIFIED\x10\x00\x12$\n\x1fWATCHDOG_AO_OUTPUT_TYPE_VOLTAGE\x10\xd2P\x12$\n\x1fWATCHDOG_AO_OUTPUT_TYPE_CURRENT\x10\x96O\x12&\n!WATCHDOG_AO_OUTPUT_TYPE_NO_CHANGE\x10\xb0O*\xac\x01\n\x14WatchdogCOExpirState\x12\'\n#WATCHDOG_CO_EXPIR_STATE_UNSPECIFIED\x10\x00\x12 \n\x1bWATCHDOG_CO_EXPIR_STATE_LOW\x10\xe6O\x12!\n\x1cWATCHDOG_CO_EXPIR_STATE_HIGH\x10\xd0O\x12&\n!WATCHDOG_CO_EXPIR_STATE_NO_CHANGE\x10\xb0O*n\n\x15WatchdogControlAction\x12\'\n#WATCHDOG_CONTROL_ACTION_RESET_TIMER\x10\x00\x12,\n(WATCHDOG_CONTROL_ACTION_CLEAR_EXPIRATION\x10\x01*\x9d\x01\n\x17WindowTriggerCondition1\x12)\n%WINDOW_TRIGGER_CONDITION1_UNSPECIFIED\x10\x00\x12+\n&WINDOW_TRIGGER_CONDITION1_ENTERING_WIN\x10\xb3O\x12*\n%WINDOW_TRIGGER_CONDITION1_LEAVING_WIN\x10\xe0O*\xc9\x01\n\x15WriteBasicTEDSOptions\x12(\n$WRITE_BASIC_TEDS_OPTIONS_UNSPECIFIED\x10\x00\x12-\n(WRITE_BASIC_TEDS_OPTIONS_WRITE_TO_EEPROM\x10\xfa\x61\x12+\n&WRITE_BASIC_TEDS_OPTIONS_WRITE_TO_PROM\x10\xfb\x61\x12*\n%WRITE_BASIC_TEDS_OPTIONS_DO_NOT_WRITE\x10\xfc\x61*\xdc\x98\x01\n\x1b\x43hannelInt32AttributeValues\x12\x1d\n\x19\x43HANNEL_INT32_UNSPECIFIED\x10\x00\x12+\n\'CHANNEL_INT32_AC_EXCIT_WIRE_MODE_4_WIRE\x10\x04\x12+\n\'CHANNEL_INT32_AC_EXCIT_WIRE_MODE_5_WIRE\x10\x05\x12+\n\'CHANNEL_INT32_AC_EXCIT_WIRE_MODE_6_WIRE\x10\x06\x12,\n\'CHANNEL_INT32_ADC_TIMING_MODE_AUTOMATIC\x10\xe1}\x12\x32\n-CHANNEL_INT32_ADC_TIMING_MODE_HIGH_RESOLUTION\x10\xd3O\x12-\n(CHANNEL_INT32_ADC_TIMING_MODE_HIGH_SPEED\x10\xf8r\x12\x37\n2CHANNEL_INT32_ADC_TIMING_MODE_BEST_50_HZ_REJECTION\x10\xf9r\x12\x37\n2CHANNEL_INT32_ADC_TIMING_MODE_BEST_60_HZ_REJECTION\x10\xfar\x12)\n$CHANNEL_INT32_ADC_TIMING_MODE_CUSTOM\x10\x99O\x12.\n)CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE\x10\xd2P\x12\x32\n-CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS\x10\xeeP\x12.\n)CHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT\x10\x96O\x12\x32\n-CHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS\x10\xefP\x12\x45\n@CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION\x10\xd3P\x12-\n(CHANNEL_INT32_AI_MEASUREMENT_TYPE_BRIDGE\x10\xa4|\x12\x33\n.CHANNEL_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE\x10\xc5O\x12\x31\n,CHANNEL_INT32_AI_MEASUREMENT_TYPE_RESISTANCE\x10\xa6P\x12.\n)CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_TC\x10\xbfP\x12\x33\n.CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR\x10\xbeP\x12/\n*CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD\x10\xbdP\x12;\n6CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR\x10\xc7P\x12\x32\n-CHANNEL_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE\x10\xbcP\x12:\n5CHANNEL_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE\x10\xec|\x12\x34\n/CHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT\x10\xf0P\x12\x34\n/CHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT\x10\xf1P\x12L\nGCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE\x10\xf3s\x12\x34\n/CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER\x10\xf4P\x12:\n5CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE\x10\xe8}\x12\x45\n@CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE\x10\xea}\x12;\n6CHANNEL_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR\x10\xde|\x12\x33\n.CHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE\x10\x9b|\x12\x38\n3CHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR\x10\x97|\x12\x36\n1CHANNEL_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE\x10\x9e|\x12@\n;CHANNEL_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE\x10\xf2P\x12\x34\n/CHANNEL_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE\x10\xa1|\x12\x32\n-CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR\x10\xf3\x61\x12-\n(CHANNEL_INT32_AI_MEASUREMENT_TYPE_CHARGE\x10\xe9}\x12,\n\'CHANNEL_INT32_AI_MEASUREMENT_TYPE_POWER\x10\xc9~\x12\x35\n0CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_ZERO_VOLTS\x10\xee\x61\x12\x39\n4CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_HIGH_IMPEDANCE\x10\xef\x61\x12\x42\n=CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE\x10\xf0\x61\x12\x31\n,CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE\x10\xd2P\x12\x31\n,CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT\x10\x96O\x12\x32\n-CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN\x10\x9es\x12\x45\n@CHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_G\x10\xe3}\x12]\nXCHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_METERS_PER_SECOND_SQUARED\x10\xe4}\x12]\nXCHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_INCHES_PER_SECOND_SQUARED\x10\xe5}\x12\x39\n4CHANNEL_INT32_ACCEL_SENSITIVITY_UNITS1_M_VOLTS_PER_G\x10\xdd\x61\x12\x37\n2CHANNEL_INT32_ACCEL_SENSITIVITY_UNITS1_VOLTS_PER_G\x10\xde\x61\x12,\n\'CHANNEL_INT32_ACCEL_UNITS2_ACCEL_UNIT_G\x10\xcaO\x12\x39\n4CHANNEL_INT32_ACCEL_UNITS2_METERS_PER_SECOND_SQUARED\x10\xb6\x61\x12\x39\n4CHANNEL_INT32_ACCEL_UNITS2_INCHES_PER_SECOND_SQUARED\x10\xb7\x61\x12\x31\n,CHANNEL_INT32_ACCEL_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N\x12\'\n\"CHANNEL_INT32_ANGLE_UNITS1_DEGREES\x10\xa2O\x12\'\n\"CHANNEL_INT32_ANGLE_UNITS1_RADIANS\x10\xa1P\x12\x31\n,CHANNEL_INT32_ANGLE_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N\x12\'\n\"CHANNEL_INT32_ANGLE_UNITS2_DEGREES\x10\xa2O\x12\'\n\"CHANNEL_INT32_ANGLE_UNITS2_RADIANS\x10\xa1P\x12%\n CHANNEL_INT32_ANGLE_UNITS2_TICKS\x10\xc0P\x12\x31\n,CHANNEL_INT32_ANGLE_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N\x12\'\n\"CHANNEL_INT32_ANGLE_UNITS3_DEGREES\x10\xa2O\x12\x31\n,CHANNEL_INT32_ANGLE_UNITS3_FROM_CUSTOM_SCALE\x10\xd1N\x12-\n(CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_RPM\x10\xd0}\x12<\n7CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_RADIANS_PER_SECOND\x10\xd1}\x12<\n7CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_DEGREES_PER_SECOND\x10\xd2}\x12;\n6CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12\'\n\"CHANNEL_INT32_AUTO_ZERO_TYPE1_NONE\x10\xf6O\x12\'\n\"CHANNEL_INT32_AUTO_ZERO_TYPE1_ONCE\x10\x84P\x12/\n*CHANNEL_INT32_AUTO_ZERO_TYPE1_EVERY_SAMPLE\x10\xb4O\x12\x34\n/CHANNEL_INT32_BRIDGE_CONFIGURATION1_FULL_BRIDGE\x10\xc6O\x12\x34\n/CHANNEL_INT32_BRIDGE_CONFIGURATION1_HALF_BRIDGE\x10\xcbO\x12\x37\n2CHANNEL_INT32_BRIDGE_CONFIGURATION1_QUARTER_BRIDGE\x10\x9eP\x12\x32\n-CHANNEL_INT32_BRIDGE_CONFIGURATION1_NO_BRIDGE\x10\xf4O\x12\x39\n4CHANNEL_INT32_BRIDGE_ELECTRICAL_UNITS_VOLTS_PER_VOLT\x10\x98|\x12;\n6CHANNEL_INT32_BRIDGE_ELECTRICAL_UNITS_M_VOLTS_PER_VOLT\x10\x99|\x12\x30\n+CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_NEWTONS\x10\x83|\x12/\n*CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_POUNDS\x10\x84|\x12\x37\n2CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_KILOGRAM_FORCE\x10\x85|\x12\x30\n+CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_PASCALS\x10\xe1N\x12?\n:CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_POUNDS_PER_SQUARE_INCH\x10\x87|\x12,\n\'CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_BAR\x10\x88|\x12\x36\n1CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_NEWTON_METERS\x10\x89|\x12\x34\n/CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_INCH_OUNCES\x10\x8a|\x12\x34\n/CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_INCH_POUNDS\x10\x8b|\x12\x34\n/CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_FOOT_POUNDS\x10\x8c|\x12\x33\n.CHANNEL_INT32_BRIDGE_SHUNT_CAL_SOURCE_BUILT_IN\x10\xd8O\x12\x38\n3CHANNEL_INT32_BRIDGE_SHUNT_CAL_SOURCE_USER_PROVIDED\x10\xb7O\x12.\n)CHANNEL_INT32_BRIDGE_UNITS_VOLTS_PER_VOLT\x10\x98|\x12\x30\n+CHANNEL_INT32_BRIDGE_UNITS_M_VOLTS_PER_VOLT\x10\x99|\x12\x31\n,CHANNEL_INT32_BRIDGE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12)\n$CHANNEL_INT32_BRIDGE_UNITS_FROM_TEDS\x10\xe4\x61\x12\x32\n-CHANNEL_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES\x10\x8dO\x12+\n&CHANNEL_INT32_CI_MEASUREMENT_TYPE_FREQ\x10\xc3O\x12-\n(CHANNEL_INT32_CI_MEASUREMENT_TYPE_PERIOD\x10\x90P\x12\x32\n-CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH\x10\xf7P\x12\x32\n-CHANNEL_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD\x10\xb1P\x12\x36\n1CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY\x10\xf8{\x12\x31\n,CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME\x10\xf9{\x12\x32\n-CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS\x10\xfa{\x12\x31\n,CHANNEL_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE\x10\xc6}\x12;\n6CHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER\x10\xf8P\x12;\n6CHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER\x10\xf9P\x12;\n6CHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER\x10\xce}\x12;\n6CHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER\x10\xcf}\x12\x33\n.CHANNEL_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP\x10\x9bP\x12\x34\n/CHANNEL_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP\x10\xfaP\x12\'\n\"CHANNEL_INT32_CJC_SOURCE1_BUILT_IN\x10\xd8O\x12(\n#CHANNEL_INT32_CJC_SOURCE1_CONST_VAL\x10\x84O\x12#\n\x1e\x43HANNEL_INT32_CJC_SOURCE1_CHAN\x10\x81O\x12,\n\'CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TIME\x10\x9dP\x12,\n\'CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_FREQ\x10\x87O\x12-\n(CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TICKS\x10\x9cP\x12\"\n\x1d\x43HANNEL_INT32_CHANNEL_TYPE_AI\x10\xf4N\x12\"\n\x1d\x43HANNEL_INT32_CHANNEL_TYPE_AO\x10\xf6N\x12\"\n\x1d\x43HANNEL_INT32_CHANNEL_TYPE_DI\x10\xa7O\x12\"\n\x1d\x43HANNEL_INT32_CHANNEL_TYPE_DO\x10\xa9O\x12\"\n\x1d\x43HANNEL_INT32_CHANNEL_TYPE_CI\x10\x93O\x12\"\n\x1d\x43HANNEL_INT32_CHANNEL_TYPE_CO\x10\x94O\x12(\n#CHANNEL_INT32_CHARGE_UNITS_COULOMBS\x10\xe6}\x12-\n(CHANNEL_INT32_CHARGE_UNITS_PICO_COULOMBS\x10\xe7}\x12\x31\n,CHANNEL_INT32_CHARGE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12\x35\n0CHANNEL_INT32_CONSTRAINED_GEN_MODE_UNCONSTRAINED\x10\xf4r\x12\x37\n2CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_HIGH_FREQ\x10\xf5r\x12\x36\n1CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_LOW_FREQ\x10\xf6r\x12\x43\n>CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_50_PERCENT_DUTY_CYCLE\x10\xf7r\x12,\n\'CHANNEL_INT32_COUNT_DIRECTION1_COUNT_UP\x10\x90O\x12.\n)CHANNEL_INT32_COUNT_DIRECTION1_COUNT_DOWN\x10\x8cO\x12\x32\n-CHANNEL_INT32_COUNT_DIRECTION1_EXT_CONTROLLED\x10\xd6P\x12:\n5CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_LOW_FREQ_1_CTR\x10\xf9N\x12;\n6CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_HIGH_FREQ_2_CTR\x10\xadO\x12;\n6CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_LARGE_RNG_2_CTR\x10\xddO\x12\x33\n.CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_DYN_AVG\x10\xc1}\x12\x1f\n\x1a\x43HANNEL_INT32_COUPLING1_AC\x10\xbdN\x12\x1f\n\x1a\x43HANNEL_INT32_COUPLING1_DC\x10\xc2N\x12 \n\x1b\x43HANNEL_INT32_COUPLING1_GND\x10\xd2N\x12<\n7CHANNEL_INT32_CURRENT_SHUNT_RESISTOR_LOCATION1_INTERNAL\x10\xd8O\x12<\n7CHANNEL_INT32_CURRENT_SHUNT_RESISTOR_LOCATION1_EXTERNAL\x10\xb7O\x12&\n!CHANNEL_INT32_CURRENT_UNITS1_AMPS\x10\xe6P\x12\x33\n.CHANNEL_INT32_CURRENT_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N\x12+\n&CHANNEL_INT32_CURRENT_UNITS1_FROM_TEDS\x10\xe4\x61\x12\x36\n1CHANNEL_INT32_DATA_JUSTIFICATION1_RIGHT_JUSTIFIED\x10\xa7P\x12\x35\n0CHANNEL_INT32_DATA_JUSTIFICATION1_LEFT_JUSTIFIED\x10\xe1O\x12.\n)CHANNEL_INT32_DATA_TRANSFER_MECHANISM_DMA\x10\xc6N\x12\x35\n0CHANNEL_INT32_DATA_TRANSFER_MECHANISM_INTERRUPTS\x10\xdcO\x12\x38\n3CHANNEL_INT32_DATA_TRANSFER_MECHANISM_PROGRAMMED_IO\x10\x98P\x12\x33\n.CHANNEL_INT32_DATA_TRANSFER_MECHANISM_US_BBULK\x10\xae\x62\x12\x32\n-CHANNEL_INT32_DIGITAL_DRIVE_TYPE_ACTIVE_DRIVE\x10\x9d\x62\x12\x34\n/CHANNEL_INT32_DIGITAL_DRIVE_TYPE_OPEN_COLLECTOR\x10\x9e\x62\x12*\n%CHANNEL_INT32_DIGITAL_LINE_STATE_HIGH\x10\xd0O\x12)\n$CHANNEL_INT32_DIGITAL_LINE_STATE_LOW\x10\xe6O\x12.\n)CHANNEL_INT32_DIGITAL_LINE_STATE_TRISTATE\x10\xc6P\x12/\n*CHANNEL_INT32_DIGITAL_LINE_STATE_NO_CHANGE\x10\xb0O\x12/\n*CHANNEL_INT32_DIGITAL_WIDTH_UNITS4_SECONDS\x10\xfcP\x12:\n5CHANNEL_INT32_DIGITAL_WIDTH_UNITS4_SAMPLE_CLK_PERIODS\x10\xaeP\x12L\nGCHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MIL\x10\xf4s\x12J\nECHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MIL\x10\xf5s\x12S\nNCHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MILLIMETER\x10\xf6s\x12Q\nLCHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MILLIMETER\x10\xf7s\x12O\nJCHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MICRON\x10\xf8s\x12\x1f\n\x1a\x43HANNEL_INT32_EDGE1_RISING\x10\xa8P\x12 \n\x1b\x43HANNEL_INT32_EDGE1_FALLING\x10\xbbO\x12#\n\x1e\x43HANNEL_INT32_ENCODER_TYPE2_X1\x10\xeaN\x12#\n\x1e\x43HANNEL_INT32_ENCODER_TYPE2_X2\x10\xebN\x12#\n\x1e\x43HANNEL_INT32_ENCODER_TYPE2_X4\x10\xecN\x12\x33\n.CHANNEL_INT32_ENCODER_TYPE2_TWO_PULSE_COUNTING\x10\xc9P\x12\x37\n2CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_HIGH_B_HIGH\x10\xb8N\x12\x36\n1CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_HIGH_B_LOW\x10\xb9N\x12\x36\n1CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_LOW_B_HIGH\x10\xbaN\x12\x35\n0CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_LOW_B_LOW\x10\xbbN\x12)\n$CHANNEL_INT32_EXCITATION_D_COR_AC_DC\x10\xc2N\x12)\n$CHANNEL_INT32_EXCITATION_D_COR_AC_AC\x10\xbdN\x12\x45\n@CHANNEL_INT32_EXCITATION_IDLE_OUTPUT_BEHAVIOR_ZERO_VOLTS_OR_AMPS\x10\xee\x61\x12J\nECHANNEL_INT32_EXCITATION_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE\x10\xf0\x61\x12-\n(CHANNEL_INT32_EXCITATION_SOURCE_INTERNAL\x10\xd8O\x12-\n(CHANNEL_INT32_EXCITATION_SOURCE_EXTERNAL\x10\xb7O\x12)\n$CHANNEL_INT32_EXCITATION_SOURCE_NONE\x10\xf6O\x12\x38\n3CHANNEL_INT32_EXCITATION_VOLTAGE_OR_CURRENT_VOLTAGE\x10\xd2P\x12\x38\n3CHANNEL_INT32_EXCITATION_VOLTAGE_OR_CURRENT_CURRENT\x10\x96O\x12\x37\n2CHANNEL_INT32_FILTER_RESPONSE_CONSTANT_GROUP_DELAY\x10\xcb}\x12.\n)CHANNEL_INT32_FILTER_RESPONSE_BUTTERWORTH\x10\xcc}\x12-\n(CHANNEL_INT32_FILTER_RESPONSE_ELLIPTICAL\x10\xcd}\x12\x33\n.CHANNEL_INT32_FILTER_RESPONSE_HARDWARE_DEFINED\x10\xcfO\x12(\n#CHANNEL_INT32_FILTER_RESPONSE1_COMB\x10\x98~\x12*\n%CHANNEL_INT32_FILTER_RESPONSE1_BESSEL\x10\x99~\x12-\n(CHANNEL_INT32_FILTER_RESPONSE1_BRICKWALL\x10\x9b~\x12/\n*CHANNEL_INT32_FILTER_RESPONSE1_BUTTERWORTH\x10\xcc}\x12\x30\n+CHANNEL_INT32_FILTER_TYPE1_HARDWARE_DEFINED\x10\xcfO\x12\'\n\"CHANNEL_INT32_FILTER_TYPE2_LOWPASS\x10\xc7}\x12(\n#CHANNEL_INT32_FILTER_TYPE2_HIGHPASS\x10\xc8}\x12(\n#CHANNEL_INT32_FILTER_TYPE2_BANDPASS\x10\xc9}\x12%\n CHANNEL_INT32_FILTER_TYPE2_NOTCH\x10\xca}\x12&\n!CHANNEL_INT32_FILTER_TYPE2_CUSTOM\x10\x99O\x12I\nDCHANNEL_INT32_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_NEWTON\x10\x93|\x12H\nCCHANNEL_INT32_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_POUND\x10\x94|\x12&\n!CHANNEL_INT32_FORCE_UNITS_NEWTONS\x10\x83|\x12%\n CHANNEL_INT32_FORCE_UNITS_POUNDS\x10\x84|\x12-\n(CHANNEL_INT32_FORCE_UNITS_KILOGRAM_FORCE\x10\x85|\x12\x30\n+CHANNEL_INT32_FORCE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12%\n CHANNEL_INT32_FREQUENCY_UNITS_HZ\x10\x85Q\x12\x34\n/CHANNEL_INT32_FREQUENCY_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12&\n!CHANNEL_INT32_FREQUENCY_UNITS2_HZ\x10\x85Q\x12&\n!CHANNEL_INT32_FREQUENCY_UNITS3_HZ\x10\x85Q\x12)\n$CHANNEL_INT32_FREQUENCY_UNITS3_TICKS\x10\xc0P\x12\x35\n0CHANNEL_INT32_FREQUENCY_UNITS3_FROM_CUSTOM_SCALE\x10\xd1N\x12%\n CHANNEL_INT32_FUNC_GEN_TYPE_SINE\x10\x9fs\x12)\n$CHANNEL_INT32_FUNC_GEN_TYPE_TRIANGLE\x10\xa0s\x12\'\n\"CHANNEL_INT32_FUNC_GEN_TYPE_SQUARE\x10\xa1s\x12)\n$CHANNEL_INT32_FUNC_GEN_TYPE_SAWTOOTH\x10\xa2s\x12)\n$CHANNEL_INT32_GPS_SIGNAL_TYPE1_IRIGB\x10\xd6N\x12\'\n\"CHANNEL_INT32_GPS_SIGNAL_TYPE1_PPS\x10\xe0N\x12(\n#CHANNEL_INT32_GPS_SIGNAL_TYPE1_NONE\x10\xf6O\x12O\nJCHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_MORE_THAN_HALF_FULL\x10\xfdO\x12\x45\n@CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_NOT_EMPTY\x10\x81P\x12K\nFCHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ONBRD_MEM_CUSTOM_THRESHOLD\x10\xa1\x62\x12\x42\n=CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_WHEN_ACQ_COMPLETE\x10\x82\x62\x12%\n CHANNEL_INT32_INPUT_TERM_CFG_RSE\x10\xe3N\x12&\n!CHANNEL_INT32_INPUT_TERM_CFG_NRSE\x10\xdeN\x12&\n!CHANNEL_INT32_INPUT_TERM_CFG_DIFF\x10\xfaN\x12-\n(CHANNEL_INT32_INPUT_TERM_CFG_PSEUDO_DIFF\x10\xf1\x61\x12\'\n\"CHANNEL_INT32_INPUT_TERM_CFG2_DIFF\x10\xfaN\x12&\n!CHANNEL_INT32_INPUT_TERM_CFG2_RSE\x10\xe3N\x12J\nECHANNEL_INT32_LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLIMETER\x10\xda\x61\x12J\nECHANNEL_INT32_LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLI_INCH\x10\xd9\x61\x12\'\n\"CHANNEL_INT32_LENGTH_UNITS2_METERS\x10\xebO\x12\'\n\"CHANNEL_INT32_LENGTH_UNITS2_INCHES\x10\x8bQ\x12\x32\n-CHANNEL_INT32_LENGTH_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N\x12\'\n\"CHANNEL_INT32_LENGTH_UNITS3_METERS\x10\xebO\x12\'\n\"CHANNEL_INT32_LENGTH_UNITS3_INCHES\x10\x8bQ\x12&\n!CHANNEL_INT32_LENGTH_UNITS3_TICKS\x10\xc0P\x12\x32\n-CHANNEL_INT32_LENGTH_UNITS3_FROM_CUSTOM_SCALE\x10\xd1N\x12\'\n\"CHANNEL_INT32_LENGTH_UNITS4_METERS\x10\xebO\x12%\n CHANNEL_INT32_LENGTH_UNITS4_FEET\x10\x8cQ\x12\x32\n-CHANNEL_INT32_LENGTH_UNITS4_FROM_CUSTOM_SCALE\x10\xd1N\x12\x1e\n\x19\x43HANNEL_INT32_LEVEL1_HIGH\x10\xd0O\x12\x1d\n\x18\x43HANNEL_INT32_LEVEL1_LOW\x10\xe6O\x12*\n%CHANNEL_INT32_LOGIC_FAMILY_2POINT_5_V\x10\x9cr\x12*\n%CHANNEL_INT32_LOGIC_FAMILY_3POINT_3_V\x10\x9dr\x12#\n\x1e\x43HANNEL_INT32_LOGIC_FAMILY_5_V\x10\x9br\x12\x39\n4CHANNEL_INT32_LOGIC_LVL_BEHAVIOR_LOGIC_LEVEL_PULL_UP\x10\xc0}\x12*\n%CHANNEL_INT32_LOGIC_LVL_BEHAVIOR_NONE\x10\xf6O\x12%\n CHANNEL_INT32_MODULATION_TYPE_AM\x10\xa4s\x12%\n CHANNEL_INT32_MODULATION_TYPE_FM\x10\xa5s\x12\'\n\"CHANNEL_INT32_MODULATION_TYPE_NONE\x10\xf6O\x12\x30\n+CHANNEL_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE\x10\xfd|\x12\x31\n,CHANNEL_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE\x10\xfe|\x12\x30\n+CHANNEL_INT32_NAV_MEASUREMENT_TYPE_LATITUDE\x10\xff|\x12\x39\n4CHANNEL_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND\x10\x80}\x12-\n(CHANNEL_INT32_NAV_MEASUREMENT_TYPE_TRACK\x10\x81}\x12\x31\n,CHANNEL_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP\x10\xf2|\x12\x35\n0CHANNEL_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY\x10\x83}\x12\x42\n=CHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_EMPTY\x10\xfbO\x12N\nICHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_HALF_FULL_OR_LESS\x10\xffO\x12\x45\n@CHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_NOT_FULL\x10\x82P\x12&\n!CHANNEL_INT32_OUTPUT_TERM_CFG_RSE\x10\xe3N\x12\'\n\"CHANNEL_INT32_OUTPUT_TERM_CFG_DIFF\x10\xfaN\x12.\n)CHANNEL_INT32_OUTPUT_TERM_CFG_PSEUDO_DIFF\x10\xf1\x61\x12=\n8CHANNEL_INT32_POWER_IDLE_OUTPUT_BEHAVIOR_OUTPUT_DISABLED\x10\x8fy\x12\x45\n@CHANNEL_INT32_POWER_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE\x10\xf0\x61\x12\x36\n1CHANNEL_INT32_POWER_OUTPUT_STATE_CONSTANT_VOLTAGE\x10\x8cy\x12\x36\n1CHANNEL_INT32_POWER_OUTPUT_STATE_CONSTANT_CURRENT\x10\x8dy\x12\x31\n,CHANNEL_INT32_POWER_OUTPUT_STATE_OVERVOLTAGE\x10\x8ey\x12\x35\n0CHANNEL_INT32_POWER_OUTPUT_STATE_OUTPUT_DISABLED\x10\x8fy\x12)\n$CHANNEL_INT32_PRESSURE_UNITS_PASCALS\x10\xe1N\x12\x38\n3CHANNEL_INT32_PRESSURE_UNITS_POUNDS_PER_SQUARE_INCH\x10\x87|\x12%\n CHANNEL_INT32_PRESSURE_UNITS_BAR\x10\x88|\x12\x33\n.CHANNEL_INT32_PRESSURE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12$\n\x1f\x43HANNEL_INT32_RTD_TYPE1_PT_3750\x10\xc1\x61\x12$\n\x1f\x43HANNEL_INT32_RTD_TYPE1_PT_3851\x10\xd7N\x12$\n\x1f\x43HANNEL_INT32_RTD_TYPE1_PT_3911\x10\xc2\x61\x12$\n\x1f\x43HANNEL_INT32_RTD_TYPE1_PT_3916\x10\xd5N\x12$\n\x1f\x43HANNEL_INT32_RTD_TYPE1_PT_3920\x10\xc5N\x12$\n\x1f\x43HANNEL_INT32_RTD_TYPE1_PT_3928\x10\xc3\x61\x12#\n\x1e\x43HANNEL_INT32_RTD_TYPE1_CUSTOM\x10\x99O\x12\x46\nACHANNEL_INT32_RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_DEGREE\x10\xdb\x61\x12\x46\nACHANNEL_INT32_RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_RADIAN\x10\xdc\x61\x12\x31\n,CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_NONE\x10\xf6O\x12=\n8CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_LOSSLESS_PACKING\x10\x8b\x62\x12>\n9CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_LOSSY_LSB_REMOVAL\x10\x8c\x62\x12\x31\n-CHANNEL_INT32_RESISTANCE_CONFIGURATION_2_WIRE\x10\x02\x12\x31\n-CHANNEL_INT32_RESISTANCE_CONFIGURATION_3_WIRE\x10\x03\x12\x31\n-CHANNEL_INT32_RESISTANCE_CONFIGURATION_4_WIRE\x10\x04\x12)\n$CHANNEL_INT32_RESISTANCE_UNITS1_OHMS\x10\x90Q\x12\x36\n1CHANNEL_INT32_RESISTANCE_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N\x12.\n)CHANNEL_INT32_RESISTANCE_UNITS1_FROM_TEDS\x10\xe4\x61\x12(\n#CHANNEL_INT32_RESOLUTION_TYPE1_BITS\x10\xfdN\x12:\n5CHANNEL_INT32_SAMP_CLK_OVERRUN_BEHAVIOR_REPEATED_DATA\x10\xbe}\x12;\n6CHANNEL_INT32_SAMP_CLK_OVERRUN_BEHAVIOR_SENTINEL_VALUE\x10\xbf}\x12V\nQCHANNEL_INT32_SAMPLE_CLOCK_ACTIVE_OR_INACTIVE_EDGE_SELECTION_SAMP_CLK_ACTIVE_EDGE\x10\x99r\x12X\nSCHANNEL_INT32_SAMPLE_CLOCK_ACTIVE_OR_INACTIVE_EDGE_SELECTION_SAMP_CLK_INACTIVE_EDGE\x10\x9ar\x12)\n$CHANNEL_INT32_SCALE_TYPE2_POLYNOMIAL\x10\xd1Q\x12$\n\x1f\x43HANNEL_INT32_SCALE_TYPE2_TABLE\x10\xd2Q\x12)\n$CHANNEL_INT32_SCALE_TYPE3_POLYNOMIAL\x10\xd1Q\x12$\n\x1f\x43HANNEL_INT32_SCALE_TYPE3_TABLE\x10\xd2Q\x12#\n\x1e\x43HANNEL_INT32_SCALE_TYPE3_NONE\x10\xf6O\x12#\n\x1e\x43HANNEL_INT32_SCALE_TYPE4_NONE\x10\xf6O\x12/\n*CHANNEL_INT32_SCALE_TYPE4_TWO_POINT_LINEAR\x10\x9a|\x12$\n\x1f\x43HANNEL_INT32_SCALE_TYPE4_TABLE\x10\xd2Q\x12)\n$CHANNEL_INT32_SCALE_TYPE4_POLYNOMIAL\x10\xd1Q\x12\x1e\n\x19\x43HANNEL_INT32_SENSE_LOCAL\x10\xdf}\x12\x1f\n\x1a\x43HANNEL_INT32_SENSE_REMOTE\x10\xe0}\x12-\n(CHANNEL_INT32_SENSOR_POWER_CFG_NO_CHANGE\x10\xb0O\x12+\n&CHANNEL_INT32_SENSOR_POWER_CFG_ENABLED\x10\x91~\x12,\n\'CHANNEL_INT32_SENSOR_POWER_CFG_DISABLED\x10\x92~\x12\'\n\"CHANNEL_INT32_SENSOR_POWER_TYPE_DC\x10\xc2N\x12\'\n\"CHANNEL_INT32_SENSOR_POWER_TYPE_AC\x10\xbdN\x12/\n*CHANNEL_INT32_SENSOR_POWER_TYPE_BIPOLAR_DC\x10\x93~\x12%\n CHANNEL_INT32_SHUNT_CAL_SELECT_A\x10\xe1\x61\x12%\n CHANNEL_INT32_SHUNT_CAL_SELECT_B\x10\xe2\x61\x12+\n&CHANNEL_INT32_SHUNT_CAL_SELECT_A_AND_B\x10\xe3\x61\x12\x30\n+CHANNEL_INT32_SOUND_PRESSURE_UNITS1_PASCALS\x10\xe1N\x12:\n5CHANNEL_INT32_SOUND_PRESSURE_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N\x12,\n\'CHANNEL_INT32_SOURCE_SELECTION_INTERNAL\x10\xd8O\x12,\n\'CHANNEL_INT32_SOURCE_SELECTION_EXTERNAL\x10\xb7O\x12\x39\n4CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_I\x10\xc7O\x12:\n5CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_II\x10\xc8O\x12;\n6CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_III\x10\xc9O\x12\x39\n4CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_I\x10\xccO\x12:\n5CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_II\x10\xcdO\x12<\n7CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_I\x10\x9fP\x12=\n8CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_II\x10\xa0P\x12J\nECHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_1\x10\xe3|\x12J\nECHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_2\x10\xe4|\x12N\nICHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_ANGLE\x10\xe5|\x12J\nECHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_STRAIN_X\x10\xe6|\x12J\nECHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_STRAIN_Y\x10\xe7|\x12Q\nLCHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_SHEAR_STRAIN_XY\x10\xe8|\x12H\nCCHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_MAX_SHEAR_STRAIN\x10\xe9|\x12N\nICHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_MAX_SHEAR_STRAIN_ANGLE\x10\xea|\x12?\n:CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_RECTANGULAR_ROSETTE\x10\xe0|\x12\x39\n4CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_DELTA_ROSETTE\x10\xe1|\x12\x37\n2CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_TEE_ROSETTE\x10\xe2|\x12\'\n\"CHANNEL_INT32_STRAIN_UNITS1_STRAIN\x10\xbbP\x12\x32\n-CHANNEL_INT32_STRAIN_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N\x12;\n6CHANNEL_INT32_SYNC_UNLOCK_BEHAVIOR_STOP_TASK_AND_ERROR\x10\xf6{\x12=\n8CHANNEL_INT32_SYNC_UNLOCK_BEHAVIOR_IGNORE_LOST_SYNC_LOCK\x10\x81~\x12+\n&CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_C\x10\x9fO\x12+\n&CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_F\x10\xa0O\x12-\n(CHANNEL_INT32_TEMPERATURE_UNITS1_KELVINS\x10\xd5P\x12+\n&CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_R\x10\xa1O\x12\x37\n2CHANNEL_INT32_TEMPERATURE_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N\x12/\n*CHANNEL_INT32_THERMOCOUPLE_TYPE1_J_TYPE_TC\x10\xd8N\x12/\n*CHANNEL_INT32_THERMOCOUPLE_TYPE1_K_TYPE_TC\x10\xd9N\x12/\n*CHANNEL_INT32_THERMOCOUPLE_TYPE1_N_TYPE_TC\x10\xddN\x12/\n*CHANNEL_INT32_THERMOCOUPLE_TYPE1_R_TYPE_TC\x10\xe2N\x12/\n*CHANNEL_INT32_THERMOCOUPLE_TYPE1_S_TYPE_TC\x10\xe5N\x12/\n*CHANNEL_INT32_THERMOCOUPLE_TYPE1_T_TYPE_TC\x10\xe6N\x12/\n*CHANNEL_INT32_THERMOCOUPLE_TYPE1_B_TYPE_TC\x10\xbfN\x12/\n*CHANNEL_INT32_THERMOCOUPLE_TYPE1_E_TYPE_TC\x10\xc7N\x12%\n CHANNEL_INT32_TIME_UNITS_SECONDS\x10\xfcP\x12/\n*CHANNEL_INT32_TIME_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12&\n!CHANNEL_INT32_TIME_UNITS2_SECONDS\x10\xfcP\x12&\n!CHANNEL_INT32_TIME_UNITS3_SECONDS\x10\xfcP\x12$\n\x1f\x43HANNEL_INT32_TIME_UNITS3_TICKS\x10\xc0P\x12\x30\n+CHANNEL_INT32_TIME_UNITS3_FROM_CUSTOM_SCALE\x10\xd1N\x12 \n\x1b\x43HANNEL_INT32_TIMESCALE_TAI\x10\xf4|\x12 \n\x1b\x43HANNEL_INT32_TIMESCALE_UTC\x10\xf3|\x12-\n(CHANNEL_INT32_TORQUE_UNITS_NEWTON_METERS\x10\x89|\x12+\n&CHANNEL_INT32_TORQUE_UNITS_INCH_OUNCES\x10\x8a|\x12+\n&CHANNEL_INT32_TORQUE_UNITS_INCH_POUNDS\x10\x8b|\x12+\n&CHANNEL_INT32_TORQUE_UNITS_FOOT_POUNDS\x10\x8c|\x12\x31\n,CHANNEL_INT32_TORQUE_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12^\nYCHANNEL_INT32_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLIVOLTS_PER_MILLIMETER_PER_SECOND\x10\xdb|\x12Y\nTCHANNEL_INT32_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLI_VOLTS_PER_INCH_PER_SECOND\x10\xdc|\x12\x33\n.CHANNEL_INT32_VELOCITY_UNITS_METERS_PER_SECOND\x10\xd7|\x12\x33\n.CHANNEL_INT32_VELOCITY_UNITS_INCHES_PER_SECOND\x10\xd8|\x12\x33\n.CHANNEL_INT32_VELOCITY_UNITS_FROM_CUSTOM_SCALE\x10\xd1N\x12\x34\n/CHANNEL_INT32_VELOCITY_UNITS2_METERS_PER_SECOND\x10\xd7|\x12\x36\n1CHANNEL_INT32_VELOCITY_UNITS2_KILOMETERS_PER_HOUR\x10\x87}\x12\x32\n-CHANNEL_INT32_VELOCITY_UNITS2_FEET_PER_SECOND\x10\x88}\x12\x31\n,CHANNEL_INT32_VELOCITY_UNITS2_MILES_PER_HOUR\x10\x89}\x12(\n#CHANNEL_INT32_VELOCITY_UNITS2_KNOTS\x10\x8a}\x12\x34\n/CHANNEL_INT32_VELOCITY_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N\x12\'\n\"CHANNEL_INT32_VOLTAGE_UNITS1_VOLTS\x10\xecP\x12\x33\n.CHANNEL_INT32_VOLTAGE_UNITS1_FROM_CUSTOM_SCALE\x10\xd1N\x12+\n&CHANNEL_INT32_VOLTAGE_UNITS1_FROM_TEDS\x10\xe4\x61\x12\'\n\"CHANNEL_INT32_VOLTAGE_UNITS2_VOLTS\x10\xecP\x12\x33\n.CHANNEL_INT32_VOLTAGE_UNITS2_FROM_CUSTOM_SCALE\x10\xd1N\x1a\x02\x10\x01*\xf1\x30\n\x1a\x44\x65viceInt32AttributeValues\x12\x1c\n\x18\x44\x45VICE_INT32_UNSPECIFIED\x10\x00\x12-\n(DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE\x10\xd2P\x12\x31\n,DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS\x10\xeeP\x12-\n(DEVICE_INT32_AI_MEASUREMENT_TYPE_CURRENT\x10\x96O\x12\x31\n,DEVICE_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS\x10\xefP\x12\x44\n?DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION\x10\xd3P\x12,\n\'DEVICE_INT32_AI_MEASUREMENT_TYPE_BRIDGE\x10\xa4|\x12\x32\n-DEVICE_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE\x10\xc5O\x12\x30\n+DEVICE_INT32_AI_MEASUREMENT_TYPE_RESISTANCE\x10\xa6P\x12-\n(DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_TC\x10\xbfP\x12\x32\n-DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR\x10\xbeP\x12.\n)DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD\x10\xbdP\x12:\n5DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR\x10\xc7P\x12\x31\n,DEVICE_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE\x10\xbcP\x12\x39\n4DEVICE_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE\x10\xec|\x12\x33\n.DEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT\x10\xf0P\x12\x33\n.DEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT\x10\xf1P\x12K\nFDEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE\x10\xf3s\x12\x33\n.DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER\x10\xf4P\x12\x39\n4DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE\x10\xe8}\x12\x44\n?DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE\x10\xea}\x12:\n5DEVICE_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR\x10\xde|\x12\x32\n-DEVICE_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE\x10\x9b|\x12\x37\n2DEVICE_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR\x10\x97|\x12\x35\n0DEVICE_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE\x10\x9e|\x12?\n:DEVICE_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE\x10\xf2P\x12\x33\n.DEVICE_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE\x10\xa1|\x12\x31\n,DEVICE_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR\x10\xf3\x61\x12,\n\'DEVICE_INT32_AI_MEASUREMENT_TYPE_CHARGE\x10\xe9}\x12+\n&DEVICE_INT32_AI_MEASUREMENT_TYPE_POWER\x10\xc9~\x12\x30\n+DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE\x10\xd2P\x12\x30\n+DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT\x10\x96O\x12\x31\n,DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN\x10\x9es\x12/\n*DEVICE_INT32_ACQUISITION_TYPE_FINITE_SAMPS\x10\xc2O\x12-\n(DEVICE_INT32_ACQUISITION_TYPE_CONT_SAMPS\x10\x8bO\x12\x38\n3DEVICE_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT\x10\xea\x61\x12\x1d\n\x18\x44\x45VICE_INT32_ALT_REF_MSL\x10\x85}\x12\x1d\n\x18\x44\x45VICE_INT32_ALT_REF_HAE\x10\x86}\x12$\n\x1f\x44\x45VICE_INT32_ANT_STATUS_UNKNOWN\x10\xac\x62\x12#\n\x1e\x44\x45VICE_INT32_ANT_STATUS_NORMAL\x10\xdbQ\x12#\n\x1e\x44\x45VICE_INT32_ANT_STATUS_ABSENT\x10\xfa|\x12(\n#DEVICE_INT32_ANT_STATUS_OVERCURRENT\x10\xfb|\x12\x1e\n\x19\x44\x45VICE_INT32_BUS_TYPE_PCI\x10\xa6\x62\x12\x1f\n\x1a\x44\x45VICE_INT32_BUS_TYPE_PCIE\x10\xacj\x12\x1e\n\x19\x44\x45VICE_INT32_BUS_TYPE_PXI\x10\xa7\x62\x12\x1f\n\x1a\x44\x45VICE_INT32_BUS_TYPE_PXIE\x10\xf2r\x12\x1f\n\x1a\x44\x45VICE_INT32_BUS_TYPE_SCXI\x10\xa8\x62\x12\x1e\n\x19\x44\x45VICE_INT32_BUS_TYPE_SCC\x10\xf3r\x12\"\n\x1d\x44\x45VICE_INT32_BUS_TYPE_PC_CARD\x10\xa9\x62\x12\x1e\n\x19\x44\x45VICE_INT32_BUS_TYPE_USB\x10\xaa\x62\x12&\n!DEVICE_INT32_BUS_TYPE_COMPACT_DAQ\x10\xadr\x12&\n!DEVICE_INT32_BUS_TYPE_COMPACT_RIO\x10\x8f~\x12 \n\x1b\x44\x45VICE_INT32_BUS_TYPE_TCPIP\x10\xecs\x12\"\n\x1d\x44\x45VICE_INT32_BUS_TYPE_UNKNOWN\x10\xac\x62\x12\'\n\"DEVICE_INT32_BUS_TYPE_SWITCH_BLOCK\x10\xfe{\x12\x31\n,DEVICE_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES\x10\x8dO\x12*\n%DEVICE_INT32_CI_MEASUREMENT_TYPE_FREQ\x10\xc3O\x12,\n\'DEVICE_INT32_CI_MEASUREMENT_TYPE_PERIOD\x10\x90P\x12\x31\n,DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH\x10\xf7P\x12\x31\n,DEVICE_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD\x10\xb1P\x12\x35\n0DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY\x10\xf8{\x12\x30\n+DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME\x10\xf9{\x12\x31\n,DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS\x10\xfa{\x12\x30\n+DEVICE_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE\x10\xc6}\x12:\n5DEVICE_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER\x10\xf8P\x12:\n5DEVICE_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER\x10\xf9P\x12:\n5DEVICE_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER\x10\xce}\x12:\n5DEVICE_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER\x10\xcf}\x12\x32\n-DEVICE_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP\x10\x9bP\x12\x33\n.DEVICE_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP\x10\xfaP\x12+\n&DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_TIME\x10\x9dP\x12+\n&DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_FREQ\x10\x87O\x12,\n\'DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_TICKS\x10\x9cP\x12\"\n\x1e\x44\x45VICE_INT32_COUPLING_TYPES_AC\x10\x01\x12\"\n\x1e\x44\x45VICE_INT32_COUPLING_TYPES_DC\x10\x02\x12&\n\"DEVICE_INT32_COUPLING_TYPES_GROUND\x10\x04\x12)\n%DEVICE_INT32_COUPLING_TYPES_HF_REJECT\x10\x08\x12)\n%DEVICE_INT32_COUPLING_TYPES_LF_REJECT\x10\x10\x12,\n(DEVICE_INT32_COUPLING_TYPES_NOISE_REJECT\x10 \x12&\n!DEVICE_INT32_FILTER_TYPE2_LOWPASS\x10\xc7}\x12\'\n\"DEVICE_INT32_FILTER_TYPE2_HIGHPASS\x10\xc8}\x12\'\n\"DEVICE_INT32_FILTER_TYPE2_BANDPASS\x10\xc9}\x12$\n\x1f\x44\x45VICE_INT32_FILTER_TYPE2_NOTCH\x10\xca}\x12%\n DEVICE_INT32_FILTER_TYPE2_CUSTOM\x10\x99O\x12/\n*DEVICE_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE\x10\xfd|\x12\x30\n+DEVICE_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE\x10\xfe|\x12/\n*DEVICE_INT32_NAV_MEASUREMENT_TYPE_LATITUDE\x10\xff|\x12\x38\n3DEVICE_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND\x10\x80}\x12,\n\'DEVICE_INT32_NAV_MEASUREMENT_TYPE_TRACK\x10\x81}\x12\x30\n+DEVICE_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP\x10\xf2|\x12\x34\n/DEVICE_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY\x10\x83}\x12!\n\x1c\x44\x45VICE_INT32_NAV_MODE_MOBILE\x10\xf5|\x12\x31\n,DEVICE_INT32_NAV_MODE_STATIONARY_WITH_SURVEY\x10\xf6|\x12:\n5DEVICE_INT32_NAV_MODE_STATIONARY_WITH_PRESET_LOCATION\x10\xf7|\x12/\n*DEVICE_INT32_PRODUCT_CATEGORY_M_SERIES_DAQ\x10\xb3r\x12/\n*DEVICE_INT32_PRODUCT_CATEGORY_X_SERIES_DAQ\x10\xf2{\x12/\n*DEVICE_INT32_PRODUCT_CATEGORY_E_SERIES_DAQ\x10\xb2r\x12/\n*DEVICE_INT32_PRODUCT_CATEGORY_S_SERIES_DAQ\x10\xb4r\x12/\n*DEVICE_INT32_PRODUCT_CATEGORY_B_SERIES_DAQ\x10\xc6r\x12\x30\n+DEVICE_INT32_PRODUCT_CATEGORY_SC_SERIES_DAQ\x10\xb5r\x12)\n$DEVICE_INT32_PRODUCT_CATEGORY_USBDAQ\x10\xb6r\x12,\n\'DEVICE_INT32_PRODUCT_CATEGORY_AO_SERIES\x10\xb7r\x12-\n(DEVICE_INT32_PRODUCT_CATEGORY_DIGITAL_IO\x10\xb8r\x12-\n(DEVICE_INT32_PRODUCT_CATEGORY_TIO_SERIES\x10\xc5r\x12=\n8DEVICE_INT32_PRODUCT_CATEGORY_DYNAMIC_SIGNAL_ACQUISITION\x10\xb9r\x12+\n&DEVICE_INT32_PRODUCT_CATEGORY_SWITCHES\x10\xbar\x12\x36\n1DEVICE_INT32_PRODUCT_CATEGORY_COMPACT_DAQ_CHASSIS\x10\xc2r\x12\x36\n1DEVICE_INT32_PRODUCT_CATEGORY_COMPACT_RIO_CHASSIS\x10\x90~\x12\x32\n-DEVICE_INT32_PRODUCT_CATEGORY_C_SERIES_MODULE\x10\xc3r\x12.\n)DEVICE_INT32_PRODUCT_CATEGORY_SCXI_MODULE\x10\xc4r\x12\x36\n1DEVICE_INT32_PRODUCT_CATEGORY_SCC_CONNECTOR_BLOCK\x10\xf0r\x12-\n(DEVICE_INT32_PRODUCT_CATEGORY_SCC_MODULE\x10\xf1r\x12*\n%DEVICE_INT32_PRODUCT_CATEGORY_NIELVIS\x10\xa3s\x12.\n)DEVICE_INT32_PRODUCT_CATEGORY_NETWORK_DAQ\x10\xeds\x12-\n(DEVICE_INT32_PRODUCT_CATEGORY_SC_EXPRESS\x10\x8e|\x12,\n\'DEVICE_INT32_PRODUCT_CATEGORY_FIELD_DAQ\x10\x97~\x12\x35\n0DEVICE_INT32_PRODUCT_CATEGORY_TEST_SCALE_CHASSIS\x10\xb4~\x12\x34\n/DEVICE_INT32_PRODUCT_CATEGORY_TEST_SCALE_MODULE\x10\xb5~\x12*\n%DEVICE_INT32_PRODUCT_CATEGORY_UNKNOWN\x10\xac\x62\x12\'\n\"DEVICE_INT32_TRIGGER_USAGE_ADVANCE\x10\xc8\x61\x12%\n DEVICE_INT32_TRIGGER_USAGE_PAUSE\x10\xc9\x61\x12)\n$DEVICE_INT32_TRIGGER_USAGE_REFERENCE\x10\xca\x61\x12%\n DEVICE_INT32_TRIGGER_USAGE_START\x10\xcb\x61\x12)\n$DEVICE_INT32_TRIGGER_USAGE_HANDSHAKE\x10\x95Q\x12)\n$DEVICE_INT32_TRIGGER_USAGE_ARM_START\x10\xb1r\x12,\n(DEVICE_INT32_TRIGGER_USAGE_TYPES_ADVANCE\x10\x01\x12*\n&DEVICE_INT32_TRIGGER_USAGE_TYPES_PAUSE\x10\x02\x12.\n*DEVICE_INT32_TRIGGER_USAGE_TYPES_REFERENCE\x10\x04\x12*\n&DEVICE_INT32_TRIGGER_USAGE_TYPES_START\x10\x08\x12.\n*DEVICE_INT32_TRIGGER_USAGE_TYPES_HANDSHAKE\x10\x10\x12.\n*DEVICE_INT32_TRIGGER_USAGE_TYPES_ARM_START\x10 \x1a\x02\x10\x01*\xc3\x08\n ExportSignalInt32AttributeValues\x12\"\n\x1e\x45XPORTSIGNAL_INT32_UNSPECIFIED\x10\x00\x12H\nCEXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_MORE_THAN_HALF_FULL\x10\xfdO\x12\x39\n4EXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_FULL\x10\xfcO\x12\x45\n@EXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_CUSTOM_THRESHOLD\x10\xa1\x62\x12=\n8EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_SAMP_CLK_PERIODS\x10\xaeP\x12\x34\n/EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_SECONDS\x10\xfcP\x12\x32\n-EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_TICKS\x10\xc0P\x12\x34\n/EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS3_SECONDS\x10\xfcP\x12,\n\'EXPORTSIGNAL_INT32_EXPORT_ACTIONS_PULSE\x10\x99P\x12-\n(EXPORTSIGNAL_INT32_EXPORT_ACTIONS_TOGGLE\x10\xc3P\x12*\n%EXPORTSIGNAL_INT32_EXPORT_ACTIONS_LVL\x10\xe2O\x12-\n(EXPORTSIGNAL_INT32_EXPORT_ACTIONS2_PULSE\x10\x99P\x12.\n)EXPORTSIGNAL_INT32_EXPORT_ACTIONS2_TOGGLE\x10\xc3P\x12-\n(EXPORTSIGNAL_INT32_EXPORT_ACTIONS3_PULSE\x10\x99P\x12+\n&EXPORTSIGNAL_INT32_EXPORT_ACTIONS3_LVL\x10\xe2O\x12\x33\n.EXPORTSIGNAL_INT32_EXPORT_ACTIONS5_INTERLOCKED\x10\x85\x62\x12-\n(EXPORTSIGNAL_INT32_EXPORT_ACTIONS5_PULSE\x10\x99P\x12#\n\x1e\x45XPORTSIGNAL_INT32_LEVEL1_HIGH\x10\xd0O\x12\"\n\x1d\x45XPORTSIGNAL_INT32_LEVEL1_LOW\x10\xe6O\x12-\n(EXPORTSIGNAL_INT32_POLARITY2_ACTIVE_HIGH\x10\xefN\x12,\n\'EXPORTSIGNAL_INT32_POLARITY2_ACTIVE_LOW\x10\xf0N\x1a\x02\x10\x01*\xdb!\n#PhysicalChannelInt32AttributeValues\x12%\n!PHYSICALCHANNEL_INT32_UNSPECIFIED\x10\x00\x12\x36\n1PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE\x10\xd2P\x12:\n5PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS\x10\xeeP\x12\x36\n1PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT\x10\x96O\x12:\n5PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS\x10\xefP\x12M\nHPHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION\x10\xd3P\x12\x35\n0PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_BRIDGE\x10\xa4|\x12;\n6PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE\x10\xc5O\x12\x39\n4PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_RESISTANCE\x10\xa6P\x12\x36\n1PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_TC\x10\xbfP\x12;\n6PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR\x10\xbeP\x12\x37\n2PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD\x10\xbdP\x12\x43\n>PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR\x10\xc7P\x12:\n5PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE\x10\xbcP\x12\x42\n=PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE\x10\xec|\x12<\n7PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT\x10\xf0P\x12<\n7PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT\x10\xf1P\x12T\nOPHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE\x10\xf3s\x12<\n7PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER\x10\xf4P\x12\x42\n=PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE\x10\xe8}\x12M\nHPHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE\x10\xea}\x12\x43\n>PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR\x10\xde|\x12;\n6PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE\x10\x9b|\x12@\n;PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR\x10\x97|\x12>\n9PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE\x10\x9e|\x12H\nCPHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE\x10\xf2P\x12<\n7PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE\x10\xa1|\x12:\n5PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR\x10\xf3\x61\x12\x35\n0PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CHARGE\x10\xe9}\x12\x34\n/PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POWER\x10\xc9~\x12\x39\n4PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE\x10\xd2P\x12\x39\n4PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT\x10\x96O\x12:\n5PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN\x10\x9es\x12>\n9PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_VOLTAGE\x10\xd2P\x12>\n9PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_CURRENT\x10\x96O\x12\x45\n@PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_HIGH_IMPEDANCE\x10\xef\x61\x12\x38\n3PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_FINITE_SAMPS\x10\xc2O\x12\x36\n1PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_CONT_SAMPS\x10\x8bO\x12\x41\n<PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT\x10\xea\x61\x12:\n5PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES\x10\x8dO\x12\x33\n.PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_FREQ\x10\xc3O\x12\x35\n0PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PERIOD\x10\x90P\x12:\n5PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH\x10\xf7P\x12:\n5PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD\x10\xb1P\x12>\n9PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY\x10\xf8{\x12\x39\n4PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME\x10\xf9{\x12:\n5PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS\x10\xfa{\x12\x39\n4PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE\x10\xc6}\x12\x43\n>PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER\x10\xf8P\x12\x43\n>PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER\x10\xf9P\x12\x43\n>PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER\x10\xce}\x12\x43\n>PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER\x10\xcf}\x12;\n6PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP\x10\x9bP\x12<\n7PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP\x10\xfaP\x12\x34\n/PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TIME\x10\x9dP\x12\x34\n/PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_FREQ\x10\x87O\x12\x35\n0PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TICKS\x10\x9cP\x12\x38\n3PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE\x10\xfd|\x12\x39\n4PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE\x10\xfe|\x12\x38\n3PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_LATITUDE\x10\xff|\x12\x41\n<PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND\x10\x80}\x12\x35\n0PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_TRACK\x10\x81}\x12\x39\n4PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP\x10\xf2|\x12=\n8PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY\x10\x83}\x12/\n*PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_DC\x10\xc2N\x12/\n*PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_AC\x10\xbdN\x12\x37\n2PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_BIPOLAR_DC\x10\x93~\x12&\n\"PHYSICALCHANNEL_INT32_TERM_CFG_RSE\x10\x01\x12\'\n#PHYSICALCHANNEL_INT32_TERM_CFG_NRSE\x10\x02\x12\'\n#PHYSICALCHANNEL_INT32_TERM_CFG_DIFF\x10\x04\x12.\n*PHYSICALCHANNEL_INT32_TERM_CFG_PSEUDO_DIFF\x10\x08\x1a\x02\x10\x01*\xd7\x06\n\x18ReadInt32AttributeValues\x12\x1a\n\x16READ_INT32_UNSPECIFIED\x10\x00\x12 \n\x1bREAD_INT32_LOGGING_MODE_OFF\x10\xf7O\x12 \n\x1bREAD_INT32_LOGGING_MODE_LOG\x10\xe4{\x12)\n$READ_INT32_LOGGING_MODE_LOG_AND_READ\x10\xe2{\x12&\n!READ_INT32_LOGGING_OPERATION_OPEN\x10\xc5Q\x12\x30\n+READ_INT32_LOGGING_OPERATION_OPEN_OR_CREATE\x10\xe6{\x12\x33\n.READ_INT32_LOGGING_OPERATION_CREATE_OR_REPLACE\x10\xe7{\x12(\n#READ_INT32_LOGGING_OPERATION_CREATE\x10\xe8{\x12\x36\n1READ_INT32_OVERWRITE_MODE1_OVERWRITE_UNREAD_SAMPS\x10\x8cP\x12=\n8READ_INT32_OVERWRITE_MODE1_DO_NOT_OVERWRITE_UNREAD_SAMPS\x10\xafO\x12-\n(READ_INT32_READ_RELATIVE_TO_FIRST_SAMPLE\x10\xb8Q\x12.\n)READ_INT32_READ_RELATIVE_TO_CURR_READ_POS\x10\xb9Q\x12)\n$READ_INT32_READ_RELATIVE_TO_REF_TRIG\x10\xbaQ\x12\x33\n.READ_INT32_READ_RELATIVE_TO_FIRST_PRETRIG_SAMP\x10\xbbQ\x12\x31\n,READ_INT32_READ_RELATIVE_TO_MOST_RECENT_SAMP\x10\xbcQ\x12,\n\'READ_INT32_WAIT_MODE_WAIT_FOR_INTERRUPT\x10\xeb\x61\x12\x1e\n\x19READ_INT32_WAIT_MODE_POLL\x10\xec\x61\x12\x1f\n\x1aREAD_INT32_WAIT_MODE_YIELD\x10\xed\x61\x12\x1f\n\x1aREAD_INT32_WAIT_MODE_SLEEP\x10\x83\x62*\xf2\x01\n\x1cRealTimeInt32AttributeValues\x12\x1e\n\x1aREALTIME_INT32_UNSPECIFIED\x10\x00\x12\x31\n,REALTIME_INT32_WAIT_MODE3_WAIT_FOR_INTERRUPT\x10\xeb\x61\x12#\n\x1eREALTIME_INT32_WAIT_MODE3_POLL\x10\xec\x61\x12\x31\n,REALTIME_INT32_WAIT_MODE4_WAIT_FOR_INTERRUPT\x10\xeb\x61\x12#\n\x1eREALTIME_INT32_WAIT_MODE4_POLL\x10\xec\x61\x1a\x02\x10\x01*\x99\x0f\n\x19ScaleInt32AttributeValues\x12\x1b\n\x17SCALE_INT32_UNSPECIFIED\x10\x00\x12\"\n\x1dSCALE_INT32_SCALE_TYPE_LINEAR\x10\xcfQ\x12&\n!SCALE_INT32_SCALE_TYPE_MAP_RANGES\x10\xd0Q\x12&\n!SCALE_INT32_SCALE_TYPE_POLYNOMIAL\x10\xd1Q\x12!\n\x1cSCALE_INT32_SCALE_TYPE_TABLE\x10\xd2Q\x12\'\n\"SCALE_INT32_UNITS_PRE_SCALED_VOLTS\x10\xecP\x12&\n!SCALE_INT32_UNITS_PRE_SCALED_AMPS\x10\xe6P\x12\'\n\"SCALE_INT32_UNITS_PRE_SCALED_DEG_F\x10\xa0O\x12\'\n\"SCALE_INT32_UNITS_PRE_SCALED_DEG_C\x10\x9fO\x12\'\n\"SCALE_INT32_UNITS_PRE_SCALED_DEG_R\x10\xa1O\x12)\n$SCALE_INT32_UNITS_PRE_SCALED_KELVINS\x10\xd5P\x12(\n#SCALE_INT32_UNITS_PRE_SCALED_STRAIN\x10\xbbP\x12&\n!SCALE_INT32_UNITS_PRE_SCALED_OHMS\x10\x90Q\x12$\n\x1fSCALE_INT32_UNITS_PRE_SCALED_HZ\x10\x85Q\x12)\n$SCALE_INT32_UNITS_PRE_SCALED_SECONDS\x10\xfcP\x12(\n#SCALE_INT32_UNITS_PRE_SCALED_METERS\x10\xebO\x12(\n#SCALE_INT32_UNITS_PRE_SCALED_INCHES\x10\x8bQ\x12)\n$SCALE_INT32_UNITS_PRE_SCALED_DEGREES\x10\xa2O\x12)\n$SCALE_INT32_UNITS_PRE_SCALED_RADIANS\x10\xa1P\x12\'\n\"SCALE_INT32_UNITS_PRE_SCALED_TICKS\x10\xc0P\x12%\n SCALE_INT32_UNITS_PRE_SCALED_RPM\x10\xd0}\x12\x34\n/SCALE_INT32_UNITS_PRE_SCALED_RADIANS_PER_SECOND\x10\xd1}\x12\x34\n/SCALE_INT32_UNITS_PRE_SCALED_DEGREES_PER_SECOND\x10\xd2}\x12#\n\x1eSCALE_INT32_UNITS_PRE_SCALED_G\x10\xcaO\x12;\n6SCALE_INT32_UNITS_PRE_SCALED_METERS_PER_SECOND_SQUARED\x10\xb6\x61\x12;\n6SCALE_INT32_UNITS_PRE_SCALED_INCHES_PER_SECOND_SQUARED\x10\xb7\x61\x12\x33\n.SCALE_INT32_UNITS_PRE_SCALED_METERS_PER_SECOND\x10\xd7|\x12\x33\n.SCALE_INT32_UNITS_PRE_SCALED_INCHES_PER_SECOND\x10\xd8|\x12)\n$SCALE_INT32_UNITS_PRE_SCALED_PASCALS\x10\xe1N\x12)\n$SCALE_INT32_UNITS_PRE_SCALED_NEWTONS\x10\x83|\x12(\n#SCALE_INT32_UNITS_PRE_SCALED_POUNDS\x10\x84|\x12\x30\n+SCALE_INT32_UNITS_PRE_SCALED_KILOGRAM_FORCE\x10\x85|\x12\x38\n3SCALE_INT32_UNITS_PRE_SCALED_POUNDS_PER_SQUARE_INCH\x10\x87|\x12%\n SCALE_INT32_UNITS_PRE_SCALED_BAR\x10\x88|\x12/\n*SCALE_INT32_UNITS_PRE_SCALED_NEWTON_METERS\x10\x89|\x12-\n(SCALE_INT32_UNITS_PRE_SCALED_INCH_OUNCES\x10\x8a|\x12-\n(SCALE_INT32_UNITS_PRE_SCALED_INCH_POUNDS\x10\x8b|\x12-\n(SCALE_INT32_UNITS_PRE_SCALED_FOOT_POUNDS\x10\x8c|\x12\x30\n+SCALE_INT32_UNITS_PRE_SCALED_VOLTS_PER_VOLT\x10\x98|\x12\x32\n-SCALE_INT32_UNITS_PRE_SCALED_M_VOLTS_PER_VOLT\x10\x99|\x12*\n%SCALE_INT32_UNITS_PRE_SCALED_COULOMBS\x10\xe6}\x12/\n*SCALE_INT32_UNITS_PRE_SCALED_PICO_COULOMBS\x10\xe7}\x12+\n&SCALE_INT32_UNITS_PRE_SCALED_FROM_TEDS\x10\xe4\x61*\xd5\x0e\n\x1aTimingInt32AttributeValues\x12\x1c\n\x18TIMING_INT32_UNSPECIFIED\x10\x00\x12/\n*TIMING_INT32_ACQUISITION_TYPE_FINITE_SAMPS\x10\xc2O\x12-\n(TIMING_INT32_ACQUISITION_TYPE_CONT_SAMPS\x10\x8bO\x12\x38\n3TIMING_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT\x10\xea\x61\x12.\n)TIMING_INT32_DIGITAL_WIDTH_UNITS2_SECONDS\x10\xfcP\x12,\n\'TIMING_INT32_DIGITAL_WIDTH_UNITS2_TICKS\x10\xc0P\x12\x1e\n\x19TIMING_INT32_EDGE1_RISING\x10\xa8P\x12\x1f\n\x1aTIMING_INT32_EDGE1_FALLING\x10\xbbO\x12\x35\n0TIMING_INT32_HANDSHAKE_START_CONDITION_IMMEDIATE\x10\xd6O\x12M\nHTIMING_INT32_HANDSHAKE_START_CONDITION_WAIT_FOR_HANDSHAKE_TRIGGER_ASSERT\x10\x86\x62\x12O\nJTIMING_INT32_HANDSHAKE_START_CONDITION_WAIT_FOR_HANDSHAKE_TRIGGER_DEASSERT\x10\x87\x62\x12<\n7TIMING_INT32_MIOAI_CONVERT_TB_SRC_SAME_AS_SAMP_TIMEBASE\x10\xacP\x12>\n9TIMING_INT32_MIOAI_CONVERT_TB_SRC_SAME_AS_MASTER_TIMEBASE\x10\xaaP\x12\x37\n2TIMING_INT32_MIOAI_CONVERT_TB_SRC_100_MHZ_TIMEBASE\x10\xf1{\x12\x36\n1TIMING_INT32_MIOAI_CONVERT_TB_SRC_80_MHZ_TIMEBASE\x10\xacr\x12\x36\n1TIMING_INT32_MIOAI_CONVERT_TB_SRC_20_MHZ_TIMEBASE\x10\xf9\x61\x12\x35\n0TIMING_INT32_MIOAI_CONVERT_TB_SRC_8_MHZ_TIMEBASE\x10\x97}\x12\x37\n2TIMING_INT32_OVERFLOW_BEHAVIOR_STOP_TASK_AND_ERROR\x10\xf6{\x12\x33\n.TIMING_INT32_OVERFLOW_BEHAVIOR_IGNORE_OVERRUNS\x10\xf7{\x12\x42\n=TIMING_INT32_SAMPLE_INPUT_DATA_WHEN_HANDSHAKE_TRIGGER_ASSERTS\x10\x88\x62\x12\x44\n?TIMING_INT32_SAMPLE_INPUT_DATA_WHEN_HANDSHAKE_TRIGGER_DEASSERTS\x10\x89\x62\x12-\n(TIMING_INT32_SAMPLE_TIMING_TYPE_SAMP_CLK\x10\x94Q\x12\x34\n/TIMING_INT32_SAMPLE_TIMING_TYPE_BURST_HANDSHAKE\x10\x84\x62\x12.\n)TIMING_INT32_SAMPLE_TIMING_TYPE_HANDSHAKE\x10\x95Q\x12-\n(TIMING_INT32_SAMPLE_TIMING_TYPE_IMPLICIT\x10\xd3Q\x12.\n)TIMING_INT32_SAMPLE_TIMING_TYPE_ON_DEMAND\x10\x96Q\x12\x35\n0TIMING_INT32_SAMPLE_TIMING_TYPE_CHANGE_DETECTION\x10\xd8\x61\x12\x37\n2TIMING_INT32_SAMPLE_TIMING_TYPE_PIPELINED_SAMP_CLK\x10\xccr\x12)\n$TIMING_INT32_SYNC_PULSE_TYPE_ONBOARD\x10\x80~\x12*\n%TIMING_INT32_SYNC_PULSE_TYPE_DIG_EDGE\x10\xa6O\x12&\n!TIMING_INT32_SYNC_PULSE_TYPE_TIME\x10\xfc|\x12&\n!TIMING_INT32_TIMESCALE2_HOST_TIME\x10\xfe}\x12+\n&TIMING_INT32_TIMESCALE2_IO_DEVICE_TIME\x10\xff}\x12:\n5TIMING_INT32_UNDERFLOW_BEHAVIOR_HALT_OUTPUT_AND_ERROR\x10\x97r\x12?\n:TIMING_INT32_UNDERFLOW_BEHAVIOR_PAUSE_UNTIL_DATA_AVAILABLE\x10\x98r*\xfc\x11\n\x1bTriggerInt32AttributeValues\x12\x1d\n\x19TRIGGER_INT32_UNSPECIFIED\x10\x00\x12)\n$TRIGGER_INT32_ACTIVE_LEVEL_ABOVE_LVL\x10\xedN\x12)\n$TRIGGER_INT32_ACTIVE_LEVEL_BELOW_LVL\x10\xfbN\x12\x1f\n\x1aTRIGGER_INT32_COUPLING2_AC\x10\xbdN\x12\x1f\n\x1aTRIGGER_INT32_COUPLING2_DC\x10\xc2N\x12=\n8TRIGGER_INT32_DIGITAL_PATTERN_CONDITION1_PATTERN_MATCHES\x10\x8eP\x12\x44\n?TRIGGER_INT32_DIGITAL_PATTERN_CONDITION1_PATTERN_DOES_NOT_MATCH\x10\x8dP\x12\x38\n3TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_SAMP_CLK_PERIODS\x10\xaeP\x12/\n*TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_SECONDS\x10\xfcP\x12-\n(TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_TICKS\x10\xc0P\x12\x1f\n\x1aTRIGGER_INT32_EDGE1_RISING\x10\xa8P\x12 \n\x1bTRIGGER_INT32_EDGE1_FALLING\x10\xbbO\x12\x1e\n\x19TRIGGER_INT32_LEVEL1_HIGH\x10\xd0O\x12\x1d\n\x18TRIGGER_INT32_LEVEL1_LOW\x10\xe6O\x12&\n!TRIGGER_INT32_SLOPE1_RISING_SLOPE\x10\xa8P\x12\'\n\"TRIGGER_INT32_SLOPE1_FALLING_SLOPE\x10\xbbO\x12!\n\x1cTRIGGER_INT32_SYNC_TYPE_NONE\x10\xf6O\x12#\n\x1eTRIGGER_INT32_SYNC_TYPE_MASTER\x10\x90|\x12\"\n\x1dTRIGGER_INT32_SYNC_TYPE_SLAVE\x10\x91|\x12\'\n\"TRIGGER_INT32_TIMESCALE2_HOST_TIME\x10\xfe}\x12,\n\'TRIGGER_INT32_TIMESCALE2_IO_DEVICE_TIME\x10\xff}\x12+\n&TRIGGER_INT32_TRIGGER_TYPE10_ANLG_EDGE\x10\xf3N\x12\x31\n,TRIGGER_INT32_TRIGGER_TYPE10_ANLG_MULTI_EDGE\x10\xec}\x12*\n%TRIGGER_INT32_TRIGGER_TYPE10_DIG_EDGE\x10\xa6O\x12-\n(TRIGGER_INT32_TRIGGER_TYPE10_DIG_PATTERN\x10\x9eQ\x12*\n%TRIGGER_INT32_TRIGGER_TYPE10_ANLG_WIN\x10\xf7N\x12&\n!TRIGGER_INT32_TRIGGER_TYPE10_TIME\x10\xfc|\x12&\n!TRIGGER_INT32_TRIGGER_TYPE10_NONE\x10\xf6O\x12)\n$TRIGGER_INT32_TRIGGER_TYPE4_DIG_EDGE\x10\xa6O\x12%\n TRIGGER_INT32_TRIGGER_TYPE4_TIME\x10\xfc|\x12%\n TRIGGER_INT32_TRIGGER_TYPE4_NONE\x10\xf6O\x12)\n$TRIGGER_INT32_TRIGGER_TYPE5_DIG_EDGE\x10\xa6O\x12)\n$TRIGGER_INT32_TRIGGER_TYPE5_SOFTWARE\x10\xb4P\x12%\n TRIGGER_INT32_TRIGGER_TYPE5_NONE\x10\xf6O\x12)\n$TRIGGER_INT32_TRIGGER_TYPE6_ANLG_LVL\x10\xf5N\x12)\n$TRIGGER_INT32_TRIGGER_TYPE6_ANLG_WIN\x10\xf7N\x12(\n#TRIGGER_INT32_TRIGGER_TYPE6_DIG_LVL\x10\xa8O\x12,\n\'TRIGGER_INT32_TRIGGER_TYPE6_DIG_PATTERN\x10\x9eQ\x12%\n TRIGGER_INT32_TRIGGER_TYPE6_NONE\x10\xf6O\x12*\n%TRIGGER_INT32_TRIGGER_TYPE8_ANLG_EDGE\x10\xf3N\x12\x30\n+TRIGGER_INT32_TRIGGER_TYPE8_ANLG_MULTI_EDGE\x10\xec}\x12)\n$TRIGGER_INT32_TRIGGER_TYPE8_DIG_EDGE\x10\xa6O\x12,\n\'TRIGGER_INT32_TRIGGER_TYPE8_DIG_PATTERN\x10\x9eQ\x12)\n$TRIGGER_INT32_TRIGGER_TYPE8_ANLG_WIN\x10\xf7N\x12%\n TRIGGER_INT32_TRIGGER_TYPE8_TIME\x10\xfc|\x12%\n TRIGGER_INT32_TRIGGER_TYPE8_NONE\x10\xf6O\x12,\n\'TRIGGER_INT32_TRIGGER_TYPE9_INTERLOCKED\x10\x85\x62\x12%\n TRIGGER_INT32_TRIGGER_TYPE9_NONE\x10\xf6O\x12\x39\n4TRIGGER_INT32_WINDOW_TRIGGER_CONDITION1_ENTERING_WIN\x10\xb3O\x12\x38\n3TRIGGER_INT32_WINDOW_TRIGGER_CONDITION1_LEAVING_WIN\x10\xe0O\x12\x37\n2TRIGGER_INT32_WINDOW_TRIGGER_CONDITION2_INSIDE_WIN\x10\xd7O\x12\x38\n3TRIGGER_INT32_WINDOW_TRIGGER_CONDITION2_OUTSIDE_WIN\x10\x8bP\x1a\x02\x10\x01*\xfa\x05\n\x1cWatchdogInt32AttributeValues\x12\x1e\n\x1aWATCHDOG_INT32_UNSPECIFIED\x10\x00\x12+\n&WATCHDOG_INT32_DIGITAL_LINE_STATE_HIGH\x10\xd0O\x12*\n%WATCHDOG_INT32_DIGITAL_LINE_STATE_LOW\x10\xe6O\x12/\n*WATCHDOG_INT32_DIGITAL_LINE_STATE_TRISTATE\x10\xc6P\x12\x30\n+WATCHDOG_INT32_DIGITAL_LINE_STATE_NO_CHANGE\x10\xb0O\x12 \n\x1bWATCHDOG_INT32_EDGE1_RISING\x10\xa8P\x12!\n\x1cWATCHDOG_INT32_EDGE1_FALLING\x10\xbbO\x12*\n%WATCHDOG_INT32_TRIGGER_TYPE4_DIG_EDGE\x10\xa6O\x12&\n!WATCHDOG_INT32_TRIGGER_TYPE4_TIME\x10\xfc|\x12&\n!WATCHDOG_INT32_TRIGGER_TYPE4_NONE\x10\xf6O\x12\x33\n.WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_VOLTAGE\x10\xd2P\x12\x33\n.WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_CURRENT\x10\x96O\x12\x35\n0WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_NO_CHANGE\x10\xb0O\x12/\n*WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_LOW\x10\xe6O\x12\x30\n+WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_HIGH\x10\xd0O\x12\x35\n0WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_NO_CHANGE\x10\xb0O\x1a\x02\x10\x01*\xed\x02\n\x19WriteInt32AttributeValues\x12\x1b\n\x17WRITE_INT32_UNSPECIFIED\x10\x00\x12/\n*WRITE_INT32_REGENERATION_MODE1_ALLOW_REGEN\x10\xf1N\x12\x36\n1WRITE_INT32_REGENERATION_MODE1_DO_NOT_ALLOW_REGEN\x10\xaeO\x12 \n\x1bWRITE_INT32_WAIT_MODE2_POLL\x10\xec\x61\x12!\n\x1cWRITE_INT32_WAIT_MODE2_YIELD\x10\xed\x61\x12!\n\x1cWRITE_INT32_WAIT_MODE2_SLEEP\x10\x83\x62\x12/\n*WRITE_INT32_WRITE_RELATIVE_TO_FIRST_SAMPLE\x10\xb8Q\x12\x31\n,WRITE_INT32_WRITE_RELATIVE_TO_CURR_WRITE_POS\x10\xbeQ2\xa1\xed\x02\n\x07NiDAQmx\x12p\n\x15\x41\x64\x64\x43\x44\x41QSyncConnection\x12*.nidaqmx_grpc.AddCDAQSyncConnectionRequest\x1a+.nidaqmx_grpc.AddCDAQSyncConnectionResponse\x12m\n\x14\x41\x64\x64GlobalChansToTask\x12).nidaqmx_grpc.AddGlobalChansToTaskRequest\x1a*.nidaqmx_grpc.AddGlobalChansToTaskResponse\x12\x61\n\x10\x41\x64\x64NetworkDevice\x12%.nidaqmx_grpc.AddNetworkDeviceRequest\x1a&.nidaqmx_grpc.AddNetworkDeviceResponse\x12\xa3\x01\n&AreConfiguredCDAQSyncPortsDisconnected\x12;.nidaqmx_grpc.AreConfiguredCDAQSyncPortsDisconnectedRequest\x1a<.nidaqmx_grpc.AreConfiguredCDAQSyncPortsDisconnectedResponse\x12\x91\x01\n AutoConfigureCDAQSyncConnections\x12\x35.nidaqmx_grpc.AutoConfigureCDAQSyncConnectionsRequest\x1a\x36.nidaqmx_grpc.AutoConfigureCDAQSyncConnectionsResponse\x12|\n\x19\x43\x61lculateReversePolyCoeff\x12..nidaqmx_grpc.CalculateReversePolyCoeffRequest\x1a/.nidaqmx_grpc.CalculateReversePolyCoeffResponse\x12g\n\x12\x43\x66gAnlgEdgeRefTrig\x12\'.nidaqmx_grpc.CfgAnlgEdgeRefTrigRequest\x1a(.nidaqmx_grpc.CfgAnlgEdgeRefTrigResponse\x12m\n\x14\x43\x66gAnlgEdgeStartTrig\x12).nidaqmx_grpc.CfgAnlgEdgeStartTrigRequest\x1a*.nidaqmx_grpc.CfgAnlgEdgeStartTrigResponse\x12v\n\x17\x43\x66gAnlgMultiEdgeRefTrig\x12,.nidaqmx_grpc.CfgAnlgMultiEdgeRefTrigRequest\x1a-.nidaqmx_grpc.CfgAnlgMultiEdgeRefTrigResponse\x12|\n\x19\x43\x66gAnlgMultiEdgeStartTrig\x12..nidaqmx_grpc.CfgAnlgMultiEdgeStartTrigRequest\x1a/.nidaqmx_grpc.CfgAnlgMultiEdgeStartTrigResponse\x12m\n\x14\x43\x66gAnlgWindowRefTrig\x12).nidaqmx_grpc.CfgAnlgWindowRefTrigRequest\x1a*.nidaqmx_grpc.CfgAnlgWindowRefTrigResponse\x12s\n\x16\x43\x66gAnlgWindowStartTrig\x12+.nidaqmx_grpc.CfgAnlgWindowStartTrigRequest\x1a,.nidaqmx_grpc.CfgAnlgWindowStartTrigResponse\x12\x9d\x01\n$CfgBurstHandshakingTimingExportClock\x12\x39.nidaqmx_grpc.CfgBurstHandshakingTimingExportClockRequest\x1a:.nidaqmx_grpc.CfgBurstHandshakingTimingExportClockResponse\x12\x9d\x01\n$CfgBurstHandshakingTimingImportClock\x12\x39.nidaqmx_grpc.CfgBurstHandshakingTimingImportClockRequest\x1a:.nidaqmx_grpc.CfgBurstHandshakingTimingImportClockResponse\x12y\n\x18\x43\x66gChangeDetectionTiming\x12-.nidaqmx_grpc.CfgChangeDetectionTimingRequest\x1a..nidaqmx_grpc.CfgChangeDetectionTimingResponse\x12\x64\n\x11\x43\x66gDigEdgeRefTrig\x12&.nidaqmx_grpc.CfgDigEdgeRefTrigRequest\x1a\'.nidaqmx_grpc.CfgDigEdgeRefTrigResponse\x12j\n\x13\x43\x66gDigEdgeStartTrig\x12(.nidaqmx_grpc.CfgDigEdgeStartTrigRequest\x1a).nidaqmx_grpc.CfgDigEdgeStartTrigResponse\x12m\n\x14\x43\x66gDigPatternRefTrig\x12).nidaqmx_grpc.CfgDigPatternRefTrigRequest\x1a*.nidaqmx_grpc.CfgDigPatternRefTrigResponse\x12s\n\x16\x43\x66gDigPatternStartTrig\x12+.nidaqmx_grpc.CfgDigPatternStartTrigRequest\x1a,.nidaqmx_grpc.CfgDigPatternStartTrigResponse\x12m\n\x14\x43\x66gHandshakingTiming\x12).nidaqmx_grpc.CfgHandshakingTimingRequest\x1a*.nidaqmx_grpc.CfgHandshakingTimingResponse\x12\x64\n\x11\x43\x66gImplicitTiming\x12&.nidaqmx_grpc.CfgImplicitTimingRequest\x1a\'.nidaqmx_grpc.CfgImplicitTimingResponse\x12[\n\x0e\x43\x66gInputBuffer\x12#.nidaqmx_grpc.CfgInputBufferRequest\x1a$.nidaqmx_grpc.CfgInputBufferResponse\x12^\n\x0f\x43\x66gOutputBuffer\x12$.nidaqmx_grpc.CfgOutputBufferRequest\x1a%.nidaqmx_grpc.CfgOutputBufferResponse\x12|\n\x19\x43\x66gPipelinedSampClkTiming\x12..nidaqmx_grpc.CfgPipelinedSampClkTimingRequest\x1a/.nidaqmx_grpc.CfgPipelinedSampClkTimingResponse\x12\x61\n\x10\x43\x66gSampClkTiming\x12%.nidaqmx_grpc.CfgSampClkTimingRequest\x1a&.nidaqmx_grpc.CfgSampClkTimingResponse\x12\x61\n\x10\x43\x66gTimeStartTrig\x12%.nidaqmx_grpc.CfgTimeStartTrigRequest\x1a&.nidaqmx_grpc.CfgTimeStartTrigResponse\x12y\n\x18\x43\x66gWatchdogAOExpirStates\x12-.nidaqmx_grpc.CfgWatchdogAOExpirStatesRequest\x1a..nidaqmx_grpc.CfgWatchdogAOExpirStatesResponse\x12y\n\x18\x43\x66gWatchdogCOExpirStates\x12-.nidaqmx_grpc.CfgWatchdogCOExpirStatesRequest\x1a..nidaqmx_grpc.CfgWatchdogCOExpirStatesResponse\x12y\n\x18\x43\x66gWatchdogDOExpirStates\x12-.nidaqmx_grpc.CfgWatchdogDOExpirStatesRequest\x1a..nidaqmx_grpc.CfgWatchdogDOExpirStatesResponse\x12L\n\tClearTEDS\x12\x1e.nidaqmx_grpc.ClearTEDSRequest\x1a\x1f.nidaqmx_grpc.ClearTEDSResponse\x12L\n\tClearTask\x12\x1e.nidaqmx_grpc.ClearTaskRequest\x1a\x1f.nidaqmx_grpc.ClearTaskResponse\x12\x61\n\x10\x43onfigureLogging\x12%.nidaqmx_grpc.ConfigureLoggingRequest\x1a&.nidaqmx_grpc.ConfigureLoggingResponse\x12X\n\rConfigureTEDS\x12\".nidaqmx_grpc.ConfigureTEDSRequest\x1a#.nidaqmx_grpc.ConfigureTEDSResponse\x12U\n\x0c\x43onnectTerms\x12!.nidaqmx_grpc.ConnectTermsRequest\x1a\".nidaqmx_grpc.ConnectTermsResponse\x12j\n\x13\x43ontrolWatchdogTask\x12(.nidaqmx_grpc.ControlWatchdogTaskRequest\x1a).nidaqmx_grpc.ControlWatchdogTaskResponse\x12\x8e\x01\n\x1f\x43reateAIAccel4WireDCVoltageChan\x12\x34.nidaqmx_grpc.CreateAIAccel4WireDCVoltageChanRequest\x1a\x35.nidaqmx_grpc.CreateAIAccel4WireDCVoltageChanResponse\x12\x64\n\x11\x43reateAIAccelChan\x12&.nidaqmx_grpc.CreateAIAccelChanRequest\x1a\'.nidaqmx_grpc.CreateAIAccelChanResponse\x12v\n\x17\x43reateAIAccelChargeChan\x12,.nidaqmx_grpc.CreateAIAccelChargeChanRequest\x1a-.nidaqmx_grpc.CreateAIAccelChargeChanResponse\x12g\n\x12\x43reateAIBridgeChan\x12\'.nidaqmx_grpc.CreateAIBridgeChanRequest\x1a(.nidaqmx_grpc.CreateAIBridgeChanResponse\x12g\n\x12\x43reateAIChargeChan\x12\'.nidaqmx_grpc.CreateAIChargeChanRequest\x1a(.nidaqmx_grpc.CreateAIChargeChanResponse\x12j\n\x13\x43reateAICurrentChan\x12(.nidaqmx_grpc.CreateAICurrentChanRequest\x1a).nidaqmx_grpc.CreateAICurrentChanResponse\x12s\n\x16\x43reateAICurrentRMSChan\x12+.nidaqmx_grpc.CreateAICurrentRMSChanRequest\x1a,.nidaqmx_grpc.CreateAICurrentRMSChanResponse\x12\x94\x01\n!CreateAIForceBridgePolynomialChan\x12\x36.nidaqmx_grpc.CreateAIForceBridgePolynomialChanRequest\x1a\x37.nidaqmx_grpc.CreateAIForceBridgePolynomialChanResponse\x12\x85\x01\n\x1c\x43reateAIForceBridgeTableChan\x12\x31.nidaqmx_grpc.CreateAIForceBridgeTableChanRequest\x1a\x32.nidaqmx_grpc.CreateAIForceBridgeTableChanResponse\x12\x97\x01\n\"CreateAIForceBridgeTwoPointLinChan\x12\x37.nidaqmx_grpc.CreateAIForceBridgeTwoPointLinChanRequest\x1a\x38.nidaqmx_grpc.CreateAIForceBridgeTwoPointLinChanResponse\x12p\n\x15\x43reateAIForceIEPEChan\x12*.nidaqmx_grpc.CreateAIForceIEPEChanRequest\x1a+.nidaqmx_grpc.CreateAIForceIEPEChanResponse\x12v\n\x17\x43reateAIFreqVoltageChan\x12,.nidaqmx_grpc.CreateAIFreqVoltageChanRequest\x1a-.nidaqmx_grpc.CreateAIFreqVoltageChanResponse\x12s\n\x16\x43reateAIMicrophoneChan\x12+.nidaqmx_grpc.CreateAIMicrophoneChanRequest\x1a,.nidaqmx_grpc.CreateAIMicrophoneChanResponse\x12\x91\x01\n CreateAIPosEddyCurrProxProbeChan\x12\x35.nidaqmx_grpc.CreateAIPosEddyCurrProxProbeChanRequest\x1a\x36.nidaqmx_grpc.CreateAIPosEddyCurrProxProbeChanResponse\x12j\n\x13\x43reateAIPosLVDTChan\x12(.nidaqmx_grpc.CreateAIPosLVDTChanRequest\x1a).nidaqmx_grpc.CreateAIPosLVDTChanResponse\x12j\n\x13\x43reateAIPosRVDTChan\x12(.nidaqmx_grpc.CreateAIPosRVDTChanRequest\x1a).nidaqmx_grpc.CreateAIPosRVDTChanResponse\x12\x64\n\x11\x43reateAIPowerChan\x12&.nidaqmx_grpc.CreateAIPowerChanRequest\x1a\'.nidaqmx_grpc.CreateAIPowerChanResponse\x12\x9d\x01\n$CreateAIPressureBridgePolynomialChan\x12\x39.nidaqmx_grpc.CreateAIPressureBridgePolynomialChanRequest\x1a:.nidaqmx_grpc.CreateAIPressureBridgePolynomialChanResponse\x12\x8e\x01\n\x1f\x43reateAIPressureBridgeTableChan\x12\x34.nidaqmx_grpc.CreateAIPressureBridgeTableChanRequest\x1a\x35.nidaqmx_grpc.CreateAIPressureBridgeTableChanResponse\x12\xa0\x01\n%CreateAIPressureBridgeTwoPointLinChan\x12:.nidaqmx_grpc.CreateAIPressureBridgeTwoPointLinChanRequest\x1a;.nidaqmx_grpc.CreateAIPressureBridgeTwoPointLinChanResponse\x12^\n\x0f\x43reateAIRTDChan\x12$.nidaqmx_grpc.CreateAIRTDChanRequest\x1a%.nidaqmx_grpc.CreateAIRTDChanResponse\x12s\n\x16\x43reateAIResistanceChan\x12+.nidaqmx_grpc.CreateAIResistanceChanRequest\x1a,.nidaqmx_grpc.CreateAIResistanceChanResponse\x12\x88\x01\n\x1d\x43reateAIRosetteStrainGageChan\x12\x32.nidaqmx_grpc.CreateAIRosetteStrainGageChanRequest\x1a\x33.nidaqmx_grpc.CreateAIRosetteStrainGageChanResponse\x12s\n\x16\x43reateAIStrainGageChan\x12+.nidaqmx_grpc.CreateAIStrainGageChanRequest\x1a,.nidaqmx_grpc.CreateAIStrainGageChanResponse\x12\x88\x01\n\x1d\x43reateAITempBuiltInSensorChan\x12\x32.nidaqmx_grpc.CreateAITempBuiltInSensorChanRequest\x1a\x33.nidaqmx_grpc.CreateAITempBuiltInSensorChanResponse\x12j\n\x13\x43reateAIThrmcplChan\x12(.nidaqmx_grpc.CreateAIThrmcplChanRequest\x1a).nidaqmx_grpc.CreateAIThrmcplChanResponse\x12s\n\x16\x43reateAIThrmstrChanIex\x12+.nidaqmx_grpc.CreateAIThrmstrChanIexRequest\x1a,.nidaqmx_grpc.CreateAIThrmstrChanIexResponse\x12s\n\x16\x43reateAIThrmstrChanVex\x12+.nidaqmx_grpc.CreateAIThrmstrChanVexRequest\x1a,.nidaqmx_grpc.CreateAIThrmstrChanVexResponse\x12\x97\x01\n\"CreateAITorqueBridgePolynomialChan\x12\x37.nidaqmx_grpc.CreateAITorqueBridgePolynomialChanRequest\x1a\x38.nidaqmx_grpc.CreateAITorqueBridgePolynomialChanResponse\x12\x88\x01\n\x1d\x43reateAITorqueBridgeTableChan\x12\x32.nidaqmx_grpc.CreateAITorqueBridgeTableChanRequest\x1a\x33.nidaqmx_grpc.CreateAITorqueBridgeTableChanResponse\x12\x9a\x01\n#CreateAITorqueBridgeTwoPointLinChan\x12\x38.nidaqmx_grpc.CreateAITorqueBridgeTwoPointLinChanRequest\x1a\x39.nidaqmx_grpc.CreateAITorqueBridgeTwoPointLinChanResponse\x12y\n\x18\x43reateAIVelocityIEPEChan\x12-.nidaqmx_grpc.CreateAIVelocityIEPEChanRequest\x1a..nidaqmx_grpc.CreateAIVelocityIEPEChanResponse\x12j\n\x13\x43reateAIVoltageChan\x12(.nidaqmx_grpc.CreateAIVoltageChanRequest\x1a).nidaqmx_grpc.CreateAIVoltageChanResponse\x12\x85\x01\n\x1c\x43reateAIVoltageChanWithExcit\x12\x31.nidaqmx_grpc.CreateAIVoltageChanWithExcitRequest\x1a\x32.nidaqmx_grpc.CreateAIVoltageChanWithExcitResponse\x12s\n\x16\x43reateAIVoltageRMSChan\x12+.nidaqmx_grpc.CreateAIVoltageRMSChanRequest\x1a,.nidaqmx_grpc.CreateAIVoltageRMSChanResponse\x12j\n\x13\x43reateAOCurrentChan\x12(.nidaqmx_grpc.CreateAOCurrentChanRequest\x1a).nidaqmx_grpc.CreateAOCurrentChanResponse\x12j\n\x13\x43reateAOFuncGenChan\x12(.nidaqmx_grpc.CreateAOFuncGenChanRequest\x1a).nidaqmx_grpc.CreateAOFuncGenChanResponse\x12j\n\x13\x43reateAOVoltageChan\x12(.nidaqmx_grpc.CreateAOVoltageChanRequest\x1a).nidaqmx_grpc.CreateAOVoltageChanResponse\x12s\n\x16\x43reateCIAngEncoderChan\x12+.nidaqmx_grpc.CreateCIAngEncoderChanRequest\x1a,.nidaqmx_grpc.CreateCIAngEncoderChanResponse\x12v\n\x17\x43reateCIAngVelocityChan\x12,.nidaqmx_grpc.CreateCIAngVelocityChanRequest\x1a-.nidaqmx_grpc.CreateCIAngVelocityChanResponse\x12s\n\x16\x43reateCICountEdgesChan\x12+.nidaqmx_grpc.CreateCICountEdgesChanRequest\x1a,.nidaqmx_grpc.CreateCICountEdgesChanResponse\x12p\n\x15\x43reateCIDutyCycleChan\x12*.nidaqmx_grpc.CreateCIDutyCycleChanRequest\x1a+.nidaqmx_grpc.CreateCIDutyCycleChanResponse\x12\x61\n\x10\x43reateCIFreqChan\x12%.nidaqmx_grpc.CreateCIFreqChanRequest\x1a&.nidaqmx_grpc.CreateCIFreqChanResponse\x12y\n\x18\x43reateCIGPSTimestampChan\x12-.nidaqmx_grpc.CreateCIGPSTimestampChanRequest\x1a..nidaqmx_grpc.CreateCIGPSTimestampChanResponse\x12s\n\x16\x43reateCILinEncoderChan\x12+.nidaqmx_grpc.CreateCILinEncoderChanRequest\x1a,.nidaqmx_grpc.CreateCILinEncoderChanResponse\x12v\n\x17\x43reateCILinVelocityChan\x12,.nidaqmx_grpc.CreateCILinVelocityChanRequest\x1a-.nidaqmx_grpc.CreateCILinVelocityChanResponse\x12g\n\x12\x43reateCIPeriodChan\x12\'.nidaqmx_grpc.CreateCIPeriodChanRequest\x1a(.nidaqmx_grpc.CreateCIPeriodChanResponse\x12p\n\x15\x43reateCIPulseChanFreq\x12*.nidaqmx_grpc.CreateCIPulseChanFreqRequest\x1a+.nidaqmx_grpc.CreateCIPulseChanFreqResponse\x12s\n\x16\x43reateCIPulseChanTicks\x12+.nidaqmx_grpc.CreateCIPulseChanTicksRequest\x1a,.nidaqmx_grpc.CreateCIPulseChanTicksResponse\x12p\n\x15\x43reateCIPulseChanTime\x12*.nidaqmx_grpc.CreateCIPulseChanTimeRequest\x1a+.nidaqmx_grpc.CreateCIPulseChanTimeResponse\x12s\n\x16\x43reateCIPulseWidthChan\x12+.nidaqmx_grpc.CreateCIPulseWidthChanRequest\x1a,.nidaqmx_grpc.CreateCIPulseWidthChanResponse\x12s\n\x16\x43reateCISemiPeriodChan\x12+.nidaqmx_grpc.CreateCISemiPeriodChanRequest\x1a,.nidaqmx_grpc.CreateCISemiPeriodChanResponse\x12s\n\x16\x43reateCITwoEdgeSepChan\x12+.nidaqmx_grpc.CreateCITwoEdgeSepChanRequest\x1a,.nidaqmx_grpc.CreateCITwoEdgeSepChanResponse\x12p\n\x15\x43reateCOPulseChanFreq\x12*.nidaqmx_grpc.CreateCOPulseChanFreqRequest\x1a+.nidaqmx_grpc.CreateCOPulseChanFreqResponse\x12s\n\x16\x43reateCOPulseChanTicks\x12+.nidaqmx_grpc.CreateCOPulseChanTicksRequest\x1a,.nidaqmx_grpc.CreateCOPulseChanTicksResponse\x12p\n\x15\x43reateCOPulseChanTime\x12*.nidaqmx_grpc.CreateCOPulseChanTimeRequest\x1a+.nidaqmx_grpc.CreateCOPulseChanTimeResponse\x12U\n\x0c\x43reateDIChan\x12!.nidaqmx_grpc.CreateDIChanRequest\x1a\".nidaqmx_grpc.CreateDIChanResponse\x12U\n\x0c\x43reateDOChan\x12!.nidaqmx_grpc.CreateDOChanRequest\x1a\".nidaqmx_grpc.CreateDOChanResponse\x12[\n\x0e\x43reateLinScale\x12#.nidaqmx_grpc.CreateLinScaleRequest\x1a$.nidaqmx_grpc.CreateLinScaleResponse\x12[\n\x0e\x43reateMapScale\x12#.nidaqmx_grpc.CreateMapScaleRequest\x1a$.nidaqmx_grpc.CreateMapScaleResponse\x12p\n\x15\x43reatePolynomialScale\x12*.nidaqmx_grpc.CreatePolynomialScaleRequest\x1a+.nidaqmx_grpc.CreatePolynomialScaleResponse\x12p\n\x15\x43reateTEDSAIAccelChan\x12*.nidaqmx_grpc.CreateTEDSAIAccelChanRequest\x1a+.nidaqmx_grpc.CreateTEDSAIAccelChanResponse\x12s\n\x16\x43reateTEDSAIBridgeChan\x12+.nidaqmx_grpc.CreateTEDSAIBridgeChanRequest\x1a,.nidaqmx_grpc.CreateTEDSAIBridgeChanResponse\x12v\n\x17\x43reateTEDSAICurrentChan\x12,.nidaqmx_grpc.CreateTEDSAICurrentChanRequest\x1a-.nidaqmx_grpc.CreateTEDSAICurrentChanResponse\x12\x82\x01\n\x1b\x43reateTEDSAIForceBridgeChan\x12\x30.nidaqmx_grpc.CreateTEDSAIForceBridgeChanRequest\x1a\x31.nidaqmx_grpc.CreateTEDSAIForceBridgeChanResponse\x12|\n\x19\x43reateTEDSAIForceIEPEChan\x12..nidaqmx_grpc.CreateTEDSAIForceIEPEChanRequest\x1a/.nidaqmx_grpc.CreateTEDSAIForceIEPEChanResponse\x12\x7f\n\x1a\x43reateTEDSAIMicrophoneChan\x12/.nidaqmx_grpc.CreateTEDSAIMicrophoneChanRequest\x1a\x30.nidaqmx_grpc.CreateTEDSAIMicrophoneChanResponse\x12v\n\x17\x43reateTEDSAIPosLVDTChan\x12,.nidaqmx_grpc.CreateTEDSAIPosLVDTChanRequest\x1a-.nidaqmx_grpc.CreateTEDSAIPosLVDTChanResponse\x12v\n\x17\x43reateTEDSAIPosRVDTChan\x12,.nidaqmx_grpc.CreateTEDSAIPosRVDTChanRequest\x1a-.nidaqmx_grpc.CreateTEDSAIPosRVDTChanResponse\x12\x8b\x01\n\x1e\x43reateTEDSAIPressureBridgeChan\x12\x33.nidaqmx_grpc.CreateTEDSAIPressureBridgeChanRequest\x1a\x34.nidaqmx_grpc.CreateTEDSAIPressureBridgeChanResponse\x12j\n\x13\x43reateTEDSAIRTDChan\x12(.nidaqmx_grpc.CreateTEDSAIRTDChanRequest\x1a).nidaqmx_grpc.CreateTEDSAIRTDChanResponse\x12\x7f\n\x1a\x43reateTEDSAIResistanceChan\x12/.nidaqmx_grpc.CreateTEDSAIResistanceChanRequest\x1a\x30.nidaqmx_grpc.CreateTEDSAIResistanceChanResponse\x12\x7f\n\x1a\x43reateTEDSAIStrainGageChan\x12/.nidaqmx_grpc.CreateTEDSAIStrainGageChanRequest\x1a\x30.nidaqmx_grpc.CreateTEDSAIStrainGageChanResponse\x12v\n\x17\x43reateTEDSAIThrmcplChan\x12,.nidaqmx_grpc.CreateTEDSAIThrmcplChanRequest\x1a-.nidaqmx_grpc.CreateTEDSAIThrmcplChanResponse\x12\x7f\n\x1a\x43reateTEDSAIThrmstrChanIex\x12/.nidaqmx_grpc.CreateTEDSAIThrmstrChanIexRequest\x1a\x30.nidaqmx_grpc.CreateTEDSAIThrmstrChanIexResponse\x12\x7f\n\x1a\x43reateTEDSAIThrmstrChanVex\x12/.nidaqmx_grpc.CreateTEDSAIThrmstrChanVexRequest\x1a\x30.nidaqmx_grpc.CreateTEDSAIThrmstrChanVexResponse\x12\x85\x01\n\x1c\x43reateTEDSAITorqueBridgeChan\x12\x31.nidaqmx_grpc.CreateTEDSAITorqueBridgeChanRequest\x1a\x32.nidaqmx_grpc.CreateTEDSAITorqueBridgeChanResponse\x12v\n\x17\x43reateTEDSAIVoltageChan\x12,.nidaqmx_grpc.CreateTEDSAIVoltageChanRequest\x1a-.nidaqmx_grpc.CreateTEDSAIVoltageChanResponse\x12\x91\x01\n CreateTEDSAIVoltageChanWithExcit\x12\x35.nidaqmx_grpc.CreateTEDSAIVoltageChanWithExcitRequest\x1a\x36.nidaqmx_grpc.CreateTEDSAIVoltageChanWithExcitResponse\x12\x61\n\x10\x43reateTableScale\x12%.nidaqmx_grpc.CreateTableScaleRequest\x1a&.nidaqmx_grpc.CreateTableScaleResponse\x12O\n\nCreateTask\x12\x1f.nidaqmx_grpc.CreateTaskRequest\x1a .nidaqmx_grpc.CreateTaskResponse\x12v\n\x17\x43reateWatchdogTimerTask\x12,.nidaqmx_grpc.CreateWatchdogTimerTaskRequest\x1a-.nidaqmx_grpc.CreateWatchdogTimerTaskResponse\x12|\n\x19\x43reateWatchdogTimerTaskEx\x12..nidaqmx_grpc.CreateWatchdogTimerTaskExRequest\x1a/.nidaqmx_grpc.CreateWatchdogTimerTaskExResponse\x12j\n\x13\x44\x65leteNetworkDevice\x12(.nidaqmx_grpc.DeleteNetworkDeviceRequest\x1a).nidaqmx_grpc.DeleteNetworkDeviceResponse\x12p\n\x15\x44\x65leteSavedGlobalChan\x12*.nidaqmx_grpc.DeleteSavedGlobalChanRequest\x1a+.nidaqmx_grpc.DeleteSavedGlobalChanResponse\x12\x61\n\x10\x44\x65leteSavedScale\x12%.nidaqmx_grpc.DeleteSavedScaleRequest\x1a&.nidaqmx_grpc.DeleteSavedScaleResponse\x12^\n\x0f\x44\x65leteSavedTask\x12$.nidaqmx_grpc.DeleteSavedTaskRequest\x1a%.nidaqmx_grpc.DeleteSavedTaskResponse\x12\x64\n\x11\x44\x65viceSupportsCal\x12&.nidaqmx_grpc.DeviceSupportsCalRequest\x1a\'.nidaqmx_grpc.DeviceSupportsCalResponse\x12[\n\x0e\x44isableRefTrig\x12#.nidaqmx_grpc.DisableRefTrigRequest\x1a$.nidaqmx_grpc.DisableRefTrigResponse\x12\x61\n\x10\x44isableStartTrig\x12%.nidaqmx_grpc.DisableStartTrigRequest\x1a&.nidaqmx_grpc.DisableStartTrigResponse\x12^\n\x0f\x44isconnectTerms\x12$.nidaqmx_grpc.DisconnectTermsRequest\x1a%.nidaqmx_grpc.DisconnectTermsResponse\x12U\n\x0c\x45xportSignal\x12!.nidaqmx_grpc.ExportSignalRequest\x1a\".nidaqmx_grpc.ExportSignalResponse\x12j\n\x13GetAIChanCalCalDate\x12(.nidaqmx_grpc.GetAIChanCalCalDateRequest\x1a).nidaqmx_grpc.GetAIChanCalCalDateResponse\x12j\n\x13GetAIChanCalExpDate\x12(.nidaqmx_grpc.GetAIChanCalExpDateRequest\x1a).nidaqmx_grpc.GetAIChanCalExpDateResponse\x12s\n\x16GetAnalogPowerUpStates\x12+.nidaqmx_grpc.GetAnalogPowerUpStatesRequest\x1a,.nidaqmx_grpc.GetAnalogPowerUpStatesResponse\x12\x9d\x01\n$GetAnalogPowerUpStatesWithOutputType\x12\x39.nidaqmx_grpc.GetAnalogPowerUpStatesWithOutputTypeRequest\x1a:.nidaqmx_grpc.GetAnalogPowerUpStatesWithOutputTypeResponse\x12\x82\x01\n\x1bGetArmStartTrigTimestampVal\x12\x30.nidaqmx_grpc.GetArmStartTrigTimestampValRequest\x1a\x31.nidaqmx_grpc.GetArmStartTrigTimestampValResponse\x12v\n\x17GetArmStartTrigTrigWhen\x12,.nidaqmx_grpc.GetArmStartTrigTrigWhenRequest\x1a-.nidaqmx_grpc.GetArmStartTrigTrigWhenResponse\x12\x9d\x01\n$GetAutoConfiguredCDAQSyncConnections\x12\x39.nidaqmx_grpc.GetAutoConfiguredCDAQSyncConnectionsRequest\x1a:.nidaqmx_grpc.GetAutoConfiguredCDAQSyncConnectionsResponse\x12y\n\x18GetBufferAttributeUInt32\x12-.nidaqmx_grpc.GetBufferAttributeUInt32Request\x1a..nidaqmx_grpc.GetBufferAttributeUInt32Response\x12v\n\x17GetCalInfoAttributeBool\x12,.nidaqmx_grpc.GetCalInfoAttributeBoolRequest\x1a-.nidaqmx_grpc.GetCalInfoAttributeBoolResponse\x12|\n\x19GetCalInfoAttributeDouble\x12..nidaqmx_grpc.GetCalInfoAttributeDoubleRequest\x1a/.nidaqmx_grpc.GetCalInfoAttributeDoubleResponse\x12|\n\x19GetCalInfoAttributeString\x12..nidaqmx_grpc.GetCalInfoAttributeStringRequest\x1a/.nidaqmx_grpc.GetCalInfoAttributeStringResponse\x12|\n\x19GetCalInfoAttributeUInt32\x12..nidaqmx_grpc.GetCalInfoAttributeUInt32Request\x1a/.nidaqmx_grpc.GetCalInfoAttributeUInt32Response\x12m\n\x14GetChanAttributeBool\x12).nidaqmx_grpc.GetChanAttributeBoolRequest\x1a*.nidaqmx_grpc.GetChanAttributeBoolResponse\x12s\n\x16GetChanAttributeDouble\x12+.nidaqmx_grpc.GetChanAttributeDoubleRequest\x1a,.nidaqmx_grpc.GetChanAttributeDoubleResponse\x12\x82\x01\n\x1bGetChanAttributeDoubleArray\x12\x30.nidaqmx_grpc.GetChanAttributeDoubleArrayRequest\x1a\x31.nidaqmx_grpc.GetChanAttributeDoubleArrayResponse\x12p\n\x15GetChanAttributeInt32\x12*.nidaqmx_grpc.GetChanAttributeInt32Request\x1a+.nidaqmx_grpc.GetChanAttributeInt32Response\x12s\n\x16GetChanAttributeString\x12+.nidaqmx_grpc.GetChanAttributeStringRequest\x1a,.nidaqmx_grpc.GetChanAttributeStringResponse\x12s\n\x16GetChanAttributeUInt32\x12+.nidaqmx_grpc.GetChanAttributeUInt32Request\x1a,.nidaqmx_grpc.GetChanAttributeUInt32Response\x12s\n\x16GetDeviceAttributeBool\x12+.nidaqmx_grpc.GetDeviceAttributeBoolRequest\x1a,.nidaqmx_grpc.GetDeviceAttributeBoolResponse\x12y\n\x18GetDeviceAttributeDouble\x12-.nidaqmx_grpc.GetDeviceAttributeDoubleRequest\x1a..nidaqmx_grpc.GetDeviceAttributeDoubleResponse\x12\x88\x01\n\x1dGetDeviceAttributeDoubleArray\x12\x32.nidaqmx_grpc.GetDeviceAttributeDoubleArrayRequest\x1a\x33.nidaqmx_grpc.GetDeviceAttributeDoubleArrayResponse\x12v\n\x17GetDeviceAttributeInt32\x12,.nidaqmx_grpc.GetDeviceAttributeInt32Request\x1a-.nidaqmx_grpc.GetDeviceAttributeInt32Response\x12\x85\x01\n\x1cGetDeviceAttributeInt32Array\x12\x31.nidaqmx_grpc.GetDeviceAttributeInt32ArrayRequest\x1a\x32.nidaqmx_grpc.GetDeviceAttributeInt32ArrayResponse\x12y\n\x18GetDeviceAttributeString\x12-.nidaqmx_grpc.GetDeviceAttributeStringRequest\x1a..nidaqmx_grpc.GetDeviceAttributeStringResponse\x12y\n\x18GetDeviceAttributeUInt32\x12-.nidaqmx_grpc.GetDeviceAttributeUInt32Request\x1a..nidaqmx_grpc.GetDeviceAttributeUInt32Response\x12\x88\x01\n\x1dGetDeviceAttributeUInt32Array\x12\x32.nidaqmx_grpc.GetDeviceAttributeUInt32ArrayRequest\x1a\x33.nidaqmx_grpc.GetDeviceAttributeUInt32ArrayResponse\x12\x94\x01\n!GetDigitalLogicFamilyPowerUpState\x12\x36.nidaqmx_grpc.GetDigitalLogicFamilyPowerUpStateRequest\x1a\x37.nidaqmx_grpc.GetDigitalLogicFamilyPowerUpStateResponse\x12v\n\x17GetDigitalPowerUpStates\x12,.nidaqmx_grpc.GetDigitalPowerUpStatesRequest\x1a-.nidaqmx_grpc.GetDigitalPowerUpStatesResponse\x12\x8b\x01\n\x1eGetDigitalPullUpPullDownStates\x12\x33.nidaqmx_grpc.GetDigitalPullUpPullDownStatesRequest\x1a\x34.nidaqmx_grpc.GetDigitalPullUpPullDownStatesResponse\x12\x85\x01\n\x1cGetDisconnectedCDAQSyncPorts\x12\x31.nidaqmx_grpc.GetDisconnectedCDAQSyncPortsRequest\x1a\x32.nidaqmx_grpc.GetDisconnectedCDAQSyncPortsResponse\x12[\n\x0eGetErrorString\x12#.nidaqmx_grpc.GetErrorStringRequest\x1a$.nidaqmx_grpc.GetErrorStringResponse\x12\x8b\x01\n\x1eGetExportedSignalAttributeBool\x12\x33.nidaqmx_grpc.GetExportedSignalAttributeBoolRequest\x1a\x34.nidaqmx_grpc.GetExportedSignalAttributeBoolResponse\x12\x91\x01\n GetExportedSignalAttributeDouble\x12\x35.nidaqmx_grpc.GetExportedSignalAttributeDoubleRequest\x1a\x36.nidaqmx_grpc.GetExportedSignalAttributeDoubleResponse\x12\x8e\x01\n\x1fGetExportedSignalAttributeInt32\x12\x34.nidaqmx_grpc.GetExportedSignalAttributeInt32Request\x1a\x35.nidaqmx_grpc.GetExportedSignalAttributeInt32Response\x12\x91\x01\n GetExportedSignalAttributeString\x12\x35.nidaqmx_grpc.GetExportedSignalAttributeStringRequest\x1a\x36.nidaqmx_grpc.GetExportedSignalAttributeStringResponse\x12\x91\x01\n GetExportedSignalAttributeUInt32\x12\x35.nidaqmx_grpc.GetExportedSignalAttributeUInt32Request\x1a\x36.nidaqmx_grpc.GetExportedSignalAttributeUInt32Response\x12y\n\x18GetExtCalLastDateAndTime\x12-.nidaqmx_grpc.GetExtCalLastDateAndTimeRequest\x1a..nidaqmx_grpc.GetExtCalLastDateAndTimeResponse\x12j\n\x13GetFirstSampClkWhen\x12(.nidaqmx_grpc.GetFirstSampClkWhenRequest\x1a).nidaqmx_grpc.GetFirstSampClkWhenResponse\x12y\n\x18GetFirstSampTimestampVal\x12-.nidaqmx_grpc.GetFirstSampTimestampValRequest\x1a..nidaqmx_grpc.GetFirstSampTimestampValResponse\x12\x64\n\x11GetNthTaskChannel\x12&.nidaqmx_grpc.GetNthTaskChannelRequest\x1a\'.nidaqmx_grpc.GetNthTaskChannelResponse\x12\x61\n\x10GetNthTaskDevice\x12%.nidaqmx_grpc.GetNthTaskDeviceRequest\x1a&.nidaqmx_grpc.GetNthTaskDeviceResponse\x12p\n\x15GetNthTaskReadChannel\x12*.nidaqmx_grpc.GetNthTaskReadChannelRequest\x1a+.nidaqmx_grpc.GetNthTaskReadChannelResponse\x12\x88\x01\n\x1dGetPersistedChanAttributeBool\x12\x32.nidaqmx_grpc.GetPersistedChanAttributeBoolRequest\x1a\x33.nidaqmx_grpc.GetPersistedChanAttributeBoolResponse\x12\x8e\x01\n\x1fGetPersistedChanAttributeString\x12\x34.nidaqmx_grpc.GetPersistedChanAttributeStringRequest\x1a\x35.nidaqmx_grpc.GetPersistedChanAttributeStringResponse\x12\x8b\x01\n\x1eGetPersistedScaleAttributeBool\x12\x33.nidaqmx_grpc.GetPersistedScaleAttributeBoolRequest\x1a\x34.nidaqmx_grpc.GetPersistedScaleAttributeBoolResponse\x12\x91\x01\n GetPersistedScaleAttributeString\x12\x35.nidaqmx_grpc.GetPersistedScaleAttributeStringRequest\x1a\x36.nidaqmx_grpc.GetPersistedScaleAttributeStringResponse\x12\x88\x01\n\x1dGetPersistedTaskAttributeBool\x12\x32.nidaqmx_grpc.GetPersistedTaskAttributeBoolRequest\x1a\x33.nidaqmx_grpc.GetPersistedTaskAttributeBoolResponse\x12\x8e\x01\n\x1fGetPersistedTaskAttributeString\x12\x34.nidaqmx_grpc.GetPersistedTaskAttributeStringRequest\x1a\x35.nidaqmx_grpc.GetPersistedTaskAttributeStringResponse\x12\x85\x01\n\x1cGetPhysicalChanAttributeBool\x12\x31.nidaqmx_grpc.GetPhysicalChanAttributeBoolRequest\x1a\x32.nidaqmx_grpc.GetPhysicalChanAttributeBoolResponse\x12\x88\x01\n\x1dGetPhysicalChanAttributeBytes\x12\x32.nidaqmx_grpc.GetPhysicalChanAttributeBytesRequest\x1a\x33.nidaqmx_grpc.GetPhysicalChanAttributeBytesResponse\x12\x8b\x01\n\x1eGetPhysicalChanAttributeDouble\x12\x33.nidaqmx_grpc.GetPhysicalChanAttributeDoubleRequest\x1a\x34.nidaqmx_grpc.GetPhysicalChanAttributeDoubleResponse\x12\x9a\x01\n#GetPhysicalChanAttributeDoubleArray\x12\x38.nidaqmx_grpc.GetPhysicalChanAttributeDoubleArrayRequest\x1a\x39.nidaqmx_grpc.GetPhysicalChanAttributeDoubleArrayResponse\x12\x88\x01\n\x1dGetPhysicalChanAttributeInt32\x12\x32.nidaqmx_grpc.GetPhysicalChanAttributeInt32Request\x1a\x33.nidaqmx_grpc.GetPhysicalChanAttributeInt32Response\x12\x97\x01\n\"GetPhysicalChanAttributeInt32Array\x12\x37.nidaqmx_grpc.GetPhysicalChanAttributeInt32ArrayRequest\x1a\x38.nidaqmx_grpc.GetPhysicalChanAttributeInt32ArrayResponse\x12\x8b\x01\n\x1eGetPhysicalChanAttributeString\x12\x33.nidaqmx_grpc.GetPhysicalChanAttributeStringRequest\x1a\x34.nidaqmx_grpc.GetPhysicalChanAttributeStringResponse\x12\x8b\x01\n\x1eGetPhysicalChanAttributeUInt32\x12\x33.nidaqmx_grpc.GetPhysicalChanAttributeUInt32Request\x1a\x34.nidaqmx_grpc.GetPhysicalChanAttributeUInt32Response\x12\x9a\x01\n#GetPhysicalChanAttributeUInt32Array\x12\x38.nidaqmx_grpc.GetPhysicalChanAttributeUInt32ArrayRequest\x1a\x39.nidaqmx_grpc.GetPhysicalChanAttributeUInt32ArrayResponse\x12m\n\x14GetReadAttributeBool\x12).nidaqmx_grpc.GetReadAttributeBoolRequest\x1a*.nidaqmx_grpc.GetReadAttributeBoolResponse\x12s\n\x16GetReadAttributeDouble\x12+.nidaqmx_grpc.GetReadAttributeDoubleRequest\x1a,.nidaqmx_grpc.GetReadAttributeDoubleResponse\x12p\n\x15GetReadAttributeInt32\x12*.nidaqmx_grpc.GetReadAttributeInt32Request\x1a+.nidaqmx_grpc.GetReadAttributeInt32Response\x12s\n\x16GetReadAttributeString\x12+.nidaqmx_grpc.GetReadAttributeStringRequest\x1a,.nidaqmx_grpc.GetReadAttributeStringResponse\x12s\n\x16GetReadAttributeUInt32\x12+.nidaqmx_grpc.GetReadAttributeUInt32Request\x1a,.nidaqmx_grpc.GetReadAttributeUInt32Response\x12s\n\x16GetReadAttributeUInt64\x12+.nidaqmx_grpc.GetReadAttributeUInt64Request\x1a,.nidaqmx_grpc.GetReadAttributeUInt64Response\x12y\n\x18GetRealTimeAttributeBool\x12-.nidaqmx_grpc.GetRealTimeAttributeBoolRequest\x1a..nidaqmx_grpc.GetRealTimeAttributeBoolResponse\x12|\n\x19GetRealTimeAttributeInt32\x12..nidaqmx_grpc.GetRealTimeAttributeInt32Request\x1a/.nidaqmx_grpc.GetRealTimeAttributeInt32Response\x12\x7f\n\x1aGetRealTimeAttributeUInt32\x12/.nidaqmx_grpc.GetRealTimeAttributeUInt32Request\x1a\x30.nidaqmx_grpc.GetRealTimeAttributeUInt32Response\x12s\n\x16GetRefTrigTimestampVal\x12+.nidaqmx_grpc.GetRefTrigTimestampValRequest\x1a,.nidaqmx_grpc.GetRefTrigTimestampValResponse\x12v\n\x17GetScaleAttributeDouble\x12,.nidaqmx_grpc.GetScaleAttributeDoubleRequest\x1a-.nidaqmx_grpc.GetScaleAttributeDoubleResponse\x12\x85\x01\n\x1cGetScaleAttributeDoubleArray\x12\x31.nidaqmx_grpc.GetScaleAttributeDoubleArrayRequest\x1a\x32.nidaqmx_grpc.GetScaleAttributeDoubleArrayResponse\x12s\n\x16GetScaleAttributeInt32\x12+.nidaqmx_grpc.GetScaleAttributeInt32Request\x1a,.nidaqmx_grpc.GetScaleAttributeInt32Response\x12v\n\x17GetScaleAttributeString\x12,.nidaqmx_grpc.GetScaleAttributeStringRequest\x1a-.nidaqmx_grpc.GetScaleAttributeStringResponse\x12|\n\x19GetSelfCalLastDateAndTime\x12..nidaqmx_grpc.GetSelfCalLastDateAndTimeRequest\x1a/.nidaqmx_grpc.GetSelfCalLastDateAndTimeResponse\x12y\n\x18GetStartTrigTimestampVal\x12-.nidaqmx_grpc.GetStartTrigTimestampValRequest\x1a..nidaqmx_grpc.GetStartTrigTimestampValResponse\x12m\n\x14GetStartTrigTrigWhen\x12).nidaqmx_grpc.GetStartTrigTrigWhenRequest\x1a*.nidaqmx_grpc.GetStartTrigTrigWhenResponse\x12m\n\x14GetSyncPulseTimeWhen\x12).nidaqmx_grpc.GetSyncPulseTimeWhenRequest\x1a*.nidaqmx_grpc.GetSyncPulseTimeWhenResponse\x12\x85\x01\n\x1cGetSystemInfoAttributeString\x12\x31.nidaqmx_grpc.GetSystemInfoAttributeStringRequest\x1a\x32.nidaqmx_grpc.GetSystemInfoAttributeStringResponse\x12\x85\x01\n\x1cGetSystemInfoAttributeUInt32\x12\x31.nidaqmx_grpc.GetSystemInfoAttributeUInt32Request\x1a\x32.nidaqmx_grpc.GetSystemInfoAttributeUInt32Response\x12m\n\x14GetTaskAttributeBool\x12).nidaqmx_grpc.GetTaskAttributeBoolRequest\x1a*.nidaqmx_grpc.GetTaskAttributeBoolResponse\x12s\n\x16GetTaskAttributeString\x12+.nidaqmx_grpc.GetTaskAttributeStringRequest\x1a,.nidaqmx_grpc.GetTaskAttributeStringResponse\x12s\n\x16GetTaskAttributeUInt32\x12+.nidaqmx_grpc.GetTaskAttributeUInt32Request\x1a,.nidaqmx_grpc.GetTaskAttributeUInt32Response\x12s\n\x16GetTimingAttributeBool\x12+.nidaqmx_grpc.GetTimingAttributeBoolRequest\x1a,.nidaqmx_grpc.GetTimingAttributeBoolResponse\x12y\n\x18GetTimingAttributeDouble\x12-.nidaqmx_grpc.GetTimingAttributeDoubleRequest\x1a..nidaqmx_grpc.GetTimingAttributeDoubleResponse\x12y\n\x18GetTimingAttributeExBool\x12-.nidaqmx_grpc.GetTimingAttributeExBoolRequest\x1a..nidaqmx_grpc.GetTimingAttributeExBoolResponse\x12\x7f\n\x1aGetTimingAttributeExDouble\x12/.nidaqmx_grpc.GetTimingAttributeExDoubleRequest\x1a\x30.nidaqmx_grpc.GetTimingAttributeExDoubleResponse\x12|\n\x19GetTimingAttributeExInt32\x12..nidaqmx_grpc.GetTimingAttributeExInt32Request\x1a/.nidaqmx_grpc.GetTimingAttributeExInt32Response\x12\x7f\n\x1aGetTimingAttributeExString\x12/.nidaqmx_grpc.GetTimingAttributeExStringRequest\x1a\x30.nidaqmx_grpc.GetTimingAttributeExStringResponse\x12\x88\x01\n\x1dGetTimingAttributeExTimestamp\x12\x32.nidaqmx_grpc.GetTimingAttributeExTimestampRequest\x1a\x33.nidaqmx_grpc.GetTimingAttributeExTimestampResponse\x12\x7f\n\x1aGetTimingAttributeExUInt32\x12/.nidaqmx_grpc.GetTimingAttributeExUInt32Request\x1a\x30.nidaqmx_grpc.GetTimingAttributeExUInt32Response\x12\x7f\n\x1aGetTimingAttributeExUInt64\x12/.nidaqmx_grpc.GetTimingAttributeExUInt64Request\x1a\x30.nidaqmx_grpc.GetTimingAttributeExUInt64Response\x12v\n\x17GetTimingAttributeInt32\x12,.nidaqmx_grpc.GetTimingAttributeInt32Request\x1a-.nidaqmx_grpc.GetTimingAttributeInt32Response\x12y\n\x18GetTimingAttributeString\x12-.nidaqmx_grpc.GetTimingAttributeStringRequest\x1a..nidaqmx_grpc.GetTimingAttributeStringResponse\x12\x82\x01\n\x1bGetTimingAttributeTimestamp\x12\x30.nidaqmx_grpc.GetTimingAttributeTimestampRequest\x1a\x31.nidaqmx_grpc.GetTimingAttributeTimestampResponse\x12y\n\x18GetTimingAttributeUInt32\x12-.nidaqmx_grpc.GetTimingAttributeUInt32Request\x1a..nidaqmx_grpc.GetTimingAttributeUInt32Response\x12y\n\x18GetTimingAttributeUInt64\x12-.nidaqmx_grpc.GetTimingAttributeUInt64Request\x1a..nidaqmx_grpc.GetTimingAttributeUInt64Response\x12m\n\x14GetTrigAttributeBool\x12).nidaqmx_grpc.GetTrigAttributeBoolRequest\x1a*.nidaqmx_grpc.GetTrigAttributeBoolResponse\x12s\n\x16GetTrigAttributeDouble\x12+.nidaqmx_grpc.GetTrigAttributeDoubleRequest\x1a,.nidaqmx_grpc.GetTrigAttributeDoubleResponse\x12\x82\x01\n\x1bGetTrigAttributeDoubleArray\x12\x30.nidaqmx_grpc.GetTrigAttributeDoubleArrayRequest\x1a\x31.nidaqmx_grpc.GetTrigAttributeDoubleArrayResponse\x12p\n\x15GetTrigAttributeInt32\x12*.nidaqmx_grpc.GetTrigAttributeInt32Request\x1a+.nidaqmx_grpc.GetTrigAttributeInt32Response\x12\x7f\n\x1aGetTrigAttributeInt32Array\x12/.nidaqmx_grpc.GetTrigAttributeInt32ArrayRequest\x1a\x30.nidaqmx_grpc.GetTrigAttributeInt32ArrayResponse\x12s\n\x16GetTrigAttributeString\x12+.nidaqmx_grpc.GetTrigAttributeStringRequest\x1a,.nidaqmx_grpc.GetTrigAttributeStringResponse\x12|\n\x19GetTrigAttributeTimestamp\x12..nidaqmx_grpc.GetTrigAttributeTimestampRequest\x1a/.nidaqmx_grpc.GetTrigAttributeTimestampResponse\x12s\n\x16GetTrigAttributeUInt32\x12+.nidaqmx_grpc.GetTrigAttributeUInt32Request\x1a,.nidaqmx_grpc.GetTrigAttributeUInt32Response\x12y\n\x18GetWatchdogAttributeBool\x12-.nidaqmx_grpc.GetWatchdogAttributeBoolRequest\x1a..nidaqmx_grpc.GetWatchdogAttributeBoolResponse\x12\x7f\n\x1aGetWatchdogAttributeDouble\x12/.nidaqmx_grpc.GetWatchdogAttributeDoubleRequest\x1a\x30.nidaqmx_grpc.GetWatchdogAttributeDoubleResponse\x12|\n\x19GetWatchdogAttributeInt32\x12..nidaqmx_grpc.GetWatchdogAttributeInt32Request\x1a/.nidaqmx_grpc.GetWatchdogAttributeInt32Response\x12\x7f\n\x1aGetWatchdogAttributeString\x12/.nidaqmx_grpc.GetWatchdogAttributeStringRequest\x1a\x30.nidaqmx_grpc.GetWatchdogAttributeStringResponse\x12p\n\x15GetWriteAttributeBool\x12*.nidaqmx_grpc.GetWriteAttributeBoolRequest\x1a+.nidaqmx_grpc.GetWriteAttributeBoolResponse\x12v\n\x17GetWriteAttributeDouble\x12,.nidaqmx_grpc.GetWriteAttributeDoubleRequest\x1a-.nidaqmx_grpc.GetWriteAttributeDoubleResponse\x12s\n\x16GetWriteAttributeInt32\x12+.nidaqmx_grpc.GetWriteAttributeInt32Request\x1a,.nidaqmx_grpc.GetWriteAttributeInt32Response\x12v\n\x17GetWriteAttributeString\x12,.nidaqmx_grpc.GetWriteAttributeStringRequest\x1a-.nidaqmx_grpc.GetWriteAttributeStringResponse\x12v\n\x17GetWriteAttributeUInt32\x12,.nidaqmx_grpc.GetWriteAttributeUInt32Request\x1a-.nidaqmx_grpc.GetWriteAttributeUInt32Response\x12v\n\x17GetWriteAttributeUInt64\x12,.nidaqmx_grpc.GetWriteAttributeUInt64Request\x1a-.nidaqmx_grpc.GetWriteAttributeUInt64Response\x12O\n\nIsTaskDone\x12\x1f.nidaqmx_grpc.IsTaskDoneRequest\x1a .nidaqmx_grpc.IsTaskDoneResponse\x12I\n\x08LoadTask\x12\x1d.nidaqmx_grpc.LoadTaskRequest\x1a\x1e.nidaqmx_grpc.LoadTaskResponse\x12\x8e\x01\n\x1fPerformBridgeOffsetNullingCalEx\x12\x34.nidaqmx_grpc.PerformBridgeOffsetNullingCalExRequest\x1a\x35.nidaqmx_grpc.PerformBridgeOffsetNullingCalExResponse\x12v\n\x17PerformBridgeShuntCalEx\x12,.nidaqmx_grpc.PerformBridgeShuntCalExRequest\x1a-.nidaqmx_grpc.PerformBridgeShuntCalExResponse\x12v\n\x17PerformStrainShuntCalEx\x12,.nidaqmx_grpc.PerformStrainShuntCalExRequest\x1a-.nidaqmx_grpc.PerformStrainShuntCalExResponse\x12\x97\x01\n\"PerformThrmcplLeadOffsetNullingCal\x12\x37.nidaqmx_grpc.PerformThrmcplLeadOffsetNullingCalRequest\x1a\x38.nidaqmx_grpc.PerformThrmcplLeadOffsetNullingCalResponse\x12X\n\rReadAnalogF64\x12\".nidaqmx_grpc.ReadAnalogF64Request\x1a#.nidaqmx_grpc.ReadAnalogF64Response\x12j\n\x13ReadAnalogScalarF64\x12(.nidaqmx_grpc.ReadAnalogScalarF64Request\x1a).nidaqmx_grpc.ReadAnalogScalarF64Response\x12X\n\rReadBinaryI16\x12\".nidaqmx_grpc.ReadBinaryI16Request\x1a#.nidaqmx_grpc.ReadBinaryI16Response\x12X\n\rReadBinaryI32\x12\".nidaqmx_grpc.ReadBinaryI32Request\x1a#.nidaqmx_grpc.ReadBinaryI32Response\x12X\n\rReadBinaryU16\x12\".nidaqmx_grpc.ReadBinaryU16Request\x1a#.nidaqmx_grpc.ReadBinaryU16Response\x12X\n\rReadBinaryU32\x12\".nidaqmx_grpc.ReadBinaryU32Request\x1a#.nidaqmx_grpc.ReadBinaryU32Response\x12[\n\x0eReadCounterF64\x12#.nidaqmx_grpc.ReadCounterF64Request\x1a$.nidaqmx_grpc.ReadCounterF64Response\x12\x61\n\x10ReadCounterF64Ex\x12%.nidaqmx_grpc.ReadCounterF64ExRequest\x1a&.nidaqmx_grpc.ReadCounterF64ExResponse\x12m\n\x14ReadCounterScalarF64\x12).nidaqmx_grpc.ReadCounterScalarF64Request\x1a*.nidaqmx_grpc.ReadCounterScalarF64Response\x12m\n\x14ReadCounterScalarU32\x12).nidaqmx_grpc.ReadCounterScalarU32Request\x1a*.nidaqmx_grpc.ReadCounterScalarU32Response\x12[\n\x0eReadCounterU32\x12#.nidaqmx_grpc.ReadCounterU32Request\x1a$.nidaqmx_grpc.ReadCounterU32Response\x12\x61\n\x10ReadCounterU32Ex\x12%.nidaqmx_grpc.ReadCounterU32ExRequest\x1a&.nidaqmx_grpc.ReadCounterU32ExResponse\x12R\n\x0bReadCtrFreq\x12 .nidaqmx_grpc.ReadCtrFreqRequest\x1a!.nidaqmx_grpc.ReadCtrFreqResponse\x12\x64\n\x11ReadCtrFreqScalar\x12&.nidaqmx_grpc.ReadCtrFreqScalarRequest\x1a\'.nidaqmx_grpc.ReadCtrFreqScalarResponse\x12U\n\x0cReadCtrTicks\x12!.nidaqmx_grpc.ReadCtrTicksRequest\x1a\".nidaqmx_grpc.ReadCtrTicksResponse\x12g\n\x12ReadCtrTicksScalar\x12\'.nidaqmx_grpc.ReadCtrTicksScalarRequest\x1a(.nidaqmx_grpc.ReadCtrTicksScalarResponse\x12R\n\x0bReadCtrTime\x12 .nidaqmx_grpc.ReadCtrTimeRequest\x1a!.nidaqmx_grpc.ReadCtrTimeResponse\x12\x64\n\x11ReadCtrTimeScalar\x12&.nidaqmx_grpc.ReadCtrTimeScalarRequest\x1a\'.nidaqmx_grpc.ReadCtrTimeScalarResponse\x12\x61\n\x10ReadDigitalLines\x12%.nidaqmx_grpc.ReadDigitalLinesRequest\x1a&.nidaqmx_grpc.ReadDigitalLinesResponse\x12m\n\x14ReadDigitalScalarU32\x12).nidaqmx_grpc.ReadDigitalScalarU32Request\x1a*.nidaqmx_grpc.ReadDigitalScalarU32Response\x12[\n\x0eReadDigitalU16\x12#.nidaqmx_grpc.ReadDigitalU16Request\x1a$.nidaqmx_grpc.ReadDigitalU16Response\x12[\n\x0eReadDigitalU32\x12#.nidaqmx_grpc.ReadDigitalU32Request\x1a$.nidaqmx_grpc.ReadDigitalU32Response\x12X\n\rReadDigitalU8\x12\".nidaqmx_grpc.ReadDigitalU8Request\x1a#.nidaqmx_grpc.ReadDigitalU8Response\x12g\n\x12ReadPowerBinaryI16\x12\'.nidaqmx_grpc.ReadPowerBinaryI16Request\x1a(.nidaqmx_grpc.ReadPowerBinaryI16Response\x12U\n\x0cReadPowerF64\x12!.nidaqmx_grpc.ReadPowerF64Request\x1a\".nidaqmx_grpc.ReadPowerF64Response\x12g\n\x12ReadPowerScalarF64\x12\'.nidaqmx_grpc.ReadPowerScalarF64Request\x1a(.nidaqmx_grpc.ReadPowerScalarF64Response\x12\x46\n\x07ReadRaw\x12\x1c.nidaqmx_grpc.ReadRawRequest\x1a\x1d.nidaqmx_grpc.ReadRawResponse\x12\x66\n\x11RegisterDoneEvent\x12&.nidaqmx_grpc.RegisterDoneEventRequest\x1a\'.nidaqmx_grpc.RegisterDoneEventResponse0\x01\x12\x81\x01\n\x1aRegisterEveryNSamplesEvent\x12/.nidaqmx_grpc.RegisterEveryNSamplesEventRequest\x1a\x30.nidaqmx_grpc.RegisterEveryNSamplesEventResponse0\x01\x12l\n\x13RegisterSignalEvent\x12(.nidaqmx_grpc.RegisterSignalEventRequest\x1a).nidaqmx_grpc.RegisterSignalEventResponse0\x01\x12y\n\x18RemoveCDAQSyncConnection\x12-.nidaqmx_grpc.RemoveCDAQSyncConnectionRequest\x1a..nidaqmx_grpc.RemoveCDAQSyncConnectionResponse\x12m\n\x14ReserveNetworkDevice\x12).nidaqmx_grpc.ReserveNetworkDeviceRequest\x1a*.nidaqmx_grpc.ReserveNetworkDeviceResponse\x12m\n\x14ResetBufferAttribute\x12).nidaqmx_grpc.ResetBufferAttributeRequest\x1a*.nidaqmx_grpc.ResetBufferAttributeResponse\x12g\n\x12ResetChanAttribute\x12\'.nidaqmx_grpc.ResetChanAttributeRequest\x1a(.nidaqmx_grpc.ResetChanAttributeResponse\x12R\n\x0bResetDevice\x12 .nidaqmx_grpc.ResetDeviceRequest\x1a!.nidaqmx_grpc.ResetDeviceResponse\x12\x85\x01\n\x1cResetExportedSignalAttribute\x12\x31.nidaqmx_grpc.ResetExportedSignalAttributeRequest\x1a\x32.nidaqmx_grpc.ResetExportedSignalAttributeResponse\x12g\n\x12ResetReadAttribute\x12\'.nidaqmx_grpc.ResetReadAttributeRequest\x1a(.nidaqmx_grpc.ResetReadAttributeResponse\x12s\n\x16ResetRealTimeAttribute\x12+.nidaqmx_grpc.ResetRealTimeAttributeRequest\x1a,.nidaqmx_grpc.ResetRealTimeAttributeResponse\x12m\n\x14ResetTimingAttribute\x12).nidaqmx_grpc.ResetTimingAttributeRequest\x1a*.nidaqmx_grpc.ResetTimingAttributeResponse\x12s\n\x16ResetTimingAttributeEx\x12+.nidaqmx_grpc.ResetTimingAttributeExRequest\x1a,.nidaqmx_grpc.ResetTimingAttributeExResponse\x12g\n\x12ResetTrigAttribute\x12\'.nidaqmx_grpc.ResetTrigAttributeRequest\x1a(.nidaqmx_grpc.ResetTrigAttributeResponse\x12s\n\x16ResetWatchdogAttribute\x12+.nidaqmx_grpc.ResetWatchdogAttributeRequest\x1a,.nidaqmx_grpc.ResetWatchdogAttributeResponse\x12j\n\x13ResetWriteAttribute\x12(.nidaqmx_grpc.ResetWriteAttributeRequest\x1a).nidaqmx_grpc.ResetWriteAttributeResponse\x12s\n\x16RestoreLastExtCalConst\x12+.nidaqmx_grpc.RestoreLastExtCalConstRequest\x1a,.nidaqmx_grpc.RestoreLastExtCalConstResponse\x12[\n\x0eSaveGlobalChan\x12#.nidaqmx_grpc.SaveGlobalChanRequest\x1a$.nidaqmx_grpc.SaveGlobalChanResponse\x12L\n\tSaveScale\x12\x1e.nidaqmx_grpc.SaveScaleRequest\x1a\x1f.nidaqmx_grpc.SaveScaleResponse\x12I\n\x08SaveTask\x12\x1d.nidaqmx_grpc.SaveTaskRequest\x1a\x1e.nidaqmx_grpc.SaveTaskResponse\x12\x46\n\x07SelfCal\x12\x1c.nidaqmx_grpc.SelfCalRequest\x1a\x1d.nidaqmx_grpc.SelfCalResponse\x12[\n\x0eSelfTestDevice\x12#.nidaqmx_grpc.SelfTestDeviceRequest\x1a$.nidaqmx_grpc.SelfTestDeviceResponse\x12j\n\x13SetAIChanCalCalDate\x12(.nidaqmx_grpc.SetAIChanCalCalDateRequest\x1a).nidaqmx_grpc.SetAIChanCalCalDateResponse\x12j\n\x13SetAIChanCalExpDate\x12(.nidaqmx_grpc.SetAIChanCalExpDateRequest\x1a).nidaqmx_grpc.SetAIChanCalExpDateResponse\x12s\n\x16SetAnalogPowerUpStates\x12+.nidaqmx_grpc.SetAnalogPowerUpStatesRequest\x1a,.nidaqmx_grpc.SetAnalogPowerUpStatesResponse\x12\x9d\x01\n$SetAnalogPowerUpStatesWithOutputType\x12\x39.nidaqmx_grpc.SetAnalogPowerUpStatesWithOutputTypeRequest\x1a:.nidaqmx_grpc.SetAnalogPowerUpStatesWithOutputTypeResponse\x12v\n\x17SetArmStartTrigTrigWhen\x12,.nidaqmx_grpc.SetArmStartTrigTrigWhenRequest\x1a-.nidaqmx_grpc.SetArmStartTrigTrigWhenResponse\x12y\n\x18SetBufferAttributeUInt32\x12-.nidaqmx_grpc.SetBufferAttributeUInt32Request\x1a..nidaqmx_grpc.SetBufferAttributeUInt32Response\x12v\n\x17SetCalInfoAttributeBool\x12,.nidaqmx_grpc.SetCalInfoAttributeBoolRequest\x1a-.nidaqmx_grpc.SetCalInfoAttributeBoolResponse\x12|\n\x19SetCalInfoAttributeDouble\x12..nidaqmx_grpc.SetCalInfoAttributeDoubleRequest\x1a/.nidaqmx_grpc.SetCalInfoAttributeDoubleResponse\x12|\n\x19SetCalInfoAttributeString\x12..nidaqmx_grpc.SetCalInfoAttributeStringRequest\x1a/.nidaqmx_grpc.SetCalInfoAttributeStringResponse\x12|\n\x19SetCalInfoAttributeUInt32\x12..nidaqmx_grpc.SetCalInfoAttributeUInt32Request\x1a/.nidaqmx_grpc.SetCalInfoAttributeUInt32Response\x12m\n\x14SetChanAttributeBool\x12).nidaqmx_grpc.SetChanAttributeBoolRequest\x1a*.nidaqmx_grpc.SetChanAttributeBoolResponse\x12s\n\x16SetChanAttributeDouble\x12+.nidaqmx_grpc.SetChanAttributeDoubleRequest\x1a,.nidaqmx_grpc.SetChanAttributeDoubleResponse\x12\x82\x01\n\x1bSetChanAttributeDoubleArray\x12\x30.nidaqmx_grpc.SetChanAttributeDoubleArrayRequest\x1a\x31.nidaqmx_grpc.SetChanAttributeDoubleArrayResponse\x12p\n\x15SetChanAttributeInt32\x12*.nidaqmx_grpc.SetChanAttributeInt32Request\x1a+.nidaqmx_grpc.SetChanAttributeInt32Response\x12s\n\x16SetChanAttributeString\x12+.nidaqmx_grpc.SetChanAttributeStringRequest\x1a,.nidaqmx_grpc.SetChanAttributeStringResponse\x12s\n\x16SetChanAttributeUInt32\x12+.nidaqmx_grpc.SetChanAttributeUInt32Request\x1a,.nidaqmx_grpc.SetChanAttributeUInt32Response\x12\x94\x01\n!SetDigitalLogicFamilyPowerUpState\x12\x36.nidaqmx_grpc.SetDigitalLogicFamilyPowerUpStateRequest\x1a\x37.nidaqmx_grpc.SetDigitalLogicFamilyPowerUpStateResponse\x12v\n\x17SetDigitalPowerUpStates\x12,.nidaqmx_grpc.SetDigitalPowerUpStatesRequest\x1a-.nidaqmx_grpc.SetDigitalPowerUpStatesResponse\x12\x8b\x01\n\x1eSetDigitalPullUpPullDownStates\x12\x33.nidaqmx_grpc.SetDigitalPullUpPullDownStatesRequest\x1a\x34.nidaqmx_grpc.SetDigitalPullUpPullDownStatesResponse\x12\x8b\x01\n\x1eSetExportedSignalAttributeBool\x12\x33.nidaqmx_grpc.SetExportedSignalAttributeBoolRequest\x1a\x34.nidaqmx_grpc.SetExportedSignalAttributeBoolResponse\x12\x91\x01\n SetExportedSignalAttributeDouble\x12\x35.nidaqmx_grpc.SetExportedSignalAttributeDoubleRequest\x1a\x36.nidaqmx_grpc.SetExportedSignalAttributeDoubleResponse\x12\x8e\x01\n\x1fSetExportedSignalAttributeInt32\x12\x34.nidaqmx_grpc.SetExportedSignalAttributeInt32Request\x1a\x35.nidaqmx_grpc.SetExportedSignalAttributeInt32Response\x12\x91\x01\n SetExportedSignalAttributeString\x12\x35.nidaqmx_grpc.SetExportedSignalAttributeStringRequest\x1a\x36.nidaqmx_grpc.SetExportedSignalAttributeStringResponse\x12\x91\x01\n SetExportedSignalAttributeUInt32\x12\x35.nidaqmx_grpc.SetExportedSignalAttributeUInt32Request\x1a\x36.nidaqmx_grpc.SetExportedSignalAttributeUInt32Response\x12j\n\x13SetFirstSampClkWhen\x12(.nidaqmx_grpc.SetFirstSampClkWhenRequest\x1a).nidaqmx_grpc.SetFirstSampClkWhenResponse\x12m\n\x14SetReadAttributeBool\x12).nidaqmx_grpc.SetReadAttributeBoolRequest\x1a*.nidaqmx_grpc.SetReadAttributeBoolResponse\x12s\n\x16SetReadAttributeDouble\x12+.nidaqmx_grpc.SetReadAttributeDoubleRequest\x1a,.nidaqmx_grpc.SetReadAttributeDoubleResponse\x12p\n\x15SetReadAttributeInt32\x12*.nidaqmx_grpc.SetReadAttributeInt32Request\x1a+.nidaqmx_grpc.SetReadAttributeInt32Response\x12s\n\x16SetReadAttributeString\x12+.nidaqmx_grpc.SetReadAttributeStringRequest\x1a,.nidaqmx_grpc.SetReadAttributeStringResponse\x12s\n\x16SetReadAttributeUInt32\x12+.nidaqmx_grpc.SetReadAttributeUInt32Request\x1a,.nidaqmx_grpc.SetReadAttributeUInt32Response\x12s\n\x16SetReadAttributeUInt64\x12+.nidaqmx_grpc.SetReadAttributeUInt64Request\x1a,.nidaqmx_grpc.SetReadAttributeUInt64Response\x12y\n\x18SetRealTimeAttributeBool\x12-.nidaqmx_grpc.SetRealTimeAttributeBoolRequest\x1a..nidaqmx_grpc.SetRealTimeAttributeBoolResponse\x12|\n\x19SetRealTimeAttributeInt32\x12..nidaqmx_grpc.SetRealTimeAttributeInt32Request\x1a/.nidaqmx_grpc.SetRealTimeAttributeInt32Response\x12\x7f\n\x1aSetRealTimeAttributeUInt32\x12/.nidaqmx_grpc.SetRealTimeAttributeUInt32Request\x1a\x30.nidaqmx_grpc.SetRealTimeAttributeUInt32Response\x12v\n\x17SetScaleAttributeDouble\x12,.nidaqmx_grpc.SetScaleAttributeDoubleRequest\x1a-.nidaqmx_grpc.SetScaleAttributeDoubleResponse\x12\x85\x01\n\x1cSetScaleAttributeDoubleArray\x12\x31.nidaqmx_grpc.SetScaleAttributeDoubleArrayRequest\x1a\x32.nidaqmx_grpc.SetScaleAttributeDoubleArrayResponse\x12s\n\x16SetScaleAttributeInt32\x12+.nidaqmx_grpc.SetScaleAttributeInt32Request\x1a,.nidaqmx_grpc.SetScaleAttributeInt32Response\x12v\n\x17SetScaleAttributeString\x12,.nidaqmx_grpc.SetScaleAttributeStringRequest\x1a-.nidaqmx_grpc.SetScaleAttributeStringResponse\x12m\n\x14SetStartTrigTrigWhen\x12).nidaqmx_grpc.SetStartTrigTrigWhenRequest\x1a*.nidaqmx_grpc.SetStartTrigTrigWhenResponse\x12m\n\x14SetSyncPulseTimeWhen\x12).nidaqmx_grpc.SetSyncPulseTimeWhenRequest\x1a*.nidaqmx_grpc.SetSyncPulseTimeWhenResponse\x12s\n\x16SetTimingAttributeBool\x12+.nidaqmx_grpc.SetTimingAttributeBoolRequest\x1a,.nidaqmx_grpc.SetTimingAttributeBoolResponse\x12y\n\x18SetTimingAttributeDouble\x12-.nidaqmx_grpc.SetTimingAttributeDoubleRequest\x1a..nidaqmx_grpc.SetTimingAttributeDoubleResponse\x12y\n\x18SetTimingAttributeExBool\x12-.nidaqmx_grpc.SetTimingAttributeExBoolRequest\x1a..nidaqmx_grpc.SetTimingAttributeExBoolResponse\x12\x7f\n\x1aSetTimingAttributeExDouble\x12/.nidaqmx_grpc.SetTimingAttributeExDoubleRequest\x1a\x30.nidaqmx_grpc.SetTimingAttributeExDoubleResponse\x12|\n\x19SetTimingAttributeExInt32\x12..nidaqmx_grpc.SetTimingAttributeExInt32Request\x1a/.nidaqmx_grpc.SetTimingAttributeExInt32Response\x12\x7f\n\x1aSetTimingAttributeExString\x12/.nidaqmx_grpc.SetTimingAttributeExStringRequest\x1a\x30.nidaqmx_grpc.SetTimingAttributeExStringResponse\x12\x88\x01\n\x1dSetTimingAttributeExTimestamp\x12\x32.nidaqmx_grpc.SetTimingAttributeExTimestampRequest\x1a\x33.nidaqmx_grpc.SetTimingAttributeExTimestampResponse\x12\x7f\n\x1aSetTimingAttributeExUInt32\x12/.nidaqmx_grpc.SetTimingAttributeExUInt32Request\x1a\x30.nidaqmx_grpc.SetTimingAttributeExUInt32Response\x12\x7f\n\x1aSetTimingAttributeExUInt64\x12/.nidaqmx_grpc.SetTimingAttributeExUInt64Request\x1a\x30.nidaqmx_grpc.SetTimingAttributeExUInt64Response\x12v\n\x17SetTimingAttributeInt32\x12,.nidaqmx_grpc.SetTimingAttributeInt32Request\x1a-.nidaqmx_grpc.SetTimingAttributeInt32Response\x12y\n\x18SetTimingAttributeString\x12-.nidaqmx_grpc.SetTimingAttributeStringRequest\x1a..nidaqmx_grpc.SetTimingAttributeStringResponse\x12\x82\x01\n\x1bSetTimingAttributeTimestamp\x12\x30.nidaqmx_grpc.SetTimingAttributeTimestampRequest\x1a\x31.nidaqmx_grpc.SetTimingAttributeTimestampResponse\x12y\n\x18SetTimingAttributeUInt32\x12-.nidaqmx_grpc.SetTimingAttributeUInt32Request\x1a..nidaqmx_grpc.SetTimingAttributeUInt32Response\x12y\n\x18SetTimingAttributeUInt64\x12-.nidaqmx_grpc.SetTimingAttributeUInt64Request\x1a..nidaqmx_grpc.SetTimingAttributeUInt64Response\x12m\n\x14SetTrigAttributeBool\x12).nidaqmx_grpc.SetTrigAttributeBoolRequest\x1a*.nidaqmx_grpc.SetTrigAttributeBoolResponse\x12s\n\x16SetTrigAttributeDouble\x12+.nidaqmx_grpc.SetTrigAttributeDoubleRequest\x1a,.nidaqmx_grpc.SetTrigAttributeDoubleResponse\x12\x82\x01\n\x1bSetTrigAttributeDoubleArray\x12\x30.nidaqmx_grpc.SetTrigAttributeDoubleArrayRequest\x1a\x31.nidaqmx_grpc.SetTrigAttributeDoubleArrayResponse\x12p\n\x15SetTrigAttributeInt32\x12*.nidaqmx_grpc.SetTrigAttributeInt32Request\x1a+.nidaqmx_grpc.SetTrigAttributeInt32Response\x12\x7f\n\x1aSetTrigAttributeInt32Array\x12/.nidaqmx_grpc.SetTrigAttributeInt32ArrayRequest\x1a\x30.nidaqmx_grpc.SetTrigAttributeInt32ArrayResponse\x12s\n\x16SetTrigAttributeString\x12+.nidaqmx_grpc.SetTrigAttributeStringRequest\x1a,.nidaqmx_grpc.SetTrigAttributeStringResponse\x12|\n\x19SetTrigAttributeTimestamp\x12..nidaqmx_grpc.SetTrigAttributeTimestampRequest\x1a/.nidaqmx_grpc.SetTrigAttributeTimestampResponse\x12s\n\x16SetTrigAttributeUInt32\x12+.nidaqmx_grpc.SetTrigAttributeUInt32Request\x1a,.nidaqmx_grpc.SetTrigAttributeUInt32Response\x12y\n\x18SetWatchdogAttributeBool\x12-.nidaqmx_grpc.SetWatchdogAttributeBoolRequest\x1a..nidaqmx_grpc.SetWatchdogAttributeBoolResponse\x12\x7f\n\x1aSetWatchdogAttributeDouble\x12/.nidaqmx_grpc.SetWatchdogAttributeDoubleRequest\x1a\x30.nidaqmx_grpc.SetWatchdogAttributeDoubleResponse\x12|\n\x19SetWatchdogAttributeInt32\x12..nidaqmx_grpc.SetWatchdogAttributeInt32Request\x1a/.nidaqmx_grpc.SetWatchdogAttributeInt32Response\x12\x7f\n\x1aSetWatchdogAttributeString\x12/.nidaqmx_grpc.SetWatchdogAttributeStringRequest\x1a\x30.nidaqmx_grpc.SetWatchdogAttributeStringResponse\x12p\n\x15SetWriteAttributeBool\x12*.nidaqmx_grpc.SetWriteAttributeBoolRequest\x1a+.nidaqmx_grpc.SetWriteAttributeBoolResponse\x12v\n\x17SetWriteAttributeDouble\x12,.nidaqmx_grpc.SetWriteAttributeDoubleRequest\x1a-.nidaqmx_grpc.SetWriteAttributeDoubleResponse\x12s\n\x16SetWriteAttributeInt32\x12+.nidaqmx_grpc.SetWriteAttributeInt32Request\x1a,.nidaqmx_grpc.SetWriteAttributeInt32Response\x12v\n\x17SetWriteAttributeString\x12,.nidaqmx_grpc.SetWriteAttributeStringRequest\x1a-.nidaqmx_grpc.SetWriteAttributeStringResponse\x12v\n\x17SetWriteAttributeUInt32\x12,.nidaqmx_grpc.SetWriteAttributeUInt32Request\x1a-.nidaqmx_grpc.SetWriteAttributeUInt32Response\x12v\n\x17SetWriteAttributeUInt64\x12,.nidaqmx_grpc.SetWriteAttributeUInt64Request\x1a-.nidaqmx_grpc.SetWriteAttributeUInt64Response\x12U\n\x0cStartNewFile\x12!.nidaqmx_grpc.StartNewFileRequest\x1a\".nidaqmx_grpc.StartNewFileResponse\x12L\n\tStartTask\x12\x1e.nidaqmx_grpc.StartTaskRequest\x1a\x1f.nidaqmx_grpc.StartTaskResponse\x12I\n\x08StopTask\x12\x1d.nidaqmx_grpc.StopTaskRequest\x1a\x1e.nidaqmx_grpc.StopTaskResponse\x12R\n\x0bTaskControl\x12 .nidaqmx_grpc.TaskControlRequest\x1a!.nidaqmx_grpc.TaskControlResponse\x12g\n\x12TristateOutputTerm\x12\'.nidaqmx_grpc.TristateOutputTermRequest\x1a(.nidaqmx_grpc.TristateOutputTermResponse\x12j\n\x13UnregisterDoneEvent\x12(.nidaqmx_grpc.UnregisterDoneEventRequest\x1a).nidaqmx_grpc.UnregisterDoneEventResponse\x12\x85\x01\n\x1cUnregisterEveryNSamplesEvent\x12\x31.nidaqmx_grpc.UnregisterEveryNSamplesEventRequest\x1a\x32.nidaqmx_grpc.UnregisterEveryNSamplesEventResponse\x12p\n\x15UnregisterSignalEvent\x12*.nidaqmx_grpc.UnregisterSignalEventRequest\x1a+.nidaqmx_grpc.UnregisterSignalEventResponse\x12s\n\x16UnreserveNetworkDevice\x12+.nidaqmx_grpc.UnreserveNetworkDeviceRequest\x1a,.nidaqmx_grpc.UnreserveNetworkDeviceResponse\x12s\n\x16WaitForNextSampleClock\x12+.nidaqmx_grpc.WaitForNextSampleClockRequest\x1a,.nidaqmx_grpc.WaitForNextSampleClockResponse\x12p\n\x15WaitForValidTimestamp\x12*.nidaqmx_grpc.WaitForValidTimestampRequest\x1a+.nidaqmx_grpc.WaitForValidTimestampResponse\x12\x64\n\x11WaitUntilTaskDone\x12&.nidaqmx_grpc.WaitUntilTaskDoneRequest\x1a\'.nidaqmx_grpc.WaitUntilTaskDoneResponse\x12[\n\x0eWriteAnalogF64\x12#.nidaqmx_grpc.WriteAnalogF64Request\x1a$.nidaqmx_grpc.WriteAnalogF64Response\x12m\n\x14WriteAnalogScalarF64\x12).nidaqmx_grpc.WriteAnalogScalarF64Request\x1a*.nidaqmx_grpc.WriteAnalogScalarF64Response\x12[\n\x0eWriteBinaryI16\x12#.nidaqmx_grpc.WriteBinaryI16Request\x1a$.nidaqmx_grpc.WriteBinaryI16Response\x12[\n\x0eWriteBinaryI32\x12#.nidaqmx_grpc.WriteBinaryI32Request\x1a$.nidaqmx_grpc.WriteBinaryI32Response\x12[\n\x0eWriteBinaryU16\x12#.nidaqmx_grpc.WriteBinaryU16Request\x1a$.nidaqmx_grpc.WriteBinaryU16Response\x12[\n\x0eWriteBinaryU32\x12#.nidaqmx_grpc.WriteBinaryU32Request\x1a$.nidaqmx_grpc.WriteBinaryU32Response\x12U\n\x0cWriteCtrFreq\x12!.nidaqmx_grpc.WriteCtrFreqRequest\x1a\".nidaqmx_grpc.WriteCtrFreqResponse\x12g\n\x12WriteCtrFreqScalar\x12\'.nidaqmx_grpc.WriteCtrFreqScalarRequest\x1a(.nidaqmx_grpc.WriteCtrFreqScalarResponse\x12X\n\rWriteCtrTicks\x12\".nidaqmx_grpc.WriteCtrTicksRequest\x1a#.nidaqmx_grpc.WriteCtrTicksResponse\x12j\n\x13WriteCtrTicksScalar\x12(.nidaqmx_grpc.WriteCtrTicksScalarRequest\x1a).nidaqmx_grpc.WriteCtrTicksScalarResponse\x12U\n\x0cWriteCtrTime\x12!.nidaqmx_grpc.WriteCtrTimeRequest\x1a\".nidaqmx_grpc.WriteCtrTimeResponse\x12g\n\x12WriteCtrTimeScalar\x12\'.nidaqmx_grpc.WriteCtrTimeScalarRequest\x1a(.nidaqmx_grpc.WriteCtrTimeScalarResponse\x12\x64\n\x11WriteDigitalLines\x12&.nidaqmx_grpc.WriteDigitalLinesRequest\x1a\'.nidaqmx_grpc.WriteDigitalLinesResponse\x12p\n\x15WriteDigitalScalarU32\x12*.nidaqmx_grpc.WriteDigitalScalarU32Request\x1a+.nidaqmx_grpc.WriteDigitalScalarU32Response\x12^\n\x0fWriteDigitalU16\x12$.nidaqmx_grpc.WriteDigitalU16Request\x1a%.nidaqmx_grpc.WriteDigitalU16Response\x12^\n\x0fWriteDigitalU32\x12$.nidaqmx_grpc.WriteDigitalU32Request\x1a%.nidaqmx_grpc.WriteDigitalU32Response\x12[\n\x0eWriteDigitalU8\x12#.nidaqmx_grpc.WriteDigitalU8Request\x1a$.nidaqmx_grpc.WriteDigitalU8Response\x12I\n\x08WriteRaw\x12\x1d.nidaqmx_grpc.WriteRawRequest\x1a\x1e.nidaqmx_grpc.WriteRawResponse\x12m\n\x14WriteToTEDSFromArray\x12).nidaqmx_grpc.WriteToTEDSFromArrayRequest\x1a*.nidaqmx_grpc.WriteToTEDSFromArrayResponse\x12j\n\x13WriteToTEDSFromFile\x12(.nidaqmx_grpc.WriteToTEDSFromFileRequest\x1a).nidaqmx_grpc.WriteToTEDSFromFileResponseBC\n\x13\x63om.ni.grpc.nidaqmxB\x07NiDAQmxP\x01\xaa\x02 NationalInstruments.Grpc.NiDAQmxb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nidaqmx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.ni.grpc.nidaqmxB\007NiDAQmxP\001\252\002 NationalInstruments.Grpc.NiDAQmx'
  _CHANNELINT32ATTRIBUTEVALUES._options = None
  _CHANNELINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _DEVICEINT32ATTRIBUTEVALUES._options = None
  _DEVICEINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _EXPORTSIGNALINT32ATTRIBUTEVALUES._options = None
  _EXPORTSIGNALINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _PHYSICALCHANNELINT32ATTRIBUTEVALUES._options = None
  _PHYSICALCHANNELINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _REALTIMEINT32ATTRIBUTEVALUES._options = None
  _REALTIMEINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _TRIGGERINT32ATTRIBUTEVALUES._options = None
  _TRIGGERINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _WATCHDOGINT32ATTRIBUTEVALUES._options = None
  _WATCHDOGINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _BUFFERUINT32ATTRIBUTE._serialized_start=121317
  _BUFFERUINT32ATTRIBUTE._serialized_end=121547
  _BUFFERRESETATTRIBUTE._serialized_start=121550
  _BUFFERRESETATTRIBUTE._serialized_end=121752
  _CALIBRATIONINFOBOOLATTRIBUTE._serialized_start=121755
  _CALIBRATIONINFOBOOLATTRIBUTE._serialized_end=121884
  _CALIBRATIONINFOSTRINGATTRIBUTE._serialized_start=121887
  _CALIBRATIONINFOSTRINGATTRIBUTE._serialized_end=122023
  _CALIBRATIONINFODOUBLEATTRIBUTE._serialized_start=122026
  _CALIBRATIONINFODOUBLEATTRIBUTE._serialized_end=122254
  _CALIBRATIONINFOUINT32ATTRIBUTE._serialized_start=122257
  _CALIBRATIONINFOUINT32ATTRIBUTE._serialized_end=122595
  _CHANNELINT32ATTRIBUTE._serialized_start=122598
  _CHANNELINT32ATTRIBUTE._serialized_end=132270
  _CHANNELDOUBLEATTRIBUTE._serialized_start=132273
  _CHANNELDOUBLEATTRIBUTE._serialized_end=141549
  _CHANNELRESETATTRIBUTE._serialized_start=141553
  _CHANNELRESETATTRIBUTE._serialized_end=173124
  _CHANNELBOOLATTRIBUTE._serialized_start=173127
  _CHANNELBOOLATTRIBUTE._serialized_end=178145
  _CHANNELSTRINGATTRIBUTE._serialized_start=178148
  _CHANNELSTRINGATTRIBUTE._serialized_end=181332
  _CHANNELUINT32ATTRIBUTE._serialized_start=181335
  _CHANNELUINT32ATTRIBUTE._serialized_end=183451
  _CHANNELDOUBLEARRAYATTRIBUTE._serialized_start=183454
  _CHANNELDOUBLEARRAYATTRIBUTE._serialized_end=184311
  _DEVICESTRINGATTRIBUTE._serialized_start=184314
  _DEVICESTRINGATTRIBUTE._serialized_end=185190
  _DEVICEUINT32ATTRIBUTE._serialized_start=185193
  _DEVICEUINT32ATTRIBUTE._serialized_end=186213
  _DEVICEBOOLATTRIBUTE._serialized_start=186216
  _DEVICEBOOLATTRIBUTE._serialized_end=186800
  _DEVICEINT32ATTRIBUTE._serialized_start=186803
  _DEVICEINT32ATTRIBUTE._serialized_end=187391
  _DEVICEDOUBLEATTRIBUTE._serialized_start=187394
  _DEVICEDOUBLEATTRIBUTE._serialized_end=188053
  _DEVICEDOUBLEARRAYATTRIBUTE._serialized_start=188056
  _DEVICEDOUBLEARRAYATTRIBUTE._serialized_end=188928
  _DEVICEUINT32ARRAYATTRIBUTE._serialized_start=188931
  _DEVICEUINT32ARRAYATTRIBUTE._serialized_end=189097
  _DEVICEINT32ARRAYATTRIBUTE._serialized_start=189100
  _DEVICEINT32ARRAYATTRIBUTE._serialized_end=189640
  _EXPORTSIGNALDOUBLEATTRIBUTE._serialized_start=189643
  _EXPORTSIGNALDOUBLEATTRIBUTE._serialized_end=190568
  _EXPORTSIGNALSTRINGATTRIBUTE._serialized_start=190571
  _EXPORTSIGNALSTRINGATTRIBUTE._serialized_end=191781
  _EXPORTSIGNALRESETATTRIBUTE._serialized_start=191784
  _EXPORTSIGNALRESETATTRIBUTE._serialized_end=195827
  _EXPORTSIGNALINT32ATTRIBUTE._serialized_start=195830
  _EXPORTSIGNALINT32ATTRIBUTE._serialized_end=198128
  _EXPORTSIGNALBOOLATTRIBUTE._serialized_start=198131
  _EXPORTSIGNALBOOLATTRIBUTE._serialized_end=198323
  _EXPORTSIGNALUINT32ATTRIBUTE._serialized_start=198326
  _EXPORTSIGNALUINT32ATTRIBUTE._serialized_end=198543
  _PERSISTEDCHANNELSTRINGATTRIBUTE._serialized_start=198546
  _PERSISTEDCHANNELSTRINGATTRIBUTE._serialized_end=198715
  _PERSISTEDCHANNELBOOLATTRIBUTE._serialized_start=198718
  _PERSISTEDCHANNELBOOLATTRIBUTE._serialized_end=198917
  _PERSISTEDSCALESTRINGATTRIBUTE._serialized_start=198920
  _PERSISTEDSCALESTRINGATTRIBUTE._serialized_end=199082
  _PERSISTEDSCALEBOOLATTRIBUTE._serialized_start=199085
  _PERSISTEDSCALEBOOLATTRIBUTE._serialized_end=199276
  _PERSISTEDTASKSTRINGATTRIBUTE._serialized_start=199279
  _PERSISTEDTASKSTRINGATTRIBUTE._serialized_end=199436
  _PERSISTEDTASKBOOLATTRIBUTE._serialized_start=199439
  _PERSISTEDTASKBOOLATTRIBUTE._serialized_end=199626
  _PHYSICALCHANNELUINT32ATTRIBUTE._serialized_start=199629
  _PHYSICALCHANNELUINT32ATTRIBUTE._serialized_end=200075
  _PHYSICALCHANNELSTRINGATTRIBUTE._serialized_start=200078
  _PHYSICALCHANNELSTRINGATTRIBUTE._serialized_end=200286
  _PHYSICALCHANNELBYTESATTRIBUTE._serialized_start=200289
  _PHYSICALCHANNELBYTESATTRIBUTE._serialized_end=200431
  _PHYSICALCHANNELUINT32ARRAYATTRIBUTE._serialized_start=200434
  _PHYSICALCHANNELUINT32ARRAYATTRIBUTE._serialized_end=200592
  _PHYSICALCHANNELINT32ATTRIBUTE._serialized_start=200595
  _PHYSICALCHANNELINT32ATTRIBUTE._serialized_end=200861
  _PHYSICALCHANNELBOOLATTRIBUTE._serialized_start=200864
  _PHYSICALCHANNELBOOLATTRIBUTE._serialized_end=201634
  _PHYSICALCHANNELRESETATTRIBUTE._serialized_start=201637
  _PHYSICALCHANNELRESETATTRIBUTE._serialized_end=202087
  _PHYSICALCHANNELDOUBLEATTRIBUTE._serialized_start=202090
  _PHYSICALCHANNELDOUBLEATTRIBUTE._serialized_end=202488
  _PHYSICALCHANNELINT32ARRAYATTRIBUTE._serialized_start=202491
  _PHYSICALCHANNELINT32ARRAYATTRIBUTE._serialized_end=203206
  _PHYSICALCHANNELDOUBLEARRAYATTRIBUTE._serialized_start=203209
  _PHYSICALCHANNELDOUBLEARRAYATTRIBUTE._serialized_end=203442
  _READINT32ATTRIBUTE._serialized_start=203445
  _READINT32ATTRIBUTE._serialized_end=203704
  _READRESETATTRIBUTE._serialized_start=203707
  _READRESETATTRIBUTE._serialized_end=204466
  _READBOOLATTRIBUTE._serialized_start=204469
  _READBOOLATTRIBUTE._serialized_end=205506
  _READUINT64ATTRIBUTE._serialized_start=205509
  _READUINT64ATTRIBUTE._serialized_end=205751
  _READUINT32ATTRIBUTE._serialized_start=205754
  _READUINT32ATTRIBUTE._serialized_end=206017
  _READSTRINGATTRIBUTE._serialized_start=206020
  _READSTRINGATTRIBUTE._serialized_end=206943
  _READDOUBLEATTRIBUTE._serialized_start=206945
  _READDOUBLEATTRIBUTE._serialized_end=207037
  _REALTIMEUINT32ATTRIBUTE._serialized_start=207039
  _REALTIMEUINT32ATTRIBUTE._serialized_end=207152
  _REALTIMERESETATTRIBUTE._serialized_start=207155
  _REALTIMERESETATTRIBUTE._serialized_end=207497
  _REALTIMEBOOLATTRIBUTE._serialized_start=207500
  _REALTIMEBOOLATTRIBUTE._serialized_end=207662
  _REALTIMEINT32ATTRIBUTE._serialized_start=207665
  _REALTIMEINT32ATTRIBUTE._serialized_end=207834
  _SCALESTRINGATTRIBUTE._serialized_start=207836
  _SCALESTRINGATTRIBUTE._serialized_end=207961
  _SCALEDOUBLEATTRIBUTE._serialized_start=207964
  _SCALEDOUBLEATTRIBUTE._serialized_end=208252
  _SCALEDOUBLEARRAYATTRIBUTE._serialized_start=208255
  _SCALEDOUBLEARRAYATTRIBUTE._serialized_end=208494
  _SCALEINT32ATTRIBUTE._serialized_start=208496
  _SCALEINT32ATTRIBUTE._serialized_end=208622
  _SYSTEMSTRINGATTRIBUTE._serialized_start=208625
  _SYSTEMSTRINGATTRIBUTE._serialized_end=208817
  _SYSTEMUINT32ATTRIBUTE._serialized_start=208820
  _SYSTEMUINT32ATTRIBUTE._serialized_end=209014
  _TASKSTRINGATTRIBUTE._serialized_start=209017
  _TASKSTRINGATTRIBUTE._serialized_end=209162
  _TASKBOOLATTRIBUTE._serialized_start=209164
  _TASKBOOLATTRIBUTE._serialized_end=209250
  _TASKUINT32ATTRIBUTE._serialized_start=209252
  _TASKUINT32ATTRIBUTE._serialized_end=209376
  _TIMINGINT32ATTRIBUTE._serialized_start=209379
  _TIMINGINT32ATTRIBUTE._serialized_end=210195
  _TIMINGRESETATTRIBUTE._serialized_start=210198
  _TIMINGRESETATTRIBUTE._serialized_end=213311
  _TIMINGDOUBLEATTRIBUTE._serialized_start=213314
  _TIMINGDOUBLEATTRIBUTE._serialized_end=214207
  _TIMINGUINT32ATTRIBUTE._serialized_start=214210
  _TIMINGUINT32ATTRIBUTE._serialized_end=214507
  _TIMINGSTRINGATTRIBUTE._serialized_start=214510
  _TIMINGSTRINGATTRIBUTE._serialized_end=215170
  _TIMINGUINT64ATTRIBUTE._serialized_start=215172
  _TIMINGUINT64ATTRIBUTE._serialized_end=215284
  _TIMINGBOOLATTRIBUTE._serialized_start=215287
  _TIMINGBOOLATTRIBUTE._serialized_end=215801
  _TIMINGTIMESTAMPATTRIBUTE._serialized_start=215804
  _TIMINGTIMESTAMPATTRIBUTE._serialized_end=216009
  _TRIGGERINT32ATTRIBUTE._serialized_start=216012
  _TRIGGERINT32ATTRIBUTE._serialized_end=217732
  _TRIGGERRESETATTRIBUTE._serialized_start=217735
  _TRIGGERRESETATTRIBUTE._serialized_end=226485
  _TRIGGERSTRINGATTRIBUTE._serialized_start=226488
  _TRIGGERSTRINGATTRIBUTE._serialized_end=228413
  _TRIGGERDOUBLEATTRIBUTE._serialized_start=228416
  _TRIGGERDOUBLEATTRIBUTE._serialized_end=230677
  _TRIGGERUINT32ATTRIBUTE._serialized_start=230680
  _TRIGGERUINT32ATTRIBUTE._serialized_end=230911
  _TRIGGERBOOLATTRIBUTE._serialized_start=230914
  _TRIGGERBOOLATTRIBUTE._serialized_end=232584
  _TRIGGERTIMESTAMPATTRIBUTE._serialized_start=232587
  _TRIGGERTIMESTAMPATTRIBUTE._serialized_end=232902
  _TRIGGERINT32ARRAYATTRIBUTE._serialized_start=232905
  _TRIGGERINT32ARRAYATTRIBUTE._serialized_end=233214
  _TRIGGERDOUBLEARRAYATTRIBUTE._serialized_start=233217
  _TRIGGERDOUBLEARRAYATTRIBUTE._serialized_end=233516
  _WATCHDOGINT32ATTRIBUTE._serialized_start=233519
  _WATCHDOGINT32ATTRIBUTE._serialized_end=233805
  _WATCHDOGRESETATTRIBUTE._serialized_start=233808
  _WATCHDOGRESETATTRIBUTE._serialized_end=234341
  _WATCHDOGSTRINGATTRIBUTE._serialized_start=234343
  _WATCHDOGSTRINGATTRIBUTE._serialized_end=234469
  _WATCHDOGBOOLATTRIBUTE._serialized_start=234472
  _WATCHDOGBOOLATTRIBUTE._serialized_end=234635
  _WATCHDOGDOUBLEATTRIBUTE._serialized_start=234638
  _WATCHDOGDOUBLEATTRIBUTE._serialized_end=234779
  _WRITEINT32ATTRIBUTE._serialized_start=234782
  _WRITEINT32ATTRIBUTE._serialized_end=234970
  _WRITERESETATTRIBUTE._serialized_start=234973
  _WRITERESETATTRIBUTE._serialized_end=235271
  _WRITEUINT64ATTRIBUTE._serialized_start=235274
  _WRITEUINT64ATTRIBUTE._serialized_end=235425
  _WRITEUINT32ATTRIBUTE._serialized_start=235428
  _WRITEUINT32ATTRIBUTE._serialized_end=235644
  _WRITEDOUBLEATTRIBUTE._serialized_start=235646
  _WRITEDOUBLEATTRIBUTE._serialized_end=235741
  _WRITEBOOLATTRIBUTE._serialized_start=235744
  _WRITEBOOLATTRIBUTE._serialized_end=236254
  _WRITESTRINGATTRIBUTE._serialized_start=236257
  _WRITESTRINGATTRIBUTE._serialized_end=236690
  _ACEXCITWIREMODE._serialized_start=236693
  _ACEXCITWIREMODE._serialized_end=236839
  _ACCELCHARGESENSITIVITYUNITS._serialized_start=236842
  _ACCELCHARGESENSITIVITYUNITS._serialized_end=237138
  _ACCELSENSITIVITYUNITS1._serialized_start=237141
  _ACCELSENSITIVITYUNITS1._serialized_end=237295
  _ACCELUNITS2._serialized_start=237298
  _ACCELUNITS2._serialized_end=237500
  _ACQUISITIONTYPE._serialized_start=237503
  _ACQUISITIONTYPE._serialized_end=237669
  _ANGLEUNITS1._serialized_start=237672
  _ANGLEUNITS1._serialized_end=237806
  _ANGLEUNITS2._serialized_start=237809
  _ANGLEUNITS2._serialized_end=237968
  _ANGULARVELOCITYUNITS._serialized_start=237971
  _ANGULARVELOCITYUNITS._serialized_end=238209
  _BRIDGECONFIGURATION1._serialized_start=238212
  _BRIDGECONFIGURATION1._serialized_end=238434
  _BRIDGEELECTRICALUNITS._serialized_start=238437
  _BRIDGEELECTRICALUNITS._serialized_end=238593
  _BRIDGEPHYSICALUNITS._serialized_start=238596
  _BRIDGEPHYSICALUNITS._serialized_end=239051
  _BRIDGEUNITS._serialized_start=239054
  _BRIDGEUNITS._serialized_end=239233
  _CJCSOURCE1._serialized_start=239235
  _CJCSOURCE1._serialized_end=239354
  _CHARGEUNITS._serialized_start=239357
  _CHARGEUNITS._serialized_end=239498
  _COUNTDIRECTION1._serialized_start=239501
  _COUNTDIRECTION1._serialized_end=239656
  _COUNTERFREQUENCYMETHOD._serialized_start=239659
  _COUNTERFREQUENCYMETHOD._serialized_end=239904
  _CURRENTSHUNTRESISTORLOCATIONWITHDEFAULT._serialized_start=239907
  _CURRENTSHUNTRESISTORLOCATIONWITHDEFAULT._serialized_end=240197
  _CURRENTUNITS2._serialized_start=240199
  _CURRENTUNITS2._serialized_end=240311
  _DIGITALLINESTATE._serialized_start=240314
  _DIGITALLINESTATE._serialized_end=240496
  _DIGITALPATTERNCONDITION1._serialized_start=240499
  _DIGITALPATTERNCONDITION1._serialized_end=240674
  _DIGITALWIDTHUNITS3._serialized_start=240676
  _DIGITALWIDTHUNITS3._serialized_end=240769
  _EDDYCURRENTPROXPROBESENSITIVITYUNITS._serialized_start=240772
  _EDDYCURRENTPROXPROBESENSITIVITYUNITS._serialized_end=241202
  _EDGE1._serialized_start=241204
  _EDGE1._serialized_end=241273
  _ENCODERTYPE2._serialized_start=241276
  _ENCODERTYPE2._serialized_end=241429
  _ENCODERZINDEXPHASE1._serialized_start=241432
  _ENCODERZINDEXPHASE1._serialized_end=241661
  _EVERYNSAMPLESEVENTTYPE._serialized_start=241664
  _EVERYNSAMPLESEVENTTYPE._serialized_end=241841
  _EXCITATIONSOURCE._serialized_start=241844
  _EXCITATIONSOURCE._serialized_end=241992
  _FORCEIEPESENSORSENSITIVITYUNITS._serialized_start=241995
  _FORCEIEPESENSORSENSITIVITYUNITS._serialized_end=242202
  _FORCEIEPEUNITS._serialized_start=242205
  _FORCEIEPEUNITS._serialized_end=242357
  _FORCEUNITS._serialized_start=242360
  _FORCEUNITS._serialized_end=242521
  _FREQUENCYUNITS._serialized_start=242523
  _FREQUENCYUNITS._serialized_end=242637
  _FREQUENCYUNITS2._serialized_start=242639
  _FREQUENCYUNITS2._serialized_end=242716
  _FREQUENCYUNITS3._serialized_start=242719
  _FREQUENCYUNITS3._serialized_end=242866
  _FUNCGENTYPE._serialized_start=242869
  _FUNCGENTYPE._serialized_end=243023
  _GPSSIGNALTYPE1._serialized_start=243026
  _GPSSIGNALTYPE1._serialized_end=243160
  _GROUPBY._serialized_start=243162
  _GROUPBY._serialized_end=243237
  _INPUTTERMCFGWITHDEFAULT._serialized_start=243240
  _INPUTTERMCFGWITHDEFAULT._serialized_end=243526
  _INVERTPOLARITY._serialized_start=243528
  _INVERTPOLARITY._serialized_end=243625
  _LVDTSENSITIVITYUNITS1._serialized_start=243628
  _LVDTSENSITIVITYUNITS1._serialized_end=243816
  _LENGTHUNITS2._serialized_start=243819
  _LENGTHUNITS2._serialized_end=243956
  _LENGTHUNITS3._serialized_start=243959
  _LENGTHUNITS3._serialized_end=244122
  _LEVEL1._serialized_start=244124
  _LEVEL1._serialized_end=244191
  _LINEGROUPING._serialized_start=244193
  _LINEGROUPING._serialized_end=244278
  _LOGGINGMODE._serialized_start=244280
  _LOGGINGMODE._serialized_end=244401
  _LOGGINGOPERATION._serialized_start=244404
  _LOGGINGOPERATION._serialized_end=244598
  _LOGICFAMILY._serialized_start=244600
  _LOGICFAMILY._serialized_end=244726
  _POLARITY2._serialized_start=244728
  _POLARITY2._serialized_end=244821
  _POWERUPCHANNELTYPE._serialized_start=244824
  _POWERUPCHANNELTYPE._serialized_end=244980
  _POWERUPSTATES._serialized_start=244983
  _POWERUPSTATES._serialized_end=245115
  _PRESSUREUNITS._serialized_start=245118
  _PRESSUREUNITS._serialized_end=245302
  _RTDTYPE1._serialized_start=245305
  _RTDTYPE1._serialized_end=245509
  _RVDTSENSITIVITYUNITS1._serialized_start=245512
  _RVDTSENSITIVITYUNITS1._serialized_end=245692
  _RESISTANCECONFIGURATION._serialized_start=245695
  _RESISTANCECONFIGURATION._serialized_end=245873
  _RESISTANCEUNITS2._serialized_start=245875
  _RESISTANCEUNITS2._serialized_end=245999
  _RESISTORSTATE._serialized_start=246001
  _RESISTORSTATE._serialized_end=246108
  _SAVEOPTIONS._serialized_start=246111
  _SAVEOPTIONS._serialized_end=246271
  _SHUNTCALSELECT._serialized_start=246274
  _SHUNTCALSELECT._serialized_end=246405
  _SHUNTCALSOURCE._serialized_start=246408
  _SHUNTCALSOURCE._serialized_end=246566
  _SHUNTELEMENTLOCATION._serialized_start=246569
  _SHUNTELEMENTLOCATION._serialized_end=246793
  _SIGNAL._serialized_start=246796
  _SIGNAL._serialized_end=247199
  _SIGNAL2._serialized_start=247202
  _SIGNAL2._serialized_end=247371
  _SLOPE1._serialized_start=247373
  _SLOPE1._serialized_end=247458
  _SOUNDPRESSUREUNITS1._serialized_start=247461
  _SOUNDPRESSUREUNITS1._serialized_end=247603
  _STRAINGAGEBRIDGETYPE1._serialized_start=247606
  _STRAINGAGEBRIDGETYPE1._serialized_end=247997
  _STRAINGAGEROSETTETYPE._serialized_start=248000
  _STRAINGAGEROSETTETYPE._serialized_end=248204
  _STRAINUNITS1._serialized_start=248206
  _STRAINUNITS1._serialized_end=248316
  _TEDSUNITS._serialized_start=248318
  _TEDSUNITS._serialized_end=248419
  _TASKCONTROLACTION._serialized_start=248422
  _TASKCONTROLACTION._serialized_end=248700
  _TEMPERATUREUNITS._serialized_start=248703
  _TEMPERATUREUNITS._serialized_end=248878
  _THERMOCOUPLETYPE1._serialized_start=248881
  _THERMOCOUPLETYPE1._serialized_end=249216
  _TIMEUNITS._serialized_start=249218
  _TIMEUNITS._serialized_end=249317
  _TIMEUNITS3._serialized_start=249319
  _TIMEUNITS3._serialized_end=249446
  _TIMESCALE2._serialized_start=249448
  _TIMESCALE2._serialized_end=249547
  _TIMESTAMPEVENT._serialized_start=249550
  _TIMESTAMPEVENT._serialized_end=249760
  _TORQUEUNITS._serialized_start=249763
  _TORQUEUNITS._serialized_end=249969
  _UNITSPRESCALED._serialized_start=249972
  _UNITSPRESCALED._serialized_end=251304
  _VELOCITYIEPESENSORSENSITIVITYUNITS._serialized_start=251307
  _VELOCITYIEPESENSORSENSITIVITYUNITS._serialized_end=251558
  _VELOCITYUNITS._serialized_start=251561
  _VELOCITYUNITS._serialized_end=251725
  _VOLTAGEUNITS2._serialized_start=251727
  _VOLTAGEUNITS2._serialized_end=251840
  _WATCHDOGAOOUTPUTTYPE._serialized_start=251843
  _WATCHDOGAOOUTPUTTYPE._serialized_end=252022
  _WATCHDOGCOEXPIRSTATE._serialized_start=252025
  _WATCHDOGCOEXPIRSTATE._serialized_end=252197
  _WATCHDOGCONTROLACTION._serialized_start=252199
  _WATCHDOGCONTROLACTION._serialized_end=252309
  _WINDOWTRIGGERCONDITION1._serialized_start=252312
  _WINDOWTRIGGERCONDITION1._serialized_end=252469
  _WRITEBASICTEDSOPTIONS._serialized_start=252472
  _WRITEBASICTEDSOPTIONS._serialized_end=252673
  _CHANNELINT32ATTRIBUTEVALUES._serialized_start=252677
  _CHANNELINT32ATTRIBUTEVALUES._serialized_end=272225
  _DEVICEINT32ATTRIBUTEVALUES._serialized_start=272228
  _DEVICEINT32ATTRIBUTEVALUES._serialized_end=278485
  _EXPORTSIGNALINT32ATTRIBUTEVALUES._serialized_start=278488
  _EXPORTSIGNALINT32ATTRIBUTEVALUES._serialized_end=279579
  _PHYSICALCHANNELINT32ATTRIBUTEVALUES._serialized_start=279582
  _PHYSICALCHANNELINT32ATTRIBUTEVALUES._serialized_end=283897
  _READINT32ATTRIBUTEVALUES._serialized_start=283900
  _READINT32ATTRIBUTEVALUES._serialized_end=284755
  _REALTIMEINT32ATTRIBUTEVALUES._serialized_start=284758
  _REALTIMEINT32ATTRIBUTEVALUES._serialized_end=285000
  _SCALEINT32ATTRIBUTEVALUES._serialized_start=285003
  _SCALEINT32ATTRIBUTEVALUES._serialized_end=286948
  _TIMINGINT32ATTRIBUTEVALUES._serialized_start=286951
  _TIMINGINT32ATTRIBUTEVALUES._serialized_end=288828
  _TRIGGERINT32ATTRIBUTEVALUES._serialized_start=288831
  _TRIGGERINT32ATTRIBUTEVALUES._serialized_end=291131
  _WATCHDOGINT32ATTRIBUTEVALUES._serialized_start=291134
  _WATCHDOGINT32ATTRIBUTEVALUES._serialized_end=291896
  _WRITEINT32ATTRIBUTEVALUES._serialized_start=291899
  _WRITEINT32ATTRIBUTEVALUES._serialized_end=292264
  _ANALOGPOWERUPCHANNELSANDSTATE._serialized_start=79
  _ANALOGPOWERUPCHANNELSANDSTATE._serialized_end=204
  _WATCHDOGEXPCHANNELSANDSTATE._serialized_start=206
  _WATCHDOGEXPCHANNELSANDSTATE._serialized_end=301
  _DIGITALPOWERUPTYPEANDCHANNEL._serialized_start=303
  _DIGITALPOWERUPTYPEANDCHANNEL._serialized_end=399
  _DIGITALPOWERUPCHANNELSANDSTATE._serialized_start=401
  _DIGITALPOWERUPCHANNELSANDSTATE._serialized_end=500
  _DIGITALPULLUPPULLDOWNCHANNELSANDSTATE._serialized_start=502
  _DIGITALPULLUPPULLDOWNCHANNELSANDSTATE._serialized_end=608
  _ANALOGPOWERUPCHANNELANDTYPE._serialized_start=610
  _ANALOGPOWERUPCHANNELANDTYPE._serialized_end=717
  _ADDCDAQSYNCCONNECTIONREQUEST._serialized_start=719
  _ADDCDAQSYNCCONNECTIONREQUEST._serialized_end=768
  _ADDCDAQSYNCCONNECTIONRESPONSE._serialized_start=770
  _ADDCDAQSYNCCONNECTIONRESPONSE._serialized_end=817
  _ADDGLOBALCHANSTOTASKREQUEST._serialized_start=819
  _ADDGLOBALCHANSTOTASKREQUEST._serialized_end=909
  _ADDGLOBALCHANSTOTASKRESPONSE._serialized_start=911
  _ADDGLOBALCHANSTOTASKRESPONSE._serialized_end=957
  _ADDNETWORKDEVICEREQUEST._serialized_start=959
  _ADDNETWORKDEVICEREQUEST._serialized_end=1071
  _ADDNETWORKDEVICERESPONSE._serialized_start=1073
  _ADDNETWORKDEVICERESPONSE._serialized_end=1140
  _ARECONFIGUREDCDAQSYNCPORTSDISCONNECTEDREQUEST._serialized_start=1142
  _ARECONFIGUREDCDAQSYNCPORTSDISCONNECTEDREQUEST._serialized_end=1237
  _ARECONFIGUREDCDAQSYNCPORTSDISCONNECTEDRESPONSE._serialized_start=1239
  _ARECONFIGUREDCDAQSYNCPORTSDISCONNECTEDRESPONSE._serialized_end=1337
  _AUTOCONFIGURECDAQSYNCCONNECTIONSREQUEST._serialized_start=1339
  _AUTOCONFIGURECDAQSYNCCONNECTIONSREQUEST._serialized_end=1428
  _AUTOCONFIGURECDAQSYNCCONNECTIONSRESPONSE._serialized_start=1430
  _AUTOCONFIGURECDAQSYNCCONNECTIONSRESPONSE._serialized_end=1488
  _CALCULATEREVERSEPOLYCOEFFREQUEST._serialized_start=1491
  _CALCULATEREVERSEPOLYCOEFFREQUEST._serialized_end=1646
  _CALCULATEREVERSEPOLYCOEFFRESPONSE._serialized_start=1648
  _CALCULATEREVERSEPOLYCOEFFRESPONSE._serialized_end=1723
  _CFGANLGEDGEREFTRIGREQUEST._serialized_start=1726
  _CFGANLGEDGEREFTRIGREQUEST._serialized_end=1964
  _CFGANLGEDGEREFTRIGRESPONSE._serialized_start=1966
  _CFGANLGEDGEREFTRIGRESPONSE._serialized_end=2010
  _CFGANLGEDGESTARTTRIGREQUEST._serialized_start=2013
  _CFGANLGEDGESTARTTRIGREQUEST._serialized_end=2225
  _CFGANLGEDGESTARTTRIGRESPONSE._serialized_start=2227
  _CFGANLGEDGESTARTTRIGRESPONSE._serialized_end=2273
  _CFGANLGMULTIEDGEREFTRIGREQUEST._serialized_start=2276
  _CFGANLGMULTIEDGEREFTRIGREQUEST._serialized_end=2457
  _CFGANLGMULTIEDGEREFTRIGRESPONSE._serialized_start=2459
  _CFGANLGMULTIEDGEREFTRIGRESPONSE._serialized_end=2508
  _CFGANLGMULTIEDGESTARTTRIGREQUEST._serialized_start=2511
  _CFGANLGMULTIEDGESTARTTRIGREQUEST._serialized_end=2666
  _CFGANLGMULTIEDGESTARTTRIGRESPONSE._serialized_start=2668
  _CFGANLGMULTIEDGESTARTTRIGRESPONSE._serialized_end=2719
  _CFGANLGWINDOWREFTRIGREQUEST._serialized_start=2722
  _CFGANLGWINDOWREFTRIGREQUEST._serialized_end=2996
  _CFGANLGWINDOWREFTRIGRESPONSE._serialized_start=2998
  _CFGANLGWINDOWREFTRIGRESPONSE._serialized_end=3044
  _CFGANLGWINDOWSTARTTRIGREQUEST._serialized_start=3047
  _CFGANLGWINDOWSTARTTRIGREQUEST._serialized_end=3295
  _CFGANLGWINDOWSTARTTRIGRESPONSE._serialized_start=3297
  _CFGANLGWINDOWSTARTTRIGRESPONSE._serialized_end=3345
  _CFGBURSTHANDSHAKINGTIMINGEXPORTCLOCKREQUEST._serialized_start=3348
  _CFGBURSTHANDSHAKINGTIMINGEXPORTCLOCKREQUEST._serialized_end=3971
  _CFGBURSTHANDSHAKINGTIMINGEXPORTCLOCKRESPONSE._serialized_start=3973
  _CFGBURSTHANDSHAKINGTIMINGEXPORTCLOCKRESPONSE._serialized_end=4035
  _CFGBURSTHANDSHAKINGTIMINGIMPORTCLOCKREQUEST._serialized_start=4038
  _CFGBURSTHANDSHAKINGTIMINGIMPORTCLOCKREQUEST._serialized_end=4642
  _CFGBURSTHANDSHAKINGTIMINGIMPORTCLOCKRESPONSE._serialized_start=4644
  _CFGBURSTHANDSHAKINGTIMINGIMPORTCLOCKRESPONSE._serialized_end=4706
  _CFGCHANGEDETECTIONTIMINGREQUEST._serialized_start=4709
  _CFGCHANGEDETECTIONTIMINGREQUEST._serialized_end=4958
  _CFGCHANGEDETECTIONTIMINGRESPONSE._serialized_start=4960
  _CFGCHANGEDETECTIONTIMINGRESPONSE._serialized_end=5010
  _CFGDIGEDGEREFTRIGREQUEST._serialized_start=5013
  _CFGDIGEDGEREFTRIGREQUEST._serialized_end=5223
  _CFGDIGEDGEREFTRIGRESPONSE._serialized_start=5225
  _CFGDIGEDGEREFTRIGRESPONSE._serialized_end=5268
  _CFGDIGEDGESTARTTRIGREQUEST._serialized_start=5271
  _CFGDIGEDGESTARTTRIGREQUEST._serialized_end=5455
  _CFGDIGEDGESTARTTRIGRESPONSE._serialized_start=5457
  _CFGDIGEDGESTARTTRIGRESPONSE._serialized_end=5502
  _CFGDIGPATTERNREFTRIGREQUEST._serialized_start=5505
  _CFGDIGPATTERNREFTRIGREQUEST._serialized_end=5762
  _CFGDIGPATTERNREFTRIGRESPONSE._serialized_start=5764
  _CFGDIGPATTERNREFTRIGRESPONSE._serialized_end=5810
  _CFGDIGPATTERNSTARTTRIGREQUEST._serialized_start=5813
  _CFGDIGPATTERNSTARTTRIGREQUEST._serialized_end=6044
  _CFGDIGPATTERNSTARTTRIGRESPONSE._serialized_start=6046
  _CFGDIGPATTERNSTARTTRIGRESPONSE._serialized_end=6094
  _CFGHANDSHAKINGTIMINGREQUEST._serialized_start=6097
  _CFGHANDSHAKINGTIMINGREQUEST._serialized_end=6289
  _CFGHANDSHAKINGTIMINGRESPONSE._serialized_start=6291
  _CFGHANDSHAKINGTIMINGRESPONSE._serialized_end=6337
  _CFGIMPLICITTIMINGREQUEST._serialized_start=6340
  _CFGIMPLICITTIMINGREQUEST._serialized_end=6529
  _CFGIMPLICITTIMINGRESPONSE._serialized_start=6531
  _CFGIMPLICITTIMINGRESPONSE._serialized_end=6574
  _CFGINPUTBUFFERREQUEST._serialized_start=6576
  _CFGINPUTBUFFERREQUEST._serialized_end=6665
  _CFGINPUTBUFFERRESPONSE._serialized_start=6667
  _CFGINPUTBUFFERRESPONSE._serialized_end=6707
  _CFGOUTPUTBUFFERREQUEST._serialized_start=6709
  _CFGOUTPUTBUFFERREQUEST._serialized_end=6799
  _CFGOUTPUTBUFFERRESPONSE._serialized_start=6801
  _CFGOUTPUTBUFFERRESPONSE._serialized_end=6842
  _CFGPIPELINEDSAMPCLKTIMINGREQUEST._serialized_start=6845
  _CFGPIPELINEDSAMPCLKTIMINGREQUEST._serialized_end=7163
  _CFGPIPELINEDSAMPCLKTIMINGRESPONSE._serialized_start=7165
  _CFGPIPELINEDSAMPCLKTIMINGRESPONSE._serialized_end=7216
  _CFGSAMPCLKTIMINGREQUEST._serialized_start=7219
  _CFGSAMPCLKTIMINGREQUEST._serialized_end=7528
  _CFGSAMPCLKTIMINGRESPONSE._serialized_start=7530
  _CFGSAMPCLKTIMINGRESPONSE._serialized_end=7572
  _CFGTIMESTARTTRIGREQUEST._serialized_start=7575
  _CFGTIMESTARTTRIGREQUEST._serialized_end=7770
  _CFGTIMESTARTTRIGRESPONSE._serialized_start=7772
  _CFGTIMESTARTTRIGRESPONSE._serialized_end=7814
  _CFGWATCHDOGAOEXPIRSTATESREQUEST._serialized_start=7817
  _CFGWATCHDOGAOEXPIRSTATESREQUEST._serialized_end=8001
  _CFGWATCHDOGAOEXPIRSTATESRESPONSE._serialized_start=8003
  _CFGWATCHDOGAOEXPIRSTATESRESPONSE._serialized_end=8053
  _CFGWATCHDOGCOEXPIRSTATESREQUEST._serialized_start=8056
  _CFGWATCHDOGCOEXPIRSTATESREQUEST._serialized_end=8213
  _CFGWATCHDOGCOEXPIRSTATESRESPONSE._serialized_start=8215
  _CFGWATCHDOGCOEXPIRSTATESRESPONSE._serialized_end=8265
  _CFGWATCHDOGDOEXPIRSTATESREQUEST._serialized_start=8268
  _CFGWATCHDOGDOEXPIRSTATESREQUEST._serialized_end=8421
  _CFGWATCHDOGDOEXPIRSTATESRESPONSE._serialized_start=8423
  _CFGWATCHDOGDOEXPIRSTATESRESPONSE._serialized_end=8473
  _CLEARTEDSREQUEST._serialized_start=8475
  _CLEARTEDSREQUEST._serialized_end=8519
  _CLEARTEDSRESPONSE._serialized_start=8521
  _CLEARTEDSRESPONSE._serialized_end=8556
  _CLEARTASKREQUEST._serialized_start=8558
  _CLEARTASKREQUEST._serialized_end=8614
  _CLEARTASKRESPONSE._serialized_start=8616
  _CLEARTASKRESPONSE._serialized_end=8651
  _CONFIGURELOGGINGREQUEST._serialized_start=8654
  _CONFIGURELOGGINGREQUEST._serialized_end=8952
  _CONFIGURELOGGINGRESPONSE._serialized_start=8954
  _CONFIGURELOGGINGRESPONSE._serialized_end=8996
  _CONFIGURETEDSREQUEST._serialized_start=8998
  _CONFIGURETEDSREQUEST._serialized_end=9065
  _CONFIGURETEDSRESPONSE._serialized_start=9067
  _CONFIGURETEDSRESPONSE._serialized_end=9106
  _CONNECTTERMSREQUEST._serialized_start=9109
  _CONNECTTERMSREQUEST._serialized_end=9300
  _CONNECTTERMSRESPONSE._serialized_start=9302
  _CONNECTTERMSRESPONSE._serialized_end=9340
  _CONTROLWATCHDOGTASKREQUEST._serialized_start=9343
  _CONTROLWATCHDOGTASKREQUEST._serialized_end=9501
  _CONTROLWATCHDOGTASKRESPONSE._serialized_start=9503
  _CONTROLWATCHDOGTASKRESPONSE._serialized_end=9548
  _CREATEAIACCEL4WIREDCVOLTAGECHANREQUEST._serialized_start=9551
  _CREATEAIACCEL4WIREDCVOLTAGECHANREQUEST._serialized_end=10285
  _CREATEAIACCEL4WIREDCVOLTAGECHANRESPONSE._serialized_start=10287
  _CREATEAIACCEL4WIREDCVOLTAGECHANRESPONSE._serialized_end=10344
  _CREATEAIACCELCHANREQUEST._serialized_start=10347
  _CREATEAIACCELCHANREQUEST._serialized_end=11036
  _CREATEAIACCELCHANRESPONSE._serialized_start=11038
  _CREATEAIACCELCHANRESPONSE._serialized_end=11081
  _CREATEAIACCELCHARGECHANREQUEST._serialized_start=11084
  _CREATEAIACCELCHARGECHANREQUEST._serialized_end=11628
  _CREATEAIACCELCHARGECHANRESPONSE._serialized_start=11630
  _CREATEAIACCELCHARGECHANRESPONSE._serialized_end=11679
  _CREATEAIBRIDGECHANREQUEST._serialized_start=11682
  _CREATEAIBRIDGECHANREQUEST._serialized_end=12251
  _CREATEAIBRIDGECHANRESPONSE._serialized_start=12253
  _CREATEAIBRIDGECHANRESPONSE._serialized_end=12297
  _CREATEAICHARGECHANREQUEST._serialized_start=12300
  _CREATEAICHARGECHANREQUEST._serialized_end=12687
  _CREATEAICHARGECHANRESPONSE._serialized_start=12689
  _CREATEAICHARGECHANRESPONSE._serialized_end=12733
  _CREATEAICURRENTCHANREQUEST._serialized_start=12736
  _CREATEAICURRENTCHANREQUEST._serialized_end=13304
  _CREATEAICURRENTCHANRESPONSE._serialized_start=13306
  _CREATEAICURRENTCHANRESPONSE._serialized_end=13351
  _CREATEAICURRENTRMSCHANREQUEST._serialized_start=13354
  _CREATEAICURRENTRMSCHANREQUEST._serialized_end=13925
  _CREATEAICURRENTRMSCHANRESPONSE._serialized_start=13927
  _CREATEAICURRENTRMSCHANRESPONSE._serialized_end=13975
  _CREATEAIFORCEBRIDGEPOLYNOMIALCHANREQUEST._serialized_start=13978
  _CREATEAIFORCEBRIDGEPOLYNOMIALCHANREQUEST._serialized_end=14845
  _CREATEAIFORCEBRIDGEPOLYNOMIALCHANRESPONSE._serialized_start=14847
  _CREATEAIFORCEBRIDGEPOLYNOMIALCHANRESPONSE._serialized_end=14906
  _CREATEAIFORCEBRIDGETABLECHANREQUEST._serialized_start=14909
  _CREATEAIFORCEBRIDGETABLECHANREQUEST._serialized_end=15771
  _CREATEAIFORCEBRIDGETABLECHANRESPONSE._serialized_start=15773
  _CREATEAIFORCEBRIDGETABLECHANRESPONSE._serialized_end=15827
  _CREATEAIFORCEBRIDGETWOPOINTLINCHANREQUEST._serialized_start=15830
  _CREATEAIFORCEBRIDGETWOPOINTLINCHANREQUEST._serialized_end=16768
  _CREATEAIFORCEBRIDGETWOPOINTLINCHANRESPONSE._serialized_start=16770
  _CREATEAIFORCEBRIDGETWOPOINTLINCHANRESPONSE._serialized_end=16830
  _CREATEAIFORCEIEPECHANREQUEST._serialized_start=16833
  _CREATEAIFORCEIEPECHANREQUEST._serialized_end=17538
  _CREATEAIFORCEIEPECHANRESPONSE._serialized_start=17540
  _CREATEAIFORCEIEPECHANRESPONSE._serialized_end=17587
  _CREATEAIFREQVOLTAGECHANREQUEST._serialized_start=17590
  _CREATEAIFREQVOLTAGECHANREQUEST._serialized_end=17909
  _CREATEAIFREQVOLTAGECHANRESPONSE._serialized_start=17911
  _CREATEAIFREQVOLTAGECHANRESPONSE._serialized_end=17960
  _CREATEAIMICROPHONECHANREQUEST._serialized_start=17963
  _CREATEAIMICROPHONECHANREQUEST._serialized_end=18538
  _CREATEAIMICROPHONECHANRESPONSE._serialized_start=18540
  _CREATEAIMICROPHONECHANRESPONSE._serialized_end=18588
  _CREATEAIPOSEDDYCURRPROXPROBECHANREQUEST._serialized_start=18591
  _CREATEAIPOSEDDYCURRPROXPROBECHANREQUEST._serialized_end=19033
  _CREATEAIPOSEDDYCURRPROXPROBECHANRESPONSE._serialized_start=19035
  _CREATEAIPOSEDDYCURRPROXPROBECHANRESPONSE._serialized_end=19093
  _CREATEAIPOSLVDTCHANREQUEST._serialized_start=19096
  _CREATEAIPOSLVDTCHANREQUEST._serialized_end=19816
  _CREATEAIPOSLVDTCHANRESPONSE._serialized_start=19818
  _CREATEAIPOSLVDTCHANRESPONSE._serialized_end=19863
  _CREATEAIPOSRVDTCHANREQUEST._serialized_start=19866
  _CREATEAIPOSRVDTCHANREQUEST._serialized_end=20585
  _CREATEAIPOSRVDTCHANRESPONSE._serialized_start=20587
  _CREATEAIPOSRVDTCHANRESPONSE._serialized_end=20632
  _CREATEAIPOWERCHANREQUEST._serialized_start=20635
  _CREATEAIPOWERCHANREQUEST._serialized_end=20835
  _CREATEAIPOWERCHANRESPONSE._serialized_start=20837
  _CREATEAIPOWERCHANRESPONSE._serialized_end=20880
  _CREATEAIPRESSUREBRIDGEPOLYNOMIALCHANREQUEST._serialized_start=20883
  _CREATEAIPRESSUREBRIDGEPOLYNOMIALCHANREQUEST._serialized_end=21756
  _CREATEAIPRESSUREBRIDGEPOLYNOMIALCHANRESPONSE._serialized_start=21758
  _CREATEAIPRESSUREBRIDGEPOLYNOMIALCHANRESPONSE._serialized_end=21820
  _CREATEAIPRESSUREBRIDGETABLECHANREQUEST._serialized_start=21823
  _CREATEAIPRESSUREBRIDGETABLECHANREQUEST._serialized_end=22691
  _CREATEAIPRESSUREBRIDGETABLECHANRESPONSE._serialized_start=22693
  _CREATEAIPRESSUREBRIDGETABLECHANRESPONSE._serialized_end=22750
  _CREATEAIPRESSUREBRIDGETWOPOINTLINCHANREQUEST._serialized_start=22753
  _CREATEAIPRESSUREBRIDGETWOPOINTLINCHANREQUEST._serialized_end=23697
  _CREATEAIPRESSUREBRIDGETWOPOINTLINCHANRESPONSE._serialized_start=23699
  _CREATEAIPRESSUREBRIDGETWOPOINTLINCHANRESPONSE._serialized_end=23762
  _CREATEAIRTDCHANREQUEST._serialized_start=23765
  _CREATEAIRTDCHANREQUEST._serialized_end=24386
  _CREATEAIRTDCHANRESPONSE._serialized_start=24388
  _CREATEAIRTDCHANRESPONSE._serialized_end=24429
  _CREATEAIRESISTANCECHANREQUEST._serialized_start=24432
  _CREATEAIRESISTANCECHANREQUEST._serialized_end=24990
  _CREATEAIRESISTANCECHANRESPONSE._serialized_start=24992
  _CREATEAIRESISTANCECHANRESPONSE._serialized_end=25040
  _CREATEAIROSETTESTRAINGAGECHANREQUEST._serialized_start=25043
  _CREATEAIROSETTESTRAINGAGECHANREQUEST._serialized_end=25754
  _CREATEAIROSETTESTRAINGAGECHANRESPONSE._serialized_start=25756
  _CREATEAIROSETTESTRAINGAGECHANRESPONSE._serialized_end=25811
  _CREATEAISTRAINGAGECHANREQUEST._serialized_start=25814
  _CREATEAISTRAINGAGECHANREQUEST._serialized_end=26493
  _CREATEAISTRAINGAGECHANRESPONSE._serialized_start=26495
  _CREATEAISTRAINGAGECHANRESPONSE._serialized_end=26543
  _CREATEAITEMPBUILTINSENSORCHANREQUEST._serialized_start=26546
  _CREATEAITEMPBUILTINSENSORCHANREQUEST._serialized_end=26767
  _CREATEAITEMPBUILTINSENSORCHANRESPONSE._serialized_start=26769
  _CREATEAITEMPBUILTINSENSORCHANRESPONSE._serialized_end=26824
  _CREATEAITHRMCPLCHANREQUEST._serialized_start=26827
  _CREATEAITHRMCPLCHANREQUEST._serialized_end=27324
  _CREATEAITHRMCPLCHANRESPONSE._serialized_start=27326
  _CREATEAITHRMCPLCHANRESPONSE._serialized_end=27371
  _CREATEAITHRMSTRCHANIEXREQUEST._serialized_start=27374
  _CREATEAITHRMSTRCHANIEXREQUEST._serialized_end=27938
  _CREATEAITHRMSTRCHANIEXRESPONSE._serialized_start=27940
  _CREATEAITHRMSTRCHANIEXRESPONSE._serialized_end=27988
  _CREATEAITHRMSTRCHANVEXREQUEST._serialized_start=27991
  _CREATEAITHRMSTRCHANVEXREQUEST._serialized_end=28567
  _CREATEAITHRMSTRCHANVEXRESPONSE._serialized_start=28569
  _CREATEAITHRMSTRCHANVEXRESPONSE._serialized_end=28617
  _CREATEAITORQUEBRIDGEPOLYNOMIALCHANREQUEST._serialized_start=28620
  _CREATEAITORQUEBRIDGEPOLYNOMIALCHANREQUEST._serialized_end=29489
  _CREATEAITORQUEBRIDGEPOLYNOMIALCHANRESPONSE._serialized_start=29491
  _CREATEAITORQUEBRIDGEPOLYNOMIALCHANRESPONSE._serialized_end=29551
  _CREATEAITORQUEBRIDGETABLECHANREQUEST._serialized_start=29554
  _CREATEAITORQUEBRIDGETABLECHANREQUEST._serialized_end=30418
  _CREATEAITORQUEBRIDGETABLECHANRESPONSE._serialized_start=30420
  _CREATEAITORQUEBRIDGETABLECHANRESPONSE._serialized_end=30475
  _CREATEAITORQUEBRIDGETWOPOINTLINCHANREQUEST._serialized_start=30478
  _CREATEAITORQUEBRIDGETWOPOINTLINCHANREQUEST._serialized_end=31418
  _CREATEAITORQUEBRIDGETWOPOINTLINCHANRESPONSE._serialized_start=31420
  _CREATEAITORQUEBRIDGETWOPOINTLINCHANRESPONSE._serialized_end=31481
  _CREATEAIVELOCITYIEPECHANREQUEST._serialized_start=31484
  _CREATEAIVELOCITYIEPECHANREQUEST._serialized_end=32194
  _CREATEAIVELOCITYIEPECHANRESPONSE._serialized_start=32196
  _CREATEAIVELOCITYIEPECHANRESPONSE._serialized_end=32246
  _CREATEAIVOLTAGECHANREQUEST._serialized_start=32249
  _CREATEAIVOLTAGECHANREQUEST._serialized_end=32639
  _CREATEAIVOLTAGECHANRESPONSE._serialized_start=32641
  _CREATEAIVOLTAGECHANRESPONSE._serialized_end=32686
  _CREATEAIVOLTAGECHANWITHEXCITREQUEST._serialized_start=32689
  _CREATEAIVOLTAGECHANWITHEXCITREQUEST._serialized_end=33387
  _CREATEAIVOLTAGECHANWITHEXCITRESPONSE._serialized_start=33389
  _CREATEAIVOLTAGECHANWITHEXCITRESPONSE._serialized_end=33443
  _CREATEAIVOLTAGERMSCHANREQUEST._serialized_start=33446
  _CREATEAIVOLTAGERMSCHANREQUEST._serialized_end=33839
  _CREATEAIVOLTAGERMSCHANRESPONSE._serialized_start=33841
  _CREATEAIVOLTAGERMSCHANRESPONSE._serialized_end=33889
  _CREATEAOCURRENTCHANREQUEST._serialized_start=33892
  _CREATEAOCURRENTCHANREQUEST._serialized_end=34161
  _CREATEAOCURRENTCHANRESPONSE._serialized_start=34163
  _CREATEAOCURRENTCHANRESPONSE._serialized_end=34208
  _CREATEAOFUNCGENCHANREQUEST._serialized_start=34211
  _CREATEAOFUNCGENCHANREQUEST._serialized_end=34463
  _CREATEAOFUNCGENCHANRESPONSE._serialized_start=34465
  _CREATEAOFUNCGENCHANRESPONSE._serialized_end=34510
  _CREATEAOVOLTAGECHANREQUEST._serialized_start=34513
  _CREATEAOVOLTAGECHANREQUEST._serialized_end=34782
  _CREATEAOVOLTAGECHANRESPONSE._serialized_start=34784
  _CREATEAOVOLTAGECHANRESPONSE._serialized_end=34829
  _CREATECIANGENCODERCHANREQUEST._serialized_start=34832
  _CREATECIANGENCODERCHANREQUEST._serialized_end=35351
  _CREATECIANGENCODERCHANRESPONSE._serialized_start=35353
  _CREATECIANGENCODERCHANRESPONSE._serialized_end=35401
  _CREATECIANGVELOCITYCHANREQUEST._serialized_start=35404
  _CREATECIANGVELOCITYCHANREQUEST._serialized_end=35803
  _CREATECIANGVELOCITYCHANRESPONSE._serialized_start=35805
  _CREATECIANGVELOCITYCHANRESPONSE._serialized_end=35854
  _CREATECICOUNTEDGESCHANREQUEST._serialized_start=35857
  _CREATECICOUNTEDGESCHANREQUEST._serialized_end=36184
  _CREATECICOUNTEDGESCHANRESPONSE._serialized_start=36186
  _CREATECICOUNTEDGESCHANRESPONSE._serialized_end=36234
  _CREATECIDUTYCYCLECHANREQUEST._serialized_start=36237
  _CREATECIDUTYCYCLECHANREQUEST._serialized_end=36490
  _CREATECIDUTYCYCLECHANRESPONSE._serialized_start=36492
  _CREATECIDUTYCYCLECHANRESPONSE._serialized_end=36539
  _CREATECIFREQCHANREQUEST._serialized_start=36542
  _CREATECIFREQCHANREQUEST._serialized_end=37015
  _CREATECIFREQCHANRESPONSE._serialized_start=37017
  _CREATECIFREQCHANRESPONSE._serialized_end=37059
  _CREATECIGPSTIMESTAMPCHANREQUEST._serialized_start=37062
  _CREATECIGPSTIMESTAMPCHANREQUEST._serialized_end=37389
  _CREATECIGPSTIMESTAMPCHANRESPONSE._serialized_start=37391
  _CREATECIGPSTIMESTAMPCHANRESPONSE._serialized_end=37441
  _CREATECILINENCODERCHANREQUEST._serialized_start=37444
  _CREATECILINENCODERCHANREQUEST._serialized_end=37962
  _CREATECILINENCODERCHANRESPONSE._serialized_start=37964
  _CREATECILINENCODERCHANRESPONSE._serialized_end=38012
  _CREATECILINVELOCITYCHANREQUEST._serialized_start=38015
  _CREATECILINVELOCITYCHANREQUEST._serialized_end=38407
  _CREATECILINVELOCITYCHANRESPONSE._serialized_start=38409
  _CREATECILINVELOCITYCHANRESPONSE._serialized_end=38458
  _CREATECIPERIODCHANREQUEST._serialized_start=38461
  _CREATECIPERIODCHANREQUEST._serialized_end=38931
  _CREATECIPERIODCHANRESPONSE._serialized_start=38933
  _CREATECIPERIODCHANRESPONSE._serialized_end=38977
  _CREATECIPULSECHANFREQREQUEST._serialized_start=38980
  _CREATECIPULSECHANFREQREQUEST._serialized_end=39217
  _CREATECIPULSECHANFREQRESPONSE._serialized_start=39219
  _CREATECIPULSECHANFREQRESPONSE._serialized_end=39266
  _CREATECIPULSECHANTICKSREQUEST._serialized_start=39269
  _CREATECIPULSECHANTICKSREQUEST._serialized_end=39449
  _CREATECIPULSECHANTICKSRESPONSE._serialized_start=39451
  _CREATECIPULSECHANTICKSRESPONSE._serialized_end=39499
  _CREATECIPULSECHANTIMEREQUEST._serialized_start=39502
  _CREATECIPULSECHANTIMEREQUEST._serialized_end=39742
  _CREATECIPULSECHANTIMERESPONSE._serialized_start=39744
  _CREATECIPULSECHANTIMERESPONSE._serialized_end=39791
  _CREATECIPULSEWIDTHCHANREQUEST._serialized_start=39794
  _CREATECIPULSEWIDTHCHANREQUEST._serialized_end=40151
  _CREATECIPULSEWIDTHCHANRESPONSE._serialized_start=40153
  _CREATECIPULSEWIDTHCHANRESPONSE._serialized_end=40201
  _CREATECISEMIPERIODCHANREQUEST._serialized_start=40204
  _CREATECISEMIPERIODCHANREQUEST._serialized_end=40464
  _CREATECISEMIPERIODCHANRESPONSE._serialized_start=40466
  _CREATECISEMIPERIODCHANRESPONSE._serialized_end=40514
  _CREATECITWOEDGESEPCHANREQUEST._serialized_start=40517
  _CREATECITWOEDGESEPCHANREQUEST._serialized_end=40956
  _CREATECITWOEDGESEPCHANRESPONSE._serialized_start=40958
  _CREATECITWOEDGESEPCHANRESPONSE._serialized_end=41006
  _CREATECOPULSECHANFREQREQUEST._serialized_start=41009
  _CREATECOPULSECHANFREQREQUEST._serialized_end=41358
  _CREATECOPULSECHANFREQRESPONSE._serialized_start=41360
  _CREATECOPULSECHANFREQRESPONSE._serialized_end=41407
  _CREATECOPULSECHANTICKSREQUEST._serialized_start=41410
  _CREATECOPULSECHANTICKSREQUEST._serialized_end=41707
  _CREATECOPULSECHANTICKSRESPONSE._serialized_start=41709
  _CREATECOPULSECHANTICKSRESPONSE._serialized_end=41757
  _CREATECOPULSECHANTIMEREQUEST._serialized_start=41760
  _CREATECOPULSECHANTIMEREQUEST._serialized_end=42115
  _CREATECOPULSECHANTIMERESPONSE._serialized_start=42117
  _CREATECOPULSECHANTIMERESPONSE._serialized_end=42164
  _CREATEDICHANREQUEST._serialized_start=42167
  _CREATEDICHANREQUEST._serialized_end=42378
  _CREATEDICHANRESPONSE._serialized_start=42380
  _CREATEDICHANRESPONSE._serialized_end=42418
  _CREATEDOCHANREQUEST._serialized_start=42421
  _CREATEDOCHANREQUEST._serialized_end=42632
  _CREATEDOCHANRESPONSE._serialized_start=42634
  _CREATEDOCHANRESPONSE._serialized_end=42672
  _CREATELINSCALEREQUEST._serialized_start=42675
  _CREATELINSCALEREQUEST._serialized_end=42885
  _CREATELINSCALERESPONSE._serialized_start=42887
  _CREATELINSCALERESPONSE._serialized_end=42927
  _CREATEMAPSCALEREQUEST._serialized_start=42930
  _CREATEMAPSCALEREQUEST._serialized_end=43190
  _CREATEMAPSCALERESPONSE._serialized_start=43192
  _CREATEMAPSCALERESPONSE._serialized_end=43232
  _CREATEPOLYNOMIALSCALEREQUEST._serialized_start=43235
  _CREATEPOLYNOMIALSCALEREQUEST._serialized_end=43464
  _CREATEPOLYNOMIALSCALERESPONSE._serialized_start=43466
  _CREATEPOLYNOMIALSCALERESPONSE._serialized_end=43513
  _CREATETEDSAIACCELCHANREQUEST._serialized_start=43516
  _CREATETEDSAIACCELCHANREQUEST._serialized_end=44062
  _CREATETEDSAIACCELCHANRESPONSE._serialized_start=44064
  _CREATETEDSAIACCELCHANRESPONSE._serialized_end=44111
  _CREATETEDSAIBRIDGECHANREQUEST._serialized_start=44114
  _CREATETEDSAIBRIDGECHANREQUEST._serialized_end=44538
  _CREATETEDSAIBRIDGECHANRESPONSE._serialized_start=44540
  _CREATETEDSAIBRIDGECHANRESPONSE._serialized_end=44588
  _CREATETEDSAICURRENTCHANREQUEST._serialized_start=44591
  _CREATETEDSAICURRENTCHANREQUEST._serialized_end=45159
  _CREATETEDSAICURRENTCHANRESPONSE._serialized_start=45161
  _CREATETEDSAICURRENTCHANRESPONSE._serialized_end=45210
  _CREATETEDSAIFORCEBRIDGECHANREQUEST._serialized_start=45213
  _CREATETEDSAIFORCEBRIDGECHANREQUEST._serialized_end=45643
  _CREATETEDSAIFORCEBRIDGECHANRESPONSE._serialized_start=45645
  _CREATETEDSAIFORCEBRIDGECHANRESPONSE._serialized_end=45698
  _CREATETEDSAIFORCEIEPECHANREQUEST._serialized_start=45701
  _CREATETEDSAIFORCEIEPECHANREQUEST._serialized_end=46254
  _CREATETEDSAIFORCEIEPECHANRESPONSE._serialized_start=46256
  _CREATETEDSAIFORCEIEPECHANRESPONSE._serialized_end=46307
  _CREATETEDSAIMICROPHONECHANREQUEST._serialized_start=46310
  _CREATETEDSAIMICROPHONECHANREQUEST._serialized_end=46864
  _CREATETEDSAIMICROPHONECHANRESPONSE._serialized_start=46866
  _CREATETEDSAIMICROPHONECHANRESPONSE._serialized_end=46918
  _CREATETEDSAIPOSLVDTCHANREQUEST._serialized_start=46921
  _CREATETEDSAIPOSLVDTCHANREQUEST._serialized_end=47499
  _CREATETEDSAIPOSLVDTCHANRESPONSE._serialized_start=47501
  _CREATETEDSAIPOSLVDTCHANRESPONSE._serialized_end=47550
  _CREATETEDSAIPOSRVDTCHANREQUEST._serialized_start=47553
  _CREATETEDSAIPOSRVDTCHANREQUEST._serialized_end=48130
  _CREATETEDSAIPOSRVDTCHANRESPONSE._serialized_start=48132
  _CREATETEDSAIPOSRVDTCHANRESPONSE._serialized_end=48181
  _CREATETEDSAIPRESSUREBRIDGECHANREQUEST._serialized_start=48184
  _CREATETEDSAIPRESSUREBRIDGECHANREQUEST._serialized_end=48620
  _CREATETEDSAIPRESSUREBRIDGECHANRESPONSE._serialized_start=48622
  _CREATETEDSAIPRESSUREBRIDGECHANRESPONSE._serialized_end=48678
  _CREATETEDSAIRTDCHANREQUEST._serialized_start=48681
  _CREATETEDSAIRTDCHANREQUEST._serialized_end=49209
  _CREATETEDSAIRTDCHANRESPONSE._serialized_start=49211
  _CREATETEDSAIRTDCHANRESPONSE._serialized_end=49256
  _CREATETEDSAIRESISTANCECHANREQUEST._serialized_start=49259
  _CREATETEDSAIRESISTANCECHANREQUEST._serialized_end=49814
  _CREATETEDSAIRESISTANCECHANRESPONSE._serialized_start=49816
  _CREATETEDSAIRESISTANCECHANRESPONSE._serialized_end=49868
  _CREATETEDSAISTRAINGAGECHANREQUEST._serialized_start=49871
  _CREATETEDSAISTRAINGAGECHANREQUEST._serialized_end=50364
  _CREATETEDSAISTRAINGAGECHANRESPONSE._serialized_start=50366
  _CREATETEDSAISTRAINGAGECHANRESPONSE._serialized_end=50418
  _CREATETEDSAITHRMCPLCHANREQUEST._serialized_start=50421
  _CREATETEDSAITHRMCPLCHANREQUEST._serialized_end=50801
  _CREATETEDSAITHRMCPLCHANRESPONSE._serialized_start=50803
  _CREATETEDSAITHRMCPLCHANRESPONSE._serialized_end=50852
  _CREATETEDSAITHRMSTRCHANIEXREQUEST._serialized_start=50855
  _CREATETEDSAITHRMSTRCHANIEXREQUEST._serialized_end=51390
  _CREATETEDSAITHRMSTRCHANIEXRESPONSE._serialized_start=51392
  _CREATETEDSAITHRMSTRCHANIEXRESPONSE._serialized_end=51444
  _CREATETEDSAITHRMSTRCHANVEXREQUEST._serialized_start=51447
  _CREATETEDSAITHRMSTRCHANVEXREQUEST._serialized_end=51994
  _CREATETEDSAITHRMSTRCHANVEXRESPONSE._serialized_start=51996
  _CREATETEDSAITHRMSTRCHANVEXRESPONSE._serialized_end=52048
  _CREATETEDSAITORQUEBRIDGECHANREQUEST._serialized_start=52051
  _CREATETEDSAITORQUEBRIDGECHANREQUEST._serialized_end=52483
  _CREATETEDSAITORQUEBRIDGECHANRESPONSE._serialized_start=52485
  _CREATETEDSAITORQUEBRIDGECHANRESPONSE._serialized_end=52539
  _CREATETEDSAIVOLTAGECHANREQUEST._serialized_start=52542
  _CREATETEDSAIVOLTAGECHANREQUEST._serialized_end=52932
  _CREATETEDSAIVOLTAGECHANRESPONSE._serialized_start=52934
  _CREATETEDSAIVOLTAGECHANRESPONSE._serialized_end=52983
  _CREATETEDSAIVOLTAGECHANWITHEXCITREQUEST._serialized_start=52986
  _CREATETEDSAIVOLTAGECHANWITHEXCITREQUEST._serialized_end=53541
  _CREATETEDSAIVOLTAGECHANWITHEXCITRESPONSE._serialized_start=53543
  _CREATETEDSAIVOLTAGECHANWITHEXCITRESPONSE._serialized_end=53601
  _CREATETABLESCALEREQUEST._serialized_start=53604
  _CREATETABLESCALEREQUEST._serialized_end=53825
  _CREATETABLESCALERESPONSE._serialized_start=53827
  _CREATETABLESCALERESPONSE._serialized_end=53869
  _CREATETASKREQUEST._serialized_start=53871
  _CREATETASKREQUEST._serialized_end=53991
  _CREATETASKRESPONSE._serialized_start=53993
  _CREATETASKRESPONSE._serialized_end=54100
  _CREATEWATCHDOGTIMERTASKREQUEST._serialized_start=54103
  _CREATEWATCHDOGTIMERTASKREQUEST._serialized_end=54337
  _CREATEWATCHDOGTIMERTASKRESPONSE._serialized_start=54339
  _CREATEWATCHDOGTIMERTASKRESPONSE._serialized_end=54459
  _CREATEWATCHDOGTIMERTASKEXREQUEST._serialized_start=54462
  _CREATEWATCHDOGTIMERTASKEXREQUEST._serialized_end=54635
  _CREATEWATCHDOGTIMERTASKEXRESPONSE._serialized_start=54637
  _CREATEWATCHDOGTIMERTASKEXRESPONSE._serialized_end=54759
  _DELETENETWORKDEVICEREQUEST._serialized_start=54761
  _DELETENETWORKDEVICEREQUEST._serialized_end=54810
  _DELETENETWORKDEVICERESPONSE._serialized_start=54812
  _DELETENETWORKDEVICERESPONSE._serialized_end=54857
  _DELETESAVEDGLOBALCHANREQUEST._serialized_start=54859
  _DELETESAVEDGLOBALCHANREQUEST._serialized_end=54911
  _DELETESAVEDGLOBALCHANRESPONSE._serialized_start=54913
  _DELETESAVEDGLOBALCHANRESPONSE._serialized_end=54960
  _DELETESAVEDSCALEREQUEST._serialized_start=54962
  _DELETESAVEDSCALEREQUEST._serialized_end=55007
  _DELETESAVEDSCALERESPONSE._serialized_start=55009
  _DELETESAVEDSCALERESPONSE._serialized_end=55051
  _DELETESAVEDTASKREQUEST._serialized_start=55053
  _DELETESAVEDTASKREQUEST._serialized_end=55096
  _DELETESAVEDTASKRESPONSE._serialized_start=55098
  _DELETESAVEDTASKRESPONSE._serialized_end=55139
  _DEVICESUPPORTSCALREQUEST._serialized_start=55141
  _DEVICESUPPORTSCALREQUEST._serialized_end=55188
  _DEVICESUPPORTSCALRESPONSE._serialized_start=55190
  _DEVICESUPPORTSCALRESPONSE._serialized_end=55256
  _DISABLEREFTRIGREQUEST._serialized_start=55258
  _DISABLEREFTRIGREQUEST._serialized_end=55319
  _DISABLEREFTRIGRESPONSE._serialized_start=55321
  _DISABLEREFTRIGRESPONSE._serialized_end=55361
  _DISABLESTARTTRIGREQUEST._serialized_start=55363
  _DISABLESTARTTRIGREQUEST._serialized_end=55426
  _DISABLESTARTTRIGRESPONSE._serialized_start=55428
  _DISABLESTARTTRIGRESPONSE._serialized_end=55470
  _DISCONNECTTERMSREQUEST._serialized_start=55472
  _DISCONNECTTERMSREQUEST._serialized_end=55551
  _DISCONNECTTERMSRESPONSE._serialized_start=55553
  _DISCONNECTTERMSRESPONSE._serialized_end=55594
  _EXPORTSIGNALREQUEST._serialized_start=55597
  _EXPORTSIGNALREQUEST._serialized_end=55767
  _EXPORTSIGNALRESPONSE._serialized_start=55769
  _EXPORTSIGNALRESPONSE._serialized_end=55807
  _GETAICHANCALCALDATEREQUEST._serialized_start=55809
  _GETAICHANCALCALDATEREQUEST._serialized_end=55897
  _GETAICHANCALCALDATERESPONSE._serialized_start=55899
  _GETAICHANCALCALDATERESPONSE._serialized_end=56016
  _GETAICHANCALEXPDATEREQUEST._serialized_start=56018
  _GETAICHANCALEXPDATEREQUEST._serialized_end=56106
  _GETAICHANCALEXPDATERESPONSE._serialized_start=56108
  _GETAICHANCALEXPDATERESPONSE._serialized_end=56225
  _GETANALOGPOWERUPSTATESREQUEST._serialized_start=56227
  _GETANALOGPOWERUPSTATESREQUEST._serialized_end=56340
  _GETANALOGPOWERUPSTATESRESPONSE._serialized_start=56342
  _GETANALOGPOWERUPSTATESRESPONSE._serialized_end=56415
  _GETANALOGPOWERUPSTATESWITHOUTPUTTYPEREQUEST._serialized_start=56417
  _GETANALOGPOWERUPSTATESWITHOUTPUTTYPEREQUEST._serialized_end=56505
  _GETANALOGPOWERUPSTATESWITHOUTPUTTYPERESPONSE._serialized_start=56508
  _GETANALOGPOWERUPSTATESWITHOUTPUTTYPERESPONSE._serialized_end=56685
  _GETARMSTARTTRIGTIMESTAMPVALREQUEST._serialized_start=56687
  _GETARMSTARTTRIGTIMESTAMPVALREQUEST._serialized_end=56761
  _GETARMSTARTTRIGTIMESTAMPVALRESPONSE._serialized_start=56763
  _GETARMSTARTTRIGTIMESTAMPVALRESPONSE._serialized_end=56858
  _GETARMSTARTTRIGTRIGWHENREQUEST._serialized_start=56860
  _GETARMSTARTTRIGTRIGWHENREQUEST._serialized_end=56930
  _GETARMSTARTTRIGTRIGWHENRESPONSE._serialized_start=56932
  _GETARMSTARTTRIGTRIGWHENRESPONSE._serialized_end=57023
  _GETAUTOCONFIGUREDCDAQSYNCCONNECTIONSREQUEST._serialized_start=57025
  _GETAUTOCONFIGUREDCDAQSYNCCONNECTIONSREQUEST._serialized_end=57070
  _GETAUTOCONFIGUREDCDAQSYNCCONNECTIONSRESPONSE._serialized_start=57072
  _GETAUTOCONFIGUREDCDAQSYNCCONNECTIONSRESPONSE._serialized_end=57153
  _GETBUFFERATTRIBUTEUINT32REQUEST._serialized_start=57156
  _GETBUFFERATTRIBUTEUINT32REQUEST._serialized_end=57328
  _GETBUFFERATTRIBUTEUINT32RESPONSE._serialized_start=57330
  _GETBUFFERATTRIBUTEUINT32RESPONSE._serialized_end=57395
  _GETCALINFOATTRIBUTEBOOLREQUEST._serialized_start=57398
  _GETCALINFOATTRIBUTEBOOLREQUEST._serialized_end=57559
  _GETCALINFOATTRIBUTEBOOLRESPONSE._serialized_start=57561
  _GETCALINFOATTRIBUTEBOOLRESPONSE._serialized_end=57625
  _GETCALINFOATTRIBUTEDOUBLEREQUEST._serialized_start=57628
  _GETCALINFOATTRIBUTEDOUBLEREQUEST._serialized_end=57793
  _GETCALINFOATTRIBUTEDOUBLERESPONSE._serialized_start=57795
  _GETCALINFOATTRIBUTEDOUBLERESPONSE._serialized_end=57861
  _GETCALINFOATTRIBUTESTRINGREQUEST._serialized_start=57864
  _GETCALINFOATTRIBUTESTRINGREQUEST._serialized_end=58029
  _GETCALINFOATTRIBUTESTRINGRESPONSE._serialized_start=58031
  _GETCALINFOATTRIBUTESTRINGRESPONSE._serialized_end=58097
  _GETCALINFOATTRIBUTEUINT32REQUEST._serialized_start=58100
  _GETCALINFOATTRIBUTEUINT32REQUEST._serialized_end=58265
  _GETCALINFOATTRIBUTEUINT32RESPONSE._serialized_start=58267
  _GETCALINFOATTRIBUTEUINT32RESPONSE._serialized_end=58333
  _GETCHANATTRIBUTEBOOLREQUEST._serialized_start=58336
  _GETCHANATTRIBUTEBOOLREQUEST._serialized_end=58520
  _GETCHANATTRIBUTEBOOLRESPONSE._serialized_start=58522
  _GETCHANATTRIBUTEBOOLRESPONSE._serialized_end=58583
  _GETCHANATTRIBUTEDOUBLEREQUEST._serialized_start=58586
  _GETCHANATTRIBUTEDOUBLEREQUEST._serialized_end=58774
  _GETCHANATTRIBUTEDOUBLERESPONSE._serialized_start=58776
  _GETCHANATTRIBUTEDOUBLERESPONSE._serialized_end=58839
  _GETCHANATTRIBUTEDOUBLEARRAYREQUEST._serialized_start=58842
  _GETCHANATTRIBUTEDOUBLEARRAYREQUEST._serialized_end=59040
  _GETCHANATTRIBUTEDOUBLEARRAYRESPONSE._serialized_start=59042
  _GETCHANATTRIBUTEDOUBLEARRAYRESPONSE._serialized_end=59110
  _GETCHANATTRIBUTEINT32REQUEST._serialized_start=59113
  _GETCHANATTRIBUTEINT32REQUEST._serialized_end=59299
  _GETCHANATTRIBUTEINT32RESPONSE._serialized_start=59301
  _GETCHANATTRIBUTEINT32RESPONSE._serialized_end=59425
  _GETCHANATTRIBUTESTRINGREQUEST._serialized_start=59428
  _GETCHANATTRIBUTESTRINGREQUEST._serialized_end=59616
  _GETCHANATTRIBUTESTRINGRESPONSE._serialized_start=59618
  _GETCHANATTRIBUTESTRINGRESPONSE._serialized_end=59681
  _GETCHANATTRIBUTEUINT32REQUEST._serialized_start=59684
  _GETCHANATTRIBUTEUINT32REQUEST._serialized_end=59872
  _GETCHANATTRIBUTEUINT32RESPONSE._serialized_start=59874
  _GETCHANATTRIBUTEUINT32RESPONSE._serialized_end=59937
  _GETDEVICEATTRIBUTEBOOLREQUEST._serialized_start=59940
  _GETDEVICEATTRIBUTEBOOLREQUEST._serialized_end=60091
  _GETDEVICEATTRIBUTEBOOLRESPONSE._serialized_start=60093
  _GETDEVICEATTRIBUTEBOOLRESPONSE._serialized_end=60156
  _GETDEVICEATTRIBUTEDOUBLEREQUEST._serialized_start=60159
  _GETDEVICEATTRIBUTEDOUBLEREQUEST._serialized_end=60314
  _GETDEVICEATTRIBUTEDOUBLERESPONSE._serialized_start=60316
  _GETDEVICEATTRIBUTEDOUBLERESPONSE._serialized_end=60381
  _GETDEVICEATTRIBUTEDOUBLEARRAYREQUEST._serialized_start=60384
  _GETDEVICEATTRIBUTEDOUBLEARRAYREQUEST._serialized_end=60549
  _GETDEVICEATTRIBUTEDOUBLEARRAYRESPONSE._serialized_start=60551
  _GETDEVICEATTRIBUTEDOUBLEARRAYRESPONSE._serialized_end=60621
  _GETDEVICEATTRIBUTEINT32REQUEST._serialized_start=60624
  _GETDEVICEATTRIBUTEINT32REQUEST._serialized_end=60777
  _GETDEVICEATTRIBUTEINT32RESPONSE._serialized_start=60779
  _GETDEVICEATTRIBUTEINT32RESPONSE._serialized_end=60904
  _GETDEVICEATTRIBUTEINT32ARRAYREQUEST._serialized_start=60907
  _GETDEVICEATTRIBUTEINT32ARRAYREQUEST._serialized_end=61070
  _GETDEVICEATTRIBUTEINT32ARRAYRESPONSE._serialized_start=61073
  _GETDEVICEATTRIBUTEINT32ARRAYRESPONSE._serialized_end=61203
  _GETDEVICEATTRIBUTESTRINGREQUEST._serialized_start=61206
  _GETDEVICEATTRIBUTESTRINGREQUEST._serialized_end=61361
  _GETDEVICEATTRIBUTESTRINGRESPONSE._serialized_start=61363
  _GETDEVICEATTRIBUTESTRINGRESPONSE._serialized_end=61428
  _GETDEVICEATTRIBUTEUINT32REQUEST._serialized_start=61431
  _GETDEVICEATTRIBUTEUINT32REQUEST._serialized_end=61586
  _GETDEVICEATTRIBUTEUINT32RESPONSE._serialized_start=61588
  _GETDEVICEATTRIBUTEUINT32RESPONSE._serialized_end=61653
  _GETDEVICEATTRIBUTEUINT32ARRAYREQUEST._serialized_start=61656
  _GETDEVICEATTRIBUTEUINT32ARRAYREQUEST._serialized_end=61821
  _GETDEVICEATTRIBUTEUINT32ARRAYRESPONSE._serialized_start=61823
  _GETDEVICEATTRIBUTEUINT32ARRAYRESPONSE._serialized_end=61893
  _GETDIGITALLOGICFAMILYPOWERUPSTATEREQUEST._serialized_start=61895
  _GETDIGITALLOGICFAMILYPOWERUPSTATEREQUEST._serialized_end=61958
  _GETDIGITALLOGICFAMILYPOWERUPSTATERESPONSE._serialized_start=61960
  _GETDIGITALLOGICFAMILYPOWERUPSTATERESPONSE._serialized_end=62041
  _GETDIGITALPOWERUPSTATESREQUEST._serialized_start=62043
  _GETDIGITALPOWERUPSTATESREQUEST._serialized_end=62118
  _GETDIGITALPOWERUPSTATESRESPONSE._serialized_start=62120
  _GETDIGITALPOWERUPSTATESRESPONSE._serialized_end=62223
  _GETDIGITALPULLUPPULLDOWNSTATESREQUEST._serialized_start=62225
  _GETDIGITALPULLUPPULLDOWNSTATESREQUEST._serialized_end=62307
  _GETDIGITALPULLUPPULLDOWNSTATESRESPONSE._serialized_start=62309
  _GETDIGITALPULLUPPULLDOWNSTATESRESPONSE._serialized_end=62428
  _GETDISCONNECTEDCDAQSYNCPORTSREQUEST._serialized_start=62430
  _GETDISCONNECTEDCDAQSYNCPORTSREQUEST._serialized_end=62467
  _GETDISCONNECTEDCDAQSYNCPORTSRESPONSE._serialized_start=62469
  _GETDISCONNECTEDCDAQSYNCPORTSRESPONSE._serialized_end=62542
  _GETERRORSTRINGREQUEST._serialized_start=62544
  _GETERRORSTRINGREQUEST._serialized_end=62587
  _GETERRORSTRINGRESPONSE._serialized_start=62589
  _GETERRORSTRINGRESPONSE._serialized_end=62651
  _GETEXPORTEDSIGNALATTRIBUTEBOOLREQUEST._serialized_start=62654
  _GETEXPORTEDSIGNALATTRIBUTEBOOLREQUEST._serialized_end=62836
  _GETEXPORTEDSIGNALATTRIBUTEBOOLRESPONSE._serialized_start=62838
  _GETEXPORTEDSIGNALATTRIBUTEBOOLRESPONSE._serialized_end=62909
  _GETEXPORTEDSIGNALATTRIBUTEDOUBLEREQUEST._serialized_start=62912
  _GETEXPORTEDSIGNALATTRIBUTEDOUBLEREQUEST._serialized_end=63098
  _GETEXPORTEDSIGNALATTRIBUTEDOUBLERESPONSE._serialized_start=63100
  _GETEXPORTEDSIGNALATTRIBUTEDOUBLERESPONSE._serialized_end=63173
  _GETEXPORTEDSIGNALATTRIBUTEINT32REQUEST._serialized_start=63176
  _GETEXPORTEDSIGNALATTRIBUTEINT32REQUEST._serialized_end=63360
  _GETEXPORTEDSIGNALATTRIBUTEINT32RESPONSE._serialized_start=63363
  _GETEXPORTEDSIGNALATTRIBUTEINT32RESPONSE._serialized_end=63502
  _GETEXPORTEDSIGNALATTRIBUTESTRINGREQUEST._serialized_start=63505
  _GETEXPORTEDSIGNALATTRIBUTESTRINGREQUEST._serialized_end=63691
  _GETEXPORTEDSIGNALATTRIBUTESTRINGRESPONSE._serialized_start=63693
  _GETEXPORTEDSIGNALATTRIBUTESTRINGRESPONSE._serialized_end=63766
  _GETEXPORTEDSIGNALATTRIBUTEUINT32REQUEST._serialized_start=63769
  _GETEXPORTEDSIGNALATTRIBUTEUINT32REQUEST._serialized_end=63955
  _GETEXPORTEDSIGNALATTRIBUTEUINT32RESPONSE._serialized_start=63957
  _GETEXPORTEDSIGNALATTRIBUTEUINT32RESPONSE._serialized_end=64030
  _GETEXTCALLASTDATEANDTIMEREQUEST._serialized_start=64032
  _GETEXTCALLASTDATEANDTIMEREQUEST._serialized_end=64086
  _GETEXTCALLASTDATEANDTIMERESPONSE._serialized_start=64088
  _GETEXTCALLASTDATEANDTIMERESPONSE._serialized_end=64210
  _GETFIRSTSAMPCLKWHENREQUEST._serialized_start=64212
  _GETFIRSTSAMPCLKWHENREQUEST._serialized_end=64278
  _GETFIRSTSAMPCLKWHENRESPONSE._serialized_start=64280
  _GETFIRSTSAMPCLKWHENRESPONSE._serialized_end=64367
  _GETFIRSTSAMPTIMESTAMPVALREQUEST._serialized_start=64369
  _GETFIRSTSAMPTIMESTAMPVALREQUEST._serialized_end=64440
  _GETFIRSTSAMPTIMESTAMPVALRESPONSE._serialized_start=64442
  _GETFIRSTSAMPTIMESTAMPVALRESPONSE._serialized_end=64534
  _GETNTHTASKCHANNELREQUEST._serialized_start=64536
  _GETNTHTASKCHANNELREQUEST._serialized_end=64615
  _GETNTHTASKCHANNELRESPONSE._serialized_start=64617
  _GETNTHTASKCHANNELRESPONSE._serialized_end=64676
  _GETNTHTASKDEVICEREQUEST._serialized_start=64678
  _GETNTHTASKDEVICEREQUEST._serialized_end=64756
  _GETNTHTASKDEVICERESPONSE._serialized_start=64758
  _GETNTHTASKDEVICERESPONSE._serialized_end=64816
  _GETNTHTASKREADCHANNELREQUEST._serialized_start=64818
  _GETNTHTASKREADCHANNELREQUEST._serialized_end=64901
  _GETNTHTASKREADCHANNELRESPONSE._serialized_start=64903
  _GETNTHTASKREADCHANNELRESPONSE._serialized_end=64966
  _GETPERSISTEDCHANATTRIBUTEBOOLREQUEST._serialized_start=64969
  _GETPERSISTEDCHANATTRIBUTEBOOLREQUEST._serialized_end=65133
  _GETPERSISTEDCHANATTRIBUTEBOOLRESPONSE._serialized_start=65135
  _GETPERSISTEDCHANATTRIBUTEBOOLRESPONSE._serialized_end=65205
  _GETPERSISTEDCHANATTRIBUTESTRINGREQUEST._serialized_start=65208
  _GETPERSISTEDCHANATTRIBUTESTRINGREQUEST._serialized_end=65376
  _GETPERSISTEDCHANATTRIBUTESTRINGRESPONSE._serialized_start=65378
  _GETPERSISTEDCHANATTRIBUTESTRINGRESPONSE._serialized_end=65450
  _GETPERSISTEDSCALEATTRIBUTEBOOLREQUEST._serialized_start=65453
  _GETPERSISTEDSCALEATTRIBUTEBOOLREQUEST._serialized_end=65619
  _GETPERSISTEDSCALEATTRIBUTEBOOLRESPONSE._serialized_start=65621
  _GETPERSISTEDSCALEATTRIBUTEBOOLRESPONSE._serialized_end=65692
  _GETPERSISTEDSCALEATTRIBUTESTRINGREQUEST._serialized_start=65695
  _GETPERSISTEDSCALEATTRIBUTESTRINGREQUEST._serialized_end=65865
  _GETPERSISTEDSCALEATTRIBUTESTRINGRESPONSE._serialized_start=65867
  _GETPERSISTEDSCALEATTRIBUTESTRINGRESPONSE._serialized_end=65940
  _GETPERSISTEDTASKATTRIBUTEBOOLREQUEST._serialized_start=65943
  _GETPERSISTEDTASKATTRIBUTEBOOLREQUEST._serialized_end=66106
  _GETPERSISTEDTASKATTRIBUTEBOOLRESPONSE._serialized_start=66108
  _GETPERSISTEDTASKATTRIBUTEBOOLRESPONSE._serialized_end=66178
  _GETPERSISTEDTASKATTRIBUTESTRINGREQUEST._serialized_start=66181
  _GETPERSISTEDTASKATTRIBUTESTRINGREQUEST._serialized_end=66348
  _GETPERSISTEDTASKATTRIBUTESTRINGRESPONSE._serialized_start=66350
  _GETPERSISTEDTASKATTRIBUTESTRINGRESPONSE._serialized_end=66422
  _GETPHYSICALCHANATTRIBUTEBOOLREQUEST._serialized_start=66425
  _GETPHYSICALCHANATTRIBUTEBOOLREQUEST._serialized_end=66596
  _GETPHYSICALCHANATTRIBUTEBOOLRESPONSE._serialized_start=66598
  _GETPHYSICALCHANATTRIBUTEBOOLRESPONSE._serialized_end=66667
  _GETPHYSICALCHANATTRIBUTEBYTESREQUEST._serialized_start=66670
  _GETPHYSICALCHANATTRIBUTEBYTESREQUEST._serialized_end=66843
  _GETPHYSICALCHANATTRIBUTEBYTESRESPONSE._serialized_start=66845
  _GETPHYSICALCHANATTRIBUTEBYTESRESPONSE._serialized_end=66915
  _GETPHYSICALCHANATTRIBUTEDOUBLEREQUEST._serialized_start=66918
  _GETPHYSICALCHANATTRIBUTEDOUBLEREQUEST._serialized_end=67093
  _GETPHYSICALCHANATTRIBUTEDOUBLERESPONSE._serialized_start=67095
  _GETPHYSICALCHANATTRIBUTEDOUBLERESPONSE._serialized_end=67166
  _GETPHYSICALCHANATTRIBUTEDOUBLEARRAYREQUEST._serialized_start=67169
  _GETPHYSICALCHANATTRIBUTEDOUBLEARRAYREQUEST._serialized_end=67354
  _GETPHYSICALCHANATTRIBUTEDOUBLEARRAYRESPONSE._serialized_start=67356
  _GETPHYSICALCHANATTRIBUTEDOUBLEARRAYRESPONSE._serialized_end=67432
  _GETPHYSICALCHANATTRIBUTEINT32REQUEST._serialized_start=67435
  _GETPHYSICALCHANATTRIBUTEINT32REQUEST._serialized_end=67608
  _GETPHYSICALCHANATTRIBUTEINT32RESPONSE._serialized_start=67611
  _GETPHYSICALCHANATTRIBUTEINT32RESPONSE._serialized_end=67751
  _GETPHYSICALCHANATTRIBUTEINT32ARRAYREQUEST._serialized_start=67754
  _GETPHYSICALCHANATTRIBUTEINT32ARRAYREQUEST._serialized_end=67937
  _GETPHYSICALCHANATTRIBUTEINT32ARRAYRESPONSE._serialized_start=67940
  _GETPHYSICALCHANATTRIBUTEINT32ARRAYRESPONSE._serialized_end=68085
  _GETPHYSICALCHANATTRIBUTESTRINGREQUEST._serialized_start=68088
  _GETPHYSICALCHANATTRIBUTESTRINGREQUEST._serialized_end=68263
  _GETPHYSICALCHANATTRIBUTESTRINGRESPONSE._serialized_start=68265
  _GETPHYSICALCHANATTRIBUTESTRINGRESPONSE._serialized_end=68336
  _GETPHYSICALCHANATTRIBUTEUINT32REQUEST._serialized_start=68339
  _GETPHYSICALCHANATTRIBUTEUINT32REQUEST._serialized_end=68514
  _GETPHYSICALCHANATTRIBUTEUINT32RESPONSE._serialized_start=68516
  _GETPHYSICALCHANATTRIBUTEUINT32RESPONSE._serialized_end=68587
  _GETPHYSICALCHANATTRIBUTEUINT32ARRAYREQUEST._serialized_start=68590
  _GETPHYSICALCHANATTRIBUTEUINT32ARRAYREQUEST._serialized_end=68775
  _GETPHYSICALCHANATTRIBUTEUINT32ARRAYRESPONSE._serialized_start=68777
  _GETPHYSICALCHANATTRIBUTEUINT32ARRAYRESPONSE._serialized_end=68853
  _GETREADATTRIBUTEBOOLREQUEST._serialized_start=68856
  _GETREADATTRIBUTEBOOLREQUEST._serialized_end=69020
  _GETREADATTRIBUTEBOOLRESPONSE._serialized_start=69022
  _GETREADATTRIBUTEBOOLRESPONSE._serialized_end=69083
  _GETREADATTRIBUTEDOUBLEREQUEST._serialized_start=69086
  _GETREADATTRIBUTEDOUBLEREQUEST._serialized_end=69254
  _GETREADATTRIBUTEDOUBLERESPONSE._serialized_start=69256
  _GETREADATTRIBUTEDOUBLERESPONSE._serialized_end=69319
  _GETREADATTRIBUTEINT32REQUEST._serialized_start=69322
  _GETREADATTRIBUTEINT32REQUEST._serialized_end=69488
  _GETREADATTRIBUTEINT32RESPONSE._serialized_start=69490
  _GETREADATTRIBUTEINT32RESPONSE._serialized_end=69611
  _GETREADATTRIBUTESTRINGREQUEST._serialized_start=69614
  _GETREADATTRIBUTESTRINGREQUEST._serialized_end=69782
  _GETREADATTRIBUTESTRINGRESPONSE._serialized_start=69784
  _GETREADATTRIBUTESTRINGRESPONSE._serialized_end=69847
  _GETREADATTRIBUTEUINT32REQUEST._serialized_start=69850
  _GETREADATTRIBUTEUINT32REQUEST._serialized_end=70018
  _GETREADATTRIBUTEUINT32RESPONSE._serialized_start=70020
  _GETREADATTRIBUTEUINT32RESPONSE._serialized_end=70083
  _GETREADATTRIBUTEUINT64REQUEST._serialized_start=70086
  _GETREADATTRIBUTEUINT64REQUEST._serialized_end=70254
  _GETREADATTRIBUTEUINT64RESPONSE._serialized_start=70256
  _GETREADATTRIBUTEUINT64RESPONSE._serialized_end=70319
  _GETREALTIMEATTRIBUTEBOOLREQUEST._serialized_start=70322
  _GETREALTIMEATTRIBUTEBOOLREQUEST._serialized_end=70494
  _GETREALTIMEATTRIBUTEBOOLRESPONSE._serialized_start=70496
  _GETREALTIMEATTRIBUTEBOOLRESPONSE._serialized_end=70561
  _GETREALTIMEATTRIBUTEINT32REQUEST._serialized_start=70564
  _GETREALTIMEATTRIBUTEINT32REQUEST._serialized_end=70738
  _GETREALTIMEATTRIBUTEINT32RESPONSE._serialized_start=70741
  _GETREALTIMEATTRIBUTEINT32RESPONSE._serialized_end=70870
  _GETREALTIMEATTRIBUTEUINT32REQUEST._serialized_start=70873
  _GETREALTIMEATTRIBUTEUINT32REQUEST._serialized_end=71049
  _GETREALTIMEATTRIBUTEUINT32RESPONSE._serialized_start=71051
  _GETREALTIMEATTRIBUTEUINT32RESPONSE._serialized_end=71118
  _GETREFTRIGTIMESTAMPVALREQUEST._serialized_start=71120
  _GETREFTRIGTIMESTAMPVALREQUEST._serialized_end=71189
  _GETREFTRIGTIMESTAMPVALRESPONSE._serialized_start=71191
  _GETREFTRIGTIMESTAMPVALRESPONSE._serialized_end=71281
  _GETSCALEATTRIBUTEDOUBLEREQUEST._serialized_start=71284
  _GETSCALEATTRIBUTEDOUBLEREQUEST._serialized_end=71436
  _GETSCALEATTRIBUTEDOUBLERESPONSE._serialized_start=71438
  _GETSCALEATTRIBUTEDOUBLERESPONSE._serialized_end=71502
  _GETSCALEATTRIBUTEDOUBLEARRAYREQUEST._serialized_start=71505
  _GETSCALEATTRIBUTEDOUBLEARRAYREQUEST._serialized_end=71667
  _GETSCALEATTRIBUTEDOUBLEARRAYRESPONSE._serialized_start=71669
  _GETSCALEATTRIBUTEDOUBLEARRAYRESPONSE._serialized_end=71738
  _GETSCALEATTRIBUTEINT32REQUEST._serialized_start=71741
  _GETSCALEATTRIBUTEINT32REQUEST._serialized_end=71891
  _GETSCALEATTRIBUTEINT32RESPONSE._serialized_start=71893
  _GETSCALEATTRIBUTEINT32RESPONSE._serialized_end=72016
  _GETSCALEATTRIBUTESTRINGREQUEST._serialized_start=72019
  _GETSCALEATTRIBUTESTRINGREQUEST._serialized_end=72171
  _GETSCALEATTRIBUTESTRINGRESPONSE._serialized_start=72173
  _GETSCALEATTRIBUTESTRINGRESPONSE._serialized_end=72237
  _GETSELFCALLASTDATEANDTIMEREQUEST._serialized_start=72239
  _GETSELFCALLASTDATEANDTIMEREQUEST._serialized_end=72294
  _GETSELFCALLASTDATEANDTIMERESPONSE._serialized_start=72296
  _GETSELFCALLASTDATEANDTIMERESPONSE._serialized_end=72419
  _GETSTARTTRIGTIMESTAMPVALREQUEST._serialized_start=72421
  _GETSTARTTRIGTIMESTAMPVALREQUEST._serialized_end=72492
  _GETSTARTTRIGTIMESTAMPVALRESPONSE._serialized_start=72494
  _GETSTARTTRIGTIMESTAMPVALRESPONSE._serialized_end=72586
  _GETSTARTTRIGTRIGWHENREQUEST._serialized_start=72588
  _GETSTARTTRIGTRIGWHENREQUEST._serialized_end=72655
  _GETSTARTTRIGTRIGWHENRESPONSE._serialized_start=72657
  _GETSTARTTRIGTRIGWHENRESPONSE._serialized_end=72745
  _GETSYNCPULSETIMEWHENREQUEST._serialized_start=72747
  _GETSYNCPULSETIMEWHENREQUEST._serialized_end=72814
  _GETSYNCPULSETIMEWHENRESPONSE._serialized_start=72816
  _GETSYNCPULSETIMEWHENRESPONSE._serialized_end=72904
  _GETSYSTEMINFOATTRIBUTESTRINGREQUEST._serialized_start=72907
  _GETSYSTEMINFOATTRIBUTESTRINGREQUEST._serialized_end=73045
  _GETSYSTEMINFOATTRIBUTESTRINGRESPONSE._serialized_start=73047
  _GETSYSTEMINFOATTRIBUTESTRINGRESPONSE._serialized_end=73116
  _GETSYSTEMINFOATTRIBUTEUINT32REQUEST._serialized_start=73119
  _GETSYSTEMINFOATTRIBUTEUINT32REQUEST._serialized_end=73257
  _GETSYSTEMINFOATTRIBUTEUINT32RESPONSE._serialized_start=73259
  _GETSYSTEMINFOATTRIBUTEUINT32RESPONSE._serialized_end=73328
  _GETTASKATTRIBUTEBOOLREQUEST._serialized_start=73331
  _GETTASKATTRIBUTEBOOLREQUEST._serialized_end=73495
  _GETTASKATTRIBUTEBOOLRESPONSE._serialized_start=73497
  _GETTASKATTRIBUTEBOOLRESPONSE._serialized_end=73558
  _GETTASKATTRIBUTESTRINGREQUEST._serialized_start=73561
  _GETTASKATTRIBUTESTRINGREQUEST._serialized_end=73729
  _GETTASKATTRIBUTESTRINGRESPONSE._serialized_start=73731
  _GETTASKATTRIBUTESTRINGRESPONSE._serialized_end=73794
  _GETTASKATTRIBUTEUINT32REQUEST._serialized_start=73797
  _GETTASKATTRIBUTEUINT32REQUEST._serialized_end=73965
  _GETTASKATTRIBUTEUINT32RESPONSE._serialized_start=73967
  _GETTASKATTRIBUTEUINT32RESPONSE._serialized_end=74030
  _GETTIMINGATTRIBUTEBOOLREQUEST._serialized_start=74033
  _GETTIMINGATTRIBUTEBOOLREQUEST._serialized_end=74201
  _GETTIMINGATTRIBUTEBOOLRESPONSE._serialized_start=74203
  _GETTIMINGATTRIBUTEBOOLRESPONSE._serialized_end=74266
  _GETTIMINGATTRIBUTEDOUBLEREQUEST._serialized_start=74269
  _GETTIMINGATTRIBUTEDOUBLEREQUEST._serialized_end=74441
  _GETTIMINGATTRIBUTEDOUBLERESPONSE._serialized_start=74443
  _GETTIMINGATTRIBUTEDOUBLERESPONSE._serialized_end=74508
  _GETTIMINGATTRIBUTEEXBOOLREQUEST._serialized_start=74511
  _GETTIMINGATTRIBUTEEXBOOLREQUEST._serialized_end=74703
  _GETTIMINGATTRIBUTEEXBOOLRESPONSE._serialized_start=74705
  _GETTIMINGATTRIBUTEEXBOOLRESPONSE._serialized_end=74770
  _GETTIMINGATTRIBUTEEXDOUBLEREQUEST._serialized_start=74773
  _GETTIMINGATTRIBUTEEXDOUBLEREQUEST._serialized_end=74969
  _GETTIMINGATTRIBUTEEXDOUBLERESPONSE._serialized_start=74971
  _GETTIMINGATTRIBUTEEXDOUBLERESPONSE._serialized_end=75038
  _GETTIMINGATTRIBUTEEXINT32REQUEST._serialized_start=75041
  _GETTIMINGATTRIBUTEEXINT32REQUEST._serialized_end=75235
  _GETTIMINGATTRIBUTEEXINT32RESPONSE._serialized_start=75237
  _GETTIMINGATTRIBUTEEXINT32RESPONSE._serialized_end=75364
  _GETTIMINGATTRIBUTEEXSTRINGREQUEST._serialized_start=75367
  _GETTIMINGATTRIBUTEEXSTRINGREQUEST._serialized_end=75563
  _GETTIMINGATTRIBUTEEXSTRINGRESPONSE._serialized_start=75565
  _GETTIMINGATTRIBUTEEXSTRINGRESPONSE._serialized_end=75632
  _GETTIMINGATTRIBUTEEXTIMESTAMPREQUEST._serialized_start=75635
  _GETTIMINGATTRIBUTEEXTIMESTAMPREQUEST._serialized_end=75837
  _GETTIMINGATTRIBUTEEXTIMESTAMPRESPONSE._serialized_start=75839
  _GETTIMINGATTRIBUTEEXTIMESTAMPRESPONSE._serialized_end=75937
  _GETTIMINGATTRIBUTEEXUINT32REQUEST._serialized_start=75940
  _GETTIMINGATTRIBUTEEXUINT32REQUEST._serialized_end=76136
  _GETTIMINGATTRIBUTEEXUINT32RESPONSE._serialized_start=76138
  _GETTIMINGATTRIBUTEEXUINT32RESPONSE._serialized_end=76205
  _GETTIMINGATTRIBUTEEXUINT64REQUEST._serialized_start=76208
  _GETTIMINGATTRIBUTEEXUINT64REQUEST._serialized_end=76404
  _GETTIMINGATTRIBUTEEXUINT64RESPONSE._serialized_start=76406
  _GETTIMINGATTRIBUTEEXUINT64RESPONSE._serialized_end=76473
  _GETTIMINGATTRIBUTEINT32REQUEST._serialized_start=76476
  _GETTIMINGATTRIBUTEINT32REQUEST._serialized_end=76646
  _GETTIMINGATTRIBUTEINT32RESPONSE._serialized_start=76648
  _GETTIMINGATTRIBUTEINT32RESPONSE._serialized_end=76773
  _GETTIMINGATTRIBUTESTRINGREQUEST._serialized_start=76776
  _GETTIMINGATTRIBUTESTRINGREQUEST._serialized_end=76948
  _GETTIMINGATTRIBUTESTRINGRESPONSE._serialized_start=76950
  _GETTIMINGATTRIBUTESTRINGRESPONSE._serialized_end=77015
  _GETTIMINGATTRIBUTETIMESTAMPREQUEST._serialized_start=77018
  _GETTIMINGATTRIBUTETIMESTAMPREQUEST._serialized_end=77196
  _GETTIMINGATTRIBUTETIMESTAMPRESPONSE._serialized_start=77198
  _GETTIMINGATTRIBUTETIMESTAMPRESPONSE._serialized_end=77294
  _GETTIMINGATTRIBUTEUINT32REQUEST._serialized_start=77297
  _GETTIMINGATTRIBUTEUINT32REQUEST._serialized_end=77469
  _GETTIMINGATTRIBUTEUINT32RESPONSE._serialized_start=77471
  _GETTIMINGATTRIBUTEUINT32RESPONSE._serialized_end=77536
  _GETTIMINGATTRIBUTEUINT64REQUEST._serialized_start=77539
  _GETTIMINGATTRIBUTEUINT64REQUEST._serialized_end=77711
  _GETTIMINGATTRIBUTEUINT64RESPONSE._serialized_start=77713
  _GETTIMINGATTRIBUTEUINT64RESPONSE._serialized_end=77778
  _GETTRIGATTRIBUTEBOOLREQUEST._serialized_start=77781
  _GETTRIGATTRIBUTEBOOLREQUEST._serialized_end=77948
  _GETTRIGATTRIBUTEBOOLRESPONSE._serialized_start=77950
  _GETTRIGATTRIBUTEBOOLRESPONSE._serialized_end=78011
  _GETTRIGATTRIBUTEDOUBLEREQUEST._serialized_start=78014
  _GETTRIGATTRIBUTEDOUBLEREQUEST._serialized_end=78185
  _GETTRIGATTRIBUTEDOUBLERESPONSE._serialized_start=78187
  _GETTRIGATTRIBUTEDOUBLERESPONSE._serialized_end=78250
  _GETTRIGATTRIBUTEDOUBLEARRAYREQUEST._serialized_start=78253
  _GETTRIGATTRIBUTEDOUBLEARRAYREQUEST._serialized_end=78434
  _GETTRIGATTRIBUTEDOUBLEARRAYRESPONSE._serialized_start=78436
  _GETTRIGATTRIBUTEDOUBLEARRAYRESPONSE._serialized_end=78504
  _GETTRIGATTRIBUTEINT32REQUEST._serialized_start=78507
  _GETTRIGATTRIBUTEINT32REQUEST._serialized_end=78676
  _GETTRIGATTRIBUTEINT32RESPONSE._serialized_start=78678
  _GETTRIGATTRIBUTEINT32RESPONSE._serialized_end=78802
  _GETTRIGATTRIBUTEINT32ARRAYREQUEST._serialized_start=78805
  _GETTRIGATTRIBUTEINT32ARRAYREQUEST._serialized_end=78984
  _GETTRIGATTRIBUTEINT32ARRAYRESPONSE._serialized_start=78987
  _GETTRIGATTRIBUTEINT32ARRAYRESPONSE._serialized_end=79116
  _GETTRIGATTRIBUTESTRINGREQUEST._serialized_start=79119
  _GETTRIGATTRIBUTESTRINGREQUEST._serialized_end=79290
  _GETTRIGATTRIBUTESTRINGRESPONSE._serialized_start=79292
  _GETTRIGATTRIBUTESTRINGRESPONSE._serialized_end=79355
  _GETTRIGATTRIBUTETIMESTAMPREQUEST._serialized_start=79358
  _GETTRIGATTRIBUTETIMESTAMPREQUEST._serialized_end=79535
  _GETTRIGATTRIBUTETIMESTAMPRESPONSE._serialized_start=79537
  _GETTRIGATTRIBUTETIMESTAMPRESPONSE._serialized_end=79631
  _GETTRIGATTRIBUTEUINT32REQUEST._serialized_start=79634
  _GETTRIGATTRIBUTEUINT32REQUEST._serialized_end=79805
  _GETTRIGATTRIBUTEUINT32RESPONSE._serialized_start=79807
  _GETTRIGATTRIBUTEUINT32RESPONSE._serialized_end=79870
  _GETWATCHDOGATTRIBUTEBOOLREQUEST._serialized_start=79873
  _GETWATCHDOGATTRIBUTEBOOLREQUEST._serialized_end=80060
  _GETWATCHDOGATTRIBUTEBOOLRESPONSE._serialized_start=80062
  _GETWATCHDOGATTRIBUTEBOOLRESPONSE._serialized_end=80127
  _GETWATCHDOGATTRIBUTEDOUBLEREQUEST._serialized_start=80130
  _GETWATCHDOGATTRIBUTEDOUBLEREQUEST._serialized_end=80321
  _GETWATCHDOGATTRIBUTEDOUBLERESPONSE._serialized_start=80323
  _GETWATCHDOGATTRIBUTEDOUBLERESPONSE._serialized_end=80390
  _GETWATCHDOGATTRIBUTEINT32REQUEST._serialized_start=80393
  _GETWATCHDOGATTRIBUTEINT32REQUEST._serialized_end=80582
  _GETWATCHDOGATTRIBUTEINT32RESPONSE._serialized_start=80585
  _GETWATCHDOGATTRIBUTEINT32RESPONSE._serialized_end=80714
  _GETWATCHDOGATTRIBUTESTRINGREQUEST._serialized_start=80717
  _GETWATCHDOGATTRIBUTESTRINGREQUEST._serialized_end=80908
  _GETWATCHDOGATTRIBUTESTRINGRESPONSE._serialized_start=80910
  _GETWATCHDOGATTRIBUTESTRINGRESPONSE._serialized_end=80977
  _GETWRITEATTRIBUTEBOOLREQUEST._serialized_start=80980
  _GETWRITEATTRIBUTEBOOLREQUEST._serialized_end=81146
  _GETWRITEATTRIBUTEBOOLRESPONSE._serialized_start=81148
  _GETWRITEATTRIBUTEBOOLRESPONSE._serialized_end=81210
  _GETWRITEATTRIBUTEDOUBLEREQUEST._serialized_start=81213
  _GETWRITEATTRIBUTEDOUBLEREQUEST._serialized_end=81383
  _GETWRITEATTRIBUTEDOUBLERESPONSE._serialized_start=81385
  _GETWRITEATTRIBUTEDOUBLERESPONSE._serialized_end=81449
  _GETWRITEATTRIBUTEINT32REQUEST._serialized_start=81452
  _GETWRITEATTRIBUTEINT32REQUEST._serialized_end=81620
  _GETWRITEATTRIBUTEINT32RESPONSE._serialized_start=81622
  _GETWRITEATTRIBUTEINT32RESPONSE._serialized_end=81745
  _GETWRITEATTRIBUTESTRINGREQUEST._serialized_start=81748
  _GETWRITEATTRIBUTESTRINGREQUEST._serialized_end=81918
  _GETWRITEATTRIBUTESTRINGRESPONSE._serialized_start=81920
  _GETWRITEATTRIBUTESTRINGRESPONSE._serialized_end=81984
  _GETWRITEATTRIBUTEUINT32REQUEST._serialized_start=81987
  _GETWRITEATTRIBUTEUINT32REQUEST._serialized_end=82157
  _GETWRITEATTRIBUTEUINT32RESPONSE._serialized_start=82159
  _GETWRITEATTRIBUTEUINT32RESPONSE._serialized_end=82223
  _GETWRITEATTRIBUTEUINT64REQUEST._serialized_start=82226
  _GETWRITEATTRIBUTEUINT64REQUEST._serialized_end=82396
  _GETWRITEATTRIBUTEUINT64RESPONSE._serialized_start=82398
  _GETWRITEATTRIBUTEUINT64RESPONSE._serialized_end=82462
  _ISTASKDONEREQUEST._serialized_start=82464
  _ISTASKDONEREQUEST._serialized_end=82521
  _ISTASKDONERESPONSE._serialized_start=82523
  _ISTASKDONERESPONSE._serialized_end=82581
  _LOADTASKREQUEST._serialized_start=82583
  _LOADTASKREQUEST._serialized_end=82701
  _LOADTASKRESPONSE._serialized_start=82703
  _LOADTASKRESPONSE._serialized_end=82808
  _PERFORMBRIDGEOFFSETNULLINGCALEXREQUEST._serialized_start=82811
  _PERFORMBRIDGEOFFSETNULLINGCALEXREQUEST._serialized_end=82941
  _PERFORMBRIDGEOFFSETNULLINGCALEXRESPONSE._serialized_start=82943
  _PERFORMBRIDGEOFFSETNULLINGCALEXRESPONSE._serialized_end=83000
  _PERFORMBRIDGESHUNTCALEXREQUEST._serialized_start=83003
  _PERFORMBRIDGESHUNTCALEXREQUEST._serialized_end=83584
  _PERFORMBRIDGESHUNTCALEXRESPONSE._serialized_start=83586
  _PERFORMBRIDGESHUNTCALEXRESPONSE._serialized_end=83635
  _PERFORMSTRAINSHUNTCALEXREQUEST._serialized_start=83638
  _PERFORMSTRAINSHUNTCALEXREQUEST._serialized_end=84192
  _PERFORMSTRAINSHUNTCALEXRESPONSE._serialized_start=84194
  _PERFORMSTRAINSHUNTCALEXRESPONSE._serialized_end=84243
  _PERFORMTHRMCPLLEADOFFSETNULLINGCALREQUEST._serialized_start=84246
  _PERFORMTHRMCPLLEADOFFSETNULLINGCALREQUEST._serialized_end=84379
  _PERFORMTHRMCPLLEADOFFSETNULLINGCALRESPONSE._serialized_start=84381
  _PERFORMTHRMCPLLEADOFFSETNULLINGCALRESPONSE._serialized_end=84441
  _READANALOGF64REQUEST._serialized_start=84444
  _READANALOGF64REQUEST._serialized_end=84665
  _READANALOGF64RESPONSE._serialized_start=84667
  _READANALOGF64RESPONSE._serialized_end=84755
  _READANALOGSCALARF64REQUEST._serialized_start=84757
  _READANALOGSCALARF64REQUEST._serialized_end=84840
  _READANALOGSCALARF64RESPONSE._serialized_start=84842
  _READANALOGSCALARF64RESPONSE._serialized_end=84902
  _READBINARYI16REQUEST._serialized_start=84905
  _READBINARYI16REQUEST._serialized_end=85126
  _READBINARYI16RESPONSE._serialized_start=85128
  _READBINARYI16RESPONSE._serialized_end=85216
  _READBINARYI32REQUEST._serialized_start=85219
  _READBINARYI32REQUEST._serialized_end=85440
  _READBINARYI32RESPONSE._serialized_start=85442
  _READBINARYI32RESPONSE._serialized_end=85530
  _READBINARYU16REQUEST._serialized_start=85533
  _READBINARYU16REQUEST._serialized_end=85754
  _READBINARYU16RESPONSE._serialized_start=85756
  _READBINARYU16RESPONSE._serialized_end=85844
  _READBINARYU32REQUEST._serialized_start=85847
  _READBINARYU32REQUEST._serialized_end=86068
  _READBINARYU32RESPONSE._serialized_start=86070
  _READBINARYU32RESPONSE._serialized_end=86158
  _READCOUNTERF64REQUEST._serialized_start=86161
  _READCOUNTERF64REQUEST._serialized_end=86296
  _READCOUNTERF64RESPONSE._serialized_start=86298
  _READCOUNTERF64RESPONSE._serialized_end=86387
  _READCOUNTERF64EXREQUEST._serialized_start=86390
  _READCOUNTERF64EXREQUEST._serialized_end=86614
  _READCOUNTERF64EXRESPONSE._serialized_start=86616
  _READCOUNTERF64EXRESPONSE._serialized_end=86707
  _READCOUNTERSCALARF64REQUEST._serialized_start=86709
  _READCOUNTERSCALARF64REQUEST._serialized_end=86793
  _READCOUNTERSCALARF64RESPONSE._serialized_start=86795
  _READCOUNTERSCALARF64RESPONSE._serialized_end=86856
  _READCOUNTERSCALARU32REQUEST._serialized_start=86858
  _READCOUNTERSCALARU32REQUEST._serialized_end=86942
  _READCOUNTERSCALARU32RESPONSE._serialized_start=86944
  _READCOUNTERSCALARU32RESPONSE._serialized_end=87005
  _READCOUNTERU32REQUEST._serialized_start=87008
  _READCOUNTERU32REQUEST._serialized_end=87143
  _READCOUNTERU32RESPONSE._serialized_start=87145
  _READCOUNTERU32RESPONSE._serialized_end=87234
  _READCOUNTERU32EXREQUEST._serialized_start=87237
  _READCOUNTERU32EXREQUEST._serialized_end=87461
  _READCOUNTERU32EXRESPONSE._serialized_start=87463
  _READCOUNTERU32EXRESPONSE._serialized_end=87554
  _READCTRFREQREQUEST._serialized_start=87557
  _READCTRFREQREQUEST._serialized_end=87782
  _READCTRFREQRESPONSE._serialized_start=87784
  _READCTRFREQRESPONSE._serialized_end=87911
  _READCTRFREQSCALARREQUEST._serialized_start=87913
  _READCTRFREQSCALARREQUEST._serialized_end=87994
  _READCTRFREQSCALARRESPONSE._serialized_start=87996
  _READCTRFREQSCALARRESPONSE._serialized_end=88078
  _READCTRTICKSREQUEST._serialized_start=88081
  _READCTRTICKSREQUEST._serialized_end=88307
  _READCTRTICKSRESPONSE._serialized_start=88310
  _READCTRTICKSRESPONSE._serialized_end=88438
  _READCTRTICKSSCALARREQUEST._serialized_start=88440
  _READCTRTICKSSCALARREQUEST._serialized_end=88522
  _READCTRTICKSSCALARRESPONSE._serialized_start=88524
  _READCTRTICKSSCALARRESPONSE._serialized_end=88607
  _READCTRTIMEREQUEST._serialized_start=88610
  _READCTRTIMEREQUEST._serialized_end=88835
  _READCTRTIMERESPONSE._serialized_start=88837
  _READCTRTIMERESPONSE._serialized_end=88962
  _READCTRTIMESCALARREQUEST._serialized_start=88964
  _READCTRTIMESCALARREQUEST._serialized_end=89045
  _READCTRTIMESCALARRESPONSE._serialized_start=89047
  _READCTRTIMESCALARRESPONSE._serialized_end=89127
  _READDIGITALLINESREQUEST._serialized_start=89130
  _READDIGITALLINESREQUEST._serialized_end=89354
  _READDIGITALLINESRESPONSE._serialized_start=89356
  _READDIGITALLINESRESPONSE._serialized_end=89475
  _READDIGITALSCALARU32REQUEST._serialized_start=89477
  _READDIGITALSCALARU32REQUEST._serialized_end=89561
  _READDIGITALSCALARU32RESPONSE._serialized_start=89563
  _READDIGITALSCALARU32RESPONSE._serialized_end=89624
  _READDIGITALU16REQUEST._serialized_start=89627
  _READDIGITALU16REQUEST._serialized_end=89849
  _READDIGITALU16RESPONSE._serialized_start=89851
  _READDIGITALU16RESPONSE._serialized_end=89940
  _READDIGITALU32REQUEST._serialized_start=89943
  _READDIGITALU32REQUEST._serialized_end=90165
  _READDIGITALU32RESPONSE._serialized_start=90167
  _READDIGITALU32RESPONSE._serialized_end=90256
  _READDIGITALU8REQUEST._serialized_start=90259
  _READDIGITALU8REQUEST._serialized_end=90480
  _READDIGITALU8RESPONSE._serialized_start=90482
  _READDIGITALU8RESPONSE._serialized_end=90570
  _READPOWERBINARYI16REQUEST._serialized_start=90573
  _READPOWERBINARYI16REQUEST._serialized_end=90799
  _READPOWERBINARYI16RESPONSE._serialized_start=90802
  _READPOWERBINARYI16RESPONSE._serialized_end=90931
  _READPOWERF64REQUEST._serialized_start=90934
  _READPOWERF64REQUEST._serialized_end=91154
  _READPOWERF64RESPONSE._serialized_start=91156
  _READPOWERF64RESPONSE._serialized_end=91279
  _READPOWERSCALARF64REQUEST._serialized_start=91281
  _READPOWERSCALARF64REQUEST._serialized_end=91363
  _READPOWERSCALARF64RESPONSE._serialized_start=91365
  _READPOWERSCALARF64RESPONSE._serialized_end=91443
  _READRAWREQUEST._serialized_start=91446
  _READRAWREQUEST._serialized_end=91574
  _READRAWRESPONSE._serialized_start=91576
  _READRAWRESPONSE._serialized_end=91677
  _REGISTERDONEEVENTREQUEST._serialized_start=91679
  _REGISTERDONEEVENTREQUEST._serialized_end=91743
  _REGISTERDONEEVENTRESPONSE._serialized_start=91745
  _REGISTERDONEEVENTRESPONSE._serialized_end=91788
  _REGISTEREVERYNSAMPLESEVENTREQUEST._serialized_start=91791
  _REGISTEREVERYNSAMPLESEVENTREQUEST._serialized_end=92036
  _REGISTEREVERYNSAMPLESEVENTRESPONSE._serialized_start=92039
  _REGISTEREVERYNSAMPLESEVENTRESPONSE._serialized_end=92224
  _REGISTERSIGNALEVENTREQUEST._serialized_start=92227
  _REGISTERSIGNALEVENTREQUEST._serialized_end=92380
  _REGISTERSIGNALEVENTRESPONSE._serialized_start=92382
  _REGISTERSIGNALEVENTRESPONSE._serialized_end=92446
  _REMOVECDAQSYNCCONNECTIONREQUEST._serialized_start=92448
  _REMOVECDAQSYNCCONNECTIONREQUEST._serialized_end=92500
  _REMOVECDAQSYNCCONNECTIONRESPONSE._serialized_start=92502
  _REMOVECDAQSYNCCONNECTIONRESPONSE._serialized_end=92552
  _RESERVENETWORKDEVICEREQUEST._serialized_start=92554
  _RESERVENETWORKDEVICEREQUEST._serialized_end=92634
  _RESERVENETWORKDEVICERESPONSE._serialized_start=92636
  _RESERVENETWORKDEVICERESPONSE._serialized_end=92682
  _RESETBUFFERATTRIBUTEREQUEST._serialized_start=92685
  _RESETBUFFERATTRIBUTEREQUEST._serialized_end=92852
  _RESETBUFFERATTRIBUTERESPONSE._serialized_start=92854
  _RESETBUFFERATTRIBUTERESPONSE._serialized_end=92900
  _RESETCHANATTRIBUTEREQUEST._serialized_start=92903
  _RESETCHANATTRIBUTEREQUEST._serialized_end=93086
  _RESETCHANATTRIBUTERESPONSE._serialized_start=93088
  _RESETCHANATTRIBUTERESPONSE._serialized_end=93132
  _RESETDEVICEREQUEST._serialized_start=93134
  _RESETDEVICEREQUEST._serialized_end=93175
  _RESETDEVICERESPONSE._serialized_start=93177
  _RESETDEVICERESPONSE._serialized_end=93214
  _RESETEXPORTEDSIGNALATTRIBUTEREQUEST._serialized_start=93217
  _RESETEXPORTEDSIGNALATTRIBUTEREQUEST._serialized_end=93398
  _RESETEXPORTEDSIGNALATTRIBUTERESPONSE._serialized_start=93400
  _RESETEXPORTEDSIGNALATTRIBUTERESPONSE._serialized_end=93454
  _RESETREADATTRIBUTEREQUEST._serialized_start=93457
  _RESETREADATTRIBUTEREQUEST._serialized_end=93620
  _RESETREADATTRIBUTERESPONSE._serialized_start=93622
  _RESETREADATTRIBUTERESPONSE._serialized_end=93666
  _RESETREALTIMEATTRIBUTEREQUEST._serialized_start=93669
  _RESETREALTIMEATTRIBUTEREQUEST._serialized_end=93840
  _RESETREALTIMEATTRIBUTERESPONSE._serialized_start=93842
  _RESETREALTIMEATTRIBUTERESPONSE._serialized_end=93890
  _RESETTIMINGATTRIBUTEREQUEST._serialized_start=93893
  _RESETTIMINGATTRIBUTEREQUEST._serialized_end=94060
  _RESETTIMINGATTRIBUTERESPONSE._serialized_start=94062
  _RESETTIMINGATTRIBUTERESPONSE._serialized_end=94108
  _RESETTIMINGATTRIBUTEEXREQUEST._serialized_start=94111
  _RESETTIMINGATTRIBUTEEXREQUEST._serialized_end=94302
  _RESETTIMINGATTRIBUTEEXRESPONSE._serialized_start=94304
  _RESETTIMINGATTRIBUTEEXRESPONSE._serialized_end=94352
  _RESETTRIGATTRIBUTEREQUEST._serialized_start=94355
  _RESETTRIGATTRIBUTEREQUEST._serialized_end=94521
  _RESETTRIGATTRIBUTERESPONSE._serialized_start=94523
  _RESETTRIGATTRIBUTERESPONSE._serialized_end=94567
  _RESETWATCHDOGATTRIBUTEREQUEST._serialized_start=94570
  _RESETWATCHDOGATTRIBUTEREQUEST._serialized_end=94756
  _RESETWATCHDOGATTRIBUTERESPONSE._serialized_start=94758
  _RESETWATCHDOGATTRIBUTERESPONSE._serialized_end=94806
  _RESETWRITEATTRIBUTEREQUEST._serialized_start=94809
  _RESETWRITEATTRIBUTEREQUEST._serialized_end=94974
  _RESETWRITEATTRIBUTERESPONSE._serialized_start=94976
  _RESETWRITEATTRIBUTERESPONSE._serialized_end=95021
  _RESTORELASTEXTCALCONSTREQUEST._serialized_start=95023
  _RESTORELASTEXTCALCONSTREQUEST._serialized_end=95075
  _RESTORELASTEXTCALCONSTRESPONSE._serialized_start=95077
  _RESTORELASTEXTCALCONSTRESPONSE._serialized_end=95125
  _SAVEGLOBALCHANREQUEST._serialized_start=95128
  _SAVEGLOBALCHANREQUEST._serialized_end=95329
  _SAVEGLOBALCHANRESPONSE._serialized_start=95331
  _SAVEGLOBALCHANRESPONSE._serialized_end=95371
  _SAVESCALEREQUEST._serialized_start=95374
  _SAVESCALEREQUEST._serialized_end=95530
  _SAVESCALERESPONSE._serialized_start=95532
  _SAVESCALERESPONSE._serialized_end=95567
  _SAVETASKREQUEST._serialized_start=95570
  _SAVETASKREQUEST._serialized_end=95743
  _SAVETASKRESPONSE._serialized_start=95745
  _SAVETASKRESPONSE._serialized_end=95779
  _SELFCALREQUEST._serialized_start=95781
  _SELFCALREQUEST._serialized_end=95818
  _SELFCALRESPONSE._serialized_start=95820
  _SELFCALRESPONSE._serialized_end=95853
  _SELFTESTDEVICEREQUEST._serialized_start=95855
  _SELFTESTDEVICEREQUEST._serialized_end=95899
  _SELFTESTDEVICERESPONSE._serialized_start=95901
  _SELFTESTDEVICERESPONSE._serialized_end=95941
  _SETAICHANCALCALDATEREQUEST._serialized_start=95944
  _SETAICHANCALCALDATEREQUEST._serialized_end=96104
  _SETAICHANCALCALDATERESPONSE._serialized_start=96106
  _SETAICHANCALCALDATERESPONSE._serialized_end=96151
  _SETAICHANCALEXPDATEREQUEST._serialized_start=96154
  _SETAICHANCALEXPDATEREQUEST._serialized_end=96314
  _SETAICHANCALEXPDATERESPONSE._serialized_start=96316
  _SETAICHANCALEXPDATERESPONSE._serialized_end=96361
  _SETANALOGPOWERUPSTATESREQUEST._serialized_start=96363
  _SETANALOGPOWERUPSTATESREQUEST._serialized_end=96485
  _SETANALOGPOWERUPSTATESRESPONSE._serialized_start=96487
  _SETANALOGPOWERUPSTATESRESPONSE._serialized_end=96535
  _SETANALOGPOWERUPSTATESWITHOUTPUTTYPEREQUEST._serialized_start=96538
  _SETANALOGPOWERUPSTATESWITHOUTPUTTYPEREQUEST._serialized_end=96689
  _SETANALOGPOWERUPSTATESWITHOUTPUTTYPERESPONSE._serialized_start=96691
  _SETANALOGPOWERUPSTATESWITHOUTPUTTYPERESPONSE._serialized_end=96753
  _SETARMSTARTTRIGTRIGWHENREQUEST._serialized_start=96755
  _SETARMSTARTTRIGTRIGWHENREQUEST._serialized_end=96867
  _SETARMSTARTTRIGTRIGWHENRESPONSE._serialized_start=96869
  _SETARMSTARTTRIGTRIGWHENRESPONSE._serialized_end=96918
  _SETBUFFERATTRIBUTEUINT32REQUEST._serialized_start=96921
  _SETBUFFERATTRIBUTEUINT32REQUEST._serialized_end=97108
  _SETBUFFERATTRIBUTEUINT32RESPONSE._serialized_start=97110
  _SETBUFFERATTRIBUTEUINT32RESPONSE._serialized_end=97160
  _SETCALINFOATTRIBUTEBOOLREQUEST._serialized_start=97163
  _SETCALINFOATTRIBUTEBOOLREQUEST._serialized_end=97339
  _SETCALINFOATTRIBUTEBOOLRESPONSE._serialized_start=97341
  _SETCALINFOATTRIBUTEBOOLRESPONSE._serialized_end=97390
  _SETCALINFOATTRIBUTEDOUBLEREQUEST._serialized_start=97393
  _SETCALINFOATTRIBUTEDOUBLEREQUEST._serialized_end=97573
  _SETCALINFOATTRIBUTEDOUBLERESPONSE._serialized_start=97575
  _SETCALINFOATTRIBUTEDOUBLERESPONSE._serialized_end=97626
  _SETCALINFOATTRIBUTESTRINGREQUEST._serialized_start=97629
  _SETCALINFOATTRIBUTESTRINGREQUEST._serialized_end=97809
  _SETCALINFOATTRIBUTESTRINGRESPONSE._serialized_start=97811
  _SETCALINFOATTRIBUTESTRINGRESPONSE._serialized_end=97862
  _SETCALINFOATTRIBUTEUINT32REQUEST._serialized_start=97865
  _SETCALINFOATTRIBUTEUINT32REQUEST._serialized_end=98045
  _SETCALINFOATTRIBUTEUINT32RESPONSE._serialized_start=98047
  _SETCALINFOATTRIBUTEUINT32RESPONSE._serialized_end=98098
  _SETCHANATTRIBUTEBOOLREQUEST._serialized_start=98101
  _SETCHANATTRIBUTEBOOLREQUEST._serialized_end=98300
  _SETCHANATTRIBUTEBOOLRESPONSE._serialized_start=98302
  _SETCHANATTRIBUTEBOOLRESPONSE._serialized_end=98348
  _SETCHANATTRIBUTEDOUBLEREQUEST._serialized_start=98351
  _SETCHANATTRIBUTEDOUBLEREQUEST._serialized_end=98554
  _SETCHANATTRIBUTEDOUBLERESPONSE._serialized_start=98556
  _SETCHANATTRIBUTEDOUBLERESPONSE._serialized_end=98604
  _SETCHANATTRIBUTEDOUBLEARRAYREQUEST._serialized_start=98607
  _SETCHANATTRIBUTEDOUBLEARRAYREQUEST._serialized_end=98820
  _SETCHANATTRIBUTEDOUBLEARRAYRESPONSE._serialized_start=98822
  _SETCHANATTRIBUTEDOUBLEARRAYRESPONSE._serialized_end=98875
  _SETCHANATTRIBUTEINT32REQUEST._serialized_start=98878
  _SETCHANATTRIBUTEINT32REQUEST._serialized_end=99159
  _SETCHANATTRIBUTEINT32RESPONSE._serialized_start=99161
  _SETCHANATTRIBUTEINT32RESPONSE._serialized_end=99208
  _SETCHANATTRIBUTESTRINGREQUEST._serialized_start=99211
  _SETCHANATTRIBUTESTRINGREQUEST._serialized_end=99414
  _SETCHANATTRIBUTESTRINGRESPONSE._serialized_start=99416
  _SETCHANATTRIBUTESTRINGRESPONSE._serialized_end=99464
  _SETCHANATTRIBUTEUINT32REQUEST._serialized_start=99467
  _SETCHANATTRIBUTEUINT32REQUEST._serialized_end=99670
  _SETCHANATTRIBUTEUINT32RESPONSE._serialized_start=99672
  _SETCHANATTRIBUTEUINT32RESPONSE._serialized_end=99720
  _SETDIGITALLOGICFAMILYPOWERUPSTATEREQUEST._serialized_start=99723
  _SETDIGITALLOGICFAMILYPOWERUPSTATEREQUEST._serialized_end=99886
  _SETDIGITALLOGICFAMILYPOWERUPSTATERESPONSE._serialized_start=99888
  _SETDIGITALLOGICFAMILYPOWERUPSTATERESPONSE._serialized_end=99947
  _SETDIGITALPOWERUPSTATESREQUEST._serialized_start=99949
  _SETDIGITALPOWERUPSTATESREQUEST._serialized_end=100073
  _SETDIGITALPOWERUPSTATESRESPONSE._serialized_start=100075
  _SETDIGITALPOWERUPSTATESRESPONSE._serialized_end=100124
  _SETDIGITALPULLUPPULLDOWNSTATESREQUEST._serialized_start=100127
  _SETDIGITALPULLUPPULLDOWNSTATESREQUEST._serialized_end=100274
  _SETDIGITALPULLUPPULLDOWNSTATESRESPONSE._serialized_start=100276
  _SETDIGITALPULLUPPULLDOWNSTATESRESPONSE._serialized_end=100332
  _SETEXPORTEDSIGNALATTRIBUTEBOOLREQUEST._serialized_start=100335
  _SETEXPORTEDSIGNALATTRIBUTEBOOLREQUEST._serialized_end=100532
  _SETEXPORTEDSIGNALATTRIBUTEBOOLRESPONSE._serialized_start=100534
  _SETEXPORTEDSIGNALATTRIBUTEBOOLRESPONSE._serialized_end=100590
  _SETEXPORTEDSIGNALATTRIBUTEDOUBLEREQUEST._serialized_start=100593
  _SETEXPORTEDSIGNALATTRIBUTEDOUBLEREQUEST._serialized_end=100794
  _SETEXPORTEDSIGNALATTRIBUTEDOUBLERESPONSE._serialized_start=100796
  _SETEXPORTEDSIGNALATTRIBUTEDOUBLERESPONSE._serialized_end=100854
  _SETEXPORTEDSIGNALATTRIBUTEINT32REQUEST._serialized_start=100857
  _SETEXPORTEDSIGNALATTRIBUTEINT32REQUEST._serialized_end=101141
  _SETEXPORTEDSIGNALATTRIBUTEINT32RESPONSE._serialized_start=101143
  _SETEXPORTEDSIGNALATTRIBUTEINT32RESPONSE._serialized_end=101200
  _SETEXPORTEDSIGNALATTRIBUTESTRINGREQUEST._serialized_start=101203
  _SETEXPORTEDSIGNALATTRIBUTESTRINGREQUEST._serialized_end=101404
  _SETEXPORTEDSIGNALATTRIBUTESTRINGRESPONSE._serialized_start=101406
  _SETEXPORTEDSIGNALATTRIBUTESTRINGRESPONSE._serialized_end=101464
  _SETEXPORTEDSIGNALATTRIBUTEUINT32REQUEST._serialized_start=101467
  _SETEXPORTEDSIGNALATTRIBUTEUINT32REQUEST._serialized_end=101668
  _SETEXPORTEDSIGNALATTRIBUTEUINT32RESPONSE._serialized_start=101670
  _SETEXPORTEDSIGNALATTRIBUTEUINT32RESPONSE._serialized_end=101728
  _SETFIRSTSAMPCLKWHENREQUEST._serialized_start=101730
  _SETFIRSTSAMPCLKWHENREQUEST._serialized_end=101838
  _SETFIRSTSAMPCLKWHENRESPONSE._serialized_start=101840
  _SETFIRSTSAMPCLKWHENRESPONSE._serialized_end=101885
  _SETREADATTRIBUTEBOOLREQUEST._serialized_start=101888
  _SETREADATTRIBUTEBOOLREQUEST._serialized_end=102067
  _SETREADATTRIBUTEBOOLRESPONSE._serialized_start=102069
  _SETREADATTRIBUTEBOOLRESPONSE._serialized_end=102115
  _SETREADATTRIBUTEDOUBLEREQUEST._serialized_start=102118
  _SETREADATTRIBUTEDOUBLEREQUEST._serialized_end=102301
  _SETREADATTRIBUTEDOUBLERESPONSE._serialized_start=102303
  _SETREADATTRIBUTEDOUBLERESPONSE._serialized_end=102351
  _SETREADATTRIBUTEINT32REQUEST._serialized_start=102354
  _SETREADATTRIBUTEINT32REQUEST._serialized_end=102612
  _SETREADATTRIBUTEINT32RESPONSE._serialized_start=102614
  _SETREADATTRIBUTEINT32RESPONSE._serialized_end=102661
  _SETREADATTRIBUTESTRINGREQUEST._serialized_start=102664
  _SETREADATTRIBUTESTRINGREQUEST._serialized_end=102847
  _SETREADATTRIBUTESTRINGRESPONSE._serialized_start=102849
  _SETREADATTRIBUTESTRINGRESPONSE._serialized_end=102897
  _SETREADATTRIBUTEUINT32REQUEST._serialized_start=102900
  _SETREADATTRIBUTEUINT32REQUEST._serialized_end=103083
  _SETREADATTRIBUTEUINT32RESPONSE._serialized_start=103085
  _SETREADATTRIBUTEUINT32RESPONSE._serialized_end=103133
  _SETREADATTRIBUTEUINT64REQUEST._serialized_start=103136
  _SETREADATTRIBUTEUINT64REQUEST._serialized_end=103319
  _SETREADATTRIBUTEUINT64RESPONSE._serialized_start=103321
  _SETREADATTRIBUTEUINT64RESPONSE._serialized_end=103369
  _SETREALTIMEATTRIBUTEBOOLREQUEST._serialized_start=103372
  _SETREALTIMEATTRIBUTEBOOLREQUEST._serialized_end=103559
  _SETREALTIMEATTRIBUTEBOOLRESPONSE._serialized_start=103561
  _SETREALTIMEATTRIBUTEBOOLRESPONSE._serialized_end=103611
  _SETREALTIMEATTRIBUTEINT32REQUEST._serialized_start=103614
  _SETREALTIMEATTRIBUTEINT32REQUEST._serialized_end=103884
  _SETREALTIMEATTRIBUTEINT32RESPONSE._serialized_start=103886
  _SETREALTIMEATTRIBUTEINT32RESPONSE._serialized_end=103937
  _SETREALTIMEATTRIBUTEUINT32REQUEST._serialized_start=103940
  _SETREALTIMEATTRIBUTEUINT32REQUEST._serialized_end=104131
  _SETREALTIMEATTRIBUTEUINT32RESPONSE._serialized_start=104133
  _SETREALTIMEATTRIBUTEUINT32RESPONSE._serialized_end=104185
  _SETSCALEATTRIBUTEDOUBLEREQUEST._serialized_start=104188
  _SETSCALEATTRIBUTEDOUBLEREQUEST._serialized_end=104355
  _SETSCALEATTRIBUTEDOUBLERESPONSE._serialized_start=104357
  _SETSCALEATTRIBUTEDOUBLERESPONSE._serialized_end=104406
  _SETSCALEATTRIBUTEDOUBLEARRAYREQUEST._serialized_start=104409
  _SETSCALEATTRIBUTEDOUBLEARRAYREQUEST._serialized_end=104586
  _SETSCALEATTRIBUTEDOUBLEARRAYRESPONSE._serialized_start=104588
  _SETSCALEATTRIBUTEDOUBLEARRAYRESPONSE._serialized_end=104642
  _SETSCALEATTRIBUTEINT32REQUEST._serialized_start=104645
  _SETSCALEATTRIBUTEINT32REQUEST._serialized_end=104888
  _SETSCALEATTRIBUTEINT32RESPONSE._serialized_start=104890
  _SETSCALEATTRIBUTEINT32RESPONSE._serialized_end=104938
  _SETSCALEATTRIBUTESTRINGREQUEST._serialized_start=104941
  _SETSCALEATTRIBUTESTRINGREQUEST._serialized_end=105108
  _SETSCALEATTRIBUTESTRINGRESPONSE._serialized_start=105110
  _SETSCALEATTRIBUTESTRINGRESPONSE._serialized_end=105159
  _SETSTARTTRIGTRIGWHENREQUEST._serialized_start=105161
  _SETSTARTTRIGTRIGWHENREQUEST._serialized_end=105270
  _SETSTARTTRIGTRIGWHENRESPONSE._serialized_start=105272
  _SETSTARTTRIGTRIGWHENRESPONSE._serialized_end=105318
  _SETSYNCPULSETIMEWHENREQUEST._serialized_start=105320
  _SETSYNCPULSETIMEWHENREQUEST._serialized_end=105429
  _SETSYNCPULSETIMEWHENRESPONSE._serialized_start=105431
  _SETSYNCPULSETIMEWHENRESPONSE._serialized_end=105477
  _SETTIMINGATTRIBUTEBOOLREQUEST._serialized_start=105480
  _SETTIMINGATTRIBUTEBOOLREQUEST._serialized_end=105663
  _SETTIMINGATTRIBUTEBOOLRESPONSE._serialized_start=105665
  _SETTIMINGATTRIBUTEBOOLRESPONSE._serialized_end=105713
  _SETTIMINGATTRIBUTEDOUBLEREQUEST._serialized_start=105716
  _SETTIMINGATTRIBUTEDOUBLEREQUEST._serialized_end=105903
  _SETTIMINGATTRIBUTEDOUBLERESPONSE._serialized_start=105905
  _SETTIMINGATTRIBUTEDOUBLERESPONSE._serialized_end=105955
  _SETTIMINGATTRIBUTEEXBOOLREQUEST._serialized_start=105958
  _SETTIMINGATTRIBUTEEXBOOLREQUEST._serialized_end=106165
  _SETTIMINGATTRIBUTEEXBOOLRESPONSE._serialized_start=106167
  _SETTIMINGATTRIBUTEEXBOOLRESPONSE._serialized_end=106217
  _SETTIMINGATTRIBUTEEXDOUBLEREQUEST._serialized_start=106220
  _SETTIMINGATTRIBUTEEXDOUBLEREQUEST._serialized_end=106431
  _SETTIMINGATTRIBUTEEXDOUBLERESPONSE._serialized_start=106433
  _SETTIMINGATTRIBUTEEXDOUBLERESPONSE._serialized_end=106485
  _SETTIMINGATTRIBUTEEXINT32REQUEST._serialized_start=106488
  _SETTIMINGATTRIBUTEEXINT32REQUEST._serialized_end=106776
  _SETTIMINGATTRIBUTEEXINT32RESPONSE._serialized_start=106778
  _SETTIMINGATTRIBUTEEXINT32RESPONSE._serialized_end=106829
  _SETTIMINGATTRIBUTEEXSTRINGREQUEST._serialized_start=106832
  _SETTIMINGATTRIBUTEEXSTRINGREQUEST._serialized_end=107043
  _SETTIMINGATTRIBUTEEXSTRINGRESPONSE._serialized_start=107045
  _SETTIMINGATTRIBUTEEXSTRINGRESPONSE._serialized_end=107097
  _SETTIMINGATTRIBUTEEXTIMESTAMPREQUEST._serialized_start=107100
  _SETTIMINGATTRIBUTEEXTIMESTAMPREQUEST._serialized_end=107345
  _SETTIMINGATTRIBUTEEXTIMESTAMPRESPONSE._serialized_start=107347
  _SETTIMINGATTRIBUTEEXTIMESTAMPRESPONSE._serialized_end=107402
  _SETTIMINGATTRIBUTEEXUINT32REQUEST._serialized_start=107405
  _SETTIMINGATTRIBUTEEXUINT32REQUEST._serialized_end=107616
  _SETTIMINGATTRIBUTEEXUINT32RESPONSE._serialized_start=107618
  _SETTIMINGATTRIBUTEEXUINT32RESPONSE._serialized_end=107670
  _SETTIMINGATTRIBUTEEXUINT64REQUEST._serialized_start=107673
  _SETTIMINGATTRIBUTEEXUINT64REQUEST._serialized_end=107884
  _SETTIMINGATTRIBUTEEXUINT64RESPONSE._serialized_start=107886
  _SETTIMINGATTRIBUTEEXUINT64RESPONSE._serialized_end=107938
  _SETTIMINGATTRIBUTEINT32REQUEST._serialized_start=107941
  _SETTIMINGATTRIBUTEINT32REQUEST._serialized_end=108205
  _SETTIMINGATTRIBUTEINT32RESPONSE._serialized_start=108207
  _SETTIMINGATTRIBUTEINT32RESPONSE._serialized_end=108256
  _SETTIMINGATTRIBUTESTRINGREQUEST._serialized_start=108259
  _SETTIMINGATTRIBUTESTRINGREQUEST._serialized_end=108446
  _SETTIMINGATTRIBUTESTRINGRESPONSE._serialized_start=108448
  _SETTIMINGATTRIBUTESTRINGRESPONSE._serialized_end=108498
  _SETTIMINGATTRIBUTETIMESTAMPREQUEST._serialized_start=108501
  _SETTIMINGATTRIBUTETIMESTAMPREQUEST._serialized_end=108722
  _SETTIMINGATTRIBUTETIMESTAMPRESPONSE._serialized_start=108724
  _SETTIMINGATTRIBUTETIMESTAMPRESPONSE._serialized_end=108777
  _SETTIMINGATTRIBUTEUINT32REQUEST._serialized_start=108780
  _SETTIMINGATTRIBUTEUINT32REQUEST._serialized_end=108967
  _SETTIMINGATTRIBUTEUINT32RESPONSE._serialized_start=108969
  _SETTIMINGATTRIBUTEUINT32RESPONSE._serialized_end=109019
  _SETTIMINGATTRIBUTEUINT64REQUEST._serialized_start=109022
  _SETTIMINGATTRIBUTEUINT64REQUEST._serialized_end=109209
  _SETTIMINGATTRIBUTEUINT64RESPONSE._serialized_start=109211
  _SETTIMINGATTRIBUTEUINT64RESPONSE._serialized_end=109261
  _SETTRIGATTRIBUTEBOOLREQUEST._serialized_start=109264
  _SETTRIGATTRIBUTEBOOLREQUEST._serialized_end=109446
  _SETTRIGATTRIBUTEBOOLRESPONSE._serialized_start=109448
  _SETTRIGATTRIBUTEBOOLRESPONSE._serialized_end=109494
  _SETTRIGATTRIBUTEDOUBLEREQUEST._serialized_start=109497
  _SETTRIGATTRIBUTEDOUBLEREQUEST._serialized_end=109683
  _SETTRIGATTRIBUTEDOUBLERESPONSE._serialized_start=109685
  _SETTRIGATTRIBUTEDOUBLERESPONSE._serialized_end=109733
  _SETTRIGATTRIBUTEDOUBLEARRAYREQUEST._serialized_start=109736
  _SETTRIGATTRIBUTEDOUBLEARRAYREQUEST._serialized_end=109932
  _SETTRIGATTRIBUTEDOUBLEARRAYRESPONSE._serialized_start=109934
  _SETTRIGATTRIBUTEDOUBLEARRAYRESPONSE._serialized_end=109987
  _SETTRIGATTRIBUTEINT32REQUEST._serialized_start=109990
  _SETTRIGATTRIBUTEINT32REQUEST._serialized_end=110254
  _SETTRIGATTRIBUTEINT32RESPONSE._serialized_start=110256
  _SETTRIGATTRIBUTEINT32RESPONSE._serialized_end=110303
  _SETTRIGATTRIBUTEINT32ARRAYREQUEST._serialized_start=110306
  _SETTRIGATTRIBUTEINT32ARRAYREQUEST._serialized_end=110500
  _SETTRIGATTRIBUTEINT32ARRAYRESPONSE._serialized_start=110502
  _SETTRIGATTRIBUTEINT32ARRAYRESPONSE._serialized_end=110554
  _SETTRIGATTRIBUTESTRINGREQUEST._serialized_start=110557
  _SETTRIGATTRIBUTESTRINGREQUEST._serialized_end=110743
  _SETTRIGATTRIBUTESTRINGRESPONSE._serialized_start=110745
  _SETTRIGATTRIBUTESTRINGRESPONSE._serialized_end=110793
  _SETTRIGATTRIBUTETIMESTAMPREQUEST._serialized_start=110796
  _SETTRIGATTRIBUTETIMESTAMPREQUEST._serialized_end=111016
  _SETTRIGATTRIBUTETIMESTAMPRESPONSE._serialized_start=111018
  _SETTRIGATTRIBUTETIMESTAMPRESPONSE._serialized_end=111069
  _SETTRIGATTRIBUTEUINT32REQUEST._serialized_start=111072
  _SETTRIGATTRIBUTEUINT32REQUEST._serialized_end=111258
  _SETTRIGATTRIBUTEUINT32RESPONSE._serialized_start=111260
  _SETTRIGATTRIBUTEUINT32RESPONSE._serialized_end=111308
  _SETWATCHDOGATTRIBUTEBOOLREQUEST._serialized_start=111311
  _SETWATCHDOGATTRIBUTEBOOLREQUEST._serialized_end=111513
  _SETWATCHDOGATTRIBUTEBOOLRESPONSE._serialized_start=111515
  _SETWATCHDOGATTRIBUTEBOOLRESPONSE._serialized_end=111565
  _SETWATCHDOGATTRIBUTEDOUBLEREQUEST._serialized_start=111568
  _SETWATCHDOGATTRIBUTEDOUBLEREQUEST._serialized_end=111774
  _SETWATCHDOGATTRIBUTEDOUBLERESPONSE._serialized_start=111776
  _SETWATCHDOGATTRIBUTEDOUBLERESPONSE._serialized_end=111828
  _SETWATCHDOGATTRIBUTEINT32REQUEST._serialized_start=111831
  _SETWATCHDOGATTRIBUTEINT32REQUEST._serialized_end=112116
  _SETWATCHDOGATTRIBUTEINT32RESPONSE._serialized_start=112118
  _SETWATCHDOGATTRIBUTEINT32RESPONSE._serialized_end=112169
  _SETWATCHDOGATTRIBUTESTRINGREQUEST._serialized_start=112172
  _SETWATCHDOGATTRIBUTESTRINGREQUEST._serialized_end=112378
  _SETWATCHDOGATTRIBUTESTRINGRESPONSE._serialized_start=112380
  _SETWATCHDOGATTRIBUTESTRINGRESPONSE._serialized_end=112432
  _SETWRITEATTRIBUTEBOOLREQUEST._serialized_start=112435
  _SETWRITEATTRIBUTEBOOLREQUEST._serialized_end=112616
  _SETWRITEATTRIBUTEBOOLRESPONSE._serialized_start=112618
  _SETWRITEATTRIBUTEBOOLRESPONSE._serialized_end=112665
  _SETWRITEATTRIBUTEDOUBLEREQUEST._serialized_start=112668
  _SETWRITEATTRIBUTEDOUBLEREQUEST._serialized_end=112853
  _SETWRITEATTRIBUTEDOUBLERESPONSE._serialized_start=112855
  _SETWRITEATTRIBUTEDOUBLERESPONSE._serialized_end=112904
  _SETWRITEATTRIBUTEINT32REQUEST._serialized_start=112907
  _SETWRITEATTRIBUTEINT32REQUEST._serialized_end=113168
  _SETWRITEATTRIBUTEINT32RESPONSE._serialized_start=113170
  _SETWRITEATTRIBUTEINT32RESPONSE._serialized_end=113218
  _SETWRITEATTRIBUTESTRINGREQUEST._serialized_start=113221
  _SETWRITEATTRIBUTESTRINGREQUEST._serialized_end=113406
  _SETWRITEATTRIBUTESTRINGRESPONSE._serialized_start=113408
  _SETWRITEATTRIBUTESTRINGRESPONSE._serialized_end=113457
  _SETWRITEATTRIBUTEUINT32REQUEST._serialized_start=113460
  _SETWRITEATTRIBUTEUINT32REQUEST._serialized_end=113645
  _SETWRITEATTRIBUTEUINT32RESPONSE._serialized_start=113647
  _SETWRITEATTRIBUTEUINT32RESPONSE._serialized_end=113696
  _SETWRITEATTRIBUTEUINT64REQUEST._serialized_start=113699
  _SETWRITEATTRIBUTEUINT64REQUEST._serialized_end=113884
  _SETWRITEATTRIBUTEUINT64RESPONSE._serialized_start=113886
  _SETWRITEATTRIBUTEUINT64RESPONSE._serialized_end=113935
  _STARTNEWFILEREQUEST._serialized_start=113937
  _STARTNEWFILEREQUEST._serialized_end=114015
  _STARTNEWFILERESPONSE._serialized_start=114017
  _STARTNEWFILERESPONSE._serialized_end=114055
  _STARTTASKREQUEST._serialized_start=114057
  _STARTTASKREQUEST._serialized_end=114113
  _STARTTASKRESPONSE._serialized_start=114115
  _STARTTASKRESPONSE._serialized_end=114150
  _STOPTASKREQUEST._serialized_start=114152
  _STOPTASKREQUEST._serialized_end=114207
  _STOPTASKRESPONSE._serialized_start=114209
  _STOPTASKRESPONSE._serialized_end=114243
  _TASKCONTROLREQUEST._serialized_start=114246
  _TASKCONTROLREQUEST._serialized_end=114392
  _TASKCONTROLRESPONSE._serialized_start=114394
  _TASKCONTROLRESPONSE._serialized_end=114431
  _TRISTATEOUTPUTTERMREQUEST._serialized_start=114433
  _TRISTATEOUTPUTTERMREQUEST._serialized_end=114485
  _TRISTATEOUTPUTTERMRESPONSE._serialized_start=114487
  _TRISTATEOUTPUTTERMRESPONSE._serialized_end=114531
  _UNREGISTERDONEEVENTREQUEST._serialized_start=114533
  _UNREGISTERDONEEVENTREQUEST._serialized_end=114599
  _UNREGISTERDONEEVENTRESPONSE._serialized_start=114601
  _UNREGISTERDONEEVENTRESPONSE._serialized_end=114646
  _UNREGISTEREVERYNSAMPLESEVENTREQUEST._serialized_start=114649
  _UNREGISTEREVERYNSAMPLESEVENTREQUEST._serialized_end=114877
  _UNREGISTEREVERYNSAMPLESEVENTRESPONSE._serialized_start=114879
  _UNREGISTEREVERYNSAMPLESEVENTRESPONSE._serialized_end=114933
  _UNREGISTERSIGNALEVENTREQUEST._serialized_start=114936
  _UNREGISTERSIGNALEVENTREQUEST._serialized_end=115091
  _UNREGISTERSIGNALEVENTRESPONSE._serialized_start=115093
  _UNREGISTERSIGNALEVENTRESPONSE._serialized_end=115140
  _UNRESERVENETWORKDEVICEREQUEST._serialized_start=115142
  _UNRESERVENETWORKDEVICEREQUEST._serialized_end=115194
  _UNRESERVENETWORKDEVICERESPONSE._serialized_start=115196
  _UNRESERVENETWORKDEVICERESPONSE._serialized_end=115244
  _WAITFORNEXTSAMPLECLOCKREQUEST._serialized_start=115246
  _WAITFORNEXTSAMPLECLOCKREQUEST._serialized_end=115332
  _WAITFORNEXTSAMPLECLOCKRESPONSE._serialized_start=115334
  _WAITFORNEXTSAMPLECLOCKRESPONSE._serialized_end=115399
  _WAITFORVALIDTIMESTAMPREQUEST._serialized_start=115402
  _WAITFORVALIDTIMESTAMPREQUEST._serialized_end=115599
  _WAITFORVALIDTIMESTAMPRESPONSE._serialized_start=115601
  _WAITFORVALIDTIMESTAMPRESPONSE._serialized_end=115695
  _WAITUNTILTASKDONEREQUEST._serialized_start=115697
  _WAITUNTILTASKDONEREQUEST._serialized_end=115783
  _WAITUNTILTASKDONERESPONSE._serialized_start=115785
  _WAITUNTILTASKDONERESPONSE._serialized_end=115828
  _WRITEANALOGF64REQUEST._serialized_start=115831
  _WRITEANALOGF64REQUEST._serialized_end=116071
  _WRITEANALOGF64RESPONSE._serialized_start=116073
  _WRITEANALOGF64RESPONSE._serialized_end=116145
  _WRITEANALOGSCALARF64REQUEST._serialized_start=116147
  _WRITEANALOGSCALARF64REQUEST._serialized_end=116266
  _WRITEANALOGSCALARF64RESPONSE._serialized_start=116268
  _WRITEANALOGSCALARF64RESPONSE._serialized_end=116314
  _WRITEBINARYI16REQUEST._serialized_start=116317
  _WRITEBINARYI16REQUEST._serialized_end=116557
  _WRITEBINARYI16RESPONSE._serialized_start=116559
  _WRITEBINARYI16RESPONSE._serialized_end=116631
  _WRITEBINARYI32REQUEST._serialized_start=116634
  _WRITEBINARYI32REQUEST._serialized_end=116874
  _WRITEBINARYI32RESPONSE._serialized_start=116876
  _WRITEBINARYI32RESPONSE._serialized_end=116948
  _WRITEBINARYU16REQUEST._serialized_start=116951
  _WRITEBINARYU16REQUEST._serialized_end=117191
  _WRITEBINARYU16RESPONSE._serialized_start=117193
  _WRITEBINARYU16RESPONSE._serialized_end=117265
  _WRITEBINARYU32REQUEST._serialized_start=117268
  _WRITEBINARYU32REQUEST._serialized_end=117508
  _WRITEBINARYU32RESPONSE._serialized_start=117510
  _WRITEBINARYU32RESPONSE._serialized_end=117582
  _WRITECTRFREQREQUEST._serialized_start=117585
  _WRITECTRFREQREQUEST._serialized_end=117841
  _WRITECTRFREQRESPONSE._serialized_start=117843
  _WRITECTRFREQRESPONSE._serialized_end=117917
  _WRITECTRFREQSCALARREQUEST._serialized_start=117920
  _WRITECTRFREQSCALARREQUEST._serialized_end=118061
  _WRITECTRFREQSCALARRESPONSE._serialized_start=118063
  _WRITECTRFREQSCALARRESPONSE._serialized_end=118107
  _WRITECTRTICKSREQUEST._serialized_start=118110
  _WRITECTRTICKSREQUEST._serialized_end=118367
  _WRITECTRTICKSRESPONSE._serialized_start=118369
  _WRITECTRTICKSRESPONSE._serialized_end=118444
  _WRITECTRTICKSSCALARREQUEST._serialized_start=118447
  _WRITECTRTICKSSCALARREQUEST._serialized_end=118589
  _WRITECTRTICKSSCALARRESPONSE._serialized_start=118591
  _WRITECTRTICKSSCALARRESPONSE._serialized_end=118636
  _WRITECTRTIMEREQUEST._serialized_start=118639
  _WRITECTRTIMEREQUEST._serialized_end=118893
  _WRITECTRTIMERESPONSE._serialized_start=118895
  _WRITECTRTIMERESPONSE._serialized_end=118969
  _WRITECTRTIMESCALARREQUEST._serialized_start=118972
  _WRITECTRTIMESCALARREQUEST._serialized_end=119111
  _WRITECTRTIMESCALARRESPONSE._serialized_start=119113
  _WRITECTRTIMESCALARRESPONSE._serialized_end=119157
  _WRITEDIGITALLINESREQUEST._serialized_start=119160
  _WRITEDIGITALLINESREQUEST._serialized_end=119403
  _WRITEDIGITALLINESRESPONSE._serialized_start=119405
  _WRITEDIGITALLINESRESPONSE._serialized_end=119480
  _WRITEDIGITALSCALARU32REQUEST._serialized_start=119482
  _WRITEDIGITALSCALARU32REQUEST._serialized_end=119602
  _WRITEDIGITALSCALARU32RESPONSE._serialized_start=119604
  _WRITEDIGITALSCALARU32RESPONSE._serialized_end=119651
  _WRITEDIGITALU16REQUEST._serialized_start=119654
  _WRITEDIGITALU16REQUEST._serialized_end=119895
  _WRITEDIGITALU16RESPONSE._serialized_start=119897
  _WRITEDIGITALU16RESPONSE._serialized_end=119970
  _WRITEDIGITALU32REQUEST._serialized_start=119973
  _WRITEDIGITALU32REQUEST._serialized_end=120214
  _WRITEDIGITALU32RESPONSE._serialized_start=120216
  _WRITEDIGITALU32RESPONSE._serialized_end=120289
  _WRITEDIGITALU8REQUEST._serialized_start=120292
  _WRITEDIGITALU8REQUEST._serialized_end=120532
  _WRITEDIGITALU8RESPONSE._serialized_start=120534
  _WRITEDIGITALU8RESPONSE._serialized_end=120606
  _WRITERAWREQUEST._serialized_start=120609
  _WRITERAWREQUEST._serialized_end=120741
  _WRITERAWRESPONSE._serialized_start=120743
  _WRITERAWRESPONSE._serialized_end=120809
  _WRITETOTEDSFROMARRAYREQUEST._serialized_start=120812
  _WRITETOTEDSFROMARRAYREQUEST._serialized_end=121015
  _WRITETOTEDSFROMARRAYRESPONSE._serialized_start=121017
  _WRITETOTEDSFROMARRAYRESPONSE._serialized_end=121063
  _WRITETOTEDSFROMFILEREQUEST._serialized_start=121066
  _WRITETOTEDSFROMFILEREQUEST._serialized_end=121267
  _WRITETOTEDSFROMFILERESPONSE._serialized_start=121269
  _WRITETOTEDSFROMFILERESPONSE._serialized_end=121314
  _NIDAQMX._serialized_start=292268
  _NIDAQMX._serialized_end=339021
# @@protoc_insertion_point(module_scope)
