"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
---------------------------------------------------------------------
This file is generated from NI-DAQMX API metadata version 23.0.0
---------------------------------------------------------------------
Proto file for the NI-DAQMX Metadata
---------------------------------------------------------------------
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
from nidaqmx._stubs import session_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BufferUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BufferUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BufferUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BUFFER_UINT32_ATTRIBUTE_UNSPECIFIED: _BufferUInt32Attribute.ValueType  # 0
    BUFFER_ATTRIBUTE_INPUT_BUF_SIZE: _BufferUInt32Attribute.ValueType  # 6252
    BUFFER_ATTRIBUTE_OUTPUT_BUF_SIZE: _BufferUInt32Attribute.ValueType  # 6253
    BUFFER_ATTRIBUTE_INPUT_ONBRD_BUF_SIZE: _BufferUInt32Attribute.ValueType  # 8970
    BUFFER_ATTRIBUTE_OUTPUT_ONBRD_BUF_SIZE: _BufferUInt32Attribute.ValueType  # 8971

class BufferUInt32Attribute(_BufferUInt32Attribute, metaclass=_BufferUInt32AttributeEnumTypeWrapper): ...

BUFFER_UINT32_ATTRIBUTE_UNSPECIFIED: BufferUInt32Attribute.ValueType  # 0
BUFFER_ATTRIBUTE_INPUT_BUF_SIZE: BufferUInt32Attribute.ValueType  # 6252
BUFFER_ATTRIBUTE_OUTPUT_BUF_SIZE: BufferUInt32Attribute.ValueType  # 6253
BUFFER_ATTRIBUTE_INPUT_ONBRD_BUF_SIZE: BufferUInt32Attribute.ValueType  # 8970
BUFFER_ATTRIBUTE_OUTPUT_ONBRD_BUF_SIZE: BufferUInt32Attribute.ValueType  # 8971
global___BufferUInt32Attribute = BufferUInt32Attribute

class _BufferResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BufferResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BufferResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BUFFER_RESET_ATTRIBUTE_UNSPECIFIED: _BufferResetAttribute.ValueType  # 0
    BUFFER_RESET_ATTRIBUTE_INPUT_BUF_SIZE: _BufferResetAttribute.ValueType  # 6252
    BUFFER_RESET_ATTRIBUTE_OUTPUT_BUF_SIZE: _BufferResetAttribute.ValueType  # 6253
    BUFFER_RESET_ATTRIBUTE_OUTPUT_ONBRD_BUF_SIZE: _BufferResetAttribute.ValueType  # 8971

class BufferResetAttribute(_BufferResetAttribute, metaclass=_BufferResetAttributeEnumTypeWrapper): ...

BUFFER_RESET_ATTRIBUTE_UNSPECIFIED: BufferResetAttribute.ValueType  # 0
BUFFER_RESET_ATTRIBUTE_INPUT_BUF_SIZE: BufferResetAttribute.ValueType  # 6252
BUFFER_RESET_ATTRIBUTE_OUTPUT_BUF_SIZE: BufferResetAttribute.ValueType  # 6253
BUFFER_RESET_ATTRIBUTE_OUTPUT_ONBRD_BUF_SIZE: BufferResetAttribute.ValueType  # 8971
global___BufferResetAttribute = BufferResetAttribute

class _CalibrationInfoBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CalibrationInfoBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CalibrationInfoBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CALIBRATIONINFO_BOOL_ATTRIBUTE_UNSPECIFIED: _CalibrationInfoBoolAttribute.ValueType  # 0
    CALIBRATIONINFO_ATTRIBUTE_SELF_CAL_SUPPORTED: _CalibrationInfoBoolAttribute.ValueType  # 6240

class CalibrationInfoBoolAttribute(_CalibrationInfoBoolAttribute, metaclass=_CalibrationInfoBoolAttributeEnumTypeWrapper): ...

CALIBRATIONINFO_BOOL_ATTRIBUTE_UNSPECIFIED: CalibrationInfoBoolAttribute.ValueType  # 0
CALIBRATIONINFO_ATTRIBUTE_SELF_CAL_SUPPORTED: CalibrationInfoBoolAttribute.ValueType  # 6240
global___CalibrationInfoBoolAttribute = CalibrationInfoBoolAttribute

class _CalibrationInfoStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CalibrationInfoStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CalibrationInfoStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CALIBRATIONINFO_STRING_ATTRIBUTE_UNSPECIFIED: _CalibrationInfoStringAttribute.ValueType  # 0
    CALIBRATIONINFO_ATTRIBUTE_CAL_USER_DEFINED_INFO: _CalibrationInfoStringAttribute.ValueType  # 6241

class CalibrationInfoStringAttribute(_CalibrationInfoStringAttribute, metaclass=_CalibrationInfoStringAttributeEnumTypeWrapper): ...

CALIBRATIONINFO_STRING_ATTRIBUTE_UNSPECIFIED: CalibrationInfoStringAttribute.ValueType  # 0
CALIBRATIONINFO_ATTRIBUTE_CAL_USER_DEFINED_INFO: CalibrationInfoStringAttribute.ValueType  # 6241
global___CalibrationInfoStringAttribute = CalibrationInfoStringAttribute

class _CalibrationInfoDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CalibrationInfoDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CalibrationInfoDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CALIBRATIONINFO_DOUBLE_ATTRIBUTE_UNSPECIFIED: _CalibrationInfoDoubleAttribute.ValueType  # 0
    CALIBRATIONINFO_ATTRIBUTE_SELF_CAL_LAST_TEMP: _CalibrationInfoDoubleAttribute.ValueType  # 6244
    CALIBRATIONINFO_ATTRIBUTE_EXT_CAL_LAST_TEMP: _CalibrationInfoDoubleAttribute.ValueType  # 6247
    CALIBRATIONINFO_ATTRIBUTE_CAL_DEV_TEMP: _CalibrationInfoDoubleAttribute.ValueType  # 8763

class CalibrationInfoDoubleAttribute(_CalibrationInfoDoubleAttribute, metaclass=_CalibrationInfoDoubleAttributeEnumTypeWrapper): ...

CALIBRATIONINFO_DOUBLE_ATTRIBUTE_UNSPECIFIED: CalibrationInfoDoubleAttribute.ValueType  # 0
CALIBRATIONINFO_ATTRIBUTE_SELF_CAL_LAST_TEMP: CalibrationInfoDoubleAttribute.ValueType  # 6244
CALIBRATIONINFO_ATTRIBUTE_EXT_CAL_LAST_TEMP: CalibrationInfoDoubleAttribute.ValueType  # 6247
CALIBRATIONINFO_ATTRIBUTE_CAL_DEV_TEMP: CalibrationInfoDoubleAttribute.ValueType  # 8763
global___CalibrationInfoDoubleAttribute = CalibrationInfoDoubleAttribute

class _CalibrationInfoUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CalibrationInfoUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CalibrationInfoUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CALIBRATIONINFO_UINT32_ATTRIBUTE_UNSPECIFIED: _CalibrationInfoUInt32Attribute.ValueType  # 0
    CALIBRATIONINFO_ATTRIBUTE_EXT_CAL_RECOMMENDED_INTERVAL: _CalibrationInfoUInt32Attribute.ValueType  # 6248
    CALIBRATIONINFO_ATTRIBUTE_CAL_USER_DEFINED_INFO_MAX_SIZE: _CalibrationInfoUInt32Attribute.ValueType  # 6428
    CALIBRATIONINFO_ATTRIBUTE_CAL_ACC_CONNECTION_COUNT: _CalibrationInfoUInt32Attribute.ValueType  # 12267
    CALIBRATIONINFO_ATTRIBUTE_CAL_RECOMMENDED_ACC_CONNECTION_COUNT_LIMIT: _CalibrationInfoUInt32Attribute.ValueType  # 12268

class CalibrationInfoUInt32Attribute(_CalibrationInfoUInt32Attribute, metaclass=_CalibrationInfoUInt32AttributeEnumTypeWrapper): ...

CALIBRATIONINFO_UINT32_ATTRIBUTE_UNSPECIFIED: CalibrationInfoUInt32Attribute.ValueType  # 0
CALIBRATIONINFO_ATTRIBUTE_EXT_CAL_RECOMMENDED_INTERVAL: CalibrationInfoUInt32Attribute.ValueType  # 6248
CALIBRATIONINFO_ATTRIBUTE_CAL_USER_DEFINED_INFO_MAX_SIZE: CalibrationInfoUInt32Attribute.ValueType  # 6428
CALIBRATIONINFO_ATTRIBUTE_CAL_ACC_CONNECTION_COUNT: CalibrationInfoUInt32Attribute.ValueType  # 12267
CALIBRATIONINFO_ATTRIBUTE_CAL_RECOMMENDED_ACC_CONNECTION_COUNT_LIMIT: CalibrationInfoUInt32Attribute.ValueType  # 12268
global___CalibrationInfoUInt32Attribute = CalibrationInfoUInt32Attribute

class _ChannelInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChannelInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_INT32_ATTRIBUTE_UNSPECIFIED: _ChannelInt32Attribute.ValueType  # 0
    CHANNEL_ATTRIBUTE_AI_RAW_SAMP_JUSTIFICATION: _ChannelInt32Attribute.ValueType  # 80
    CHANNEL_ATTRIBUTE_AI_COUPLING: _ChannelInt32Attribute.ValueType  # 100
    CHANNEL_ATTRIBUTE_AI_BRIDGE_CFG: _ChannelInt32Attribute.ValueType  # 135
    CHANNEL_ATTRIBUTE_AO_DAC_REF_SRC: _ChannelInt32Attribute.ValueType  # 306
    CHANNEL_ATTRIBUTE_AO_DATA_XFER_MECH: _ChannelInt32Attribute.ValueType  # 308
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_ACTIVE_EDGE: _ChannelInt32Attribute.ValueType  # 322
    CHANNEL_ATTRIBUTE_CI_FREQ_MEAS_METH: _ChannelInt32Attribute.ValueType  # 324
    CHANNEL_ATTRIBUTE_CI_OUTPUT_STATE: _ChannelInt32Attribute.ValueType  # 329
    CHANNEL_ATTRIBUTE_CI_DATA_XFER_MECH: _ChannelInt32Attribute.ValueType  # 512
    CHANNEL_ATTRIBUTE_CO_OUTPUT_STATE: _ChannelInt32Attribute.ValueType  # 660
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_ACTIVE_EDGE: _ChannelInt32Attribute.ValueType  # 833
    CHANNEL_ATTRIBUTE_AI_ACCEL_UNITS: _ChannelInt32Attribute.ValueType  # 1651
    CHANNEL_ATTRIBUTE_AI_MEAS_TYPE: _ChannelInt32Attribute.ValueType  # 1685
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIR: _ChannelInt32Attribute.ValueType  # 1686
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_ACTIVE_EDGE: _ChannelInt32Attribute.ValueType  # 1687
    CHANNEL_ATTRIBUTE_AI_CURRENT_UNITS: _ChannelInt32Attribute.ValueType  # 1793
    CHANNEL_ATTRIBUTE_CI_FREQ_STARTING_EDGE: _ChannelInt32Attribute.ValueType  # 1945
    CHANNEL_ATTRIBUTE_AI_FREQ_UNITS: _ChannelInt32Attribute.ValueType  # 2054
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_UNITS: _ChannelInt32Attribute.ValueType  # 2083
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_STARTING_EDGE: _ChannelInt32Attribute.ValueType  # 2085
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_EDGE: _ChannelInt32Attribute.ValueType  # 2099
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_EDGE: _ChannelInt32Attribute.ValueType  # 2100
    CHANNEL_ATTRIBUTE_CI_PERIOD_STARTING_EDGE: _ChannelInt32Attribute.ValueType  # 2130
    CHANNEL_ATTRIBUTE_AI_RVDT_UNITS: _ChannelInt32Attribute.ValueType  # 2167
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_PHASE: _ChannelInt32Attribute.ValueType  # 2185
    CHANNEL_ATTRIBUTE_AI_LVDT_UNITS: _ChannelInt32Attribute.ValueType  # 2320
    CHANNEL_ATTRIBUTE_AI_RESISTANCE_UNITS: _ChannelInt32Attribute.ValueType  # 2389
    CHANNEL_ATTRIBUTE_AI_STRAIN_UNITS: _ChannelInt32Attribute.ValueType  # 2433
    CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_CFG: _ChannelInt32Attribute.ValueType  # 2434
    CHANNEL_ATTRIBUTE_AI_RTD_TYPE: _ChannelInt32Attribute.ValueType  # 4146
    CHANNEL_ATTRIBUTE_AI_TEMP_UNITS: _ChannelInt32Attribute.ValueType  # 4147
    CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_SRC: _ChannelInt32Attribute.ValueType  # 4149
    CHANNEL_ATTRIBUTE_AI_THRMCPL_TYPE: _ChannelInt32Attribute.ValueType  # 4176
    CHANNEL_ATTRIBUTE_CI_GPS_SYNC_METHOD: _ChannelInt32Attribute.ValueType  # 4242
    CHANNEL_ATTRIBUTE_AI_VOLTAGE_UNITS: _ChannelInt32Attribute.ValueType  # 4244
    CHANNEL_ATTRIBUTE_AI_TERM_CFG: _ChannelInt32Attribute.ValueType  # 4247
    CHANNEL_ATTRIBUTE_AO_OUTPUT_TYPE: _ChannelInt32Attribute.ValueType  # 4360
    CHANNEL_ATTRIBUTE_AO_CURRENT_UNITS: _ChannelInt32Attribute.ValueType  # 4361
    CHANNEL_ATTRIBUTE_DO_OUTPUT_DRIVE_TYPE: _ChannelInt32Attribute.ValueType  # 4407
    CHANNEL_ATTRIBUTE_CO_PULSE_IDLE_STATE: _ChannelInt32Attribute.ValueType  # 4464
    CHANNEL_ATTRIBUTE_AO_VOLTAGE_UNITS: _ChannelInt32Attribute.ValueType  # 4484
    CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_UNITS: _ChannelInt32Attribute.ValueType  # 5416
    CHANNEL_ATTRIBUTE_AI_AUTO_ZERO_MODE: _ChannelInt32Attribute.ValueType  # 5984
    CHANNEL_ATTRIBUTE_AI_RESOLUTION_UNITS: _ChannelInt32Attribute.ValueType  # 5988
    CHANNEL_ATTRIBUTE_AI_VOLTAGE_ACRMS_UNITS: _ChannelInt32Attribute.ValueType  # 6114
    CHANNEL_ATTRIBUTE_AI_CURRENT_ACRMS_UNITS: _ChannelInt32Attribute.ValueType  # 6115
    CHANNEL_ATTRIBUTE_AI_BRIDGE_BALANCE_COARSE_POT: _ChannelInt32Attribute.ValueType  # 6129
    CHANNEL_ATTRIBUTE_AI_CURRENT_SHUNT_LOC: _ChannelInt32Attribute.ValueType  # 6130
    CHANNEL_ATTRIBUTE_AI_EXCIT_SRC: _ChannelInt32Attribute.ValueType  # 6132
    CHANNEL_ATTRIBUTE_AI_EXCIT_VOLTAGE_OR_CURRENT: _ChannelInt32Attribute.ValueType  # 6134
    CHANNEL_ATTRIBUTE_AI_EXCIT_D_COR_AC: _ChannelInt32Attribute.ValueType  # 6139
    CHANNEL_ATTRIBUTE_AI_HIGHPASS_TYPE: _ChannelInt32Attribute.ValueType  # 6152
    CHANNEL_ATTRIBUTE_AI_BANDPASS_TYPE: _ChannelInt32Attribute.ValueType  # 6157
    CHANNEL_ATTRIBUTE_AI_NOTCH_TYPE: _ChannelInt32Attribute.ValueType  # 6161
    CHANNEL_ATTRIBUTE_AI_DATA_XFER_MECH: _ChannelInt32Attribute.ValueType  # 6177
    CHANNEL_ATTRIBUTE_AO_RESOLUTION_UNITS: _ChannelInt32Attribute.ValueType  # 6187
    CHANNEL_ATTRIBUTE_AO_DATA_XFER_REQ_COND: _ChannelInt32Attribute.ValueType  # 6204
    CHANNEL_ATTRIBUTE_CHAN_TYPE: _ChannelInt32Attribute.ValueType  # 6271
    CHANNEL_ATTRIBUTE_AI_RESISTANCE_CFG: _ChannelInt32Attribute.ValueType  # 6273
    CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_CLK_SRC: _ChannelInt32Attribute.ValueType  # 6276
    CHANNEL_ATTRIBUTE_AI_DATA_XFER_REQ_COND: _ChannelInt32Attribute.ValueType  # 6283
    CHANNEL_ATTRIBUTE_AO_TERM_CFG: _ChannelInt32Attribute.ValueType  # 6286
    CHANNEL_ATTRIBUTE_CI_MEAS_TYPE: _ChannelInt32Attribute.ValueType  # 6304
    CHANNEL_ATTRIBUTE_CI_FREQ_UNITS: _ChannelInt32Attribute.ValueType  # 6305
    CHANNEL_ATTRIBUTE_CI_PERIOD_UNITS: _ChannelInt32Attribute.ValueType  # 6307
    CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_UNITS: _ChannelInt32Attribute.ValueType  # 6310
    CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_UNITS: _ChannelInt32Attribute.ValueType  # 6313
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_UNITS: _ChannelInt32Attribute.ValueType  # 6316
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_UNITS: _ChannelInt32Attribute.ValueType  # 6319
    CHANNEL_ATTRIBUTE_CO_OUTPUT_TYPE: _ChannelInt32Attribute.ValueType  # 6325
    CHANNEL_ATTRIBUTE_AI_AC_EXCIT_WIRE_MODE: _ChannelInt32Attribute.ValueType  # 6349
    CHANNEL_ATTRIBUTE_CO_PULSE_FREQ_UNITS: _ChannelInt32Attribute.ValueType  # 6357
    CHANNEL_ATTRIBUTE_CO_PULSE_TIME_UNITS: _ChannelInt32Attribute.ValueType  # 6358
    CHANNEL_ATTRIBUTE_AI_BRIDGE_BALANCE_FINE_POT: _ChannelInt32Attribute.ValueType  # 6388
    CHANNEL_ATTRIBUTE_CI_PERIOD_MEAS_METH: _ChannelInt32Attribute.ValueType  # 6444
    CHANNEL_ATTRIBUTE_AI_LVDT_SENSITIVITY_UNITS: _ChannelInt32Attribute.ValueType  # 8602
    CHANNEL_ATTRIBUTE_AI_RVDT_SENSITIVITY_UNITS: _ChannelInt32Attribute.ValueType  # 8603
    CHANNEL_ATTRIBUTE_AI_ACCEL_SENSITIVITY_UNITS: _ChannelInt32Attribute.ValueType  # 8604
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SELECT: _ChannelInt32Attribute.ValueType  # 8661
    CHANNEL_ATTRIBUTE_CI_ENCODER_DECODING_TYPE: _ChannelInt32Attribute.ValueType  # 8678
    CHANNEL_ATTRIBUTE_AO_IDLE_OUTPUT_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 8768
    CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_SRC: _ChannelInt32Attribute.ValueType  # 8787
    CHANNEL_ATTRIBUTE_DI_DATA_XFER_MECH: _ChannelInt32Attribute.ValueType  # 8803
    CHANNEL_ATTRIBUTE_DI_DATA_XFER_REQ_COND: _ChannelInt32Attribute.ValueType  # 8804
    CHANNEL_ATTRIBUTE_DO_DATA_XFER_MECH: _ChannelInt32Attribute.ValueType  # 8806
    CHANNEL_ATTRIBUTE_DO_DATA_XFER_REQ_COND: _ChannelInt32Attribute.ValueType  # 8807
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_SCALE_TYPE: _ChannelInt32Attribute.ValueType  # 8860
    CHANNEL_ATTRIBUTE_CI_TIMESTAMP_UNITS: _ChannelInt32Attribute.ValueType  # 8883
    CHANNEL_ATTRIBUTE_AI_RAW_DATA_COMPRESSION_TYPE: _ChannelInt32Attribute.ValueType  # 8920
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_STARTING_EDGE: _ChannelInt32Attribute.ValueType  # 8958
    CHANNEL_ATTRIBUTE_DI_ACQUIRE_ON: _ChannelInt32Attribute.ValueType  # 10598
    CHANNEL_ATTRIBUTE_DO_LINE_STATES_PAUSED_STATE: _ChannelInt32Attribute.ValueType  # 10599
    CHANNEL_ATTRIBUTE_DO_LINE_STATES_DONE_STATE: _ChannelInt32Attribute.ValueType  # 10600
    CHANNEL_ATTRIBUTE_DO_GENERATE_ON: _ChannelInt32Attribute.ValueType  # 10601
    CHANNEL_ATTRIBUTE_DI_LOGIC_FAMILY: _ChannelInt32Attribute.ValueType  # 10605
    CHANNEL_ATTRIBUTE_DO_LOGIC_FAMILY: _ChannelInt32Attribute.ValueType  # 10606
    CHANNEL_ATTRIBUTE_DO_LINE_STATES_START_STATE: _ChannelInt32Attribute.ValueType  # 10610
    CHANNEL_ATTRIBUTE_AI_THRMCPL_SCALE_TYPE: _ChannelInt32Attribute.ValueType  # 10704
    CHANNEL_ATTRIBUTE_CO_CONSTRAINED_GEN_MODE: _ChannelInt32Attribute.ValueType  # 10738
    CHANNEL_ATTRIBUTE_AI_ADC_TIMING_MODE: _ChannelInt32Attribute.ValueType  # 10745
    CHANNEL_ATTRIBUTE_AO_FUNC_GEN_TYPE: _ChannelInt32Attribute.ValueType  # 10776
    CHANNEL_ATTRIBUTE_AO_FUNC_GEN_MODULATION_TYPE: _ChannelInt32Attribute.ValueType  # 10786
    CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS: _ChannelInt32Attribute.ValueType  # 10943
    CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_UNITS: _ChannelInt32Attribute.ValueType  # 10944
    CHANNEL_ATTRIBUTE_CO_DATA_XFER_MECH: _ChannelInt32Attribute.ValueType  # 11980
    CHANNEL_ATTRIBUTE_CO_DATA_XFER_REQ_COND: _ChannelInt32Attribute.ValueType  # 11981
    CHANNEL_ATTRIBUTE_CI_DATA_XFER_REQ_COND: _ChannelInt32Attribute.ValueType  # 12027
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_START_EDGE: _ChannelInt32Attribute.ValueType  # 12037
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_UNITS: _ChannelInt32Attribute.ValueType  # 12043
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_START_EDGE: _ChannelInt32Attribute.ValueType  # 12045
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_UNITS: _ChannelInt32Attribute.ValueType  # 12051
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_START_EDGE: _ChannelInt32Attribute.ValueType  # 12053
    CHANNEL_ATTRIBUTE_AI_FORCE_UNITS: _ChannelInt32Attribute.ValueType  # 12149
    CHANNEL_ATTRIBUTE_AI_PRESSURE_UNITS: _ChannelInt32Attribute.ValueType  # 12150
    CHANNEL_ATTRIBUTE_AI_TORQUE_UNITS: _ChannelInt32Attribute.ValueType  # 12151
    CHANNEL_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS: _ChannelInt32Attribute.ValueType  # 12162
    CHANNEL_ATTRIBUTE_AI_BRIDGE_ELECTRICAL_UNITS: _ChannelInt32Attribute.ValueType  # 12167
    CHANNEL_ATTRIBUTE_AI_BRIDGE_PHYSICAL_UNITS: _ChannelInt32Attribute.ValueType  # 12168
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SCALE_TYPE: _ChannelInt32Attribute.ValueType  # 12169
    CHANNEL_ATTRIBUTE_AI_BRIDGE_UNITS: _ChannelInt32Attribute.ValueType  # 12178
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ACTIVE_EDGE: _ChannelInt32Attribute.ValueType  # 12210
    CHANNEL_ATTRIBUTE_AI_VELOCITY_UNITS: _ChannelInt32Attribute.ValueType  # 12276
    CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS: _ChannelInt32Attribute.ValueType  # 12279
    CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_MEAS_TYPE: _ChannelInt32Attribute.ValueType  # 12285
    CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_TYPE: _ChannelInt32Attribute.ValueType  # 12286
    CHANNEL_ATTRIBUTE_CI_TIMESTAMP_EDGE: _ChannelInt32Attribute.ValueType  # 12346
    CHANNEL_ATTRIBUTE_CI_TIMESTAMP_TIMESCALE: _ChannelInt32Attribute.ValueType  # 12347
    CHANNEL_ATTRIBUTE_NAV_MEAS_TYPE: _ChannelInt32Attribute.ValueType  # 12349
    CHANNEL_ATTRIBUTE_NAV_ALT_UNITS: _ChannelInt32Attribute.ValueType  # 12350
    CHANNEL_ATTRIBUTE_NAV_LAT_UNITS: _ChannelInt32Attribute.ValueType  # 12351
    CHANNEL_ATTRIBUTE_NAV_LONG_UNITS: _ChannelInt32Attribute.ValueType  # 12352
    CHANNEL_ATTRIBUTE_NAV_SPEED_OVER_GROUND_UNITS: _ChannelInt32Attribute.ValueType  # 12353
    CHANNEL_ATTRIBUTE_NAV_TRACK_UNITS: _ChannelInt32Attribute.ValueType  # 12354
    CHANNEL_ATTRIBUTE_NAV_VERT_VELOCITY_UNITS: _ChannelInt32Attribute.ValueType  # 12355
    CHANNEL_ATTRIBUTE_NAV_TIMESTAMP_UNITS: _ChannelInt32Attribute.ValueType  # 12356
    CHANNEL_ATTRIBUTE_NAV_TIMESTAMP_TIMESCALE: _ChannelInt32Attribute.ValueType  # 12357
    CHANNEL_ATTRIBUTE_AI_FILTER_DELAY_UNITS: _ChannelInt32Attribute.ValueType  # 12401
    CHANNEL_ATTRIBUTE_AO_FILTER_DELAY_UNITS: _ChannelInt32Attribute.ValueType  # 12406
    CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_STARTING_EDGE: _ChannelInt32Attribute.ValueType  # 12434
    CHANNEL_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12435
    CHANNEL_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_SENTINEL_VAL: _ChannelInt32Attribute.ValueType  # 12436
    CHANNEL_ATTRIBUTE_CI_FREQ_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12439
    CHANNEL_ATTRIBUTE_CI_FREQ_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12440
    CHANNEL_ATTRIBUTE_CI_PERIOD_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12441
    CHANNEL_ATTRIBUTE_CI_PERIOD_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12442
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12443
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12444
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12445
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12446
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12447
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12448
    CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12449
    CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12450
    CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12451
    CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12452
    CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12453
    CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12454
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12455
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12456
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12457
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12458
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12459
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12460
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12461
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12462
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12463
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12464
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12465
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12466
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12467
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12468
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12469
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12470
    CHANNEL_ATTRIBUTE_AI_EXCIT_IDLE_OUTPUT_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12472
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_TYPE: _ChannelInt32Attribute.ValueType  # 12478
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_RESPONSE: _ChannelInt32Attribute.ValueType  # 12479
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_SRC: _ChannelInt32Attribute.ValueType  # 12490
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_UNITS: _ChannelInt32Attribute.ValueType  # 12504
    CHANNEL_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_UNITS: _ChannelInt32Attribute.ValueType  # 12506
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_DECODING_TYPE: _ChannelInt32Attribute.ValueType  # 12508
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12510
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12511
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12517
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12518
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM_CFG: _ChannelInt32Attribute.ValueType  # 12527
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_LOGIC_LVL_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12528
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_WHEN: _ChannelInt32Attribute.ValueType  # 12533
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_SRC: _ChannelInt32Attribute.ValueType  # 12535
    CHANNEL_ATTRIBUTE_AI_EXCIT_SENSE: _ChannelInt32Attribute.ValueType  # 12541
    CHANNEL_ATTRIBUTE_AI_CHARGE_UNITS: _ChannelInt32Attribute.ValueType  # 12562
    CHANNEL_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY_UNITS: _ChannelInt32Attribute.ValueType  # 12564
    CHANNEL_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY_UNITS: _ChannelInt32Attribute.ValueType  # 12566
    CHANNEL_ATTRIBUTE_CHAN_SYNC_UNLOCK_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12604
    CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_CFG: _ChannelInt32Attribute.ValueType  # 12650
    CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_TYPE: _ChannelInt32Attribute.ValueType  # 12651
    CHANNEL_ATTRIBUTE_AI_FILTER_RESPONSE: _ChannelInt32Attribute.ValueType  # 12661
    CHANNEL_ATTRIBUTE_CI_FILTER_RESPONSE: _ChannelInt32Attribute.ValueType  # 12729
    CHANNEL_ATTRIBUTE_CI_FILTER_DELAY_UNITS: _ChannelInt32Attribute.ValueType  # 12732
    CHANNEL_ATTRIBUTE_PWR_OUTPUT_STATE: _ChannelInt32Attribute.ValueType  # 12759
    CHANNEL_ATTRIBUTE_PWR_IDLE_OUTPUT_BEHAVIOR: _ChannelInt32Attribute.ValueType  # 12760
    CHANNEL_ATTRIBUTE_PWR_REMOTE_SENSE: _ChannelInt32Attribute.ValueType  # 12763

class ChannelInt32Attribute(_ChannelInt32Attribute, metaclass=_ChannelInt32AttributeEnumTypeWrapper): ...

CHANNEL_INT32_ATTRIBUTE_UNSPECIFIED: ChannelInt32Attribute.ValueType  # 0
CHANNEL_ATTRIBUTE_AI_RAW_SAMP_JUSTIFICATION: ChannelInt32Attribute.ValueType  # 80
CHANNEL_ATTRIBUTE_AI_COUPLING: ChannelInt32Attribute.ValueType  # 100
CHANNEL_ATTRIBUTE_AI_BRIDGE_CFG: ChannelInt32Attribute.ValueType  # 135
CHANNEL_ATTRIBUTE_AO_DAC_REF_SRC: ChannelInt32Attribute.ValueType  # 306
CHANNEL_ATTRIBUTE_AO_DATA_XFER_MECH: ChannelInt32Attribute.ValueType  # 308
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_ACTIVE_EDGE: ChannelInt32Attribute.ValueType  # 322
CHANNEL_ATTRIBUTE_CI_FREQ_MEAS_METH: ChannelInt32Attribute.ValueType  # 324
CHANNEL_ATTRIBUTE_CI_OUTPUT_STATE: ChannelInt32Attribute.ValueType  # 329
CHANNEL_ATTRIBUTE_CI_DATA_XFER_MECH: ChannelInt32Attribute.ValueType  # 512
CHANNEL_ATTRIBUTE_CO_OUTPUT_STATE: ChannelInt32Attribute.ValueType  # 660
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_ACTIVE_EDGE: ChannelInt32Attribute.ValueType  # 833
CHANNEL_ATTRIBUTE_AI_ACCEL_UNITS: ChannelInt32Attribute.ValueType  # 1651
CHANNEL_ATTRIBUTE_AI_MEAS_TYPE: ChannelInt32Attribute.ValueType  # 1685
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIR: ChannelInt32Attribute.ValueType  # 1686
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_ACTIVE_EDGE: ChannelInt32Attribute.ValueType  # 1687
CHANNEL_ATTRIBUTE_AI_CURRENT_UNITS: ChannelInt32Attribute.ValueType  # 1793
CHANNEL_ATTRIBUTE_CI_FREQ_STARTING_EDGE: ChannelInt32Attribute.ValueType  # 1945
CHANNEL_ATTRIBUTE_AI_FREQ_UNITS: ChannelInt32Attribute.ValueType  # 2054
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_UNITS: ChannelInt32Attribute.ValueType  # 2083
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_STARTING_EDGE: ChannelInt32Attribute.ValueType  # 2085
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_EDGE: ChannelInt32Attribute.ValueType  # 2099
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_EDGE: ChannelInt32Attribute.ValueType  # 2100
CHANNEL_ATTRIBUTE_CI_PERIOD_STARTING_EDGE: ChannelInt32Attribute.ValueType  # 2130
CHANNEL_ATTRIBUTE_AI_RVDT_UNITS: ChannelInt32Attribute.ValueType  # 2167
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_PHASE: ChannelInt32Attribute.ValueType  # 2185
CHANNEL_ATTRIBUTE_AI_LVDT_UNITS: ChannelInt32Attribute.ValueType  # 2320
CHANNEL_ATTRIBUTE_AI_RESISTANCE_UNITS: ChannelInt32Attribute.ValueType  # 2389
CHANNEL_ATTRIBUTE_AI_STRAIN_UNITS: ChannelInt32Attribute.ValueType  # 2433
CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_CFG: ChannelInt32Attribute.ValueType  # 2434
CHANNEL_ATTRIBUTE_AI_RTD_TYPE: ChannelInt32Attribute.ValueType  # 4146
CHANNEL_ATTRIBUTE_AI_TEMP_UNITS: ChannelInt32Attribute.ValueType  # 4147
CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_SRC: ChannelInt32Attribute.ValueType  # 4149
CHANNEL_ATTRIBUTE_AI_THRMCPL_TYPE: ChannelInt32Attribute.ValueType  # 4176
CHANNEL_ATTRIBUTE_CI_GPS_SYNC_METHOD: ChannelInt32Attribute.ValueType  # 4242
CHANNEL_ATTRIBUTE_AI_VOLTAGE_UNITS: ChannelInt32Attribute.ValueType  # 4244
CHANNEL_ATTRIBUTE_AI_TERM_CFG: ChannelInt32Attribute.ValueType  # 4247
CHANNEL_ATTRIBUTE_AO_OUTPUT_TYPE: ChannelInt32Attribute.ValueType  # 4360
CHANNEL_ATTRIBUTE_AO_CURRENT_UNITS: ChannelInt32Attribute.ValueType  # 4361
CHANNEL_ATTRIBUTE_DO_OUTPUT_DRIVE_TYPE: ChannelInt32Attribute.ValueType  # 4407
CHANNEL_ATTRIBUTE_CO_PULSE_IDLE_STATE: ChannelInt32Attribute.ValueType  # 4464
CHANNEL_ATTRIBUTE_AO_VOLTAGE_UNITS: ChannelInt32Attribute.ValueType  # 4484
CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_UNITS: ChannelInt32Attribute.ValueType  # 5416
CHANNEL_ATTRIBUTE_AI_AUTO_ZERO_MODE: ChannelInt32Attribute.ValueType  # 5984
CHANNEL_ATTRIBUTE_AI_RESOLUTION_UNITS: ChannelInt32Attribute.ValueType  # 5988
CHANNEL_ATTRIBUTE_AI_VOLTAGE_ACRMS_UNITS: ChannelInt32Attribute.ValueType  # 6114
CHANNEL_ATTRIBUTE_AI_CURRENT_ACRMS_UNITS: ChannelInt32Attribute.ValueType  # 6115
CHANNEL_ATTRIBUTE_AI_BRIDGE_BALANCE_COARSE_POT: ChannelInt32Attribute.ValueType  # 6129
CHANNEL_ATTRIBUTE_AI_CURRENT_SHUNT_LOC: ChannelInt32Attribute.ValueType  # 6130
CHANNEL_ATTRIBUTE_AI_EXCIT_SRC: ChannelInt32Attribute.ValueType  # 6132
CHANNEL_ATTRIBUTE_AI_EXCIT_VOLTAGE_OR_CURRENT: ChannelInt32Attribute.ValueType  # 6134
CHANNEL_ATTRIBUTE_AI_EXCIT_D_COR_AC: ChannelInt32Attribute.ValueType  # 6139
CHANNEL_ATTRIBUTE_AI_HIGHPASS_TYPE: ChannelInt32Attribute.ValueType  # 6152
CHANNEL_ATTRIBUTE_AI_BANDPASS_TYPE: ChannelInt32Attribute.ValueType  # 6157
CHANNEL_ATTRIBUTE_AI_NOTCH_TYPE: ChannelInt32Attribute.ValueType  # 6161
CHANNEL_ATTRIBUTE_AI_DATA_XFER_MECH: ChannelInt32Attribute.ValueType  # 6177
CHANNEL_ATTRIBUTE_AO_RESOLUTION_UNITS: ChannelInt32Attribute.ValueType  # 6187
CHANNEL_ATTRIBUTE_AO_DATA_XFER_REQ_COND: ChannelInt32Attribute.ValueType  # 6204
CHANNEL_ATTRIBUTE_CHAN_TYPE: ChannelInt32Attribute.ValueType  # 6271
CHANNEL_ATTRIBUTE_AI_RESISTANCE_CFG: ChannelInt32Attribute.ValueType  # 6273
CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_CLK_SRC: ChannelInt32Attribute.ValueType  # 6276
CHANNEL_ATTRIBUTE_AI_DATA_XFER_REQ_COND: ChannelInt32Attribute.ValueType  # 6283
CHANNEL_ATTRIBUTE_AO_TERM_CFG: ChannelInt32Attribute.ValueType  # 6286
CHANNEL_ATTRIBUTE_CI_MEAS_TYPE: ChannelInt32Attribute.ValueType  # 6304
CHANNEL_ATTRIBUTE_CI_FREQ_UNITS: ChannelInt32Attribute.ValueType  # 6305
CHANNEL_ATTRIBUTE_CI_PERIOD_UNITS: ChannelInt32Attribute.ValueType  # 6307
CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_UNITS: ChannelInt32Attribute.ValueType  # 6310
CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_UNITS: ChannelInt32Attribute.ValueType  # 6313
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_UNITS: ChannelInt32Attribute.ValueType  # 6316
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_UNITS: ChannelInt32Attribute.ValueType  # 6319
CHANNEL_ATTRIBUTE_CO_OUTPUT_TYPE: ChannelInt32Attribute.ValueType  # 6325
CHANNEL_ATTRIBUTE_AI_AC_EXCIT_WIRE_MODE: ChannelInt32Attribute.ValueType  # 6349
CHANNEL_ATTRIBUTE_CO_PULSE_FREQ_UNITS: ChannelInt32Attribute.ValueType  # 6357
CHANNEL_ATTRIBUTE_CO_PULSE_TIME_UNITS: ChannelInt32Attribute.ValueType  # 6358
CHANNEL_ATTRIBUTE_AI_BRIDGE_BALANCE_FINE_POT: ChannelInt32Attribute.ValueType  # 6388
CHANNEL_ATTRIBUTE_CI_PERIOD_MEAS_METH: ChannelInt32Attribute.ValueType  # 6444
CHANNEL_ATTRIBUTE_AI_LVDT_SENSITIVITY_UNITS: ChannelInt32Attribute.ValueType  # 8602
CHANNEL_ATTRIBUTE_AI_RVDT_SENSITIVITY_UNITS: ChannelInt32Attribute.ValueType  # 8603
CHANNEL_ATTRIBUTE_AI_ACCEL_SENSITIVITY_UNITS: ChannelInt32Attribute.ValueType  # 8604
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SELECT: ChannelInt32Attribute.ValueType  # 8661
CHANNEL_ATTRIBUTE_CI_ENCODER_DECODING_TYPE: ChannelInt32Attribute.ValueType  # 8678
CHANNEL_ATTRIBUTE_AO_IDLE_OUTPUT_BEHAVIOR: ChannelInt32Attribute.ValueType  # 8768
CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_SRC: ChannelInt32Attribute.ValueType  # 8787
CHANNEL_ATTRIBUTE_DI_DATA_XFER_MECH: ChannelInt32Attribute.ValueType  # 8803
CHANNEL_ATTRIBUTE_DI_DATA_XFER_REQ_COND: ChannelInt32Attribute.ValueType  # 8804
CHANNEL_ATTRIBUTE_DO_DATA_XFER_MECH: ChannelInt32Attribute.ValueType  # 8806
CHANNEL_ATTRIBUTE_DO_DATA_XFER_REQ_COND: ChannelInt32Attribute.ValueType  # 8807
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_SCALE_TYPE: ChannelInt32Attribute.ValueType  # 8860
CHANNEL_ATTRIBUTE_CI_TIMESTAMP_UNITS: ChannelInt32Attribute.ValueType  # 8883
CHANNEL_ATTRIBUTE_AI_RAW_DATA_COMPRESSION_TYPE: ChannelInt32Attribute.ValueType  # 8920
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_STARTING_EDGE: ChannelInt32Attribute.ValueType  # 8958
CHANNEL_ATTRIBUTE_DI_ACQUIRE_ON: ChannelInt32Attribute.ValueType  # 10598
CHANNEL_ATTRIBUTE_DO_LINE_STATES_PAUSED_STATE: ChannelInt32Attribute.ValueType  # 10599
CHANNEL_ATTRIBUTE_DO_LINE_STATES_DONE_STATE: ChannelInt32Attribute.ValueType  # 10600
CHANNEL_ATTRIBUTE_DO_GENERATE_ON: ChannelInt32Attribute.ValueType  # 10601
CHANNEL_ATTRIBUTE_DI_LOGIC_FAMILY: ChannelInt32Attribute.ValueType  # 10605
CHANNEL_ATTRIBUTE_DO_LOGIC_FAMILY: ChannelInt32Attribute.ValueType  # 10606
CHANNEL_ATTRIBUTE_DO_LINE_STATES_START_STATE: ChannelInt32Attribute.ValueType  # 10610
CHANNEL_ATTRIBUTE_AI_THRMCPL_SCALE_TYPE: ChannelInt32Attribute.ValueType  # 10704
CHANNEL_ATTRIBUTE_CO_CONSTRAINED_GEN_MODE: ChannelInt32Attribute.ValueType  # 10738
CHANNEL_ATTRIBUTE_AI_ADC_TIMING_MODE: ChannelInt32Attribute.ValueType  # 10745
CHANNEL_ATTRIBUTE_AO_FUNC_GEN_TYPE: ChannelInt32Attribute.ValueType  # 10776
CHANNEL_ATTRIBUTE_AO_FUNC_GEN_MODULATION_TYPE: ChannelInt32Attribute.ValueType  # 10786
CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS: ChannelInt32Attribute.ValueType  # 10943
CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_UNITS: ChannelInt32Attribute.ValueType  # 10944
CHANNEL_ATTRIBUTE_CO_DATA_XFER_MECH: ChannelInt32Attribute.ValueType  # 11980
CHANNEL_ATTRIBUTE_CO_DATA_XFER_REQ_COND: ChannelInt32Attribute.ValueType  # 11981
CHANNEL_ATTRIBUTE_CI_DATA_XFER_REQ_COND: ChannelInt32Attribute.ValueType  # 12027
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_START_EDGE: ChannelInt32Attribute.ValueType  # 12037
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_UNITS: ChannelInt32Attribute.ValueType  # 12043
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_START_EDGE: ChannelInt32Attribute.ValueType  # 12045
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_UNITS: ChannelInt32Attribute.ValueType  # 12051
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_START_EDGE: ChannelInt32Attribute.ValueType  # 12053
CHANNEL_ATTRIBUTE_AI_FORCE_UNITS: ChannelInt32Attribute.ValueType  # 12149
CHANNEL_ATTRIBUTE_AI_PRESSURE_UNITS: ChannelInt32Attribute.ValueType  # 12150
CHANNEL_ATTRIBUTE_AI_TORQUE_UNITS: ChannelInt32Attribute.ValueType  # 12151
CHANNEL_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS: ChannelInt32Attribute.ValueType  # 12162
CHANNEL_ATTRIBUTE_AI_BRIDGE_ELECTRICAL_UNITS: ChannelInt32Attribute.ValueType  # 12167
CHANNEL_ATTRIBUTE_AI_BRIDGE_PHYSICAL_UNITS: ChannelInt32Attribute.ValueType  # 12168
CHANNEL_ATTRIBUTE_AI_BRIDGE_SCALE_TYPE: ChannelInt32Attribute.ValueType  # 12169
CHANNEL_ATTRIBUTE_AI_BRIDGE_UNITS: ChannelInt32Attribute.ValueType  # 12178
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ACTIVE_EDGE: ChannelInt32Attribute.ValueType  # 12210
CHANNEL_ATTRIBUTE_AI_VELOCITY_UNITS: ChannelInt32Attribute.ValueType  # 12276
CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS: ChannelInt32Attribute.ValueType  # 12279
CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_MEAS_TYPE: ChannelInt32Attribute.ValueType  # 12285
CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_TYPE: ChannelInt32Attribute.ValueType  # 12286
CHANNEL_ATTRIBUTE_CI_TIMESTAMP_EDGE: ChannelInt32Attribute.ValueType  # 12346
CHANNEL_ATTRIBUTE_CI_TIMESTAMP_TIMESCALE: ChannelInt32Attribute.ValueType  # 12347
CHANNEL_ATTRIBUTE_NAV_MEAS_TYPE: ChannelInt32Attribute.ValueType  # 12349
CHANNEL_ATTRIBUTE_NAV_ALT_UNITS: ChannelInt32Attribute.ValueType  # 12350
CHANNEL_ATTRIBUTE_NAV_LAT_UNITS: ChannelInt32Attribute.ValueType  # 12351
CHANNEL_ATTRIBUTE_NAV_LONG_UNITS: ChannelInt32Attribute.ValueType  # 12352
CHANNEL_ATTRIBUTE_NAV_SPEED_OVER_GROUND_UNITS: ChannelInt32Attribute.ValueType  # 12353
CHANNEL_ATTRIBUTE_NAV_TRACK_UNITS: ChannelInt32Attribute.ValueType  # 12354
CHANNEL_ATTRIBUTE_NAV_VERT_VELOCITY_UNITS: ChannelInt32Attribute.ValueType  # 12355
CHANNEL_ATTRIBUTE_NAV_TIMESTAMP_UNITS: ChannelInt32Attribute.ValueType  # 12356
CHANNEL_ATTRIBUTE_NAV_TIMESTAMP_TIMESCALE: ChannelInt32Attribute.ValueType  # 12357
CHANNEL_ATTRIBUTE_AI_FILTER_DELAY_UNITS: ChannelInt32Attribute.ValueType  # 12401
CHANNEL_ATTRIBUTE_AO_FILTER_DELAY_UNITS: ChannelInt32Attribute.ValueType  # 12406
CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_STARTING_EDGE: ChannelInt32Attribute.ValueType  # 12434
CHANNEL_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12435
CHANNEL_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_SENTINEL_VAL: ChannelInt32Attribute.ValueType  # 12436
CHANNEL_ATTRIBUTE_CI_FREQ_TERM_CFG: ChannelInt32Attribute.ValueType  # 12439
CHANNEL_ATTRIBUTE_CI_FREQ_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12440
CHANNEL_ATTRIBUTE_CI_PERIOD_TERM_CFG: ChannelInt32Attribute.ValueType  # 12441
CHANNEL_ATTRIBUTE_CI_PERIOD_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12442
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_TERM_CFG: ChannelInt32Attribute.ValueType  # 12443
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12444
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_TERM_CFG: ChannelInt32Attribute.ValueType  # 12445
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12446
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM_CFG: ChannelInt32Attribute.ValueType  # 12447
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12448
CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_TERM_CFG: ChannelInt32Attribute.ValueType  # 12449
CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12450
CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM_CFG: ChannelInt32Attribute.ValueType  # 12451
CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12452
CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM_CFG: ChannelInt32Attribute.ValueType  # 12453
CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12454
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM_CFG: ChannelInt32Attribute.ValueType  # 12455
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12456
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_TERM_CFG: ChannelInt32Attribute.ValueType  # 12457
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12458
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM_CFG: ChannelInt32Attribute.ValueType  # 12459
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12460
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM_CFG: ChannelInt32Attribute.ValueType  # 12461
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12462
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_TERM_CFG: ChannelInt32Attribute.ValueType  # 12463
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12464
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_TERM_CFG: ChannelInt32Attribute.ValueType  # 12465
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12466
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_TERM_CFG: ChannelInt32Attribute.ValueType  # 12467
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12468
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_TERM_CFG: ChannelInt32Attribute.ValueType  # 12469
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12470
CHANNEL_ATTRIBUTE_AI_EXCIT_IDLE_OUTPUT_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12472
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_TYPE: ChannelInt32Attribute.ValueType  # 12478
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_RESPONSE: ChannelInt32Attribute.ValueType  # 12479
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_SRC: ChannelInt32Attribute.ValueType  # 12490
CHANNEL_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_UNITS: ChannelInt32Attribute.ValueType  # 12504
CHANNEL_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_UNITS: ChannelInt32Attribute.ValueType  # 12506
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_DECODING_TYPE: ChannelInt32Attribute.ValueType  # 12508
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM_CFG: ChannelInt32Attribute.ValueType  # 12510
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12511
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM_CFG: ChannelInt32Attribute.ValueType  # 12517
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12518
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM_CFG: ChannelInt32Attribute.ValueType  # 12527
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_LOGIC_LVL_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12528
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_WHEN: ChannelInt32Attribute.ValueType  # 12533
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_SRC: ChannelInt32Attribute.ValueType  # 12535
CHANNEL_ATTRIBUTE_AI_EXCIT_SENSE: ChannelInt32Attribute.ValueType  # 12541
CHANNEL_ATTRIBUTE_AI_CHARGE_UNITS: ChannelInt32Attribute.ValueType  # 12562
CHANNEL_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY_UNITS: ChannelInt32Attribute.ValueType  # 12564
CHANNEL_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY_UNITS: ChannelInt32Attribute.ValueType  # 12566
CHANNEL_ATTRIBUTE_CHAN_SYNC_UNLOCK_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12604
CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_CFG: ChannelInt32Attribute.ValueType  # 12650
CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_TYPE: ChannelInt32Attribute.ValueType  # 12651
CHANNEL_ATTRIBUTE_AI_FILTER_RESPONSE: ChannelInt32Attribute.ValueType  # 12661
CHANNEL_ATTRIBUTE_CI_FILTER_RESPONSE: ChannelInt32Attribute.ValueType  # 12729
CHANNEL_ATTRIBUTE_CI_FILTER_DELAY_UNITS: ChannelInt32Attribute.ValueType  # 12732
CHANNEL_ATTRIBUTE_PWR_OUTPUT_STATE: ChannelInt32Attribute.ValueType  # 12759
CHANNEL_ATTRIBUTE_PWR_IDLE_OUTPUT_BEHAVIOR: ChannelInt32Attribute.ValueType  # 12760
CHANNEL_ATTRIBUTE_PWR_REMOTE_SENSE: ChannelInt32Attribute.ValueType  # 12763
global___ChannelInt32Attribute = ChannelInt32Attribute

class _ChannelDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChannelDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_DOUBLE_ATTRIBUTE_UNSPECIFIED: _ChannelDoubleAttribute.ValueType  # 0
    CHANNEL_ATTRIBUTE_AI_IMPEDANCE: _ChannelDoubleAttribute.ValueType  # 98
    CHANNEL_ATTRIBUTE_AI_AC_EXCIT_FREQ: _ChannelDoubleAttribute.ValueType  # 257
    CHANNEL_ATTRIBUTE_AO_GAIN: _ChannelDoubleAttribute.ValueType  # 280
    CHANNEL_ATTRIBUTE_AO_LOAD_IMPEDANCE: _ChannelDoubleAttribute.ValueType  # 289
    CHANNEL_ATTRIBUTE_CI_FREQ_MEAS_TIME: _ChannelDoubleAttribute.ValueType  # 325
    CHANNEL_ATTRIBUTE_CO_PULSE_FREQ_INITIAL_DELAY: _ChannelDoubleAttribute.ValueType  # 665
    CHANNEL_ATTRIBUTE_AI_ACCEL_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 1682
    CHANNEL_ATTRIBUTE_AI_FREQ_HYST: _ChannelDoubleAttribute.ValueType  # 2068
    CHANNEL_ATTRIBUTE_AI_FREQ_THRESH_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 2069
    CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_INITIAL_ANGLE: _ChannelDoubleAttribute.ValueType  # 2177
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_VAL: _ChannelDoubleAttribute.ValueType  # 2184
    CHANNEL_ATTRIBUTE_AI_RVDT_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 2307
    CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_DIST_PER_PULSE: _ChannelDoubleAttribute.ValueType  # 2321
    CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_INITIAL_POS: _ChannelDoubleAttribute.ValueType  # 2325
    CHANNEL_ATTRIBUTE_AI_LVDT_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 2361
    CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_GAGE_FACTOR: _ChannelDoubleAttribute.ValueType  # 2452
    CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_POISSON_RATIO: _ChannelDoubleAttribute.ValueType  # 2456
    CHANNEL_ATTRIBUTE_AI_RTD_A: _ChannelDoubleAttribute.ValueType  # 4112
    CHANNEL_ATTRIBUTE_AI_RTD_B: _ChannelDoubleAttribute.ValueType  # 4113
    CHANNEL_ATTRIBUTE_AI_RTD_C: _ChannelDoubleAttribute.ValueType  # 4115
    CHANNEL_ATTRIBUTE_AI_RTD_R0: _ChannelDoubleAttribute.ValueType  # 4144
    CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_VAL: _ChannelDoubleAttribute.ValueType  # 4150
    CHANNEL_ATTRIBUTE_AI_THRMSTR_R1: _ChannelDoubleAttribute.ValueType  # 4193
    CHANNEL_ATTRIBUTE_CO_PULSE_DUTY_CYC: _ChannelDoubleAttribute.ValueType  # 4470
    CHANNEL_ATTRIBUTE_CO_PULSE_FREQ: _ChannelDoubleAttribute.ValueType  # 4472
    CHANNEL_ATTRIBUTE_AO_MAX: _ChannelDoubleAttribute.ValueType  # 4486
    CHANNEL_ATTRIBUTE_AO_MIN: _ChannelDoubleAttribute.ValueType  # 4487
    CHANNEL_ATTRIBUTE_AO_OUTPUT_IMPEDANCE: _ChannelDoubleAttribute.ValueType  # 5264
    CHANNEL_ATTRIBUTE_AI_MICROPHONE_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 5430
    CHANNEL_ATTRIBUTE_AI_RESOLUTION: _ChannelDoubleAttribute.ValueType  # 5989
    CHANNEL_ATTRIBUTE_AI_MAX: _ChannelDoubleAttribute.ValueType  # 6109
    CHANNEL_ATTRIBUTE_AI_MIN: _ChannelDoubleAttribute.ValueType  # 6110
    CHANNEL_ATTRIBUTE_AI_BRIDGE_NOM_RESISTANCE: _ChannelDoubleAttribute.ValueType  # 6124
    CHANNEL_ATTRIBUTE_AI_BRIDGE_INITIAL_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 6125
    CHANNEL_ATTRIBUTE_AI_LEAD_WIRE_RESISTANCE: _ChannelDoubleAttribute.ValueType  # 6126
    CHANNEL_ATTRIBUTE_AI_CURRENT_SHUNT_RESISTANCE: _ChannelDoubleAttribute.ValueType  # 6131
    CHANNEL_ATTRIBUTE_AI_EXCIT_VAL: _ChannelDoubleAttribute.ValueType  # 6133
    CHANNEL_ATTRIBUTE_AI_ATTEN: _ChannelDoubleAttribute.ValueType  # 6145
    CHANNEL_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ: _ChannelDoubleAttribute.ValueType  # 6147
    CHANNEL_ATTRIBUTE_AI_HIGHPASS_CUTOFF_FREQ: _ChannelDoubleAttribute.ValueType  # 6151
    CHANNEL_ATTRIBUTE_AI_BANDPASS_CENTER_FREQ: _ChannelDoubleAttribute.ValueType  # 6156
    CHANNEL_ATTRIBUTE_AI_BANDPASS_WIDTH: _ChannelDoubleAttribute.ValueType  # 6158
    CHANNEL_ATTRIBUTE_AI_NOTCH_CENTER_FREQ: _ChannelDoubleAttribute.ValueType  # 6160
    CHANNEL_ATTRIBUTE_AI_NOTCH_WIDTH: _ChannelDoubleAttribute.ValueType  # 6162
    CHANNEL_ATTRIBUTE_AI_RNG_HIGH: _ChannelDoubleAttribute.ValueType  # 6165
    CHANNEL_ATTRIBUTE_AI_RNG_LOW: _ChannelDoubleAttribute.ValueType  # 6166
    CHANNEL_ATTRIBUTE_AI_GAIN: _ChannelDoubleAttribute.ValueType  # 6168
    CHANNEL_ATTRIBUTE_AO_RESOLUTION: _ChannelDoubleAttribute.ValueType  # 6188
    CHANNEL_ATTRIBUTE_AO_DAC_RNG_LOW: _ChannelDoubleAttribute.ValueType  # 6189
    CHANNEL_ATTRIBUTE_AO_DAC_RNG_HIGH: _ChannelDoubleAttribute.ValueType  # 6190
    CHANNEL_ATTRIBUTE_AO_DAC_REF_VAL: _ChannelDoubleAttribute.ValueType  # 6194
    CHANNEL_ATTRIBUTE_AI_EXCIT_ACTUAL_VAL: _ChannelDoubleAttribute.ValueType  # 6275
    CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_FREQ: _ChannelDoubleAttribute.ValueType  # 6277
    CHANNEL_ATTRIBUTE_CI_MAX: _ChannelDoubleAttribute.ValueType  # 6300
    CHANNEL_ATTRIBUTE_CI_MIN: _ChannelDoubleAttribute.ValueType  # 6301
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 6322
    CHANNEL_ATTRIBUTE_CO_PULSE_HIGH_TIME: _ChannelDoubleAttribute.ValueType  # 6330
    CHANNEL_ATTRIBUTE_CO_PULSE_LOW_TIME: _ChannelDoubleAttribute.ValueType  # 6331
    CHANNEL_ATTRIBUTE_CO_PULSE_TIME_INITIAL_DELAY: _ChannelDoubleAttribute.ValueType  # 6332
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 6338
    CHANNEL_ATTRIBUTE_AI_THRMSTR_A: _ChannelDoubleAttribute.ValueType  # 6345
    CHANNEL_ATTRIBUTE_AI_THRMSTR_C: _ChannelDoubleAttribute.ValueType  # 6346
    CHANNEL_ATTRIBUTE_AI_THRMSTR_B: _ChannelDoubleAttribute.ValueType  # 6347
    CHANNEL_ATTRIBUTE_CI_PERIOD_MEAS_TIME: _ChannelDoubleAttribute.ValueType  # 6445
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_GAIN_ADJUST: _ChannelDoubleAttribute.ValueType  # 6463
    CHANNEL_ATTRIBUTE_DI_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8663
    CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8680
    CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8682
    CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8685
    CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8687
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8690
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8692
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8695
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8697
    CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8700
    CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8702
    CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8705
    CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8707
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8710
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8712
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8715
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8717
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8720
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8722
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8725
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8727
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8730
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8732
    CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_MAX_SOUND_PRESSURE_LVL: _ChannelDoubleAttribute.ValueType  # 8762
    CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_VAL: _ChannelDoubleAttribute.ValueType  # 8789
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8818
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8820
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 8823
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 8825
    CHANNEL_ATTRIBUTE_AI_VOLTAGE_DB_REF: _ChannelDoubleAttribute.ValueType  # 10672
    CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_DB_REF: _ChannelDoubleAttribute.ValueType  # 10673
    CHANNEL_ATTRIBUTE_AI_ACCEL_DB_REF: _ChannelDoubleAttribute.ValueType  # 10674
    CHANNEL_ATTRIBUTE_AO_FUNC_GEN_FREQ: _ChannelDoubleAttribute.ValueType  # 10777
    CHANNEL_ATTRIBUTE_AO_FUNC_GEN_AMPLITUDE: _ChannelDoubleAttribute.ValueType  # 10778
    CHANNEL_ATTRIBUTE_AO_FUNC_GEN_OFFSET: _ChannelDoubleAttribute.ValueType  # 10779
    CHANNEL_ATTRIBUTE_AO_FUNC_GEN_SQUARE_DUTY_CYCLE: _ChannelDoubleAttribute.ValueType  # 10780
    CHANNEL_ATTRIBUTE_AO_VOLTAGE_CURRENT_LIMIT: _ChannelDoubleAttribute.ValueType  # 10781
    CHANNEL_ATTRIBUTE_AO_FUNC_GEN_FM_DEVIATION: _ChannelDoubleAttribute.ValueType  # 10787
    CHANNEL_ATTRIBUTE_DO_OVERCURRENT_LIMIT: _ChannelDoubleAttribute.ValueType  # 10885
    CHANNEL_ATTRIBUTE_DO_OVERCURRENT_REENABLE_PERIOD: _ChannelDoubleAttribute.ValueType  # 10887
    CHANNEL_ATTRIBUTE_AI_PROBE_ATTEN: _ChannelDoubleAttribute.ValueType  # 10888
    CHANNEL_ATTRIBUTE_AI_DC_OFFSET: _ChannelDoubleAttribute.ValueType  # 10889
    CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 10942
    CHANNEL_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 11989
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 12039
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 12041
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 12047
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 12049
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 12055
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 12057
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_RESISTANCE: _ChannelDoubleAttribute.ValueType  # 12152
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_ACTUAL_RESISTANCE: _ChannelDoubleAttribute.ValueType  # 12153
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_RESISTANCE: _ChannelDoubleAttribute.ValueType  # 12154
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_ACTUAL_RESISTANCE: _ChannelDoubleAttribute.ValueType  # 12155
    CHANNEL_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 12161
    CHANNEL_ATTRIBUTE_AI_BRIDGE_INITIAL_RATIO: _ChannelDoubleAttribute.ValueType  # 12166
    CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_ELECTRICAL_VAL: _ChannelDoubleAttribute.ValueType  # 12170
    CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_PHYSICAL_VAL: _ChannelDoubleAttribute.ValueType  # 12171
    CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_ELECTRICAL_VAL: _ChannelDoubleAttribute.ValueType  # 12172
    CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_PHYSICAL_VAL: _ChannelDoubleAttribute.ValueType  # 12173
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 12212
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 12214
    CHANNEL_ATTRIBUTE_AI_THRMCPL_LEAD_OFFSET_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12216
    CHANNEL_ATTRIBUTE_AI_FILTER_DELAY: _ChannelDoubleAttribute.ValueType  # 12269
    CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_DB_REF: _ChannelDoubleAttribute.ValueType  # 12277
    CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 12278
    CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ORIENTATION: _ChannelDoubleAttribute.ValueType  # 12284
    CHANNEL_ATTRIBUTE_AO_FILTER_DELAY_ADJUSTMENT: _ChannelDoubleAttribute.ValueType  # 12402
    CHANNEL_ATTRIBUTE_AI_FILTER_DELAY_ADJUSTMENT: _ChannelDoubleAttribute.ValueType  # 12404
    CHANNEL_ATTRIBUTE_AO_FILTER_DELAY: _ChannelDoubleAttribute.ValueType  # 12405
    CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 12431
    CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 12433
    CHANNEL_ATTRIBUTE_CI_MAX_MEAS_PERIOD: _ChannelDoubleAttribute.ValueType  # 12437
    CHANNEL_ATTRIBUTE_CI_THRESH_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12471
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ: _ChannelDoubleAttribute.ValueType  # 12481
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_HIGHPASS_CUTOFF_FREQ: _ChannelDoubleAttribute.ValueType  # 12482
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_CENTER_FREQ: _ChannelDoubleAttribute.ValueType  # 12483
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_WIDTH: _ChannelDoubleAttribute.ValueType  # 12484
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_NOTCH_CENTER_FREQ: _ChannelDoubleAttribute.ValueType  # 12485
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_NOTCH_WIDTH: _ChannelDoubleAttribute.ValueType  # 12486
    CHANNEL_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_DIST_PER_PULSE: _ChannelDoubleAttribute.ValueType  # 12507
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 12513
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 12515
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 12520
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 12522
    CHANNEL_ATTRIBUTE_CI_VELOCITY_MEAS_TIME: _ChannelDoubleAttribute.ValueType  # 12523
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelDoubleAttribute.ValueType  # 12530
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_RATE: _ChannelDoubleAttribute.ValueType  # 12532
    CHANNEL_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 12563
    CHANNEL_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY: _ChannelDoubleAttribute.ValueType  # 12565
    CHANNEL_ATTRIBUTE_AI_DATA_XFER_MAX_RATE: _ChannelDoubleAttribute.ValueType  # 12567
    CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12649
    CHANNEL_ATTRIBUTE_AI_FILTER_FREQ: _ChannelDoubleAttribute.ValueType  # 12660
    CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_UPPER_LIMIT: _ChannelDoubleAttribute.ValueType  # 12684
    CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_LOWER_LIMIT: _ChannelDoubleAttribute.ValueType  # 12685
    CHANNEL_ATTRIBUTE_CI_FREQ_THRESH_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12715
    CHANNEL_ATTRIBUTE_CI_FREQ_HYST: _ChannelDoubleAttribute.ValueType  # 12716
    CHANNEL_ATTRIBUTE_CI_PERIOD_THRESH_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12717
    CHANNEL_ATTRIBUTE_CI_PERIOD_HYST: _ChannelDoubleAttribute.ValueType  # 12718
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_THRESH_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12719
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_HYST: _ChannelDoubleAttribute.ValueType  # 12720
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_THRESH_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12721
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_HYST: _ChannelDoubleAttribute.ValueType  # 12722
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_THRESH_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12723
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_HYST: _ChannelDoubleAttribute.ValueType  # 12724
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_THRESH_VOLTAGE: _ChannelDoubleAttribute.ValueType  # 12725
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_HYST: _ChannelDoubleAttribute.ValueType  # 12726
    CHANNEL_ATTRIBUTE_CI_FILTER_FREQ: _ChannelDoubleAttribute.ValueType  # 12728
    CHANNEL_ATTRIBUTE_CI_FILTER_DELAY: _ChannelDoubleAttribute.ValueType  # 12731
    CHANNEL_ATTRIBUTE_AO_FUNC_GEN_START_PHASE: _ChannelDoubleAttribute.ValueType  # 12740
    CHANNEL_ATTRIBUTE_AO_COMMON_MODE_OFFSET: _ChannelDoubleAttribute.ValueType  # 12748
    CHANNEL_ATTRIBUTE_PWR_VOLTAGE_SETPOINT: _ChannelDoubleAttribute.ValueType  # 12756
    CHANNEL_ATTRIBUTE_PWR_CURRENT_SETPOINT: _ChannelDoubleAttribute.ValueType  # 12757

class ChannelDoubleAttribute(_ChannelDoubleAttribute, metaclass=_ChannelDoubleAttributeEnumTypeWrapper): ...

CHANNEL_DOUBLE_ATTRIBUTE_UNSPECIFIED: ChannelDoubleAttribute.ValueType  # 0
CHANNEL_ATTRIBUTE_AI_IMPEDANCE: ChannelDoubleAttribute.ValueType  # 98
CHANNEL_ATTRIBUTE_AI_AC_EXCIT_FREQ: ChannelDoubleAttribute.ValueType  # 257
CHANNEL_ATTRIBUTE_AO_GAIN: ChannelDoubleAttribute.ValueType  # 280
CHANNEL_ATTRIBUTE_AO_LOAD_IMPEDANCE: ChannelDoubleAttribute.ValueType  # 289
CHANNEL_ATTRIBUTE_CI_FREQ_MEAS_TIME: ChannelDoubleAttribute.ValueType  # 325
CHANNEL_ATTRIBUTE_CO_PULSE_FREQ_INITIAL_DELAY: ChannelDoubleAttribute.ValueType  # 665
CHANNEL_ATTRIBUTE_AI_ACCEL_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 1682
CHANNEL_ATTRIBUTE_AI_FREQ_HYST: ChannelDoubleAttribute.ValueType  # 2068
CHANNEL_ATTRIBUTE_AI_FREQ_THRESH_VOLTAGE: ChannelDoubleAttribute.ValueType  # 2069
CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_INITIAL_ANGLE: ChannelDoubleAttribute.ValueType  # 2177
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_VAL: ChannelDoubleAttribute.ValueType  # 2184
CHANNEL_ATTRIBUTE_AI_RVDT_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 2307
CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_DIST_PER_PULSE: ChannelDoubleAttribute.ValueType  # 2321
CHANNEL_ATTRIBUTE_CI_LIN_ENCODER_INITIAL_POS: ChannelDoubleAttribute.ValueType  # 2325
CHANNEL_ATTRIBUTE_AI_LVDT_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 2361
CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_GAGE_FACTOR: ChannelDoubleAttribute.ValueType  # 2452
CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_POISSON_RATIO: ChannelDoubleAttribute.ValueType  # 2456
CHANNEL_ATTRIBUTE_AI_RTD_A: ChannelDoubleAttribute.ValueType  # 4112
CHANNEL_ATTRIBUTE_AI_RTD_B: ChannelDoubleAttribute.ValueType  # 4113
CHANNEL_ATTRIBUTE_AI_RTD_C: ChannelDoubleAttribute.ValueType  # 4115
CHANNEL_ATTRIBUTE_AI_RTD_R0: ChannelDoubleAttribute.ValueType  # 4144
CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_VAL: ChannelDoubleAttribute.ValueType  # 4150
CHANNEL_ATTRIBUTE_AI_THRMSTR_R1: ChannelDoubleAttribute.ValueType  # 4193
CHANNEL_ATTRIBUTE_CO_PULSE_DUTY_CYC: ChannelDoubleAttribute.ValueType  # 4470
CHANNEL_ATTRIBUTE_CO_PULSE_FREQ: ChannelDoubleAttribute.ValueType  # 4472
CHANNEL_ATTRIBUTE_AO_MAX: ChannelDoubleAttribute.ValueType  # 4486
CHANNEL_ATTRIBUTE_AO_MIN: ChannelDoubleAttribute.ValueType  # 4487
CHANNEL_ATTRIBUTE_AO_OUTPUT_IMPEDANCE: ChannelDoubleAttribute.ValueType  # 5264
CHANNEL_ATTRIBUTE_AI_MICROPHONE_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 5430
CHANNEL_ATTRIBUTE_AI_RESOLUTION: ChannelDoubleAttribute.ValueType  # 5989
CHANNEL_ATTRIBUTE_AI_MAX: ChannelDoubleAttribute.ValueType  # 6109
CHANNEL_ATTRIBUTE_AI_MIN: ChannelDoubleAttribute.ValueType  # 6110
CHANNEL_ATTRIBUTE_AI_BRIDGE_NOM_RESISTANCE: ChannelDoubleAttribute.ValueType  # 6124
CHANNEL_ATTRIBUTE_AI_BRIDGE_INITIAL_VOLTAGE: ChannelDoubleAttribute.ValueType  # 6125
CHANNEL_ATTRIBUTE_AI_LEAD_WIRE_RESISTANCE: ChannelDoubleAttribute.ValueType  # 6126
CHANNEL_ATTRIBUTE_AI_CURRENT_SHUNT_RESISTANCE: ChannelDoubleAttribute.ValueType  # 6131
CHANNEL_ATTRIBUTE_AI_EXCIT_VAL: ChannelDoubleAttribute.ValueType  # 6133
CHANNEL_ATTRIBUTE_AI_ATTEN: ChannelDoubleAttribute.ValueType  # 6145
CHANNEL_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ: ChannelDoubleAttribute.ValueType  # 6147
CHANNEL_ATTRIBUTE_AI_HIGHPASS_CUTOFF_FREQ: ChannelDoubleAttribute.ValueType  # 6151
CHANNEL_ATTRIBUTE_AI_BANDPASS_CENTER_FREQ: ChannelDoubleAttribute.ValueType  # 6156
CHANNEL_ATTRIBUTE_AI_BANDPASS_WIDTH: ChannelDoubleAttribute.ValueType  # 6158
CHANNEL_ATTRIBUTE_AI_NOTCH_CENTER_FREQ: ChannelDoubleAttribute.ValueType  # 6160
CHANNEL_ATTRIBUTE_AI_NOTCH_WIDTH: ChannelDoubleAttribute.ValueType  # 6162
CHANNEL_ATTRIBUTE_AI_RNG_HIGH: ChannelDoubleAttribute.ValueType  # 6165
CHANNEL_ATTRIBUTE_AI_RNG_LOW: ChannelDoubleAttribute.ValueType  # 6166
CHANNEL_ATTRIBUTE_AI_GAIN: ChannelDoubleAttribute.ValueType  # 6168
CHANNEL_ATTRIBUTE_AO_RESOLUTION: ChannelDoubleAttribute.ValueType  # 6188
CHANNEL_ATTRIBUTE_AO_DAC_RNG_LOW: ChannelDoubleAttribute.ValueType  # 6189
CHANNEL_ATTRIBUTE_AO_DAC_RNG_HIGH: ChannelDoubleAttribute.ValueType  # 6190
CHANNEL_ATTRIBUTE_AO_DAC_REF_VAL: ChannelDoubleAttribute.ValueType  # 6194
CHANNEL_ATTRIBUTE_AI_EXCIT_ACTUAL_VAL: ChannelDoubleAttribute.ValueType  # 6275
CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_FREQ: ChannelDoubleAttribute.ValueType  # 6277
CHANNEL_ATTRIBUTE_CI_MAX: ChannelDoubleAttribute.ValueType  # 6300
CHANNEL_ATTRIBUTE_CI_MIN: ChannelDoubleAttribute.ValueType  # 6301
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 6322
CHANNEL_ATTRIBUTE_CO_PULSE_HIGH_TIME: ChannelDoubleAttribute.ValueType  # 6330
CHANNEL_ATTRIBUTE_CO_PULSE_LOW_TIME: ChannelDoubleAttribute.ValueType  # 6331
CHANNEL_ATTRIBUTE_CO_PULSE_TIME_INITIAL_DELAY: ChannelDoubleAttribute.ValueType  # 6332
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 6338
CHANNEL_ATTRIBUTE_AI_THRMSTR_A: ChannelDoubleAttribute.ValueType  # 6345
CHANNEL_ATTRIBUTE_AI_THRMSTR_C: ChannelDoubleAttribute.ValueType  # 6346
CHANNEL_ATTRIBUTE_AI_THRMSTR_B: ChannelDoubleAttribute.ValueType  # 6347
CHANNEL_ATTRIBUTE_CI_PERIOD_MEAS_TIME: ChannelDoubleAttribute.ValueType  # 6445
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_GAIN_ADJUST: ChannelDoubleAttribute.ValueType  # 6463
CHANNEL_ATTRIBUTE_DI_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8663
CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8680
CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8682
CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8685
CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8687
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8690
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8692
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8695
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8697
CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8700
CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8702
CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8705
CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8707
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8710
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8712
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8715
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8717
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8720
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8722
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8725
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8727
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8730
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8732
CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_MAX_SOUND_PRESSURE_LVL: ChannelDoubleAttribute.ValueType  # 8762
CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_VAL: ChannelDoubleAttribute.ValueType  # 8789
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8818
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8820
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 8823
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 8825
CHANNEL_ATTRIBUTE_AI_VOLTAGE_DB_REF: ChannelDoubleAttribute.ValueType  # 10672
CHANNEL_ATTRIBUTE_AI_SOUND_PRESSURE_DB_REF: ChannelDoubleAttribute.ValueType  # 10673
CHANNEL_ATTRIBUTE_AI_ACCEL_DB_REF: ChannelDoubleAttribute.ValueType  # 10674
CHANNEL_ATTRIBUTE_AO_FUNC_GEN_FREQ: ChannelDoubleAttribute.ValueType  # 10777
CHANNEL_ATTRIBUTE_AO_FUNC_GEN_AMPLITUDE: ChannelDoubleAttribute.ValueType  # 10778
CHANNEL_ATTRIBUTE_AO_FUNC_GEN_OFFSET: ChannelDoubleAttribute.ValueType  # 10779
CHANNEL_ATTRIBUTE_AO_FUNC_GEN_SQUARE_DUTY_CYCLE: ChannelDoubleAttribute.ValueType  # 10780
CHANNEL_ATTRIBUTE_AO_VOLTAGE_CURRENT_LIMIT: ChannelDoubleAttribute.ValueType  # 10781
CHANNEL_ATTRIBUTE_AO_FUNC_GEN_FM_DEVIATION: ChannelDoubleAttribute.ValueType  # 10787
CHANNEL_ATTRIBUTE_DO_OVERCURRENT_LIMIT: ChannelDoubleAttribute.ValueType  # 10885
CHANNEL_ATTRIBUTE_DO_OVERCURRENT_REENABLE_PERIOD: ChannelDoubleAttribute.ValueType  # 10887
CHANNEL_ATTRIBUTE_AI_PROBE_ATTEN: ChannelDoubleAttribute.ValueType  # 10888
CHANNEL_ATTRIBUTE_AI_DC_OFFSET: ChannelDoubleAttribute.ValueType  # 10889
CHANNEL_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 10942
CHANNEL_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 11989
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 12039
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 12041
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 12047
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 12049
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 12055
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 12057
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_RESISTANCE: ChannelDoubleAttribute.ValueType  # 12152
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_ACTUAL_RESISTANCE: ChannelDoubleAttribute.ValueType  # 12153
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_RESISTANCE: ChannelDoubleAttribute.ValueType  # 12154
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_ACTUAL_RESISTANCE: ChannelDoubleAttribute.ValueType  # 12155
CHANNEL_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 12161
CHANNEL_ATTRIBUTE_AI_BRIDGE_INITIAL_RATIO: ChannelDoubleAttribute.ValueType  # 12166
CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_ELECTRICAL_VAL: ChannelDoubleAttribute.ValueType  # 12170
CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_PHYSICAL_VAL: ChannelDoubleAttribute.ValueType  # 12171
CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_ELECTRICAL_VAL: ChannelDoubleAttribute.ValueType  # 12172
CHANNEL_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_PHYSICAL_VAL: ChannelDoubleAttribute.ValueType  # 12173
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 12212
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 12214
CHANNEL_ATTRIBUTE_AI_THRMCPL_LEAD_OFFSET_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12216
CHANNEL_ATTRIBUTE_AI_FILTER_DELAY: ChannelDoubleAttribute.ValueType  # 12269
CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_DB_REF: ChannelDoubleAttribute.ValueType  # 12277
CHANNEL_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 12278
CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ORIENTATION: ChannelDoubleAttribute.ValueType  # 12284
CHANNEL_ATTRIBUTE_AO_FILTER_DELAY_ADJUSTMENT: ChannelDoubleAttribute.ValueType  # 12402
CHANNEL_ATTRIBUTE_AI_FILTER_DELAY_ADJUSTMENT: ChannelDoubleAttribute.ValueType  # 12404
CHANNEL_ATTRIBUTE_AO_FILTER_DELAY: ChannelDoubleAttribute.ValueType  # 12405
CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 12431
CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 12433
CHANNEL_ATTRIBUTE_CI_MAX_MEAS_PERIOD: ChannelDoubleAttribute.ValueType  # 12437
CHANNEL_ATTRIBUTE_CI_THRESH_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12471
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ: ChannelDoubleAttribute.ValueType  # 12481
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_HIGHPASS_CUTOFF_FREQ: ChannelDoubleAttribute.ValueType  # 12482
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_CENTER_FREQ: ChannelDoubleAttribute.ValueType  # 12483
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_WIDTH: ChannelDoubleAttribute.ValueType  # 12484
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_NOTCH_CENTER_FREQ: ChannelDoubleAttribute.ValueType  # 12485
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_NOTCH_WIDTH: ChannelDoubleAttribute.ValueType  # 12486
CHANNEL_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_DIST_PER_PULSE: ChannelDoubleAttribute.ValueType  # 12507
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 12513
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 12515
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 12520
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 12522
CHANNEL_ATTRIBUTE_CI_VELOCITY_MEAS_TIME: ChannelDoubleAttribute.ValueType  # 12523
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_MIN_PULSE_WIDTH: ChannelDoubleAttribute.ValueType  # 12530
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_RATE: ChannelDoubleAttribute.ValueType  # 12532
CHANNEL_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 12563
CHANNEL_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY: ChannelDoubleAttribute.ValueType  # 12565
CHANNEL_ATTRIBUTE_AI_DATA_XFER_MAX_RATE: ChannelDoubleAttribute.ValueType  # 12567
CHANNEL_ATTRIBUTE_AI_SENSOR_POWER_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12649
CHANNEL_ATTRIBUTE_AI_FILTER_FREQ: ChannelDoubleAttribute.ValueType  # 12660
CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_UPPER_LIMIT: ChannelDoubleAttribute.ValueType  # 12684
CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_LOWER_LIMIT: ChannelDoubleAttribute.ValueType  # 12685
CHANNEL_ATTRIBUTE_CI_FREQ_THRESH_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12715
CHANNEL_ATTRIBUTE_CI_FREQ_HYST: ChannelDoubleAttribute.ValueType  # 12716
CHANNEL_ATTRIBUTE_CI_PERIOD_THRESH_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12717
CHANNEL_ATTRIBUTE_CI_PERIOD_HYST: ChannelDoubleAttribute.ValueType  # 12718
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_THRESH_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12719
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_HYST: ChannelDoubleAttribute.ValueType  # 12720
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_THRESH_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12721
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_HYST: ChannelDoubleAttribute.ValueType  # 12722
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_THRESH_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12723
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_HYST: ChannelDoubleAttribute.ValueType  # 12724
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_THRESH_VOLTAGE: ChannelDoubleAttribute.ValueType  # 12725
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_HYST: ChannelDoubleAttribute.ValueType  # 12726
CHANNEL_ATTRIBUTE_CI_FILTER_FREQ: ChannelDoubleAttribute.ValueType  # 12728
CHANNEL_ATTRIBUTE_CI_FILTER_DELAY: ChannelDoubleAttribute.ValueType  # 12731
CHANNEL_ATTRIBUTE_AO_FUNC_GEN_START_PHASE: ChannelDoubleAttribute.ValueType  # 12740
CHANNEL_ATTRIBUTE_AO_COMMON_MODE_OFFSET: ChannelDoubleAttribute.ValueType  # 12748
CHANNEL_ATTRIBUTE_PWR_VOLTAGE_SETPOINT: ChannelDoubleAttribute.ValueType  # 12756
CHANNEL_ATTRIBUTE_PWR_CURRENT_SETPOINT: ChannelDoubleAttribute.ValueType  # 12757
global___ChannelDoubleAttribute = ChannelDoubleAttribute

class _ChannelResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChannelResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_RESET_ATTRIBUTE_UNSPECIFIED: _ChannelResetAttribute.ValueType  # 0
    CHANNEL_RESET_ATTRIBUTE_AI_IMPEDANCE: _ChannelResetAttribute.ValueType  # 98
    CHANNEL_RESET_ATTRIBUTE_AI_COUPLING: _ChannelResetAttribute.ValueType  # 100
    CHANNEL_RESET_ATTRIBUTE_AI_DITHER_ENABLE: _ChannelResetAttribute.ValueType  # 104
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_CFG: _ChannelResetAttribute.ValueType  # 135
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_ENABLE: _ChannelResetAttribute.ValueType  # 148
    CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_FREQ: _ChannelResetAttribute.ValueType  # 257
    CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 258
    CHANNEL_RESET_ATTRIBUTE_AO_GAIN: _ChannelResetAttribute.ValueType  # 280
    CHANNEL_RESET_ATTRIBUTE_AO_LOAD_IMPEDANCE: _ChannelResetAttribute.ValueType  # 289
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_CONN_TO_GND: _ChannelResetAttribute.ValueType  # 304
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_SRC: _ChannelResetAttribute.ValueType  # 306
    CHANNEL_RESET_ATTRIBUTE_AO_REGLITCH_ENABLE: _ChannelResetAttribute.ValueType  # 307
    CHANNEL_RESET_ATTRIBUTE_AO_DATA_XFER_MECH: _ChannelResetAttribute.ValueType  # 308
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_ACTIVE_EDGE: _ChannelResetAttribute.ValueType  # 322
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 323
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_MEAS_METH: _ChannelResetAttribute.ValueType  # 324
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_MEAS_TIME: _ChannelResetAttribute.ValueType  # 325
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIV: _ChannelResetAttribute.ValueType  # 327
    CHANNEL_RESET_ATTRIBUTE_CI_DATA_XFER_MECH: _ChannelResetAttribute.ValueType  # 512
    CHANNEL_RESET_ATTRIBUTE_CO_AUTO_INCR_CNT: _ChannelResetAttribute.ValueType  # 661
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TICKS_INITIAL_DELAY: _ChannelResetAttribute.ValueType  # 664
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ_INITIAL_DELAY: _ChannelResetAttribute.ValueType  # 665
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 825
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_ACTIVE_EDGE: _ChannelResetAttribute.ValueType  # 833
    CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_UNITS: _ChannelResetAttribute.ValueType  # 1651
    CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_SENSITIVITY: _ChannelResetAttribute.ValueType  # 1682
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIR: _ChannelResetAttribute.ValueType  # 1686
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_ACTIVE_EDGE: _ChannelResetAttribute.ValueType  # 1687
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_INITIAL_CNT: _ChannelResetAttribute.ValueType  # 1688
    CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_UNITS: _ChannelResetAttribute.ValueType  # 1793
    CHANNEL_RESET_ATTRIBUTE_DI_INVERT_LINES: _ChannelResetAttribute.ValueType  # 1939
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_STARTING_EDGE: _ChannelResetAttribute.ValueType  # 1945
    CHANNEL_RESET_ATTRIBUTE_AI_FREQ_UNITS: _ChannelResetAttribute.ValueType  # 2054
    CHANNEL_RESET_ATTRIBUTE_AI_FREQ_HYST: _ChannelResetAttribute.ValueType  # 2068
    CHANNEL_RESET_ATTRIBUTE_AI_FREQ_THRESH_VOLTAGE: _ChannelResetAttribute.ValueType  # 2069
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_UNITS: _ChannelResetAttribute.ValueType  # 2083
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_STARTING_EDGE: _ChannelResetAttribute.ValueType  # 2085
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_EDGE: _ChannelResetAttribute.ValueType  # 2099
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_EDGE: _ChannelResetAttribute.ValueType  # 2100
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_STARTING_EDGE: _ChannelResetAttribute.ValueType  # 2130
    CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_PULSES_PER_REV: _ChannelResetAttribute.ValueType  # 2165
    CHANNEL_RESET_ATTRIBUTE_AI_RVDT_UNITS: _ChannelResetAttribute.ValueType  # 2167
    CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_INITIAL_ANGLE: _ChannelResetAttribute.ValueType  # 2177
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_VAL: _ChannelResetAttribute.ValueType  # 2184
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_PHASE: _ChannelResetAttribute.ValueType  # 2185
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_ENABLE: _ChannelResetAttribute.ValueType  # 2192
    CHANNEL_RESET_ATTRIBUTE_AI_RVDT_SENSITIVITY: _ChannelResetAttribute.ValueType  # 2307
    CHANNEL_RESET_ATTRIBUTE_AI_LVDT_UNITS: _ChannelResetAttribute.ValueType  # 2320
    CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_DIST_PER_PULSE: _ChannelResetAttribute.ValueType  # 2321
    CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_INITIAL_POS: _ChannelResetAttribute.ValueType  # 2325
    CHANNEL_RESET_ATTRIBUTE_AI_LVDT_SENSITIVITY: _ChannelResetAttribute.ValueType  # 2361
    CHANNEL_RESET_ATTRIBUTE_AI_RESISTANCE_UNITS: _ChannelResetAttribute.ValueType  # 2389
    CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_UNITS: _ChannelResetAttribute.ValueType  # 2433
    CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_CFG: _ChannelResetAttribute.ValueType  # 2434
    CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_GAGE_FACTOR: _ChannelResetAttribute.ValueType  # 2452
    CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_POISSON_RATIO: _ChannelResetAttribute.ValueType  # 2456
    CHANNEL_RESET_ATTRIBUTE_AI_RTD_A: _ChannelResetAttribute.ValueType  # 4112
    CHANNEL_RESET_ATTRIBUTE_AI_RTD_B: _ChannelResetAttribute.ValueType  # 4113
    CHANNEL_RESET_ATTRIBUTE_AI_RTD_C: _ChannelResetAttribute.ValueType  # 4115
    CHANNEL_RESET_ATTRIBUTE_AI_RTD_R0: _ChannelResetAttribute.ValueType  # 4144
    CHANNEL_RESET_ATTRIBUTE_AI_RTD_TYPE: _ChannelResetAttribute.ValueType  # 4146
    CHANNEL_RESET_ATTRIBUTE_AI_TEMP_UNITS: _ChannelResetAttribute.ValueType  # 4147
    CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_CJC_VAL: _ChannelResetAttribute.ValueType  # 4150
    CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_TYPE: _ChannelResetAttribute.ValueType  # 4176
    CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_R1: _ChannelResetAttribute.ValueType  # 4193
    CHANNEL_RESET_ATTRIBUTE_CI_GPS_SYNC_METHOD: _ChannelResetAttribute.ValueType  # 4242
    CHANNEL_RESET_ATTRIBUTE_CI_GPS_SYNC_SRC: _ChannelResetAttribute.ValueType  # 4243
    CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_UNITS: _ChannelResetAttribute.ValueType  # 4244
    CHANNEL_RESET_ATTRIBUTE_AI_TERM_CFG: _ChannelResetAttribute.ValueType  # 4247
    CHANNEL_RESET_ATTRIBUTE_AO_CURRENT_UNITS: _ChannelResetAttribute.ValueType  # 4361
    CHANNEL_RESET_ATTRIBUTE_DO_INVERT_LINES: _ChannelResetAttribute.ValueType  # 4403
    CHANNEL_RESET_ATTRIBUTE_DO_OUTPUT_DRIVE_TYPE: _ChannelResetAttribute.ValueType  # 4407
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_HIGH_TICKS: _ChannelResetAttribute.ValueType  # 4457
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_IDLE_STATE: _ChannelResetAttribute.ValueType  # 4464
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_LOW_TICKS: _ChannelResetAttribute.ValueType  # 4465
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_DUTY_CYC: _ChannelResetAttribute.ValueType  # 4470
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ: _ChannelResetAttribute.ValueType  # 4472
    CHANNEL_RESET_ATTRIBUTE_AO_VOLTAGE_UNITS: _ChannelResetAttribute.ValueType  # 4484
    CHANNEL_RESET_ATTRIBUTE_AO_MAX: _ChannelResetAttribute.ValueType  # 4486
    CHANNEL_RESET_ATTRIBUTE_AO_MIN: _ChannelResetAttribute.ValueType  # 4487
    CHANNEL_RESET_ATTRIBUTE_AO_CUSTOM_SCALE_NAME: _ChannelResetAttribute.ValueType  # 4488
    CHANNEL_RESET_ATTRIBUTE_AO_OUTPUT_IMPEDANCE: _ChannelResetAttribute.ValueType  # 5264
    CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_UNITS: _ChannelResetAttribute.ValueType  # 5416
    CHANNEL_RESET_ATTRIBUTE_AI_MICROPHONE_SENSITIVITY: _ChannelResetAttribute.ValueType  # 5430
    CHANNEL_RESET_ATTRIBUTE_AI_AUTO_ZERO_MODE: _ChannelResetAttribute.ValueType  # 5984
    CHANNEL_RESET_ATTRIBUTE_AI_MAX: _ChannelResetAttribute.ValueType  # 6109
    CHANNEL_RESET_ATTRIBUTE_AI_MIN: _ChannelResetAttribute.ValueType  # 6110
    CHANNEL_RESET_ATTRIBUTE_AI_CUSTOM_SCALE_NAME: _ChannelResetAttribute.ValueType  # 6112
    CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_ACRMS_UNITS: _ChannelResetAttribute.ValueType  # 6114
    CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_ACRMS_UNITS: _ChannelResetAttribute.ValueType  # 6115
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_NOM_RESISTANCE: _ChannelResetAttribute.ValueType  # 6124
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_INITIAL_VOLTAGE: _ChannelResetAttribute.ValueType  # 6125
    CHANNEL_RESET_ATTRIBUTE_AI_LEAD_WIRE_RESISTANCE: _ChannelResetAttribute.ValueType  # 6126
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_BALANCE_COARSE_POT: _ChannelResetAttribute.ValueType  # 6129
    CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_SHUNT_LOC: _ChannelResetAttribute.ValueType  # 6130
    CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_SHUNT_RESISTANCE: _ChannelResetAttribute.ValueType  # 6131
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_SRC: _ChannelResetAttribute.ValueType  # 6132
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_VAL: _ChannelResetAttribute.ValueType  # 6133
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_VOLTAGE_OR_CURRENT: _ChannelResetAttribute.ValueType  # 6134
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_D_COR_AC: _ChannelResetAttribute.ValueType  # 6139
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_USE_FOR_SCALING: _ChannelResetAttribute.ValueType  # 6140
    CHANNEL_RESET_ATTRIBUTE_AI_ATTEN: _ChannelResetAttribute.ValueType  # 6145
    CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_ENABLE: _ChannelResetAttribute.ValueType  # 6146
    CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ: _ChannelResetAttribute.ValueType  # 6147
    CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_ENABLE: _ChannelResetAttribute.ValueType  # 6150
    CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_CUTOFF_FREQ: _ChannelResetAttribute.ValueType  # 6151
    CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_TYPE: _ChannelResetAttribute.ValueType  # 6152
    CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_ORDER: _ChannelResetAttribute.ValueType  # 6153
    CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_ENABLE: _ChannelResetAttribute.ValueType  # 6155
    CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_CENTER_FREQ: _ChannelResetAttribute.ValueType  # 6156
    CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_TYPE: _ChannelResetAttribute.ValueType  # 6157
    CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_WIDTH: _ChannelResetAttribute.ValueType  # 6158
    CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_CENTER_FREQ: _ChannelResetAttribute.ValueType  # 6160
    CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_TYPE: _ChannelResetAttribute.ValueType  # 6161
    CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_WIDTH: _ChannelResetAttribute.ValueType  # 6162
    CHANNEL_RESET_ATTRIBUTE_AI_RNG_HIGH: _ChannelResetAttribute.ValueType  # 6165
    CHANNEL_RESET_ATTRIBUTE_AI_RNG_LOW: _ChannelResetAttribute.ValueType  # 6166
    CHANNEL_RESET_ATTRIBUTE_AI_GAIN: _ChannelResetAttribute.ValueType  # 6168
    CHANNEL_RESET_ATTRIBUTE_AI_SAMP_AND_HOLD_ENABLE: _ChannelResetAttribute.ValueType  # 6170
    CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_MECH: _ChannelResetAttribute.ValueType  # 6177
    CHANNEL_RESET_ATTRIBUTE_AO_RESOLUTION_UNITS: _ChannelResetAttribute.ValueType  # 6187
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_RNG_LOW: _ChannelResetAttribute.ValueType  # 6189
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_RNG_HIGH: _ChannelResetAttribute.ValueType  # 6190
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_ALLOW_CONN_TO_GND: _ChannelResetAttribute.ValueType  # 6192
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_VAL: _ChannelResetAttribute.ValueType  # 6194
    CHANNEL_RESET_ATTRIBUTE_AO_USE_ONLY_ON_BRD_MEM: _ChannelResetAttribute.ValueType  # 6202
    CHANNEL_RESET_ATTRIBUTE_AO_DATA_XFER_REQ_COND: _ChannelResetAttribute.ValueType  # 6204
    CHANNEL_RESET_ATTRIBUTE_AI_RESISTANCE_CFG: _ChannelResetAttribute.ValueType  # 6273
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_ACTUAL_VAL: _ChannelResetAttribute.ValueType  # 6275
    CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_CLK_SRC: _ChannelResetAttribute.ValueType  # 6276
    CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_FREQ: _ChannelResetAttribute.ValueType  # 6277
    CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_DIV: _ChannelResetAttribute.ValueType  # 6278
    CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_OUT_CLK_DIV: _ChannelResetAttribute.ValueType  # 6279
    CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_REQ_COND: _ChannelResetAttribute.ValueType  # 6283
    CHANNEL_RESET_ATTRIBUTE_AI_MEM_MAP_ENABLE: _ChannelResetAttribute.ValueType  # 6284
    CHANNEL_RESET_ATTRIBUTE_AO_TERM_CFG: _ChannelResetAttribute.ValueType  # 6286
    CHANNEL_RESET_ATTRIBUTE_AO_MEM_MAP_ENABLE: _ChannelResetAttribute.ValueType  # 6287
    CHANNEL_RESET_ATTRIBUTE_DI_TRISTATE: _ChannelResetAttribute.ValueType  # 6288
    CHANNEL_RESET_ATTRIBUTE_CI_MAX: _ChannelResetAttribute.ValueType  # 6300
    CHANNEL_RESET_ATTRIBUTE_CI_MIN: _ChannelResetAttribute.ValueType  # 6301
    CHANNEL_RESET_ATTRIBUTE_CI_CUSTOM_SCALE_NAME: _ChannelResetAttribute.ValueType  # 6302
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_UNITS: _ChannelResetAttribute.ValueType  # 6305
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_TERM: _ChannelResetAttribute.ValueType  # 6306
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_UNITS: _ChannelResetAttribute.ValueType  # 6307
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_TERM: _ChannelResetAttribute.ValueType  # 6308
    CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_UNITS: _ChannelResetAttribute.ValueType  # 6310
    CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_UNITS: _ChannelResetAttribute.ValueType  # 6313
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_TERM: _ChannelResetAttribute.ValueType  # 6314
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_UNITS: _ChannelResetAttribute.ValueType  # 6316
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM: _ChannelResetAttribute.ValueType  # 6317
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM: _ChannelResetAttribute.ValueType  # 6318
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_UNITS: _ChannelResetAttribute.ValueType  # 6319
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_TERM: _ChannelResetAttribute.ValueType  # 6320
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 6322
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_MASTER_TIMEBASE_DIV: _ChannelResetAttribute.ValueType  # 6323
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_HIGH_TIME: _ChannelResetAttribute.ValueType  # 6330
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_LOW_TIME: _ChannelResetAttribute.ValueType  # 6331
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TIME_INITIAL_DELAY: _ChannelResetAttribute.ValueType  # 6332
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 6338
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_MASTER_TIMEBASE_DIV: _ChannelResetAttribute.ValueType  # 6339
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_TERM: _ChannelResetAttribute.ValueType  # 6343
    CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_A: _ChannelResetAttribute.ValueType  # 6345
    CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_C: _ChannelResetAttribute.ValueType  # 6346
    CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_B: _ChannelResetAttribute.ValueType  # 6347
    CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_WIRE_MODE: _ChannelResetAttribute.ValueType  # 6349
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ_UNITS: _ChannelResetAttribute.ValueType  # 6357
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TIME_UNITS: _ChannelResetAttribute.ValueType  # 6358
    CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TERM: _ChannelResetAttribute.ValueType  # 6369
    CHANNEL_RESET_ATTRIBUTE_DO_TRISTATE: _ChannelResetAttribute.ValueType  # 6387
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_BALANCE_FINE_POT: _ChannelResetAttribute.ValueType  # 6388
    CHANNEL_RESET_ATTRIBUTE_AI_FORCE_READ_FROM_CHAN: _ChannelResetAttribute.ValueType  # 6392
    CHANNEL_RESET_ATTRIBUTE_CHAN_DESCR: _ChannelResetAttribute.ValueType  # 6438
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_MEAS_METH: _ChannelResetAttribute.ValueType  # 6444
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_MEAS_TIME: _ChannelResetAttribute.ValueType  # 6445
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIV: _ChannelResetAttribute.ValueType  # 6446
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_GAIN_ADJUST: _ChannelResetAttribute.ValueType  # 6463
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_USE_MULTIPLEXED: _ChannelResetAttribute.ValueType  # 8576
    CHANNEL_RESET_ATTRIBUTE_AI_INPUT_SRC: _ChannelResetAttribute.ValueType  # 8600
    CHANNEL_RESET_ATTRIBUTE_AI_LVDT_SENSITIVITY_UNITS: _ChannelResetAttribute.ValueType  # 8602
    CHANNEL_RESET_ATTRIBUTE_AI_RVDT_SENSITIVITY_UNITS: _ChannelResetAttribute.ValueType  # 8603
    CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_SENSITIVITY_UNITS: _ChannelResetAttribute.ValueType  # 8604
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM: _ChannelResetAttribute.ValueType  # 8605
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM: _ChannelResetAttribute.ValueType  # 8606
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM: _ChannelResetAttribute.ValueType  # 8607
    CHANNEL_RESET_ATTRIBUTE_CI_DUP_COUNT_PREVENT: _ChannelResetAttribute.ValueType  # 8620
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SELECT: _ChannelResetAttribute.ValueType  # 8661
    CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8662
    CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8663
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIR_TERM: _ChannelResetAttribute.ValueType  # 8673
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_DECODING_TYPE: _ChannelResetAttribute.ValueType  # 8678
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8679
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8680
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8681
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8682
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8683
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8684
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8685
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8686
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8687
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8688
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8689
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8690
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8691
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8692
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8693
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8694
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8695
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8696
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8697
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8698
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8699
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8700
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8701
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8702
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8703
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8704
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8705
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8706
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8707
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8708
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8709
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8710
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8711
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8712
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8713
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8714
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8715
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8716
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8717
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8718
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8719
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8720
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8721
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8722
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8723
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8724
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8725
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8726
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8727
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8728
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8729
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8730
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8731
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8732
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8733
    CHANNEL_RESET_ATTRIBUTE_CI_PRESCALER: _ChannelResetAttribute.ValueType  # 8761
    CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_MAX_SOUND_PRESSURE_LVL: _ChannelResetAttribute.ValueType  # 8762
    CHANNEL_RESET_ATTRIBUTE_AO_IDLE_OUTPUT_BEHAVIOR: _ChannelResetAttribute.ValueType  # 8768
    CHANNEL_RESET_ATTRIBUTE_AO_ENHANCED_IMAGE_REJECTION_ENABLE: _ChannelResetAttribute.ValueType  # 8769
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_EXT_SRC: _ChannelResetAttribute.ValueType  # 8786
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_SRC: _ChannelResetAttribute.ValueType  # 8787
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_EXT_SRC: _ChannelResetAttribute.ValueType  # 8788
    CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_VAL: _ChannelResetAttribute.ValueType  # 8789
    CHANNEL_RESET_ATTRIBUTE_DI_DATA_XFER_MECH: _ChannelResetAttribute.ValueType  # 8803
    CHANNEL_RESET_ATTRIBUTE_DI_DATA_XFER_REQ_COND: _ChannelResetAttribute.ValueType  # 8804
    CHANNEL_RESET_ATTRIBUTE_DO_USE_ONLY_ON_BRD_MEM: _ChannelResetAttribute.ValueType  # 8805
    CHANNEL_RESET_ATTRIBUTE_DO_DATA_XFER_MECH: _ChannelResetAttribute.ValueType  # 8806
    CHANNEL_RESET_ATTRIBUTE_DO_DATA_XFER_REQ_COND: _ChannelResetAttribute.ValueType  # 8807
    CHANNEL_RESET_ATTRIBUTE_CO_PRESCALER: _ChannelResetAttribute.ValueType  # 8813
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8817
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8818
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8819
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8820
    CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8821
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 8822
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 8823
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 8824
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 8825
    CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 8826
    CHANNEL_RESET_ATTRIBUTE_AI_ENHANCED_ALIAS_REJECTION_ENABLE: _ChannelResetAttribute.ValueType  # 8852
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_ENABLE_CAL: _ChannelResetAttribute.ValueType  # 8856
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_APPLY_CAL_IF_EXP: _ChannelResetAttribute.ValueType  # 8857
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_SCALE_TYPE: _ChannelResetAttribute.ValueType  # 8860
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_TABLE_PRE_SCALED_VALS: _ChannelResetAttribute.ValueType  # 8861
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_TABLE_SCALED_VALS: _ChannelResetAttribute.ValueType  # 8862
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_POLY_FORWARD_COEFF: _ChannelResetAttribute.ValueType  # 8863
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_POLY_REVERSE_COEFF: _ChannelResetAttribute.ValueType  # 8864
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_VERIF_REF_VALS: _ChannelResetAttribute.ValueType  # 8865
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_VERIF_ACQ_VALS: _ChannelResetAttribute.ValueType  # 8866
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_OPERATOR_NAME: _ChannelResetAttribute.ValueType  # 8867
    CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_DESC: _ChannelResetAttribute.ValueType  # 8868
    CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_UNITS: _ChannelResetAttribute.ValueType  # 8883
    CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_INITIAL_SECONDS: _ChannelResetAttribute.ValueType  # 8884
    CHANNEL_RESET_ATTRIBUTE_AI_RAW_DATA_COMPRESSION_TYPE: _ChannelResetAttribute.ValueType  # 8920
    CHANNEL_RESET_ATTRIBUTE_AI_LOSSY_LSB_REMOVAL_COMPRESSED_SAMP_SIZE: _ChannelResetAttribute.ValueType  # 8921
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_STARTING_EDGE: _ChannelResetAttribute.ValueType  # 8958
    CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_CUSTOM_THRESHOLD: _ChannelResetAttribute.ValueType  # 8972
    CHANNEL_RESET_ATTRIBUTE_DI_ACQUIRE_ON: _ChannelResetAttribute.ValueType  # 10598
    CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_PAUSED_STATE: _ChannelResetAttribute.ValueType  # 10599
    CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_DONE_STATE: _ChannelResetAttribute.ValueType  # 10600
    CHANNEL_RESET_ATTRIBUTE_DO_GENERATE_ON: _ChannelResetAttribute.ValueType  # 10601
    CHANNEL_RESET_ATTRIBUTE_DI_MEM_MAP_ENABLE: _ChannelResetAttribute.ValueType  # 10602
    CHANNEL_RESET_ATTRIBUTE_DO_MEM_MAP_ENABLE: _ChannelResetAttribute.ValueType  # 10603
    CHANNEL_RESET_ATTRIBUTE_DI_LOGIC_FAMILY: _ChannelResetAttribute.ValueType  # 10605
    CHANNEL_RESET_ATTRIBUTE_DO_LOGIC_FAMILY: _ChannelResetAttribute.ValueType  # 10606
    CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_START_STATE: _ChannelResetAttribute.ValueType  # 10610
    CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_DB_REF: _ChannelResetAttribute.ValueType  # 10672
    CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_DB_REF: _ChannelResetAttribute.ValueType  # 10673
    CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_DB_REF: _ChannelResetAttribute.ValueType  # 10674
    CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_SCALE_TYPE: _ChannelResetAttribute.ValueType  # 10704
    CHANNEL_RESET_ATTRIBUTE_CO_CONSTRAINED_GEN_MODE: _ChannelResetAttribute.ValueType  # 10738
    CHANNEL_RESET_ATTRIBUTE_AI_ADC_TIMING_MODE: _ChannelResetAttribute.ValueType  # 10745
    CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_TYPE: _ChannelResetAttribute.ValueType  # 10776
    CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_FREQ: _ChannelResetAttribute.ValueType  # 10777
    CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_AMPLITUDE: _ChannelResetAttribute.ValueType  # 10778
    CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_OFFSET: _ChannelResetAttribute.ValueType  # 10779
    CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_SQUARE_DUTY_CYCLE: _ChannelResetAttribute.ValueType  # 10780
    CHANNEL_RESET_ATTRIBUTE_AO_VOLTAGE_CURRENT_LIMIT: _ChannelResetAttribute.ValueType  # 10781
    CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_MODULATION_TYPE: _ChannelResetAttribute.ValueType  # 10786
    CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_FM_DEVIATION: _ChannelResetAttribute.ValueType  # 10787
    CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_LIMIT: _ChannelResetAttribute.ValueType  # 10885
    CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_AUTO_REENABLE: _ChannelResetAttribute.ValueType  # 10886
    CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_REENABLE_PERIOD: _ChannelResetAttribute.ValueType  # 10887
    CHANNEL_RESET_ATTRIBUTE_AI_PROBE_ATTEN: _ChannelResetAttribute.ValueType  # 10888
    CHANNEL_RESET_ATTRIBUTE_AI_DC_OFFSET: _ChannelResetAttribute.ValueType  # 10889
    CHANNEL_RESET_ATTRIBUTE_AI_USB_XFER_REQ_SIZE: _ChannelResetAttribute.ValueType  # 10894
    CHANNEL_RESET_ATTRIBUTE_AO_USB_XFER_REQ_SIZE: _ChannelResetAttribute.ValueType  # 10895
    CHANNEL_RESET_ATTRIBUTE_DI_USB_XFER_REQ_SIZE: _ChannelResetAttribute.ValueType  # 10896
    CHANNEL_RESET_ATTRIBUTE_DO_USB_XFER_REQ_SIZE: _ChannelResetAttribute.ValueType  # 10897
    CHANNEL_RESET_ATTRIBUTE_CI_USB_XFER_REQ_SIZE: _ChannelResetAttribute.ValueType  # 10898
    CHANNEL_RESET_ATTRIBUTE_CO_USB_XFER_REQ_SIZE: _ChannelResetAttribute.ValueType  # 10899
    CHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY: _ChannelResetAttribute.ValueType  # 10942
    CHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS: _ChannelResetAttribute.ValueType  # 10943
    CHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_UNITS: _ChannelResetAttribute.ValueType  # 10944
    CHANNEL_RESET_ATTRIBUTE_CO_ENABLE_INITIAL_DELAY_ON_RETRIGGER: _ChannelResetAttribute.ValueType  # 11977
    CHANNEL_RESET_ATTRIBUTE_CO_USE_ONLY_ON_BRD_MEM: _ChannelResetAttribute.ValueType  # 11979
    CHANNEL_RESET_ATTRIBUTE_CO_DATA_XFER_MECH: _ChannelResetAttribute.ValueType  # 11980
    CHANNEL_RESET_ATTRIBUTE_CO_DATA_XFER_REQ_COND: _ChannelResetAttribute.ValueType  # 11981
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_ENABLE_AVERAGING: _ChannelResetAttribute.ValueType  # 11984
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_ENABLE_AVERAGING: _ChannelResetAttribute.ValueType  # 11985
    CHANNEL_RESET_ATTRIBUTE_CI_MEM_MAP_ENABLE: _ChannelResetAttribute.ValueType  # 11986
    CHANNEL_RESET_ATTRIBUTE_CO_MEM_MAP_ENABLE: _ChannelResetAttribute.ValueType  # 11987
    CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 11988
    CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 11989
    CHANNEL_RESET_ATTRIBUTE_DI_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 11990
    CHANNEL_RESET_ATTRIBUTE_CI_DATA_XFER_REQ_COND: _ChannelResetAttribute.ValueType  # 12027
    CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_ENABLE_BUS_MODE: _ChannelResetAttribute.ValueType  # 12030
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_TERM: _ChannelResetAttribute.ValueType  # 12036
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_START_EDGE: _ChannelResetAttribute.ValueType  # 12037
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12038
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 12039
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 12040
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 12041
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 12042
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_UNITS: _ChannelResetAttribute.ValueType  # 12043
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_TERM: _ChannelResetAttribute.ValueType  # 12044
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_START_EDGE: _ChannelResetAttribute.ValueType  # 12045
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12046
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 12047
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 12048
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 12049
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 12050
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_UNITS: _ChannelResetAttribute.ValueType  # 12051
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_TERM: _ChannelResetAttribute.ValueType  # 12052
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_START_EDGE: _ChannelResetAttribute.ValueType  # 12053
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12054
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 12055
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 12056
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 12057
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 12058
    CHANNEL_RESET_ATTRIBUTE_AI_ADC_CUSTOM_TIMING_MODE: _ChannelResetAttribute.ValueType  # 12139
    CHANNEL_RESET_ATTRIBUTE_AI_OPEN_THRMCPL_DETECT_ENABLE: _ChannelResetAttribute.ValueType  # 12146
    CHANNEL_RESET_ATTRIBUTE_AI_FORCE_UNITS: _ChannelResetAttribute.ValueType  # 12149
    CHANNEL_RESET_ATTRIBUTE_AI_PRESSURE_UNITS: _ChannelResetAttribute.ValueType  # 12150
    CHANNEL_RESET_ATTRIBUTE_AI_TORQUE_UNITS: _ChannelResetAttribute.ValueType  # 12151
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_RESISTANCE: _ChannelResetAttribute.ValueType  # 12152
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_ACTUAL_RESISTANCE: _ChannelResetAttribute.ValueType  # 12153
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_RESISTANCE: _ChannelResetAttribute.ValueType  # 12154
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_ACTUAL_RESISTANCE: _ChannelResetAttribute.ValueType  # 12155
    CHANNEL_RESET_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY: _ChannelResetAttribute.ValueType  # 12161
    CHANNEL_RESET_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS: _ChannelResetAttribute.ValueType  # 12162
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_INITIAL_RATIO: _ChannelResetAttribute.ValueType  # 12166
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_ELECTRICAL_UNITS: _ChannelResetAttribute.ValueType  # 12167
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_PHYSICAL_UNITS: _ChannelResetAttribute.ValueType  # 12168
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SCALE_TYPE: _ChannelResetAttribute.ValueType  # 12169
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_ELECTRICAL_VAL: _ChannelResetAttribute.ValueType  # 12170
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_PHYSICAL_VAL: _ChannelResetAttribute.ValueType  # 12171
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_ELECTRICAL_VAL: _ChannelResetAttribute.ValueType  # 12172
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_PHYSICAL_VAL: _ChannelResetAttribute.ValueType  # 12173
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TABLE_ELECTRICAL_VALS: _ChannelResetAttribute.ValueType  # 12174
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TABLE_PHYSICAL_VALS: _ChannelResetAttribute.ValueType  # 12175
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_POLY_FORWARD_COEFF: _ChannelResetAttribute.ValueType  # 12176
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_POLY_REVERSE_COEFF: _ChannelResetAttribute.ValueType  # 12177
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_UNITS: _ChannelResetAttribute.ValueType  # 12178
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ENABLE: _ChannelResetAttribute.ValueType  # 12207
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_RESET_COUNT: _ChannelResetAttribute.ValueType  # 12208
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM: _ChannelResetAttribute.ValueType  # 12209
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ACTIVE_EDGE: _ChannelResetAttribute.ValueType  # 12210
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12211
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 12212
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 12213
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 12214
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_SYNC_ENABLE: _ChannelResetAttribute.ValueType  # 12215
    CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_LEAD_OFFSET_VOLTAGE: _ChannelResetAttribute.ValueType  # 12216
    CHANNEL_RESET_ATTRIBUTE_AI_REMOVE_FILTER_DELAY: _ChannelResetAttribute.ValueType  # 12221
    CHANNEL_RESET_ATTRIBUTE_AI_AVERAGING_WIN_SIZE: _ChannelResetAttribute.ValueType  # 12270
    CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_UNITS: _ChannelResetAttribute.ValueType  # 12276
    CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_DB_REF: _ChannelResetAttribute.ValueType  # 12277
    CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY: _ChannelResetAttribute.ValueType  # 12278
    CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS: _ChannelResetAttribute.ValueType  # 12279
    CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_FORCE_READ_FROM_CHAN: _ChannelResetAttribute.ValueType  # 12282
    CHANNEL_RESET_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ORIENTATION: _ChannelResetAttribute.ValueType  # 12284
    CHANNEL_RESET_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_MEAS_TYPE: _ChannelResetAttribute.ValueType  # 12285
    CHANNEL_RESET_ATTRIBUTE_AI_USB_XFER_REQ_COUNT: _ChannelResetAttribute.ValueType  # 12288
    CHANNEL_RESET_ATTRIBUTE_AO_USB_XFER_REQ_COUNT: _ChannelResetAttribute.ValueType  # 12289
    CHANNEL_RESET_ATTRIBUTE_DI_USB_XFER_REQ_COUNT: _ChannelResetAttribute.ValueType  # 12290
    CHANNEL_RESET_ATTRIBUTE_DO_USB_XFER_REQ_COUNT: _ChannelResetAttribute.ValueType  # 12291
    CHANNEL_RESET_ATTRIBUTE_CI_USB_XFER_REQ_COUNT: _ChannelResetAttribute.ValueType  # 12292
    CHANNEL_RESET_ATTRIBUTE_CO_USB_XFER_REQ_COUNT: _ChannelResetAttribute.ValueType  # 12293
    CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_TERM: _ChannelResetAttribute.ValueType  # 12345
    CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_EDGE: _ChannelResetAttribute.ValueType  # 12346
    CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_TIMESCALE: _ChannelResetAttribute.ValueType  # 12347
    CHANNEL_RESET_ATTRIBUTE_NAV_CUSTOM_SCALE_NAME: _ChannelResetAttribute.ValueType  # 12348
    CHANNEL_RESET_ATTRIBUTE_NAV_ALT_UNITS: _ChannelResetAttribute.ValueType  # 12350
    CHANNEL_RESET_ATTRIBUTE_NAV_LAT_UNITS: _ChannelResetAttribute.ValueType  # 12351
    CHANNEL_RESET_ATTRIBUTE_NAV_LONG_UNITS: _ChannelResetAttribute.ValueType  # 12352
    CHANNEL_RESET_ATTRIBUTE_NAV_SPEED_OVER_GROUND_UNITS: _ChannelResetAttribute.ValueType  # 12353
    CHANNEL_RESET_ATTRIBUTE_NAV_TRACK_UNITS: _ChannelResetAttribute.ValueType  # 12354
    CHANNEL_RESET_ATTRIBUTE_NAV_VERT_VELOCITY_UNITS: _ChannelResetAttribute.ValueType  # 12355
    CHANNEL_RESET_ATTRIBUTE_NAV_TIMESTAMP_UNITS: _ChannelResetAttribute.ValueType  # 12356
    CHANNEL_RESET_ATTRIBUTE_NAV_TIMESTAMP_TIMESCALE: _ChannelResetAttribute.ValueType  # 12357
    CHANNEL_RESET_ATTRIBUTE_AI_FILTER_DELAY_UNITS: _ChannelResetAttribute.ValueType  # 12401
    CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY_ADJUSTMENT: _ChannelResetAttribute.ValueType  # 12402
    CHANNEL_RESET_ATTRIBUTE_AI_FILTER_DELAY_ADJUSTMENT: _ChannelResetAttribute.ValueType  # 12404
    CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY: _ChannelResetAttribute.ValueType  # 12405
    CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY_UNITS: _ChannelResetAttribute.ValueType  # 12406
    CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_TERM: _ChannelResetAttribute.ValueType  # 12429
    CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12430
    CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 12431
    CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 12432
    CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 12433
    CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_STARTING_EDGE: _ChannelResetAttribute.ValueType  # 12434
    CHANNEL_RESET_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12435
    CHANNEL_RESET_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_SENTINEL_VAL: _ChannelResetAttribute.ValueType  # 12436
    CHANNEL_RESET_ATTRIBUTE_CI_MAX_MEAS_PERIOD: _ChannelResetAttribute.ValueType  # 12437
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_TERM_CFG: _ChannelResetAttribute.ValueType  # 12439
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12440
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_TERM_CFG: _ChannelResetAttribute.ValueType  # 12441
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12442
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_TERM_CFG: _ChannelResetAttribute.ValueType  # 12443
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12444
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_TERM_CFG: _ChannelResetAttribute.ValueType  # 12445
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12446
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM_CFG: _ChannelResetAttribute.ValueType  # 12447
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12448
    CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_TERM_CFG: _ChannelResetAttribute.ValueType  # 12449
    CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12450
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM_CFG: _ChannelResetAttribute.ValueType  # 12451
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12452
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM_CFG: _ChannelResetAttribute.ValueType  # 12453
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12454
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM_CFG: _ChannelResetAttribute.ValueType  # 12455
    CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12456
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_TERM_CFG: _ChannelResetAttribute.ValueType  # 12457
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12458
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM_CFG: _ChannelResetAttribute.ValueType  # 12459
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12460
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM_CFG: _ChannelResetAttribute.ValueType  # 12461
    CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12462
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_TERM_CFG: _ChannelResetAttribute.ValueType  # 12463
    CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12464
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_TERM_CFG: _ChannelResetAttribute.ValueType  # 12465
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12466
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_TERM_CFG: _ChannelResetAttribute.ValueType  # 12467
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12468
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_TERM_CFG: _ChannelResetAttribute.ValueType  # 12469
    CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12470
    CHANNEL_RESET_ATTRIBUTE_CI_THRESH_VOLTAGE: _ChannelResetAttribute.ValueType  # 12471
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_IDLE_OUTPUT_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12472
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12477
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_TYPE: _ChannelResetAttribute.ValueType  # 12478
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_RESPONSE: _ChannelResetAttribute.ValueType  # 12479
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_ORDER: _ChannelResetAttribute.ValueType  # 12480
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ: _ChannelResetAttribute.ValueType  # 12481
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_HIGHPASS_CUTOFF_FREQ: _ChannelResetAttribute.ValueType  # 12482
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_CENTER_FREQ: _ChannelResetAttribute.ValueType  # 12483
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_WIDTH: _ChannelResetAttribute.ValueType  # 12484
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_NOTCH_CENTER_FREQ: _ChannelResetAttribute.ValueType  # 12485
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_NOTCH_WIDTH: _ChannelResetAttribute.ValueType  # 12486
    CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_COEFF: _ChannelResetAttribute.ValueType  # 12487
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_SRC: _ChannelResetAttribute.ValueType  # 12490
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_UNITS: _ChannelResetAttribute.ValueType  # 12504
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_PULSES_PER_REV: _ChannelResetAttribute.ValueType  # 12505
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_UNITS: _ChannelResetAttribute.ValueType  # 12506
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_DIST_PER_PULSE: _ChannelResetAttribute.ValueType  # 12507
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_DECODING_TYPE: _ChannelResetAttribute.ValueType  # 12508
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM: _ChannelResetAttribute.ValueType  # 12509
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM_CFG: _ChannelResetAttribute.ValueType  # 12510
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12511
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12512
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 12513
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 12514
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 12515
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM: _ChannelResetAttribute.ValueType  # 12516
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM_CFG: _ChannelResetAttribute.ValueType  # 12517
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12518
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12519
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 12520
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 12521
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 12522
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_MEAS_TIME: _ChannelResetAttribute.ValueType  # 12523
    CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_DIV: _ChannelResetAttribute.ValueType  # 12524
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_ENABLE: _ChannelResetAttribute.ValueType  # 12525
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM: _ChannelResetAttribute.ValueType  # 12526
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM_CFG: _ChannelResetAttribute.ValueType  # 12527
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_LOGIC_LVL_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12528
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_ENABLE: _ChannelResetAttribute.ValueType  # 12529
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_MIN_PULSE_WIDTH: _ChannelResetAttribute.ValueType  # 12530
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_SRC: _ChannelResetAttribute.ValueType  # 12531
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_RATE: _ChannelResetAttribute.ValueType  # 12532
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_WHEN: _ChannelResetAttribute.ValueType  # 12533
    CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_SRC: _ChannelResetAttribute.ValueType  # 12535
    CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_SENSE: _ChannelResetAttribute.ValueType  # 12541
    CHANNEL_RESET_ATTRIBUTE_AI_OPEN_CHAN_DETECT_ENABLE: _ChannelResetAttribute.ValueType  # 12543
    CHANNEL_RESET_ATTRIBUTE_AI_CHARGE_UNITS: _ChannelResetAttribute.ValueType  # 12562
    CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY: _ChannelResetAttribute.ValueType  # 12563
    CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY_UNITS: _ChannelResetAttribute.ValueType  # 12564
    CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY: _ChannelResetAttribute.ValueType  # 12565
    CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY_UNITS: _ChannelResetAttribute.ValueType  # 12566
    CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_MAX_RATE: _ChannelResetAttribute.ValueType  # 12567
    CHANNEL_RESET_ATTRIBUTE_CHAN_SYNC_UNLOCK_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12604
    CHANNEL_RESET_ATTRIBUTE_AI_CHOP_ENABLE: _ChannelResetAttribute.ValueType  # 12611
    CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_VOLTAGE: _ChannelResetAttribute.ValueType  # 12649
    CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_CFG: _ChannelResetAttribute.ValueType  # 12650
    CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_TYPE: _ChannelResetAttribute.ValueType  # 12651
    CHANNEL_RESET_ATTRIBUTE_AI_FILTER_ENABLE: _ChannelResetAttribute.ValueType  # 12659
    CHANNEL_RESET_ATTRIBUTE_AI_FILTER_FREQ: _ChannelResetAttribute.ValueType  # 12660
    CHANNEL_RESET_ATTRIBUTE_AI_FILTER_RESPONSE: _ChannelResetAttribute.ValueType  # 12661
    CHANNEL_RESET_ATTRIBUTE_AI_FILTER_ORDER: _ChannelResetAttribute.ValueType  # 12662
    CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_UPPER_LIMIT: _ChannelResetAttribute.ValueType  # 12684
    CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_LOWER_LIMIT: _ChannelResetAttribute.ValueType  # 12685
    CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_ENABLE: _ChannelResetAttribute.ValueType  # 12686
    CHANNEL_RESET_ATTRIBUTE_AI_POWER_SUPPLY_FAULT_DETECT_ENABLE: _ChannelResetAttribute.ValueType  # 12689
    CHANNEL_RESET_ATTRIBUTE_AI_OVERCURRENT_DETECT_ENABLE: _ChannelResetAttribute.ValueType  # 12692
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_THRESH_VOLTAGE: _ChannelResetAttribute.ValueType  # 12715
    CHANNEL_RESET_ATTRIBUTE_CI_FREQ_HYST: _ChannelResetAttribute.ValueType  # 12716
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_THRESH_VOLTAGE: _ChannelResetAttribute.ValueType  # 12717
    CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_HYST: _ChannelResetAttribute.ValueType  # 12718
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_THRESH_VOLTAGE: _ChannelResetAttribute.ValueType  # 12719
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_HYST: _ChannelResetAttribute.ValueType  # 12720
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_THRESH_VOLTAGE: _ChannelResetAttribute.ValueType  # 12721
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_HYST: _ChannelResetAttribute.ValueType  # 12722
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_THRESH_VOLTAGE: _ChannelResetAttribute.ValueType  # 12723
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_HYST: _ChannelResetAttribute.ValueType  # 12724
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_THRESH_VOLTAGE: _ChannelResetAttribute.ValueType  # 12725
    CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_HYST: _ChannelResetAttribute.ValueType  # 12726
    CHANNEL_RESET_ATTRIBUTE_CI_FILTER_ENABLE: _ChannelResetAttribute.ValueType  # 12727
    CHANNEL_RESET_ATTRIBUTE_CI_FILTER_FREQ: _ChannelResetAttribute.ValueType  # 12728
    CHANNEL_RESET_ATTRIBUTE_CI_FILTER_RESPONSE: _ChannelResetAttribute.ValueType  # 12729
    CHANNEL_RESET_ATTRIBUTE_CI_FILTER_ORDER: _ChannelResetAttribute.ValueType  # 12730
    CHANNEL_RESET_ATTRIBUTE_CI_FILTER_DELAY_UNITS: _ChannelResetAttribute.ValueType  # 12732
    CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_START_PHASE: _ChannelResetAttribute.ValueType  # 12740
    CHANNEL_RESET_ATTRIBUTE_AO_COMMON_MODE_OFFSET: _ChannelResetAttribute.ValueType  # 12748
    CHANNEL_RESET_ATTRIBUTE_PWR_VOLTAGE_SETPOINT: _ChannelResetAttribute.ValueType  # 12756
    CHANNEL_RESET_ATTRIBUTE_PWR_CURRENT_SETPOINT: _ChannelResetAttribute.ValueType  # 12757
    CHANNEL_RESET_ATTRIBUTE_PWR_OUTPUT_ENABLE: _ChannelResetAttribute.ValueType  # 12758
    CHANNEL_RESET_ATTRIBUTE_PWR_IDLE_OUTPUT_BEHAVIOR: _ChannelResetAttribute.ValueType  # 12760
    CHANNEL_RESET_ATTRIBUTE_PWR_REMOTE_SENSE: _ChannelResetAttribute.ValueType  # 12763

class ChannelResetAttribute(_ChannelResetAttribute, metaclass=_ChannelResetAttributeEnumTypeWrapper): ...

CHANNEL_RESET_ATTRIBUTE_UNSPECIFIED: ChannelResetAttribute.ValueType  # 0
CHANNEL_RESET_ATTRIBUTE_AI_IMPEDANCE: ChannelResetAttribute.ValueType  # 98
CHANNEL_RESET_ATTRIBUTE_AI_COUPLING: ChannelResetAttribute.ValueType  # 100
CHANNEL_RESET_ATTRIBUTE_AI_DITHER_ENABLE: ChannelResetAttribute.ValueType  # 104
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_CFG: ChannelResetAttribute.ValueType  # 135
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_ENABLE: ChannelResetAttribute.ValueType  # 148
CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_FREQ: ChannelResetAttribute.ValueType  # 257
CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 258
CHANNEL_RESET_ATTRIBUTE_AO_GAIN: ChannelResetAttribute.ValueType  # 280
CHANNEL_RESET_ATTRIBUTE_AO_LOAD_IMPEDANCE: ChannelResetAttribute.ValueType  # 289
CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_CONN_TO_GND: ChannelResetAttribute.ValueType  # 304
CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_SRC: ChannelResetAttribute.ValueType  # 306
CHANNEL_RESET_ATTRIBUTE_AO_REGLITCH_ENABLE: ChannelResetAttribute.ValueType  # 307
CHANNEL_RESET_ATTRIBUTE_AO_DATA_XFER_MECH: ChannelResetAttribute.ValueType  # 308
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_ACTIVE_EDGE: ChannelResetAttribute.ValueType  # 322
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 323
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_MEAS_METH: ChannelResetAttribute.ValueType  # 324
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_MEAS_TIME: ChannelResetAttribute.ValueType  # 325
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIV: ChannelResetAttribute.ValueType  # 327
CHANNEL_RESET_ATTRIBUTE_CI_DATA_XFER_MECH: ChannelResetAttribute.ValueType  # 512
CHANNEL_RESET_ATTRIBUTE_CO_AUTO_INCR_CNT: ChannelResetAttribute.ValueType  # 661
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TICKS_INITIAL_DELAY: ChannelResetAttribute.ValueType  # 664
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ_INITIAL_DELAY: ChannelResetAttribute.ValueType  # 665
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 825
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_ACTIVE_EDGE: ChannelResetAttribute.ValueType  # 833
CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_UNITS: ChannelResetAttribute.ValueType  # 1651
CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_SENSITIVITY: ChannelResetAttribute.ValueType  # 1682
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIR: ChannelResetAttribute.ValueType  # 1686
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_ACTIVE_EDGE: ChannelResetAttribute.ValueType  # 1687
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_INITIAL_CNT: ChannelResetAttribute.ValueType  # 1688
CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_UNITS: ChannelResetAttribute.ValueType  # 1793
CHANNEL_RESET_ATTRIBUTE_DI_INVERT_LINES: ChannelResetAttribute.ValueType  # 1939
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_STARTING_EDGE: ChannelResetAttribute.ValueType  # 1945
CHANNEL_RESET_ATTRIBUTE_AI_FREQ_UNITS: ChannelResetAttribute.ValueType  # 2054
CHANNEL_RESET_ATTRIBUTE_AI_FREQ_HYST: ChannelResetAttribute.ValueType  # 2068
CHANNEL_RESET_ATTRIBUTE_AI_FREQ_THRESH_VOLTAGE: ChannelResetAttribute.ValueType  # 2069
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_UNITS: ChannelResetAttribute.ValueType  # 2083
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_STARTING_EDGE: ChannelResetAttribute.ValueType  # 2085
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_EDGE: ChannelResetAttribute.ValueType  # 2099
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_EDGE: ChannelResetAttribute.ValueType  # 2100
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_STARTING_EDGE: ChannelResetAttribute.ValueType  # 2130
CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_PULSES_PER_REV: ChannelResetAttribute.ValueType  # 2165
CHANNEL_RESET_ATTRIBUTE_AI_RVDT_UNITS: ChannelResetAttribute.ValueType  # 2167
CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_INITIAL_ANGLE: ChannelResetAttribute.ValueType  # 2177
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_VAL: ChannelResetAttribute.ValueType  # 2184
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_PHASE: ChannelResetAttribute.ValueType  # 2185
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INDEX_ENABLE: ChannelResetAttribute.ValueType  # 2192
CHANNEL_RESET_ATTRIBUTE_AI_RVDT_SENSITIVITY: ChannelResetAttribute.ValueType  # 2307
CHANNEL_RESET_ATTRIBUTE_AI_LVDT_UNITS: ChannelResetAttribute.ValueType  # 2320
CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_DIST_PER_PULSE: ChannelResetAttribute.ValueType  # 2321
CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_INITIAL_POS: ChannelResetAttribute.ValueType  # 2325
CHANNEL_RESET_ATTRIBUTE_AI_LVDT_SENSITIVITY: ChannelResetAttribute.ValueType  # 2361
CHANNEL_RESET_ATTRIBUTE_AI_RESISTANCE_UNITS: ChannelResetAttribute.ValueType  # 2389
CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_UNITS: ChannelResetAttribute.ValueType  # 2433
CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_CFG: ChannelResetAttribute.ValueType  # 2434
CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_GAGE_FACTOR: ChannelResetAttribute.ValueType  # 2452
CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_POISSON_RATIO: ChannelResetAttribute.ValueType  # 2456
CHANNEL_RESET_ATTRIBUTE_AI_RTD_A: ChannelResetAttribute.ValueType  # 4112
CHANNEL_RESET_ATTRIBUTE_AI_RTD_B: ChannelResetAttribute.ValueType  # 4113
CHANNEL_RESET_ATTRIBUTE_AI_RTD_C: ChannelResetAttribute.ValueType  # 4115
CHANNEL_RESET_ATTRIBUTE_AI_RTD_R0: ChannelResetAttribute.ValueType  # 4144
CHANNEL_RESET_ATTRIBUTE_AI_RTD_TYPE: ChannelResetAttribute.ValueType  # 4146
CHANNEL_RESET_ATTRIBUTE_AI_TEMP_UNITS: ChannelResetAttribute.ValueType  # 4147
CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_CJC_VAL: ChannelResetAttribute.ValueType  # 4150
CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_TYPE: ChannelResetAttribute.ValueType  # 4176
CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_R1: ChannelResetAttribute.ValueType  # 4193
CHANNEL_RESET_ATTRIBUTE_CI_GPS_SYNC_METHOD: ChannelResetAttribute.ValueType  # 4242
CHANNEL_RESET_ATTRIBUTE_CI_GPS_SYNC_SRC: ChannelResetAttribute.ValueType  # 4243
CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_UNITS: ChannelResetAttribute.ValueType  # 4244
CHANNEL_RESET_ATTRIBUTE_AI_TERM_CFG: ChannelResetAttribute.ValueType  # 4247
CHANNEL_RESET_ATTRIBUTE_AO_CURRENT_UNITS: ChannelResetAttribute.ValueType  # 4361
CHANNEL_RESET_ATTRIBUTE_DO_INVERT_LINES: ChannelResetAttribute.ValueType  # 4403
CHANNEL_RESET_ATTRIBUTE_DO_OUTPUT_DRIVE_TYPE: ChannelResetAttribute.ValueType  # 4407
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_HIGH_TICKS: ChannelResetAttribute.ValueType  # 4457
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_IDLE_STATE: ChannelResetAttribute.ValueType  # 4464
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_LOW_TICKS: ChannelResetAttribute.ValueType  # 4465
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_DUTY_CYC: ChannelResetAttribute.ValueType  # 4470
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ: ChannelResetAttribute.ValueType  # 4472
CHANNEL_RESET_ATTRIBUTE_AO_VOLTAGE_UNITS: ChannelResetAttribute.ValueType  # 4484
CHANNEL_RESET_ATTRIBUTE_AO_MAX: ChannelResetAttribute.ValueType  # 4486
CHANNEL_RESET_ATTRIBUTE_AO_MIN: ChannelResetAttribute.ValueType  # 4487
CHANNEL_RESET_ATTRIBUTE_AO_CUSTOM_SCALE_NAME: ChannelResetAttribute.ValueType  # 4488
CHANNEL_RESET_ATTRIBUTE_AO_OUTPUT_IMPEDANCE: ChannelResetAttribute.ValueType  # 5264
CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_UNITS: ChannelResetAttribute.ValueType  # 5416
CHANNEL_RESET_ATTRIBUTE_AI_MICROPHONE_SENSITIVITY: ChannelResetAttribute.ValueType  # 5430
CHANNEL_RESET_ATTRIBUTE_AI_AUTO_ZERO_MODE: ChannelResetAttribute.ValueType  # 5984
CHANNEL_RESET_ATTRIBUTE_AI_MAX: ChannelResetAttribute.ValueType  # 6109
CHANNEL_RESET_ATTRIBUTE_AI_MIN: ChannelResetAttribute.ValueType  # 6110
CHANNEL_RESET_ATTRIBUTE_AI_CUSTOM_SCALE_NAME: ChannelResetAttribute.ValueType  # 6112
CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_ACRMS_UNITS: ChannelResetAttribute.ValueType  # 6114
CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_ACRMS_UNITS: ChannelResetAttribute.ValueType  # 6115
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_NOM_RESISTANCE: ChannelResetAttribute.ValueType  # 6124
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_INITIAL_VOLTAGE: ChannelResetAttribute.ValueType  # 6125
CHANNEL_RESET_ATTRIBUTE_AI_LEAD_WIRE_RESISTANCE: ChannelResetAttribute.ValueType  # 6126
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_BALANCE_COARSE_POT: ChannelResetAttribute.ValueType  # 6129
CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_SHUNT_LOC: ChannelResetAttribute.ValueType  # 6130
CHANNEL_RESET_ATTRIBUTE_AI_CURRENT_SHUNT_RESISTANCE: ChannelResetAttribute.ValueType  # 6131
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_SRC: ChannelResetAttribute.ValueType  # 6132
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_VAL: ChannelResetAttribute.ValueType  # 6133
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_VOLTAGE_OR_CURRENT: ChannelResetAttribute.ValueType  # 6134
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_D_COR_AC: ChannelResetAttribute.ValueType  # 6139
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_USE_FOR_SCALING: ChannelResetAttribute.ValueType  # 6140
CHANNEL_RESET_ATTRIBUTE_AI_ATTEN: ChannelResetAttribute.ValueType  # 6145
CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_ENABLE: ChannelResetAttribute.ValueType  # 6146
CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ: ChannelResetAttribute.ValueType  # 6147
CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_ENABLE: ChannelResetAttribute.ValueType  # 6150
CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_CUTOFF_FREQ: ChannelResetAttribute.ValueType  # 6151
CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_TYPE: ChannelResetAttribute.ValueType  # 6152
CHANNEL_RESET_ATTRIBUTE_AI_HIGHPASS_ORDER: ChannelResetAttribute.ValueType  # 6153
CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_ENABLE: ChannelResetAttribute.ValueType  # 6155
CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_CENTER_FREQ: ChannelResetAttribute.ValueType  # 6156
CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_TYPE: ChannelResetAttribute.ValueType  # 6157
CHANNEL_RESET_ATTRIBUTE_AI_BANDPASS_WIDTH: ChannelResetAttribute.ValueType  # 6158
CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_CENTER_FREQ: ChannelResetAttribute.ValueType  # 6160
CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_TYPE: ChannelResetAttribute.ValueType  # 6161
CHANNEL_RESET_ATTRIBUTE_AI_NOTCH_WIDTH: ChannelResetAttribute.ValueType  # 6162
CHANNEL_RESET_ATTRIBUTE_AI_RNG_HIGH: ChannelResetAttribute.ValueType  # 6165
CHANNEL_RESET_ATTRIBUTE_AI_RNG_LOW: ChannelResetAttribute.ValueType  # 6166
CHANNEL_RESET_ATTRIBUTE_AI_GAIN: ChannelResetAttribute.ValueType  # 6168
CHANNEL_RESET_ATTRIBUTE_AI_SAMP_AND_HOLD_ENABLE: ChannelResetAttribute.ValueType  # 6170
CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_MECH: ChannelResetAttribute.ValueType  # 6177
CHANNEL_RESET_ATTRIBUTE_AO_RESOLUTION_UNITS: ChannelResetAttribute.ValueType  # 6187
CHANNEL_RESET_ATTRIBUTE_AO_DAC_RNG_LOW: ChannelResetAttribute.ValueType  # 6189
CHANNEL_RESET_ATTRIBUTE_AO_DAC_RNG_HIGH: ChannelResetAttribute.ValueType  # 6190
CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_ALLOW_CONN_TO_GND: ChannelResetAttribute.ValueType  # 6192
CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_VAL: ChannelResetAttribute.ValueType  # 6194
CHANNEL_RESET_ATTRIBUTE_AO_USE_ONLY_ON_BRD_MEM: ChannelResetAttribute.ValueType  # 6202
CHANNEL_RESET_ATTRIBUTE_AO_DATA_XFER_REQ_COND: ChannelResetAttribute.ValueType  # 6204
CHANNEL_RESET_ATTRIBUTE_AI_RESISTANCE_CFG: ChannelResetAttribute.ValueType  # 6273
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_ACTUAL_VAL: ChannelResetAttribute.ValueType  # 6275
CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_CLK_SRC: ChannelResetAttribute.ValueType  # 6276
CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_FREQ: ChannelResetAttribute.ValueType  # 6277
CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_DIV: ChannelResetAttribute.ValueType  # 6278
CHANNEL_RESET_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_OUT_CLK_DIV: ChannelResetAttribute.ValueType  # 6279
CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_REQ_COND: ChannelResetAttribute.ValueType  # 6283
CHANNEL_RESET_ATTRIBUTE_AI_MEM_MAP_ENABLE: ChannelResetAttribute.ValueType  # 6284
CHANNEL_RESET_ATTRIBUTE_AO_TERM_CFG: ChannelResetAttribute.ValueType  # 6286
CHANNEL_RESET_ATTRIBUTE_AO_MEM_MAP_ENABLE: ChannelResetAttribute.ValueType  # 6287
CHANNEL_RESET_ATTRIBUTE_DI_TRISTATE: ChannelResetAttribute.ValueType  # 6288
CHANNEL_RESET_ATTRIBUTE_CI_MAX: ChannelResetAttribute.ValueType  # 6300
CHANNEL_RESET_ATTRIBUTE_CI_MIN: ChannelResetAttribute.ValueType  # 6301
CHANNEL_RESET_ATTRIBUTE_CI_CUSTOM_SCALE_NAME: ChannelResetAttribute.ValueType  # 6302
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_UNITS: ChannelResetAttribute.ValueType  # 6305
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_TERM: ChannelResetAttribute.ValueType  # 6306
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_UNITS: ChannelResetAttribute.ValueType  # 6307
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_TERM: ChannelResetAttribute.ValueType  # 6308
CHANNEL_RESET_ATTRIBUTE_CI_ANG_ENCODER_UNITS: ChannelResetAttribute.ValueType  # 6310
CHANNEL_RESET_ATTRIBUTE_CI_LIN_ENCODER_UNITS: ChannelResetAttribute.ValueType  # 6313
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_TERM: ChannelResetAttribute.ValueType  # 6314
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_UNITS: ChannelResetAttribute.ValueType  # 6316
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM: ChannelResetAttribute.ValueType  # 6317
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM: ChannelResetAttribute.ValueType  # 6318
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_UNITS: ChannelResetAttribute.ValueType  # 6319
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_TERM: ChannelResetAttribute.ValueType  # 6320
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 6322
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_MASTER_TIMEBASE_DIV: ChannelResetAttribute.ValueType  # 6323
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_HIGH_TIME: ChannelResetAttribute.ValueType  # 6330
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_LOW_TIME: ChannelResetAttribute.ValueType  # 6331
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TIME_INITIAL_DELAY: ChannelResetAttribute.ValueType  # 6332
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 6338
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_MASTER_TIMEBASE_DIV: ChannelResetAttribute.ValueType  # 6339
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_TERM: ChannelResetAttribute.ValueType  # 6343
CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_A: ChannelResetAttribute.ValueType  # 6345
CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_C: ChannelResetAttribute.ValueType  # 6346
CHANNEL_RESET_ATTRIBUTE_AI_THRMSTR_B: ChannelResetAttribute.ValueType  # 6347
CHANNEL_RESET_ATTRIBUTE_AI_AC_EXCIT_WIRE_MODE: ChannelResetAttribute.ValueType  # 6349
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_FREQ_UNITS: ChannelResetAttribute.ValueType  # 6357
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TIME_UNITS: ChannelResetAttribute.ValueType  # 6358
CHANNEL_RESET_ATTRIBUTE_CO_PULSE_TERM: ChannelResetAttribute.ValueType  # 6369
CHANNEL_RESET_ATTRIBUTE_DO_TRISTATE: ChannelResetAttribute.ValueType  # 6387
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_BALANCE_FINE_POT: ChannelResetAttribute.ValueType  # 6388
CHANNEL_RESET_ATTRIBUTE_AI_FORCE_READ_FROM_CHAN: ChannelResetAttribute.ValueType  # 6392
CHANNEL_RESET_ATTRIBUTE_CHAN_DESCR: ChannelResetAttribute.ValueType  # 6438
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_MEAS_METH: ChannelResetAttribute.ValueType  # 6444
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_MEAS_TIME: ChannelResetAttribute.ValueType  # 6445
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIV: ChannelResetAttribute.ValueType  # 6446
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_GAIN_ADJUST: ChannelResetAttribute.ValueType  # 6463
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_USE_MULTIPLEXED: ChannelResetAttribute.ValueType  # 8576
CHANNEL_RESET_ATTRIBUTE_AI_INPUT_SRC: ChannelResetAttribute.ValueType  # 8600
CHANNEL_RESET_ATTRIBUTE_AI_LVDT_SENSITIVITY_UNITS: ChannelResetAttribute.ValueType  # 8602
CHANNEL_RESET_ATTRIBUTE_AI_RVDT_SENSITIVITY_UNITS: ChannelResetAttribute.ValueType  # 8603
CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_SENSITIVITY_UNITS: ChannelResetAttribute.ValueType  # 8604
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM: ChannelResetAttribute.ValueType  # 8605
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM: ChannelResetAttribute.ValueType  # 8606
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM: ChannelResetAttribute.ValueType  # 8607
CHANNEL_RESET_ATTRIBUTE_CI_DUP_COUNT_PREVENT: ChannelResetAttribute.ValueType  # 8620
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SELECT: ChannelResetAttribute.ValueType  # 8661
CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8662
CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8663
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIR_TERM: ChannelResetAttribute.ValueType  # 8673
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_DECODING_TYPE: ChannelResetAttribute.ValueType  # 8678
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8679
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8680
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8681
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8682
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8683
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8684
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8685
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8686
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8687
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8688
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8689
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8690
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8691
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8692
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8693
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8694
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8695
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8696
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8697
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8698
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8699
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8700
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8701
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8702
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8703
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8704
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8705
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8706
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8707
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8708
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8709
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8710
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8711
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8712
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8713
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8714
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8715
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8716
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8717
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8718
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8719
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8720
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8721
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8722
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8723
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8724
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8725
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8726
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8727
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8728
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8729
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8730
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8731
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8732
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8733
CHANNEL_RESET_ATTRIBUTE_CI_PRESCALER: ChannelResetAttribute.ValueType  # 8761
CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_MAX_SOUND_PRESSURE_LVL: ChannelResetAttribute.ValueType  # 8762
CHANNEL_RESET_ATTRIBUTE_AO_IDLE_OUTPUT_BEHAVIOR: ChannelResetAttribute.ValueType  # 8768
CHANNEL_RESET_ATTRIBUTE_AO_ENHANCED_IMAGE_REJECTION_ENABLE: ChannelResetAttribute.ValueType  # 8769
CHANNEL_RESET_ATTRIBUTE_AO_DAC_REF_EXT_SRC: ChannelResetAttribute.ValueType  # 8786
CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_SRC: ChannelResetAttribute.ValueType  # 8787
CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_EXT_SRC: ChannelResetAttribute.ValueType  # 8788
CHANNEL_RESET_ATTRIBUTE_AO_DAC_OFFSET_VAL: ChannelResetAttribute.ValueType  # 8789
CHANNEL_RESET_ATTRIBUTE_DI_DATA_XFER_MECH: ChannelResetAttribute.ValueType  # 8803
CHANNEL_RESET_ATTRIBUTE_DI_DATA_XFER_REQ_COND: ChannelResetAttribute.ValueType  # 8804
CHANNEL_RESET_ATTRIBUTE_DO_USE_ONLY_ON_BRD_MEM: ChannelResetAttribute.ValueType  # 8805
CHANNEL_RESET_ATTRIBUTE_DO_DATA_XFER_MECH: ChannelResetAttribute.ValueType  # 8806
CHANNEL_RESET_ATTRIBUTE_DO_DATA_XFER_REQ_COND: ChannelResetAttribute.ValueType  # 8807
CHANNEL_RESET_ATTRIBUTE_CO_PRESCALER: ChannelResetAttribute.ValueType  # 8813
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8817
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8818
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8819
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8820
CHANNEL_RESET_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8821
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 8822
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 8823
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 8824
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 8825
CHANNEL_RESET_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 8826
CHANNEL_RESET_ATTRIBUTE_AI_ENHANCED_ALIAS_REJECTION_ENABLE: ChannelResetAttribute.ValueType  # 8852
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_ENABLE_CAL: ChannelResetAttribute.ValueType  # 8856
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_APPLY_CAL_IF_EXP: ChannelResetAttribute.ValueType  # 8857
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_SCALE_TYPE: ChannelResetAttribute.ValueType  # 8860
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_TABLE_PRE_SCALED_VALS: ChannelResetAttribute.ValueType  # 8861
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_TABLE_SCALED_VALS: ChannelResetAttribute.ValueType  # 8862
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_POLY_FORWARD_COEFF: ChannelResetAttribute.ValueType  # 8863
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_POLY_REVERSE_COEFF: ChannelResetAttribute.ValueType  # 8864
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_VERIF_REF_VALS: ChannelResetAttribute.ValueType  # 8865
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_VERIF_ACQ_VALS: ChannelResetAttribute.ValueType  # 8866
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_OPERATOR_NAME: ChannelResetAttribute.ValueType  # 8867
CHANNEL_RESET_ATTRIBUTE_AI_CHAN_CAL_DESC: ChannelResetAttribute.ValueType  # 8868
CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_UNITS: ChannelResetAttribute.ValueType  # 8883
CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_INITIAL_SECONDS: ChannelResetAttribute.ValueType  # 8884
CHANNEL_RESET_ATTRIBUTE_AI_RAW_DATA_COMPRESSION_TYPE: ChannelResetAttribute.ValueType  # 8920
CHANNEL_RESET_ATTRIBUTE_AI_LOSSY_LSB_REMOVAL_COMPRESSED_SAMP_SIZE: ChannelResetAttribute.ValueType  # 8921
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_STARTING_EDGE: ChannelResetAttribute.ValueType  # 8958
CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_CUSTOM_THRESHOLD: ChannelResetAttribute.ValueType  # 8972
CHANNEL_RESET_ATTRIBUTE_DI_ACQUIRE_ON: ChannelResetAttribute.ValueType  # 10598
CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_PAUSED_STATE: ChannelResetAttribute.ValueType  # 10599
CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_DONE_STATE: ChannelResetAttribute.ValueType  # 10600
CHANNEL_RESET_ATTRIBUTE_DO_GENERATE_ON: ChannelResetAttribute.ValueType  # 10601
CHANNEL_RESET_ATTRIBUTE_DI_MEM_MAP_ENABLE: ChannelResetAttribute.ValueType  # 10602
CHANNEL_RESET_ATTRIBUTE_DO_MEM_MAP_ENABLE: ChannelResetAttribute.ValueType  # 10603
CHANNEL_RESET_ATTRIBUTE_DI_LOGIC_FAMILY: ChannelResetAttribute.ValueType  # 10605
CHANNEL_RESET_ATTRIBUTE_DO_LOGIC_FAMILY: ChannelResetAttribute.ValueType  # 10606
CHANNEL_RESET_ATTRIBUTE_DO_LINE_STATES_START_STATE: ChannelResetAttribute.ValueType  # 10610
CHANNEL_RESET_ATTRIBUTE_AI_VOLTAGE_DB_REF: ChannelResetAttribute.ValueType  # 10672
CHANNEL_RESET_ATTRIBUTE_AI_SOUND_PRESSURE_DB_REF: ChannelResetAttribute.ValueType  # 10673
CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_DB_REF: ChannelResetAttribute.ValueType  # 10674
CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_SCALE_TYPE: ChannelResetAttribute.ValueType  # 10704
CHANNEL_RESET_ATTRIBUTE_CO_CONSTRAINED_GEN_MODE: ChannelResetAttribute.ValueType  # 10738
CHANNEL_RESET_ATTRIBUTE_AI_ADC_TIMING_MODE: ChannelResetAttribute.ValueType  # 10745
CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_TYPE: ChannelResetAttribute.ValueType  # 10776
CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_FREQ: ChannelResetAttribute.ValueType  # 10777
CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_AMPLITUDE: ChannelResetAttribute.ValueType  # 10778
CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_OFFSET: ChannelResetAttribute.ValueType  # 10779
CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_SQUARE_DUTY_CYCLE: ChannelResetAttribute.ValueType  # 10780
CHANNEL_RESET_ATTRIBUTE_AO_VOLTAGE_CURRENT_LIMIT: ChannelResetAttribute.ValueType  # 10781
CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_MODULATION_TYPE: ChannelResetAttribute.ValueType  # 10786
CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_FM_DEVIATION: ChannelResetAttribute.ValueType  # 10787
CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_LIMIT: ChannelResetAttribute.ValueType  # 10885
CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_AUTO_REENABLE: ChannelResetAttribute.ValueType  # 10886
CHANNEL_RESET_ATTRIBUTE_DO_OVERCURRENT_REENABLE_PERIOD: ChannelResetAttribute.ValueType  # 10887
CHANNEL_RESET_ATTRIBUTE_AI_PROBE_ATTEN: ChannelResetAttribute.ValueType  # 10888
CHANNEL_RESET_ATTRIBUTE_AI_DC_OFFSET: ChannelResetAttribute.ValueType  # 10889
CHANNEL_RESET_ATTRIBUTE_AI_USB_XFER_REQ_SIZE: ChannelResetAttribute.ValueType  # 10894
CHANNEL_RESET_ATTRIBUTE_AO_USB_XFER_REQ_SIZE: ChannelResetAttribute.ValueType  # 10895
CHANNEL_RESET_ATTRIBUTE_DI_USB_XFER_REQ_SIZE: ChannelResetAttribute.ValueType  # 10896
CHANNEL_RESET_ATTRIBUTE_DO_USB_XFER_REQ_SIZE: ChannelResetAttribute.ValueType  # 10897
CHANNEL_RESET_ATTRIBUTE_CI_USB_XFER_REQ_SIZE: ChannelResetAttribute.ValueType  # 10898
CHANNEL_RESET_ATTRIBUTE_CO_USB_XFER_REQ_SIZE: ChannelResetAttribute.ValueType  # 10899
CHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY: ChannelResetAttribute.ValueType  # 10942
CHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS: ChannelResetAttribute.ValueType  # 10943
CHANNEL_RESET_ATTRIBUTE_AI_EDDY_CURRENT_PROX_PROBE_UNITS: ChannelResetAttribute.ValueType  # 10944
CHANNEL_RESET_ATTRIBUTE_CO_ENABLE_INITIAL_DELAY_ON_RETRIGGER: ChannelResetAttribute.ValueType  # 11977
CHANNEL_RESET_ATTRIBUTE_CO_USE_ONLY_ON_BRD_MEM: ChannelResetAttribute.ValueType  # 11979
CHANNEL_RESET_ATTRIBUTE_CO_DATA_XFER_MECH: ChannelResetAttribute.ValueType  # 11980
CHANNEL_RESET_ATTRIBUTE_CO_DATA_XFER_REQ_COND: ChannelResetAttribute.ValueType  # 11981
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_ENABLE_AVERAGING: ChannelResetAttribute.ValueType  # 11984
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_ENABLE_AVERAGING: ChannelResetAttribute.ValueType  # 11985
CHANNEL_RESET_ATTRIBUTE_CI_MEM_MAP_ENABLE: ChannelResetAttribute.ValueType  # 11986
CHANNEL_RESET_ATTRIBUTE_CO_MEM_MAP_ENABLE: ChannelResetAttribute.ValueType  # 11987
CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 11988
CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 11989
CHANNEL_RESET_ATTRIBUTE_DI_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 11990
CHANNEL_RESET_ATTRIBUTE_CI_DATA_XFER_REQ_COND: ChannelResetAttribute.ValueType  # 12027
CHANNEL_RESET_ATTRIBUTE_DI_DIG_FLTR_ENABLE_BUS_MODE: ChannelResetAttribute.ValueType  # 12030
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_TERM: ChannelResetAttribute.ValueType  # 12036
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_START_EDGE: ChannelResetAttribute.ValueType  # 12037
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12038
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 12039
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 12040
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 12041
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 12042
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_UNITS: ChannelResetAttribute.ValueType  # 12043
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_TERM: ChannelResetAttribute.ValueType  # 12044
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_START_EDGE: ChannelResetAttribute.ValueType  # 12045
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12046
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 12047
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 12048
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 12049
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 12050
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_UNITS: ChannelResetAttribute.ValueType  # 12051
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_TERM: ChannelResetAttribute.ValueType  # 12052
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_START_EDGE: ChannelResetAttribute.ValueType  # 12053
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12054
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 12055
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 12056
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 12057
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 12058
CHANNEL_RESET_ATTRIBUTE_AI_ADC_CUSTOM_TIMING_MODE: ChannelResetAttribute.ValueType  # 12139
CHANNEL_RESET_ATTRIBUTE_AI_OPEN_THRMCPL_DETECT_ENABLE: ChannelResetAttribute.ValueType  # 12146
CHANNEL_RESET_ATTRIBUTE_AI_FORCE_UNITS: ChannelResetAttribute.ValueType  # 12149
CHANNEL_RESET_ATTRIBUTE_AI_PRESSURE_UNITS: ChannelResetAttribute.ValueType  # 12150
CHANNEL_RESET_ATTRIBUTE_AI_TORQUE_UNITS: ChannelResetAttribute.ValueType  # 12151
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_RESISTANCE: ChannelResetAttribute.ValueType  # 12152
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_ACTUAL_RESISTANCE: ChannelResetAttribute.ValueType  # 12153
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_RESISTANCE: ChannelResetAttribute.ValueType  # 12154
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_ACTUAL_RESISTANCE: ChannelResetAttribute.ValueType  # 12155
CHANNEL_RESET_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY: ChannelResetAttribute.ValueType  # 12161
CHANNEL_RESET_ATTRIBUTE_AI_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS: ChannelResetAttribute.ValueType  # 12162
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_INITIAL_RATIO: ChannelResetAttribute.ValueType  # 12166
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_ELECTRICAL_UNITS: ChannelResetAttribute.ValueType  # 12167
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_PHYSICAL_UNITS: ChannelResetAttribute.ValueType  # 12168
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SCALE_TYPE: ChannelResetAttribute.ValueType  # 12169
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_ELECTRICAL_VAL: ChannelResetAttribute.ValueType  # 12170
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_FIRST_PHYSICAL_VAL: ChannelResetAttribute.ValueType  # 12171
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_ELECTRICAL_VAL: ChannelResetAttribute.ValueType  # 12172
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TWO_POINT_LIN_SECOND_PHYSICAL_VAL: ChannelResetAttribute.ValueType  # 12173
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TABLE_ELECTRICAL_VALS: ChannelResetAttribute.ValueType  # 12174
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_TABLE_PHYSICAL_VALS: ChannelResetAttribute.ValueType  # 12175
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_POLY_FORWARD_COEFF: ChannelResetAttribute.ValueType  # 12176
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_POLY_REVERSE_COEFF: ChannelResetAttribute.ValueType  # 12177
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_UNITS: ChannelResetAttribute.ValueType  # 12178
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ENABLE: ChannelResetAttribute.ValueType  # 12207
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_RESET_COUNT: ChannelResetAttribute.ValueType  # 12208
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM: ChannelResetAttribute.ValueType  # 12209
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ACTIVE_EDGE: ChannelResetAttribute.ValueType  # 12210
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12211
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 12212
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 12213
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 12214
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_SYNC_ENABLE: ChannelResetAttribute.ValueType  # 12215
CHANNEL_RESET_ATTRIBUTE_AI_THRMCPL_LEAD_OFFSET_VOLTAGE: ChannelResetAttribute.ValueType  # 12216
CHANNEL_RESET_ATTRIBUTE_AI_REMOVE_FILTER_DELAY: ChannelResetAttribute.ValueType  # 12221
CHANNEL_RESET_ATTRIBUTE_AI_AVERAGING_WIN_SIZE: ChannelResetAttribute.ValueType  # 12270
CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_UNITS: ChannelResetAttribute.ValueType  # 12276
CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_DB_REF: ChannelResetAttribute.ValueType  # 12277
CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY: ChannelResetAttribute.ValueType  # 12278
CHANNEL_RESET_ATTRIBUTE_AI_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS: ChannelResetAttribute.ValueType  # 12279
CHANNEL_RESET_ATTRIBUTE_AI_STRAIN_GAGE_FORCE_READ_FROM_CHAN: ChannelResetAttribute.ValueType  # 12282
CHANNEL_RESET_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ORIENTATION: ChannelResetAttribute.ValueType  # 12284
CHANNEL_RESET_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_ROSETTE_MEAS_TYPE: ChannelResetAttribute.ValueType  # 12285
CHANNEL_RESET_ATTRIBUTE_AI_USB_XFER_REQ_COUNT: ChannelResetAttribute.ValueType  # 12288
CHANNEL_RESET_ATTRIBUTE_AO_USB_XFER_REQ_COUNT: ChannelResetAttribute.ValueType  # 12289
CHANNEL_RESET_ATTRIBUTE_DI_USB_XFER_REQ_COUNT: ChannelResetAttribute.ValueType  # 12290
CHANNEL_RESET_ATTRIBUTE_DO_USB_XFER_REQ_COUNT: ChannelResetAttribute.ValueType  # 12291
CHANNEL_RESET_ATTRIBUTE_CI_USB_XFER_REQ_COUNT: ChannelResetAttribute.ValueType  # 12292
CHANNEL_RESET_ATTRIBUTE_CO_USB_XFER_REQ_COUNT: ChannelResetAttribute.ValueType  # 12293
CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_TERM: ChannelResetAttribute.ValueType  # 12345
CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_EDGE: ChannelResetAttribute.ValueType  # 12346
CHANNEL_RESET_ATTRIBUTE_CI_TIMESTAMP_TIMESCALE: ChannelResetAttribute.ValueType  # 12347
CHANNEL_RESET_ATTRIBUTE_NAV_CUSTOM_SCALE_NAME: ChannelResetAttribute.ValueType  # 12348
CHANNEL_RESET_ATTRIBUTE_NAV_ALT_UNITS: ChannelResetAttribute.ValueType  # 12350
CHANNEL_RESET_ATTRIBUTE_NAV_LAT_UNITS: ChannelResetAttribute.ValueType  # 12351
CHANNEL_RESET_ATTRIBUTE_NAV_LONG_UNITS: ChannelResetAttribute.ValueType  # 12352
CHANNEL_RESET_ATTRIBUTE_NAV_SPEED_OVER_GROUND_UNITS: ChannelResetAttribute.ValueType  # 12353
CHANNEL_RESET_ATTRIBUTE_NAV_TRACK_UNITS: ChannelResetAttribute.ValueType  # 12354
CHANNEL_RESET_ATTRIBUTE_NAV_VERT_VELOCITY_UNITS: ChannelResetAttribute.ValueType  # 12355
CHANNEL_RESET_ATTRIBUTE_NAV_TIMESTAMP_UNITS: ChannelResetAttribute.ValueType  # 12356
CHANNEL_RESET_ATTRIBUTE_NAV_TIMESTAMP_TIMESCALE: ChannelResetAttribute.ValueType  # 12357
CHANNEL_RESET_ATTRIBUTE_AI_FILTER_DELAY_UNITS: ChannelResetAttribute.ValueType  # 12401
CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY_ADJUSTMENT: ChannelResetAttribute.ValueType  # 12402
CHANNEL_RESET_ATTRIBUTE_AI_FILTER_DELAY_ADJUSTMENT: ChannelResetAttribute.ValueType  # 12404
CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY: ChannelResetAttribute.ValueType  # 12405
CHANNEL_RESET_ATTRIBUTE_AO_FILTER_DELAY_UNITS: ChannelResetAttribute.ValueType  # 12406
CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_TERM: ChannelResetAttribute.ValueType  # 12429
CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12430
CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 12431
CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 12432
CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 12433
CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_STARTING_EDGE: ChannelResetAttribute.ValueType  # 12434
CHANNEL_RESET_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_BEHAVIOR: ChannelResetAttribute.ValueType  # 12435
CHANNEL_RESET_ATTRIBUTE_CI_SAMP_CLK_OVERRUN_SENTINEL_VAL: ChannelResetAttribute.ValueType  # 12436
CHANNEL_RESET_ATTRIBUTE_CI_MAX_MEAS_PERIOD: ChannelResetAttribute.ValueType  # 12437
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_TERM_CFG: ChannelResetAttribute.ValueType  # 12439
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12440
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_TERM_CFG: ChannelResetAttribute.ValueType  # 12441
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12442
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_TERM_CFG: ChannelResetAttribute.ValueType  # 12443
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12444
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_TERM_CFG: ChannelResetAttribute.ValueType  # 12445
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12446
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM_CFG: ChannelResetAttribute.ValueType  # 12447
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12448
CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_TERM_CFG: ChannelResetAttribute.ValueType  # 12449
CHANNEL_RESET_ATTRIBUTE_CI_DUTY_CYCLE_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12450
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM_CFG: ChannelResetAttribute.ValueType  # 12451
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12452
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM_CFG: ChannelResetAttribute.ValueType  # 12453
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12454
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM_CFG: ChannelResetAttribute.ValueType  # 12455
CHANNEL_RESET_ATTRIBUTE_CI_ENCODER_Z_INPUT_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12456
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_TERM_CFG: ChannelResetAttribute.ValueType  # 12457
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_WIDTH_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12458
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM_CFG: ChannelResetAttribute.ValueType  # 12459
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12460
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM_CFG: ChannelResetAttribute.ValueType  # 12461
CHANNEL_RESET_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12462
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_TERM_CFG: ChannelResetAttribute.ValueType  # 12463
CHANNEL_RESET_ATTRIBUTE_CI_SEMI_PERIOD_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12464
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_TERM_CFG: ChannelResetAttribute.ValueType  # 12465
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_FREQ_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12466
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_TERM_CFG: ChannelResetAttribute.ValueType  # 12467
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TIME_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12468
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_TERM_CFG: ChannelResetAttribute.ValueType  # 12469
CHANNEL_RESET_ATTRIBUTE_CI_PULSE_TICKS_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12470
CHANNEL_RESET_ATTRIBUTE_CI_THRESH_VOLTAGE: ChannelResetAttribute.ValueType  # 12471
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_IDLE_OUTPUT_BEHAVIOR: ChannelResetAttribute.ValueType  # 12472
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12477
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_TYPE: ChannelResetAttribute.ValueType  # 12478
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_RESPONSE: ChannelResetAttribute.ValueType  # 12479
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_ORDER: ChannelResetAttribute.ValueType  # 12480
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ: ChannelResetAttribute.ValueType  # 12481
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_HIGHPASS_CUTOFF_FREQ: ChannelResetAttribute.ValueType  # 12482
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_CENTER_FREQ: ChannelResetAttribute.ValueType  # 12483
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_BANDPASS_WIDTH: ChannelResetAttribute.ValueType  # 12484
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_NOTCH_CENTER_FREQ: ChannelResetAttribute.ValueType  # 12485
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_NOTCH_WIDTH: ChannelResetAttribute.ValueType  # 12486
CHANNEL_RESET_ATTRIBUTE_AI_DIG_FLTR_COEFF: ChannelResetAttribute.ValueType  # 12487
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_A_SRC: ChannelResetAttribute.ValueType  # 12490
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_UNITS: ChannelResetAttribute.ValueType  # 12504
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_PULSES_PER_REV: ChannelResetAttribute.ValueType  # 12505
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_UNITS: ChannelResetAttribute.ValueType  # 12506
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_LIN_ENCODER_DIST_PER_PULSE: ChannelResetAttribute.ValueType  # 12507
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_DECODING_TYPE: ChannelResetAttribute.ValueType  # 12508
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM: ChannelResetAttribute.ValueType  # 12509
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM_CFG: ChannelResetAttribute.ValueType  # 12510
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12511
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12512
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 12513
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 12514
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 12515
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM: ChannelResetAttribute.ValueType  # 12516
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM_CFG: ChannelResetAttribute.ValueType  # 12517
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12518
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12519
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 12520
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 12521
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 12522
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_MEAS_TIME: ChannelResetAttribute.ValueType  # 12523
CHANNEL_RESET_ATTRIBUTE_CI_VELOCITY_DIV: ChannelResetAttribute.ValueType  # 12524
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_ENABLE: ChannelResetAttribute.ValueType  # 12525
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM: ChannelResetAttribute.ValueType  # 12526
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM_CFG: ChannelResetAttribute.ValueType  # 12527
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_LOGIC_LVL_BEHAVIOR: ChannelResetAttribute.ValueType  # 12528
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_ENABLE: ChannelResetAttribute.ValueType  # 12529
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_MIN_PULSE_WIDTH: ChannelResetAttribute.ValueType  # 12530
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_SRC: ChannelResetAttribute.ValueType  # 12531
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_RATE: ChannelResetAttribute.ValueType  # 12532
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_WHEN: ChannelResetAttribute.ValueType  # 12533
CHANNEL_RESET_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_SHUNT_CAL_B_SRC: ChannelResetAttribute.ValueType  # 12535
CHANNEL_RESET_ATTRIBUTE_AI_EXCIT_SENSE: ChannelResetAttribute.ValueType  # 12541
CHANNEL_RESET_ATTRIBUTE_AI_OPEN_CHAN_DETECT_ENABLE: ChannelResetAttribute.ValueType  # 12543
CHANNEL_RESET_ATTRIBUTE_AI_CHARGE_UNITS: ChannelResetAttribute.ValueType  # 12562
CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY: ChannelResetAttribute.ValueType  # 12563
CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_CHARGE_SENSITIVITY_UNITS: ChannelResetAttribute.ValueType  # 12564
CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY: ChannelResetAttribute.ValueType  # 12565
CHANNEL_RESET_ATTRIBUTE_AI_ACCEL_4_WIRE_DC_VOLTAGE_SENSITIVITY_UNITS: ChannelResetAttribute.ValueType  # 12566
CHANNEL_RESET_ATTRIBUTE_AI_DATA_XFER_MAX_RATE: ChannelResetAttribute.ValueType  # 12567
CHANNEL_RESET_ATTRIBUTE_CHAN_SYNC_UNLOCK_BEHAVIOR: ChannelResetAttribute.ValueType  # 12604
CHANNEL_RESET_ATTRIBUTE_AI_CHOP_ENABLE: ChannelResetAttribute.ValueType  # 12611
CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_VOLTAGE: ChannelResetAttribute.ValueType  # 12649
CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_CFG: ChannelResetAttribute.ValueType  # 12650
CHANNEL_RESET_ATTRIBUTE_AI_SENSOR_POWER_TYPE: ChannelResetAttribute.ValueType  # 12651
CHANNEL_RESET_ATTRIBUTE_AI_FILTER_ENABLE: ChannelResetAttribute.ValueType  # 12659
CHANNEL_RESET_ATTRIBUTE_AI_FILTER_FREQ: ChannelResetAttribute.ValueType  # 12660
CHANNEL_RESET_ATTRIBUTE_AI_FILTER_RESPONSE: ChannelResetAttribute.ValueType  # 12661
CHANNEL_RESET_ATTRIBUTE_AI_FILTER_ORDER: ChannelResetAttribute.ValueType  # 12662
CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_UPPER_LIMIT: ChannelResetAttribute.ValueType  # 12684
CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_LOWER_LIMIT: ChannelResetAttribute.ValueType  # 12685
CHANNEL_RESET_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_ENABLE: ChannelResetAttribute.ValueType  # 12686
CHANNEL_RESET_ATTRIBUTE_AI_POWER_SUPPLY_FAULT_DETECT_ENABLE: ChannelResetAttribute.ValueType  # 12689
CHANNEL_RESET_ATTRIBUTE_AI_OVERCURRENT_DETECT_ENABLE: ChannelResetAttribute.ValueType  # 12692
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_THRESH_VOLTAGE: ChannelResetAttribute.ValueType  # 12715
CHANNEL_RESET_ATTRIBUTE_CI_FREQ_HYST: ChannelResetAttribute.ValueType  # 12716
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_THRESH_VOLTAGE: ChannelResetAttribute.ValueType  # 12717
CHANNEL_RESET_ATTRIBUTE_CI_PERIOD_HYST: ChannelResetAttribute.ValueType  # 12718
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_THRESH_VOLTAGE: ChannelResetAttribute.ValueType  # 12719
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_HYST: ChannelResetAttribute.ValueType  # 12720
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_THRESH_VOLTAGE: ChannelResetAttribute.ValueType  # 12721
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_HYST: ChannelResetAttribute.ValueType  # 12722
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_THRESH_VOLTAGE: ChannelResetAttribute.ValueType  # 12723
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_HYST: ChannelResetAttribute.ValueType  # 12724
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_THRESH_VOLTAGE: ChannelResetAttribute.ValueType  # 12725
CHANNEL_RESET_ATTRIBUTE_CI_COUNT_EDGES_GATE_HYST: ChannelResetAttribute.ValueType  # 12726
CHANNEL_RESET_ATTRIBUTE_CI_FILTER_ENABLE: ChannelResetAttribute.ValueType  # 12727
CHANNEL_RESET_ATTRIBUTE_CI_FILTER_FREQ: ChannelResetAttribute.ValueType  # 12728
CHANNEL_RESET_ATTRIBUTE_CI_FILTER_RESPONSE: ChannelResetAttribute.ValueType  # 12729
CHANNEL_RESET_ATTRIBUTE_CI_FILTER_ORDER: ChannelResetAttribute.ValueType  # 12730
CHANNEL_RESET_ATTRIBUTE_CI_FILTER_DELAY_UNITS: ChannelResetAttribute.ValueType  # 12732
CHANNEL_RESET_ATTRIBUTE_AO_FUNC_GEN_START_PHASE: ChannelResetAttribute.ValueType  # 12740
CHANNEL_RESET_ATTRIBUTE_AO_COMMON_MODE_OFFSET: ChannelResetAttribute.ValueType  # 12748
CHANNEL_RESET_ATTRIBUTE_PWR_VOLTAGE_SETPOINT: ChannelResetAttribute.ValueType  # 12756
CHANNEL_RESET_ATTRIBUTE_PWR_CURRENT_SETPOINT: ChannelResetAttribute.ValueType  # 12757
CHANNEL_RESET_ATTRIBUTE_PWR_OUTPUT_ENABLE: ChannelResetAttribute.ValueType  # 12758
CHANNEL_RESET_ATTRIBUTE_PWR_IDLE_OUTPUT_BEHAVIOR: ChannelResetAttribute.ValueType  # 12760
CHANNEL_RESET_ATTRIBUTE_PWR_REMOTE_SENSE: ChannelResetAttribute.ValueType  # 12763
global___ChannelResetAttribute = ChannelResetAttribute

class _ChannelBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChannelBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED: _ChannelBoolAttribute.ValueType  # 0
    CHANNEL_ATTRIBUTE_AI_DITHER_ENABLE: _ChannelBoolAttribute.ValueType  # 104
    CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_ENABLE: _ChannelBoolAttribute.ValueType  # 148
    CHANNEL_ATTRIBUTE_AI_AC_EXCIT_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 258
    CHANNEL_ATTRIBUTE_AO_DAC_REF_CONN_TO_GND: _ChannelBoolAttribute.ValueType  # 304
    CHANNEL_ATTRIBUTE_AO_REGLITCH_ENABLE: _ChannelBoolAttribute.ValueType  # 307
    CHANNEL_ATTRIBUTE_CI_TC_REACHED: _ChannelBoolAttribute.ValueType  # 336
    CHANNEL_ATTRIBUTE_DI_INVERT_LINES: _ChannelBoolAttribute.ValueType  # 1939
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_ENABLE: _ChannelBoolAttribute.ValueType  # 2192
    CHANNEL_ATTRIBUTE_DO_INVERT_LINES: _ChannelBoolAttribute.ValueType  # 4403
    CHANNEL_ATTRIBUTE_AI_EXCIT_USE_FOR_SCALING: _ChannelBoolAttribute.ValueType  # 6140
    CHANNEL_ATTRIBUTE_AI_LOWPASS_ENABLE: _ChannelBoolAttribute.ValueType  # 6146
    CHANNEL_ATTRIBUTE_AI_HIGHPASS_ENABLE: _ChannelBoolAttribute.ValueType  # 6150
    CHANNEL_ATTRIBUTE_AI_BANDPASS_ENABLE: _ChannelBoolAttribute.ValueType  # 6155
    CHANNEL_ATTRIBUTE_AI_SAMP_AND_HOLD_ENABLE: _ChannelBoolAttribute.ValueType  # 6170
    CHANNEL_ATTRIBUTE_AO_DAC_REF_ALLOW_CONN_TO_GND: _ChannelBoolAttribute.ValueType  # 6192
    CHANNEL_ATTRIBUTE_AO_USE_ONLY_ON_BRD_MEM: _ChannelBoolAttribute.ValueType  # 6202
    CHANNEL_ATTRIBUTE_AI_MEM_MAP_ENABLE: _ChannelBoolAttribute.ValueType  # 6284
    CHANNEL_ATTRIBUTE_AO_MEM_MAP_ENABLE: _ChannelBoolAttribute.ValueType  # 6287
    CHANNEL_ATTRIBUTE_DI_TRISTATE: _ChannelBoolAttribute.ValueType  # 6288
    CHANNEL_ATTRIBUTE_DO_TRISTATE: _ChannelBoolAttribute.ValueType  # 6387
    CHANNEL_ATTRIBUTE_AI_FORCE_READ_FROM_CHAN: _ChannelBoolAttribute.ValueType  # 6392
    CHANNEL_ATTRIBUTE_CO_PULSE_DONE: _ChannelBoolAttribute.ValueType  # 6414
    CHANNEL_ATTRIBUTE_AI_EXCIT_USE_MULTIPLEXED: _ChannelBoolAttribute.ValueType  # 8576
    CHANNEL_ATTRIBUTE_CI_DUP_COUNT_PREVENT: _ChannelBoolAttribute.ValueType  # 8620
    CHANNEL_ATTRIBUTE_DI_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8662
    CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8679
    CHANNEL_ATTRIBUTE_CI_FREQ_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8683
    CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8684
    CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8688
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8689
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8693
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8694
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8698
    CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8699
    CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8703
    CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8704
    CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8708
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8709
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8713
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8714
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8718
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8719
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8723
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8724
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8728
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8729
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8733
    CHANNEL_ATTRIBUTE_AO_ENHANCED_IMAGE_REJECTION_ENABLE: _ChannelBoolAttribute.ValueType  # 8769
    CHANNEL_ATTRIBUTE_DO_USE_ONLY_ON_BRD_MEM: _ChannelBoolAttribute.ValueType  # 8805
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8817
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8821
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 8822
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 8826
    CHANNEL_ATTRIBUTE_AI_ENHANCED_ALIAS_REJECTION_ENABLE: _ChannelBoolAttribute.ValueType  # 8852
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_HAS_VALID_CAL_INFO: _ChannelBoolAttribute.ValueType  # 8855
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_ENABLE_CAL: _ChannelBoolAttribute.ValueType  # 8856
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_APPLY_CAL_IF_EXP: _ChannelBoolAttribute.ValueType  # 8857
    CHANNEL_ATTRIBUTE_CO_RDY_FOR_NEW_VAL: _ChannelBoolAttribute.ValueType  # 8959
    CHANNEL_ATTRIBUTE_CHAN_IS_GLOBAL: _ChannelBoolAttribute.ValueType  # 8964
    CHANNEL_ATTRIBUTE_DI_MEM_MAP_ENABLE: _ChannelBoolAttribute.ValueType  # 10602
    CHANNEL_ATTRIBUTE_DO_MEM_MAP_ENABLE: _ChannelBoolAttribute.ValueType  # 10603
    CHANNEL_ATTRIBUTE_AI_IS_TEDS: _ChannelBoolAttribute.ValueType  # 10627
    CHANNEL_ATTRIBUTE_DO_OVERCURRENT_AUTO_REENABLE: _ChannelBoolAttribute.ValueType  # 10886
    CHANNEL_ATTRIBUTE_CO_ENABLE_INITIAL_DELAY_ON_RETRIGGER: _ChannelBoolAttribute.ValueType  # 11977
    CHANNEL_ATTRIBUTE_CO_USE_ONLY_ON_BRD_MEM: _ChannelBoolAttribute.ValueType  # 11979
    CHANNEL_ATTRIBUTE_CI_FREQ_ENABLE_AVERAGING: _ChannelBoolAttribute.ValueType  # 11984
    CHANNEL_ATTRIBUTE_CI_PERIOD_ENABLE_AVERAGING: _ChannelBoolAttribute.ValueType  # 11985
    CHANNEL_ATTRIBUTE_CI_MEM_MAP_ENABLE: _ChannelBoolAttribute.ValueType  # 11986
    CHANNEL_ATTRIBUTE_CO_MEM_MAP_ENABLE: _ChannelBoolAttribute.ValueType  # 11987
    CHANNEL_ATTRIBUTE_DI_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 11990
    CHANNEL_ATTRIBUTE_DI_DIG_FLTR_ENABLE_BUS_MODE: _ChannelBoolAttribute.ValueType  # 12030
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12038
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 12042
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12046
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 12050
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12054
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 12058
    CHANNEL_ATTRIBUTE_AI_OPEN_THRMCPL_DETECT_ENABLE: _ChannelBoolAttribute.ValueType  # 12146
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ENABLE: _ChannelBoolAttribute.ValueType  # 12207
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12211
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_SYNC_ENABLE: _ChannelBoolAttribute.ValueType  # 12215
    CHANNEL_ATTRIBUTE_AI_REMOVE_FILTER_DELAY: _ChannelBoolAttribute.ValueType  # 12221
    CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_FORCE_READ_FROM_CHAN: _ChannelBoolAttribute.ValueType  # 12282
    CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12430
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12477
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12512
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12519
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_ENABLE: _ChannelBoolAttribute.ValueType  # 12525
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_ENABLE: _ChannelBoolAttribute.ValueType  # 12529
    CHANNEL_ATTRIBUTE_AI_OPEN_CHAN_DETECT_ENABLE: _ChannelBoolAttribute.ValueType  # 12543
    CHANNEL_ATTRIBUTE_AI_CHOP_ENABLE: _ChannelBoolAttribute.ValueType  # 12611
    CHANNEL_ATTRIBUTE_AI_FILTER_ENABLE: _ChannelBoolAttribute.ValueType  # 12659
    CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_ENABLE: _ChannelBoolAttribute.ValueType  # 12686
    CHANNEL_ATTRIBUTE_AI_POWER_SUPPLY_FAULT_DETECT_ENABLE: _ChannelBoolAttribute.ValueType  # 12689
    CHANNEL_ATTRIBUTE_AI_OVERCURRENT_DETECT_ENABLE: _ChannelBoolAttribute.ValueType  # 12692
    CHANNEL_ATTRIBUTE_CI_FILTER_ENABLE: _ChannelBoolAttribute.ValueType  # 12727
    CHANNEL_ATTRIBUTE_PWR_OUTPUT_ENABLE: _ChannelBoolAttribute.ValueType  # 12758

class ChannelBoolAttribute(_ChannelBoolAttribute, metaclass=_ChannelBoolAttributeEnumTypeWrapper): ...

CHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED: ChannelBoolAttribute.ValueType  # 0
CHANNEL_ATTRIBUTE_AI_DITHER_ENABLE: ChannelBoolAttribute.ValueType  # 104
CHANNEL_ATTRIBUTE_AI_BRIDGE_SHUNT_CAL_ENABLE: ChannelBoolAttribute.ValueType  # 148
CHANNEL_ATTRIBUTE_AI_AC_EXCIT_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 258
CHANNEL_ATTRIBUTE_AO_DAC_REF_CONN_TO_GND: ChannelBoolAttribute.ValueType  # 304
CHANNEL_ATTRIBUTE_AO_REGLITCH_ENABLE: ChannelBoolAttribute.ValueType  # 307
CHANNEL_ATTRIBUTE_CI_TC_REACHED: ChannelBoolAttribute.ValueType  # 336
CHANNEL_ATTRIBUTE_DI_INVERT_LINES: ChannelBoolAttribute.ValueType  # 1939
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INDEX_ENABLE: ChannelBoolAttribute.ValueType  # 2192
CHANNEL_ATTRIBUTE_DO_INVERT_LINES: ChannelBoolAttribute.ValueType  # 4403
CHANNEL_ATTRIBUTE_AI_EXCIT_USE_FOR_SCALING: ChannelBoolAttribute.ValueType  # 6140
CHANNEL_ATTRIBUTE_AI_LOWPASS_ENABLE: ChannelBoolAttribute.ValueType  # 6146
CHANNEL_ATTRIBUTE_AI_HIGHPASS_ENABLE: ChannelBoolAttribute.ValueType  # 6150
CHANNEL_ATTRIBUTE_AI_BANDPASS_ENABLE: ChannelBoolAttribute.ValueType  # 6155
CHANNEL_ATTRIBUTE_AI_SAMP_AND_HOLD_ENABLE: ChannelBoolAttribute.ValueType  # 6170
CHANNEL_ATTRIBUTE_AO_DAC_REF_ALLOW_CONN_TO_GND: ChannelBoolAttribute.ValueType  # 6192
CHANNEL_ATTRIBUTE_AO_USE_ONLY_ON_BRD_MEM: ChannelBoolAttribute.ValueType  # 6202
CHANNEL_ATTRIBUTE_AI_MEM_MAP_ENABLE: ChannelBoolAttribute.ValueType  # 6284
CHANNEL_ATTRIBUTE_AO_MEM_MAP_ENABLE: ChannelBoolAttribute.ValueType  # 6287
CHANNEL_ATTRIBUTE_DI_TRISTATE: ChannelBoolAttribute.ValueType  # 6288
CHANNEL_ATTRIBUTE_DO_TRISTATE: ChannelBoolAttribute.ValueType  # 6387
CHANNEL_ATTRIBUTE_AI_FORCE_READ_FROM_CHAN: ChannelBoolAttribute.ValueType  # 6392
CHANNEL_ATTRIBUTE_CO_PULSE_DONE: ChannelBoolAttribute.ValueType  # 6414
CHANNEL_ATTRIBUTE_AI_EXCIT_USE_MULTIPLEXED: ChannelBoolAttribute.ValueType  # 8576
CHANNEL_ATTRIBUTE_CI_DUP_COUNT_PREVENT: ChannelBoolAttribute.ValueType  # 8620
CHANNEL_ATTRIBUTE_DI_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8662
CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8679
CHANNEL_ATTRIBUTE_CI_FREQ_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8683
CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8684
CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8688
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8689
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8693
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8694
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8698
CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8699
CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8703
CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8704
CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8708
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8709
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8713
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8714
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8718
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8719
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8723
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8724
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8728
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8729
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8733
CHANNEL_ATTRIBUTE_AO_ENHANCED_IMAGE_REJECTION_ENABLE: ChannelBoolAttribute.ValueType  # 8769
CHANNEL_ATTRIBUTE_DO_USE_ONLY_ON_BRD_MEM: ChannelBoolAttribute.ValueType  # 8805
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8817
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8821
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 8822
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 8826
CHANNEL_ATTRIBUTE_AI_ENHANCED_ALIAS_REJECTION_ENABLE: ChannelBoolAttribute.ValueType  # 8852
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_HAS_VALID_CAL_INFO: ChannelBoolAttribute.ValueType  # 8855
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_ENABLE_CAL: ChannelBoolAttribute.ValueType  # 8856
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_APPLY_CAL_IF_EXP: ChannelBoolAttribute.ValueType  # 8857
CHANNEL_ATTRIBUTE_CO_RDY_FOR_NEW_VAL: ChannelBoolAttribute.ValueType  # 8959
CHANNEL_ATTRIBUTE_CHAN_IS_GLOBAL: ChannelBoolAttribute.ValueType  # 8964
CHANNEL_ATTRIBUTE_DI_MEM_MAP_ENABLE: ChannelBoolAttribute.ValueType  # 10602
CHANNEL_ATTRIBUTE_DO_MEM_MAP_ENABLE: ChannelBoolAttribute.ValueType  # 10603
CHANNEL_ATTRIBUTE_AI_IS_TEDS: ChannelBoolAttribute.ValueType  # 10627
CHANNEL_ATTRIBUTE_DO_OVERCURRENT_AUTO_REENABLE: ChannelBoolAttribute.ValueType  # 10886
CHANNEL_ATTRIBUTE_CO_ENABLE_INITIAL_DELAY_ON_RETRIGGER: ChannelBoolAttribute.ValueType  # 11977
CHANNEL_ATTRIBUTE_CO_USE_ONLY_ON_BRD_MEM: ChannelBoolAttribute.ValueType  # 11979
CHANNEL_ATTRIBUTE_CI_FREQ_ENABLE_AVERAGING: ChannelBoolAttribute.ValueType  # 11984
CHANNEL_ATTRIBUTE_CI_PERIOD_ENABLE_AVERAGING: ChannelBoolAttribute.ValueType  # 11985
CHANNEL_ATTRIBUTE_CI_MEM_MAP_ENABLE: ChannelBoolAttribute.ValueType  # 11986
CHANNEL_ATTRIBUTE_CO_MEM_MAP_ENABLE: ChannelBoolAttribute.ValueType  # 11987
CHANNEL_ATTRIBUTE_DI_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 11990
CHANNEL_ATTRIBUTE_DI_DIG_FLTR_ENABLE_BUS_MODE: ChannelBoolAttribute.ValueType  # 12030
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12038
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 12042
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12046
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 12050
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12054
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 12058
CHANNEL_ATTRIBUTE_AI_OPEN_THRMCPL_DETECT_ENABLE: ChannelBoolAttribute.ValueType  # 12146
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_ENABLE: ChannelBoolAttribute.ValueType  # 12207
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12211
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_SYNC_ENABLE: ChannelBoolAttribute.ValueType  # 12215
CHANNEL_ATTRIBUTE_AI_REMOVE_FILTER_DELAY: ChannelBoolAttribute.ValueType  # 12221
CHANNEL_ATTRIBUTE_AI_STRAIN_GAGE_FORCE_READ_FROM_CHAN: ChannelBoolAttribute.ValueType  # 12282
CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12430
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12477
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12512
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12519
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_ENABLE: ChannelBoolAttribute.ValueType  # 12525
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_ENABLE: ChannelBoolAttribute.ValueType  # 12529
CHANNEL_ATTRIBUTE_AI_OPEN_CHAN_DETECT_ENABLE: ChannelBoolAttribute.ValueType  # 12543
CHANNEL_ATTRIBUTE_AI_CHOP_ENABLE: ChannelBoolAttribute.ValueType  # 12611
CHANNEL_ATTRIBUTE_AI_FILTER_ENABLE: ChannelBoolAttribute.ValueType  # 12659
CHANNEL_ATTRIBUTE_AI_INPUT_LIMITS_FAULT_DETECT_ENABLE: ChannelBoolAttribute.ValueType  # 12686
CHANNEL_ATTRIBUTE_AI_POWER_SUPPLY_FAULT_DETECT_ENABLE: ChannelBoolAttribute.ValueType  # 12689
CHANNEL_ATTRIBUTE_AI_OVERCURRENT_DETECT_ENABLE: ChannelBoolAttribute.ValueType  # 12692
CHANNEL_ATTRIBUTE_CI_FILTER_ENABLE: ChannelBoolAttribute.ValueType  # 12727
CHANNEL_ATTRIBUTE_PWR_OUTPUT_ENABLE: ChannelBoolAttribute.ValueType  # 12758
global___ChannelBoolAttribute = ChannelBoolAttribute

class _ChannelStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChannelStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_STRING_ATTRIBUTE_UNSPECIFIED: _ChannelStringAttribute.ValueType  # 0
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 323
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 825
    CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_CHAN: _ChannelStringAttribute.ValueType  # 4148
    CHANNEL_ATTRIBUTE_CI_GPS_SYNC_SRC: _ChannelStringAttribute.ValueType  # 4243
    CHANNEL_ATTRIBUTE_AO_CUSTOM_SCALE_NAME: _ChannelStringAttribute.ValueType  # 4488
    CHANNEL_ATTRIBUTE_AI_CUSTOM_SCALE_NAME: _ChannelStringAttribute.ValueType  # 6112
    CHANNEL_ATTRIBUTE_CI_CUSTOM_SCALE_NAME: _ChannelStringAttribute.ValueType  # 6302
    CHANNEL_ATTRIBUTE_CI_FREQ_TERM: _ChannelStringAttribute.ValueType  # 6306
    CHANNEL_ATTRIBUTE_CI_PERIOD_TERM: _ChannelStringAttribute.ValueType  # 6308
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_TERM: _ChannelStringAttribute.ValueType  # 6314
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM: _ChannelStringAttribute.ValueType  # 6317
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM: _ChannelStringAttribute.ValueType  # 6318
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_TERM: _ChannelStringAttribute.ValueType  # 6320
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_TERM: _ChannelStringAttribute.ValueType  # 6343
    CHANNEL_ATTRIBUTE_CO_PULSE_TERM: _ChannelStringAttribute.ValueType  # 6369
    CHANNEL_ATTRIBUTE_PHYSICAL_CHAN_NAME: _ChannelStringAttribute.ValueType  # 6389
    CHANNEL_ATTRIBUTE_CHAN_DESCR: _ChannelStringAttribute.ValueType  # 6438
    CHANNEL_ATTRIBUTE_AI_INPUT_SRC: _ChannelStringAttribute.ValueType  # 8600
    CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM: _ChannelStringAttribute.ValueType  # 8605
    CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM: _ChannelStringAttribute.ValueType  # 8606
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM: _ChannelStringAttribute.ValueType  # 8607
    CHANNEL_ATTRIBUTE_AI_TEDS_UNITS: _ChannelStringAttribute.ValueType  # 8672
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIR_TERM: _ChannelStringAttribute.ValueType  # 8673
    CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8681
    CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8686
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8691
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8696
    CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8701
    CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8706
    CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8711
    CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8716
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8721
    CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8726
    CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8731
    CHANNEL_ATTRIBUTE_AO_DAC_REF_EXT_SRC: _ChannelStringAttribute.ValueType  # 8786
    CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_EXT_SRC: _ChannelStringAttribute.ValueType  # 8788
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8819
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 8824
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_OPERATOR_NAME: _ChannelStringAttribute.ValueType  # 8867
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_DESC: _ChannelStringAttribute.ValueType  # 8868
    CHANNEL_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 11988
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_TERM: _ChannelStringAttribute.ValueType  # 12036
    CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 12040
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_TERM: _ChannelStringAttribute.ValueType  # 12044
    CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 12048
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_TERM: _ChannelStringAttribute.ValueType  # 12052
    CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 12056
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM: _ChannelStringAttribute.ValueType  # 12209
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 12213
    CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_STRAIN_CHANS: _ChannelStringAttribute.ValueType  # 12283
    CHANNEL_ATTRIBUTE_CI_TIMESTAMP_TERM: _ChannelStringAttribute.ValueType  # 12345
    CHANNEL_ATTRIBUTE_NAV_CUSTOM_SCALE_NAME: _ChannelStringAttribute.ValueType  # 12348
    CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_TERM: _ChannelStringAttribute.ValueType  # 12429
    CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 12432
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM: _ChannelStringAttribute.ValueType  # 12509
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 12514
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM: _ChannelStringAttribute.ValueType  # 12516
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 12521
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM: _ChannelStringAttribute.ValueType  # 12526
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_SRC: _ChannelStringAttribute.ValueType  # 12531

class ChannelStringAttribute(_ChannelStringAttribute, metaclass=_ChannelStringAttributeEnumTypeWrapper): ...

CHANNEL_STRING_ATTRIBUTE_UNSPECIFIED: ChannelStringAttribute.ValueType  # 0
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 323
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 825
CHANNEL_ATTRIBUTE_AI_THRMCPL_CJC_CHAN: ChannelStringAttribute.ValueType  # 4148
CHANNEL_ATTRIBUTE_CI_GPS_SYNC_SRC: ChannelStringAttribute.ValueType  # 4243
CHANNEL_ATTRIBUTE_AO_CUSTOM_SCALE_NAME: ChannelStringAttribute.ValueType  # 4488
CHANNEL_ATTRIBUTE_AI_CUSTOM_SCALE_NAME: ChannelStringAttribute.ValueType  # 6112
CHANNEL_ATTRIBUTE_CI_CUSTOM_SCALE_NAME: ChannelStringAttribute.ValueType  # 6302
CHANNEL_ATTRIBUTE_CI_FREQ_TERM: ChannelStringAttribute.ValueType  # 6306
CHANNEL_ATTRIBUTE_CI_PERIOD_TERM: ChannelStringAttribute.ValueType  # 6308
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_TERM: ChannelStringAttribute.ValueType  # 6314
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_TERM: ChannelStringAttribute.ValueType  # 6317
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_TERM: ChannelStringAttribute.ValueType  # 6318
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_TERM: ChannelStringAttribute.ValueType  # 6320
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_TERM: ChannelStringAttribute.ValueType  # 6343
CHANNEL_ATTRIBUTE_CO_PULSE_TERM: ChannelStringAttribute.ValueType  # 6369
CHANNEL_ATTRIBUTE_PHYSICAL_CHAN_NAME: ChannelStringAttribute.ValueType  # 6389
CHANNEL_ATTRIBUTE_CHAN_DESCR: ChannelStringAttribute.ValueType  # 6438
CHANNEL_ATTRIBUTE_AI_INPUT_SRC: ChannelStringAttribute.ValueType  # 8600
CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_TERM: ChannelStringAttribute.ValueType  # 8605
CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_TERM: ChannelStringAttribute.ValueType  # 8606
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_TERM: ChannelStringAttribute.ValueType  # 8607
CHANNEL_ATTRIBUTE_AI_TEDS_UNITS: ChannelStringAttribute.ValueType  # 8672
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIR_TERM: ChannelStringAttribute.ValueType  # 8673
CHANNEL_ATTRIBUTE_CI_FREQ_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8681
CHANNEL_ATTRIBUTE_CI_PERIOD_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8686
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_DIR_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8691
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8696
CHANNEL_ATTRIBUTE_CI_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8701
CHANNEL_ATTRIBUTE_CI_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8706
CHANNEL_ATTRIBUTE_CI_ENCODER_Z_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8711
CHANNEL_ATTRIBUTE_CI_PULSE_WIDTH_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8716
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_FIRST_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8721
CHANNEL_ATTRIBUTE_CI_TWO_EDGE_SEP_SECOND_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8726
CHANNEL_ATTRIBUTE_CI_SEMI_PERIOD_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8731
CHANNEL_ATTRIBUTE_AO_DAC_REF_EXT_SRC: ChannelStringAttribute.ValueType  # 8786
CHANNEL_ATTRIBUTE_AO_DAC_OFFSET_EXT_SRC: ChannelStringAttribute.ValueType  # 8788
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8819
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 8824
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_OPERATOR_NAME: ChannelStringAttribute.ValueType  # 8867
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_DESC: ChannelStringAttribute.ValueType  # 8868
CHANNEL_ATTRIBUTE_DI_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 11988
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_TERM: ChannelStringAttribute.ValueType  # 12036
CHANNEL_ATTRIBUTE_CI_PULSE_FREQ_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 12040
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_TERM: ChannelStringAttribute.ValueType  # 12044
CHANNEL_ATTRIBUTE_CI_PULSE_TIME_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 12048
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_TERM: ChannelStringAttribute.ValueType  # 12052
CHANNEL_ATTRIBUTE_CI_PULSE_TICKS_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 12056
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_TERM: ChannelStringAttribute.ValueType  # 12209
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 12213
CHANNEL_ATTRIBUTE_AI_ROSETTE_STRAIN_GAGE_STRAIN_CHANS: ChannelStringAttribute.ValueType  # 12283
CHANNEL_ATTRIBUTE_CI_TIMESTAMP_TERM: ChannelStringAttribute.ValueType  # 12345
CHANNEL_ATTRIBUTE_NAV_CUSTOM_SCALE_NAME: ChannelStringAttribute.ValueType  # 12348
CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_TERM: ChannelStringAttribute.ValueType  # 12429
CHANNEL_ATTRIBUTE_CI_DUTY_CYCLE_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 12432
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_TERM: ChannelStringAttribute.ValueType  # 12509
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_A_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 12514
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_TERM: ChannelStringAttribute.ValueType  # 12516
CHANNEL_ATTRIBUTE_CI_VELOCITY_ENCODER_B_INPUT_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 12521
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_TERM: ChannelStringAttribute.ValueType  # 12526
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_GATE_DIG_FLTR_TIMEBASE_SRC: ChannelStringAttribute.ValueType  # 12531
global___ChannelStringAttribute = ChannelStringAttribute

class _ChannelUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChannelUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_UINT32_ATTRIBUTE_UNSPECIFIED: _ChannelUInt32Attribute.ValueType  # 0
    CHANNEL_ATTRIBUTE_CI_FREQ_DIV: _ChannelUInt32Attribute.ValueType  # 327
    CHANNEL_ATTRIBUTE_CI_COUNT: _ChannelUInt32Attribute.ValueType  # 328
    CHANNEL_ATTRIBUTE_CO_COUNT: _ChannelUInt32Attribute.ValueType  # 659
    CHANNEL_ATTRIBUTE_CO_AUTO_INCR_CNT: _ChannelUInt32Attribute.ValueType  # 661
    CHANNEL_ATTRIBUTE_CO_PULSE_TICKS_INITIAL_DELAY: _ChannelUInt32Attribute.ValueType  # 664
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_INITIAL_CNT: _ChannelUInt32Attribute.ValueType  # 1688
    CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_PULSES_PER_REV: _ChannelUInt32Attribute.ValueType  # 2165
    CHANNEL_ATTRIBUTE_CO_PULSE_HIGH_TICKS: _ChannelUInt32Attribute.ValueType  # 4457
    CHANNEL_ATTRIBUTE_CO_PULSE_LOW_TICKS: _ChannelUInt32Attribute.ValueType  # 4465
    CHANNEL_ATTRIBUTE_AI_HIGHPASS_ORDER: _ChannelUInt32Attribute.ValueType  # 6153
    CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_DIV: _ChannelUInt32Attribute.ValueType  # 6278
    CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_OUT_CLK_DIV: _ChannelUInt32Attribute.ValueType  # 6279
    CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_MASTER_TIMEBASE_DIV: _ChannelUInt32Attribute.ValueType  # 6323
    CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_MASTER_TIMEBASE_DIV: _ChannelUInt32Attribute.ValueType  # 6339
    CHANNEL_ATTRIBUTE_CI_PERIOD_DIV: _ChannelUInt32Attribute.ValueType  # 6446
    CHANNEL_ATTRIBUTE_CI_NUM_POSSIBLY_INVALID_SAMPS: _ChannelUInt32Attribute.ValueType  # 6460
    CHANNEL_ATTRIBUTE_DI_NUM_LINES: _ChannelUInt32Attribute.ValueType  # 8568
    CHANNEL_ATTRIBUTE_DO_NUM_LINES: _ChannelUInt32Attribute.ValueType  # 8569
    CHANNEL_ATTRIBUTE_CI_PRESCALER: _ChannelUInt32Attribute.ValueType  # 8761
    CHANNEL_ATTRIBUTE_CO_PRESCALER: _ChannelUInt32Attribute.ValueType  # 8813
    CHANNEL_ATTRIBUTE_CI_TIMESTAMP_INITIAL_SECONDS: _ChannelUInt32Attribute.ValueType  # 8884
    CHANNEL_ATTRIBUTE_AI_LOSSY_LSB_REMOVAL_COMPRESSED_SAMP_SIZE: _ChannelUInt32Attribute.ValueType  # 8921
    CHANNEL_ATTRIBUTE_AI_RAW_SAMP_SIZE: _ChannelUInt32Attribute.ValueType  # 8922
    CHANNEL_ATTRIBUTE_AI_DATA_XFER_CUSTOM_THRESHOLD: _ChannelUInt32Attribute.ValueType  # 8972
    CHANNEL_ATTRIBUTE_AI_USB_XFER_REQ_SIZE: _ChannelUInt32Attribute.ValueType  # 10894
    CHANNEL_ATTRIBUTE_AO_USB_XFER_REQ_SIZE: _ChannelUInt32Attribute.ValueType  # 10895
    CHANNEL_ATTRIBUTE_DI_USB_XFER_REQ_SIZE: _ChannelUInt32Attribute.ValueType  # 10896
    CHANNEL_ATTRIBUTE_DO_USB_XFER_REQ_SIZE: _ChannelUInt32Attribute.ValueType  # 10897
    CHANNEL_ATTRIBUTE_CI_USB_XFER_REQ_SIZE: _ChannelUInt32Attribute.ValueType  # 10898
    CHANNEL_ATTRIBUTE_CO_USB_XFER_REQ_SIZE: _ChannelUInt32Attribute.ValueType  # 10899
    CHANNEL_ATTRIBUTE_AI_ADC_CUSTOM_TIMING_MODE: _ChannelUInt32Attribute.ValueType  # 12139
    CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_RESET_COUNT: _ChannelUInt32Attribute.ValueType  # 12208
    CHANNEL_ATTRIBUTE_AI_AVERAGING_WIN_SIZE: _ChannelUInt32Attribute.ValueType  # 12270
    CHANNEL_ATTRIBUTE_AI_USB_XFER_REQ_COUNT: _ChannelUInt32Attribute.ValueType  # 12288
    CHANNEL_ATTRIBUTE_AO_USB_XFER_REQ_COUNT: _ChannelUInt32Attribute.ValueType  # 12289
    CHANNEL_ATTRIBUTE_DI_USB_XFER_REQ_COUNT: _ChannelUInt32Attribute.ValueType  # 12290
    CHANNEL_ATTRIBUTE_DO_USB_XFER_REQ_COUNT: _ChannelUInt32Attribute.ValueType  # 12291
    CHANNEL_ATTRIBUTE_CI_USB_XFER_REQ_COUNT: _ChannelUInt32Attribute.ValueType  # 12292
    CHANNEL_ATTRIBUTE_CO_USB_XFER_REQ_COUNT: _ChannelUInt32Attribute.ValueType  # 12293
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_ORDER: _ChannelUInt32Attribute.ValueType  # 12480
    CHANNEL_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_PULSES_PER_REV: _ChannelUInt32Attribute.ValueType  # 12505
    CHANNEL_ATTRIBUTE_CI_VELOCITY_DIV: _ChannelUInt32Attribute.ValueType  # 12524
    CHANNEL_ATTRIBUTE_AI_FILTER_ORDER: _ChannelUInt32Attribute.ValueType  # 12662
    CHANNEL_ATTRIBUTE_CI_FILTER_ORDER: _ChannelUInt32Attribute.ValueType  # 12730

class ChannelUInt32Attribute(_ChannelUInt32Attribute, metaclass=_ChannelUInt32AttributeEnumTypeWrapper): ...

CHANNEL_UINT32_ATTRIBUTE_UNSPECIFIED: ChannelUInt32Attribute.ValueType  # 0
CHANNEL_ATTRIBUTE_CI_FREQ_DIV: ChannelUInt32Attribute.ValueType  # 327
CHANNEL_ATTRIBUTE_CI_COUNT: ChannelUInt32Attribute.ValueType  # 328
CHANNEL_ATTRIBUTE_CO_COUNT: ChannelUInt32Attribute.ValueType  # 659
CHANNEL_ATTRIBUTE_CO_AUTO_INCR_CNT: ChannelUInt32Attribute.ValueType  # 661
CHANNEL_ATTRIBUTE_CO_PULSE_TICKS_INITIAL_DELAY: ChannelUInt32Attribute.ValueType  # 664
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_INITIAL_CNT: ChannelUInt32Attribute.ValueType  # 1688
CHANNEL_ATTRIBUTE_CI_ANG_ENCODER_PULSES_PER_REV: ChannelUInt32Attribute.ValueType  # 2165
CHANNEL_ATTRIBUTE_CO_PULSE_HIGH_TICKS: ChannelUInt32Attribute.ValueType  # 4457
CHANNEL_ATTRIBUTE_CO_PULSE_LOW_TICKS: ChannelUInt32Attribute.ValueType  # 4465
CHANNEL_ATTRIBUTE_AI_HIGHPASS_ORDER: ChannelUInt32Attribute.ValueType  # 6153
CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_EXT_CLK_DIV: ChannelUInt32Attribute.ValueType  # 6278
CHANNEL_ATTRIBUTE_AI_LOWPASS_SWITCH_CAP_OUT_CLK_DIV: ChannelUInt32Attribute.ValueType  # 6279
CHANNEL_ATTRIBUTE_CI_CTR_TIMEBASE_MASTER_TIMEBASE_DIV: ChannelUInt32Attribute.ValueType  # 6323
CHANNEL_ATTRIBUTE_CO_CTR_TIMEBASE_MASTER_TIMEBASE_DIV: ChannelUInt32Attribute.ValueType  # 6339
CHANNEL_ATTRIBUTE_CI_PERIOD_DIV: ChannelUInt32Attribute.ValueType  # 6446
CHANNEL_ATTRIBUTE_CI_NUM_POSSIBLY_INVALID_SAMPS: ChannelUInt32Attribute.ValueType  # 6460
CHANNEL_ATTRIBUTE_DI_NUM_LINES: ChannelUInt32Attribute.ValueType  # 8568
CHANNEL_ATTRIBUTE_DO_NUM_LINES: ChannelUInt32Attribute.ValueType  # 8569
CHANNEL_ATTRIBUTE_CI_PRESCALER: ChannelUInt32Attribute.ValueType  # 8761
CHANNEL_ATTRIBUTE_CO_PRESCALER: ChannelUInt32Attribute.ValueType  # 8813
CHANNEL_ATTRIBUTE_CI_TIMESTAMP_INITIAL_SECONDS: ChannelUInt32Attribute.ValueType  # 8884
CHANNEL_ATTRIBUTE_AI_LOSSY_LSB_REMOVAL_COMPRESSED_SAMP_SIZE: ChannelUInt32Attribute.ValueType  # 8921
CHANNEL_ATTRIBUTE_AI_RAW_SAMP_SIZE: ChannelUInt32Attribute.ValueType  # 8922
CHANNEL_ATTRIBUTE_AI_DATA_XFER_CUSTOM_THRESHOLD: ChannelUInt32Attribute.ValueType  # 8972
CHANNEL_ATTRIBUTE_AI_USB_XFER_REQ_SIZE: ChannelUInt32Attribute.ValueType  # 10894
CHANNEL_ATTRIBUTE_AO_USB_XFER_REQ_SIZE: ChannelUInt32Attribute.ValueType  # 10895
CHANNEL_ATTRIBUTE_DI_USB_XFER_REQ_SIZE: ChannelUInt32Attribute.ValueType  # 10896
CHANNEL_ATTRIBUTE_DO_USB_XFER_REQ_SIZE: ChannelUInt32Attribute.ValueType  # 10897
CHANNEL_ATTRIBUTE_CI_USB_XFER_REQ_SIZE: ChannelUInt32Attribute.ValueType  # 10898
CHANNEL_ATTRIBUTE_CO_USB_XFER_REQ_SIZE: ChannelUInt32Attribute.ValueType  # 10899
CHANNEL_ATTRIBUTE_AI_ADC_CUSTOM_TIMING_MODE: ChannelUInt32Attribute.ValueType  # 12139
CHANNEL_ATTRIBUTE_CI_COUNT_EDGES_COUNT_RESET_RESET_COUNT: ChannelUInt32Attribute.ValueType  # 12208
CHANNEL_ATTRIBUTE_AI_AVERAGING_WIN_SIZE: ChannelUInt32Attribute.ValueType  # 12270
CHANNEL_ATTRIBUTE_AI_USB_XFER_REQ_COUNT: ChannelUInt32Attribute.ValueType  # 12288
CHANNEL_ATTRIBUTE_AO_USB_XFER_REQ_COUNT: ChannelUInt32Attribute.ValueType  # 12289
CHANNEL_ATTRIBUTE_DI_USB_XFER_REQ_COUNT: ChannelUInt32Attribute.ValueType  # 12290
CHANNEL_ATTRIBUTE_DO_USB_XFER_REQ_COUNT: ChannelUInt32Attribute.ValueType  # 12291
CHANNEL_ATTRIBUTE_CI_USB_XFER_REQ_COUNT: ChannelUInt32Attribute.ValueType  # 12292
CHANNEL_ATTRIBUTE_CO_USB_XFER_REQ_COUNT: ChannelUInt32Attribute.ValueType  # 12293
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_ORDER: ChannelUInt32Attribute.ValueType  # 12480
CHANNEL_ATTRIBUTE_CI_VELOCITY_ANG_ENCODER_PULSES_PER_REV: ChannelUInt32Attribute.ValueType  # 12505
CHANNEL_ATTRIBUTE_CI_VELOCITY_DIV: ChannelUInt32Attribute.ValueType  # 12524
CHANNEL_ATTRIBUTE_AI_FILTER_ORDER: ChannelUInt32Attribute.ValueType  # 12662
CHANNEL_ATTRIBUTE_CI_FILTER_ORDER: ChannelUInt32Attribute.ValueType  # 12730
global___ChannelUInt32Attribute = ChannelUInt32Attribute

class _ChannelDoubleArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelDoubleArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChannelDoubleArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: _ChannelDoubleArrayAttribute.ValueType  # 0
    CHANNEL_ATTRIBUTE_AI_DEV_SCALING_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 6448
    CHANNEL_ATTRIBUTE_AO_DEV_SCALING_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 6449
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_TABLE_PRE_SCALED_VALS: _ChannelDoubleArrayAttribute.ValueType  # 8861
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_TABLE_SCALED_VALS: _ChannelDoubleArrayAttribute.ValueType  # 8862
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_POLY_FORWARD_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 8863
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_POLY_REVERSE_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 8864
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_VERIF_REF_VALS: _ChannelDoubleArrayAttribute.ValueType  # 8865
    CHANNEL_ATTRIBUTE_AI_CHAN_CAL_VERIF_ACQ_VALS: _ChannelDoubleArrayAttribute.ValueType  # 8866
    CHANNEL_ATTRIBUTE_AI_BRIDGE_TABLE_ELECTRICAL_VALS: _ChannelDoubleArrayAttribute.ValueType  # 12174
    CHANNEL_ATTRIBUTE_AI_BRIDGE_TABLE_PHYSICAL_VALS: _ChannelDoubleArrayAttribute.ValueType  # 12175
    CHANNEL_ATTRIBUTE_AI_BRIDGE_POLY_FORWARD_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 12176
    CHANNEL_ATTRIBUTE_AI_BRIDGE_POLY_REVERSE_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 12177
    CHANNEL_ATTRIBUTE_AI_DIG_FLTR_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 12487
    CHANNEL_ATTRIBUTE_PWR_VOLTAGE_DEV_SCALING_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 12761
    CHANNEL_ATTRIBUTE_PWR_CURRENT_DEV_SCALING_COEFF: _ChannelDoubleArrayAttribute.ValueType  # 12762

class ChannelDoubleArrayAttribute(_ChannelDoubleArrayAttribute, metaclass=_ChannelDoubleArrayAttributeEnumTypeWrapper): ...

CHANNEL_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: ChannelDoubleArrayAttribute.ValueType  # 0
CHANNEL_ATTRIBUTE_AI_DEV_SCALING_COEFF: ChannelDoubleArrayAttribute.ValueType  # 6448
CHANNEL_ATTRIBUTE_AO_DEV_SCALING_COEFF: ChannelDoubleArrayAttribute.ValueType  # 6449
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_TABLE_PRE_SCALED_VALS: ChannelDoubleArrayAttribute.ValueType  # 8861
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_TABLE_SCALED_VALS: ChannelDoubleArrayAttribute.ValueType  # 8862
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_POLY_FORWARD_COEFF: ChannelDoubleArrayAttribute.ValueType  # 8863
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_POLY_REVERSE_COEFF: ChannelDoubleArrayAttribute.ValueType  # 8864
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_VERIF_REF_VALS: ChannelDoubleArrayAttribute.ValueType  # 8865
CHANNEL_ATTRIBUTE_AI_CHAN_CAL_VERIF_ACQ_VALS: ChannelDoubleArrayAttribute.ValueType  # 8866
CHANNEL_ATTRIBUTE_AI_BRIDGE_TABLE_ELECTRICAL_VALS: ChannelDoubleArrayAttribute.ValueType  # 12174
CHANNEL_ATTRIBUTE_AI_BRIDGE_TABLE_PHYSICAL_VALS: ChannelDoubleArrayAttribute.ValueType  # 12175
CHANNEL_ATTRIBUTE_AI_BRIDGE_POLY_FORWARD_COEFF: ChannelDoubleArrayAttribute.ValueType  # 12176
CHANNEL_ATTRIBUTE_AI_BRIDGE_POLY_REVERSE_COEFF: ChannelDoubleArrayAttribute.ValueType  # 12177
CHANNEL_ATTRIBUTE_AI_DIG_FLTR_COEFF: ChannelDoubleArrayAttribute.ValueType  # 12487
CHANNEL_ATTRIBUTE_PWR_VOLTAGE_DEV_SCALING_COEFF: ChannelDoubleArrayAttribute.ValueType  # 12761
CHANNEL_ATTRIBUTE_PWR_CURRENT_DEV_SCALING_COEFF: ChannelDoubleArrayAttribute.ValueType  # 12762
global___ChannelDoubleArrayAttribute = ChannelDoubleArrayAttribute

class _DeviceStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_STRING_ATTRIBUTE_UNSPECIFIED: _DeviceStringAttribute.ValueType  # 0
    DEVICE_ATTRIBUTE_PRODUCT_TYPE: _DeviceStringAttribute.ValueType  # 1585
    DEVICE_ATTRIBUTE_AI_PHYSICAL_CHANS: _DeviceStringAttribute.ValueType  # 8990
    DEVICE_ATTRIBUTE_AO_PHYSICAL_CHANS: _DeviceStringAttribute.ValueType  # 8991
    DEVICE_ATTRIBUTE_DI_LINES: _DeviceStringAttribute.ValueType  # 8992
    DEVICE_ATTRIBUTE_DI_PORTS: _DeviceStringAttribute.ValueType  # 8993
    DEVICE_ATTRIBUTE_DO_LINES: _DeviceStringAttribute.ValueType  # 8994
    DEVICE_ATTRIBUTE_DO_PORTS: _DeviceStringAttribute.ValueType  # 8995
    DEVICE_ATTRIBUTE_CI_PHYSICAL_CHANS: _DeviceStringAttribute.ValueType  # 8996
    DEVICE_ATTRIBUTE_CO_PHYSICAL_CHANS: _DeviceStringAttribute.ValueType  # 8997
    DEVICE_ATTRIBUTE_CHASSIS_MODULE_DEV_NAMES: _DeviceStringAttribute.ValueType  # 10678
    DEVICE_ATTRIBUTE_COMPACT_DAQ_CHASSIS_DEV_NAME: _DeviceStringAttribute.ValueType  # 10679
    DEVICE_ATTRIBUTE_TERMINALS: _DeviceStringAttribute.ValueType  # 10816
    DEVICE_ATTRIBUTE_TCPIP_HOSTNAME: _DeviceStringAttribute.ValueType  # 10891
    DEVICE_ATTRIBUTE_TCPIP_ETHERNET_IP: _DeviceStringAttribute.ValueType  # 10892
    DEVICE_ATTRIBUTE_TCPIP_WIRELESS_IP: _DeviceStringAttribute.ValueType  # 10893
    DEVICE_ATTRIBUTE_ACCESSORY_PRODUCT_TYPES: _DeviceStringAttribute.ValueType  # 12141
    DEVICE_ATTRIBUTE_NAV_PHYSICAL_CHANS: _DeviceStringAttribute.ValueType  # 12322
    DEVICE_ATTRIBUTE_COMPACT_RIO_CHASSIS_DEV_NAME: _DeviceStringAttribute.ValueType  # 12641
    DEVICE_ATTRIBUTE_FIELD_DAQ_DEV_NAME: _DeviceStringAttribute.ValueType  # 12657
    DEVICE_ATTRIBUTE_FIELD_DAQ_BANK_DEV_NAMES: _DeviceStringAttribute.ValueType  # 12664

class DeviceStringAttribute(_DeviceStringAttribute, metaclass=_DeviceStringAttributeEnumTypeWrapper): ...

DEVICE_STRING_ATTRIBUTE_UNSPECIFIED: DeviceStringAttribute.ValueType  # 0
DEVICE_ATTRIBUTE_PRODUCT_TYPE: DeviceStringAttribute.ValueType  # 1585
DEVICE_ATTRIBUTE_AI_PHYSICAL_CHANS: DeviceStringAttribute.ValueType  # 8990
DEVICE_ATTRIBUTE_AO_PHYSICAL_CHANS: DeviceStringAttribute.ValueType  # 8991
DEVICE_ATTRIBUTE_DI_LINES: DeviceStringAttribute.ValueType  # 8992
DEVICE_ATTRIBUTE_DI_PORTS: DeviceStringAttribute.ValueType  # 8993
DEVICE_ATTRIBUTE_DO_LINES: DeviceStringAttribute.ValueType  # 8994
DEVICE_ATTRIBUTE_DO_PORTS: DeviceStringAttribute.ValueType  # 8995
DEVICE_ATTRIBUTE_CI_PHYSICAL_CHANS: DeviceStringAttribute.ValueType  # 8996
DEVICE_ATTRIBUTE_CO_PHYSICAL_CHANS: DeviceStringAttribute.ValueType  # 8997
DEVICE_ATTRIBUTE_CHASSIS_MODULE_DEV_NAMES: DeviceStringAttribute.ValueType  # 10678
DEVICE_ATTRIBUTE_COMPACT_DAQ_CHASSIS_DEV_NAME: DeviceStringAttribute.ValueType  # 10679
DEVICE_ATTRIBUTE_TERMINALS: DeviceStringAttribute.ValueType  # 10816
DEVICE_ATTRIBUTE_TCPIP_HOSTNAME: DeviceStringAttribute.ValueType  # 10891
DEVICE_ATTRIBUTE_TCPIP_ETHERNET_IP: DeviceStringAttribute.ValueType  # 10892
DEVICE_ATTRIBUTE_TCPIP_WIRELESS_IP: DeviceStringAttribute.ValueType  # 10893
DEVICE_ATTRIBUTE_ACCESSORY_PRODUCT_TYPES: DeviceStringAttribute.ValueType  # 12141
DEVICE_ATTRIBUTE_NAV_PHYSICAL_CHANS: DeviceStringAttribute.ValueType  # 12322
DEVICE_ATTRIBUTE_COMPACT_RIO_CHASSIS_DEV_NAME: DeviceStringAttribute.ValueType  # 12641
DEVICE_ATTRIBUTE_FIELD_DAQ_DEV_NAME: DeviceStringAttribute.ValueType  # 12657
DEVICE_ATTRIBUTE_FIELD_DAQ_BANK_DEV_NAMES: DeviceStringAttribute.ValueType  # 12664
global___DeviceStringAttribute = DeviceStringAttribute

class _DeviceUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_UINT32_ATTRIBUTE_UNSPECIFIED: _DeviceUInt32Attribute.ValueType  # 0
    DEVICE_ATTRIBUTE_SERIAL_NUM: _DeviceUInt32Attribute.ValueType  # 1586
    DEVICE_ATTRIBUTE_PRODUCT_NUM: _DeviceUInt32Attribute.ValueType  # 8989
    DEVICE_ATTRIBUTE_PCI_BUS_NUM: _DeviceUInt32Attribute.ValueType  # 8999
    DEVICE_ATTRIBUTE_PCI_DEV_NUM: _DeviceUInt32Attribute.ValueType  # 9000
    DEVICE_ATTRIBUTE_PXI_CHASSIS_NUM: _DeviceUInt32Attribute.ValueType  # 9001
    DEVICE_ATTRIBUTE_PXI_SLOT_NUM: _DeviceUInt32Attribute.ValueType  # 9002
    DEVICE_ATTRIBUTE_NUM_DMA_CHANS: _DeviceUInt32Attribute.ValueType  # 9020
    DEVICE_ATTRIBUTE_CI_MAX_SIZE: _DeviceUInt32Attribute.ValueType  # 10655
    DEVICE_ATTRIBUTE_CO_MAX_SIZE: _DeviceUInt32Attribute.ValueType  # 10657
    DEVICE_ATTRIBUTE_COMPACT_DAQ_SLOT_NUM: _DeviceUInt32Attribute.ValueType  # 10680
    DEVICE_ATTRIBUTE_CARRIER_SERIAL_NUM: _DeviceUInt32Attribute.ValueType  # 10890
    DEVICE_ATTRIBUTE_NAV_NUM_SURVEY_FIXES: _DeviceUInt32Attribute.ValueType  # 12331
    DEVICE_ATTRIBUTE_NAV_REMAINING_SURVEY_FIXES: _DeviceUInt32Attribute.ValueType  # 12332
    DEVICE_ATTRIBUTE_NAV_NUM_SATS: _DeviceUInt32Attribute.ValueType  # 12337
    DEVICE_ATTRIBUTE_NUM_TIME_TRIGS: _DeviceUInt32Attribute.ValueType  # 12609
    DEVICE_ATTRIBUTE_NUM_TIMESTAMP_ENGINES: _DeviceUInt32Attribute.ValueType  # 12610
    DEVICE_ATTRIBUTE_COMPACT_RIO_SLOT_NUM: _DeviceUInt32Attribute.ValueType  # 12642
    DEVICE_ATTRIBUTE_AI_NUM_SAMP_TIMING_ENGINES: _DeviceUInt32Attribute.ValueType  # 12643
    DEVICE_ATTRIBUTE_AI_NUM_SYNC_PULSE_SRCS: _DeviceUInt32Attribute.ValueType  # 12644
    DEVICE_ATTRIBUTE_AO_NUM_SAMP_TIMING_ENGINES: _DeviceUInt32Attribute.ValueType  # 12645
    DEVICE_ATTRIBUTE_AO_NUM_SYNC_PULSE_SRCS: _DeviceUInt32Attribute.ValueType  # 12646
    DEVICE_ATTRIBUTE_DI_NUM_SAMP_TIMING_ENGINES: _DeviceUInt32Attribute.ValueType  # 12647
    DEVICE_ATTRIBUTE_DO_NUM_SAMP_TIMING_ENGINES: _DeviceUInt32Attribute.ValueType  # 12648

class DeviceUInt32Attribute(_DeviceUInt32Attribute, metaclass=_DeviceUInt32AttributeEnumTypeWrapper): ...

DEVICE_UINT32_ATTRIBUTE_UNSPECIFIED: DeviceUInt32Attribute.ValueType  # 0
DEVICE_ATTRIBUTE_SERIAL_NUM: DeviceUInt32Attribute.ValueType  # 1586
DEVICE_ATTRIBUTE_PRODUCT_NUM: DeviceUInt32Attribute.ValueType  # 8989
DEVICE_ATTRIBUTE_PCI_BUS_NUM: DeviceUInt32Attribute.ValueType  # 8999
DEVICE_ATTRIBUTE_PCI_DEV_NUM: DeviceUInt32Attribute.ValueType  # 9000
DEVICE_ATTRIBUTE_PXI_CHASSIS_NUM: DeviceUInt32Attribute.ValueType  # 9001
DEVICE_ATTRIBUTE_PXI_SLOT_NUM: DeviceUInt32Attribute.ValueType  # 9002
DEVICE_ATTRIBUTE_NUM_DMA_CHANS: DeviceUInt32Attribute.ValueType  # 9020
DEVICE_ATTRIBUTE_CI_MAX_SIZE: DeviceUInt32Attribute.ValueType  # 10655
DEVICE_ATTRIBUTE_CO_MAX_SIZE: DeviceUInt32Attribute.ValueType  # 10657
DEVICE_ATTRIBUTE_COMPACT_DAQ_SLOT_NUM: DeviceUInt32Attribute.ValueType  # 10680
DEVICE_ATTRIBUTE_CARRIER_SERIAL_NUM: DeviceUInt32Attribute.ValueType  # 10890
DEVICE_ATTRIBUTE_NAV_NUM_SURVEY_FIXES: DeviceUInt32Attribute.ValueType  # 12331
DEVICE_ATTRIBUTE_NAV_REMAINING_SURVEY_FIXES: DeviceUInt32Attribute.ValueType  # 12332
DEVICE_ATTRIBUTE_NAV_NUM_SATS: DeviceUInt32Attribute.ValueType  # 12337
DEVICE_ATTRIBUTE_NUM_TIME_TRIGS: DeviceUInt32Attribute.ValueType  # 12609
DEVICE_ATTRIBUTE_NUM_TIMESTAMP_ENGINES: DeviceUInt32Attribute.ValueType  # 12610
DEVICE_ATTRIBUTE_COMPACT_RIO_SLOT_NUM: DeviceUInt32Attribute.ValueType  # 12642
DEVICE_ATTRIBUTE_AI_NUM_SAMP_TIMING_ENGINES: DeviceUInt32Attribute.ValueType  # 12643
DEVICE_ATTRIBUTE_AI_NUM_SYNC_PULSE_SRCS: DeviceUInt32Attribute.ValueType  # 12644
DEVICE_ATTRIBUTE_AO_NUM_SAMP_TIMING_ENGINES: DeviceUInt32Attribute.ValueType  # 12645
DEVICE_ATTRIBUTE_AO_NUM_SYNC_PULSE_SRCS: DeviceUInt32Attribute.ValueType  # 12646
DEVICE_ATTRIBUTE_DI_NUM_SAMP_TIMING_ENGINES: DeviceUInt32Attribute.ValueType  # 12647
DEVICE_ATTRIBUTE_DO_NUM_SAMP_TIMING_ENGINES: DeviceUInt32Attribute.ValueType  # 12648
global___DeviceUInt32Attribute = DeviceUInt32Attribute

class _DeviceBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_BOOL_ATTRIBUTE_UNSPECIFIED: _DeviceBoolAttribute.ValueType  # 0
    DEVICE_ATTRIBUTE_IS_SIMULATED: _DeviceBoolAttribute.ValueType  # 8906
    DEVICE_ATTRIBUTE_ANLG_TRIG_SUPPORTED: _DeviceBoolAttribute.ValueType  # 10628
    DEVICE_ATTRIBUTE_DIG_TRIG_SUPPORTED: _DeviceBoolAttribute.ValueType  # 10629
    DEVICE_ATTRIBUTE_AI_SIMULTANEOUS_SAMPLING_SUPPORTED: _DeviceBoolAttribute.ValueType  # 10639
    DEVICE_ATTRIBUTE_AO_SAMP_CLK_SUPPORTED: _DeviceBoolAttribute.ValueType  # 10646
    DEVICE_ATTRIBUTE_CI_SAMP_CLK_SUPPORTED: _DeviceBoolAttribute.ValueType  # 10654
    DEVICE_ATTRIBUTE_CO_SAMP_CLK_SUPPORTED: _DeviceBoolAttribute.ValueType  # 12123
    DEVICE_ATTRIBUTE_TEDS_HWTEDS_SUPPORTED: _DeviceBoolAttribute.ValueType  # 12246
    DEVICE_ATTRIBUTE_TIME_TRIG_SUPPORTED: _DeviceBoolAttribute.ValueType  # 12319
    DEVICE_ATTRIBUTE_CI_UTC_OFFSET_READY: _DeviceBoolAttribute.ValueType  # 12321
    DEVICE_ATTRIBUTE_NAV_HAS_FIX: _DeviceBoolAttribute.ValueType  # 12333
    DEVICE_ATTRIBUTE_NAV_UTC_OFFSET_READY: _DeviceBoolAttribute.ValueType  # 12335

class DeviceBoolAttribute(_DeviceBoolAttribute, metaclass=_DeviceBoolAttributeEnumTypeWrapper): ...

DEVICE_BOOL_ATTRIBUTE_UNSPECIFIED: DeviceBoolAttribute.ValueType  # 0
DEVICE_ATTRIBUTE_IS_SIMULATED: DeviceBoolAttribute.ValueType  # 8906
DEVICE_ATTRIBUTE_ANLG_TRIG_SUPPORTED: DeviceBoolAttribute.ValueType  # 10628
DEVICE_ATTRIBUTE_DIG_TRIG_SUPPORTED: DeviceBoolAttribute.ValueType  # 10629
DEVICE_ATTRIBUTE_AI_SIMULTANEOUS_SAMPLING_SUPPORTED: DeviceBoolAttribute.ValueType  # 10639
DEVICE_ATTRIBUTE_AO_SAMP_CLK_SUPPORTED: DeviceBoolAttribute.ValueType  # 10646
DEVICE_ATTRIBUTE_CI_SAMP_CLK_SUPPORTED: DeviceBoolAttribute.ValueType  # 10654
DEVICE_ATTRIBUTE_CO_SAMP_CLK_SUPPORTED: DeviceBoolAttribute.ValueType  # 12123
DEVICE_ATTRIBUTE_TEDS_HWTEDS_SUPPORTED: DeviceBoolAttribute.ValueType  # 12246
DEVICE_ATTRIBUTE_TIME_TRIG_SUPPORTED: DeviceBoolAttribute.ValueType  # 12319
DEVICE_ATTRIBUTE_CI_UTC_OFFSET_READY: DeviceBoolAttribute.ValueType  # 12321
DEVICE_ATTRIBUTE_NAV_HAS_FIX: DeviceBoolAttribute.ValueType  # 12333
DEVICE_ATTRIBUTE_NAV_UTC_OFFSET_READY: DeviceBoolAttribute.ValueType  # 12335
global___DeviceBoolAttribute = DeviceBoolAttribute

class _DeviceInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_INT32_ATTRIBUTE_UNSPECIFIED: _DeviceInt32Attribute.ValueType  # 0
    DEVICE_ATTRIBUTE_BUS_TYPE: _DeviceInt32Attribute.ValueType  # 8998
    DEVICE_ATTRIBUTE_AI_TRIG_USAGE: _DeviceInt32Attribute.ValueType  # 10630
    DEVICE_ATTRIBUTE_AO_TRIG_USAGE: _DeviceInt32Attribute.ValueType  # 10631
    DEVICE_ATTRIBUTE_DI_TRIG_USAGE: _DeviceInt32Attribute.ValueType  # 10632
    DEVICE_ATTRIBUTE_DO_TRIG_USAGE: _DeviceInt32Attribute.ValueType  # 10633
    DEVICE_ATTRIBUTE_CI_TRIG_USAGE: _DeviceInt32Attribute.ValueType  # 10634
    DEVICE_ATTRIBUTE_CO_TRIG_USAGE: _DeviceInt32Attribute.ValueType  # 10635
    DEVICE_ATTRIBUTE_AI_COUPLINGS: _DeviceInt32Attribute.ValueType  # 10644
    DEVICE_ATTRIBUTE_PRODUCT_CATEGORY: _DeviceInt32Attribute.ValueType  # 10665
    DEVICE_ATTRIBUTE_CI_CURRENT_UTC_OFFSET: _DeviceInt32Attribute.ValueType  # 12320
    DEVICE_ATTRIBUTE_NAV_MODE: _DeviceInt32Attribute.ValueType  # 12325
    DEVICE_ATTRIBUTE_NAV_ALT_REF: _DeviceInt32Attribute.ValueType  # 12329
    DEVICE_ATTRIBUTE_NAV_ANT_STATUS: _DeviceInt32Attribute.ValueType  # 12334
    DEVICE_ATTRIBUTE_NAV_CURRENT_UTC_OFFSET: _DeviceInt32Attribute.ValueType  # 12336

class DeviceInt32Attribute(_DeviceInt32Attribute, metaclass=_DeviceInt32AttributeEnumTypeWrapper): ...

DEVICE_INT32_ATTRIBUTE_UNSPECIFIED: DeviceInt32Attribute.ValueType  # 0
DEVICE_ATTRIBUTE_BUS_TYPE: DeviceInt32Attribute.ValueType  # 8998
DEVICE_ATTRIBUTE_AI_TRIG_USAGE: DeviceInt32Attribute.ValueType  # 10630
DEVICE_ATTRIBUTE_AO_TRIG_USAGE: DeviceInt32Attribute.ValueType  # 10631
DEVICE_ATTRIBUTE_DI_TRIG_USAGE: DeviceInt32Attribute.ValueType  # 10632
DEVICE_ATTRIBUTE_DO_TRIG_USAGE: DeviceInt32Attribute.ValueType  # 10633
DEVICE_ATTRIBUTE_CI_TRIG_USAGE: DeviceInt32Attribute.ValueType  # 10634
DEVICE_ATTRIBUTE_CO_TRIG_USAGE: DeviceInt32Attribute.ValueType  # 10635
DEVICE_ATTRIBUTE_AI_COUPLINGS: DeviceInt32Attribute.ValueType  # 10644
DEVICE_ATTRIBUTE_PRODUCT_CATEGORY: DeviceInt32Attribute.ValueType  # 10665
DEVICE_ATTRIBUTE_CI_CURRENT_UTC_OFFSET: DeviceInt32Attribute.ValueType  # 12320
DEVICE_ATTRIBUTE_NAV_MODE: DeviceInt32Attribute.ValueType  # 12325
DEVICE_ATTRIBUTE_NAV_ALT_REF: DeviceInt32Attribute.ValueType  # 12329
DEVICE_ATTRIBUTE_NAV_ANT_STATUS: DeviceInt32Attribute.ValueType  # 12334
DEVICE_ATTRIBUTE_NAV_CURRENT_UTC_OFFSET: DeviceInt32Attribute.ValueType  # 12336
global___DeviceInt32Attribute = DeviceInt32Attribute

class _DeviceDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_DOUBLE_ATTRIBUTE_UNSPECIFIED: _DeviceDoubleAttribute.ValueType  # 0
    DEVICE_ATTRIBUTE_AI_MAX_SINGLE_CHAN_RATE: _DeviceDoubleAttribute.ValueType  # 10636
    DEVICE_ATTRIBUTE_AI_MAX_MULTI_CHAN_RATE: _DeviceDoubleAttribute.ValueType  # 10637
    DEVICE_ATTRIBUTE_AI_MIN_RATE: _DeviceDoubleAttribute.ValueType  # 10638
    DEVICE_ATTRIBUTE_AO_MAX_RATE: _DeviceDoubleAttribute.ValueType  # 10647
    DEVICE_ATTRIBUTE_AO_MIN_RATE: _DeviceDoubleAttribute.ValueType  # 10648
    DEVICE_ATTRIBUTE_DI_MAX_RATE: _DeviceDoubleAttribute.ValueType  # 10649
    DEVICE_ATTRIBUTE_DO_MAX_RATE: _DeviceDoubleAttribute.ValueType  # 10650
    DEVICE_ATTRIBUTE_CI_MAX_TIMEBASE: _DeviceDoubleAttribute.ValueType  # 10656
    DEVICE_ATTRIBUTE_CO_MAX_TIMEBASE: _DeviceDoubleAttribute.ValueType  # 10658
    DEVICE_ATTRIBUTE_NAV_PRESET_LAT: _DeviceDoubleAttribute.ValueType  # 12326
    DEVICE_ATTRIBUTE_NAV_PRESET_LONG: _DeviceDoubleAttribute.ValueType  # 12327
    DEVICE_ATTRIBUTE_NAV_PRESET_ALT: _DeviceDoubleAttribute.ValueType  # 12328
    DEVICE_ATTRIBUTE_NAV_PPS_COMPEN: _DeviceDoubleAttribute.ValueType  # 12330
    DEVICE_ATTRIBUTE_NAV_PDOP: _DeviceDoubleAttribute.ValueType  # 12338
    DEVICE_ATTRIBUTE_NAV_HDOP: _DeviceDoubleAttribute.ValueType  # 12339
    DEVICE_ATTRIBUTE_NAV_VDOP: _DeviceDoubleAttribute.ValueType  # 12340

class DeviceDoubleAttribute(_DeviceDoubleAttribute, metaclass=_DeviceDoubleAttributeEnumTypeWrapper): ...

DEVICE_DOUBLE_ATTRIBUTE_UNSPECIFIED: DeviceDoubleAttribute.ValueType  # 0
DEVICE_ATTRIBUTE_AI_MAX_SINGLE_CHAN_RATE: DeviceDoubleAttribute.ValueType  # 10636
DEVICE_ATTRIBUTE_AI_MAX_MULTI_CHAN_RATE: DeviceDoubleAttribute.ValueType  # 10637
DEVICE_ATTRIBUTE_AI_MIN_RATE: DeviceDoubleAttribute.ValueType  # 10638
DEVICE_ATTRIBUTE_AO_MAX_RATE: DeviceDoubleAttribute.ValueType  # 10647
DEVICE_ATTRIBUTE_AO_MIN_RATE: DeviceDoubleAttribute.ValueType  # 10648
DEVICE_ATTRIBUTE_DI_MAX_RATE: DeviceDoubleAttribute.ValueType  # 10649
DEVICE_ATTRIBUTE_DO_MAX_RATE: DeviceDoubleAttribute.ValueType  # 10650
DEVICE_ATTRIBUTE_CI_MAX_TIMEBASE: DeviceDoubleAttribute.ValueType  # 10656
DEVICE_ATTRIBUTE_CO_MAX_TIMEBASE: DeviceDoubleAttribute.ValueType  # 10658
DEVICE_ATTRIBUTE_NAV_PRESET_LAT: DeviceDoubleAttribute.ValueType  # 12326
DEVICE_ATTRIBUTE_NAV_PRESET_LONG: DeviceDoubleAttribute.ValueType  # 12327
DEVICE_ATTRIBUTE_NAV_PRESET_ALT: DeviceDoubleAttribute.ValueType  # 12328
DEVICE_ATTRIBUTE_NAV_PPS_COMPEN: DeviceDoubleAttribute.ValueType  # 12330
DEVICE_ATTRIBUTE_NAV_PDOP: DeviceDoubleAttribute.ValueType  # 12338
DEVICE_ATTRIBUTE_NAV_HDOP: DeviceDoubleAttribute.ValueType  # 12339
DEVICE_ATTRIBUTE_NAV_VDOP: DeviceDoubleAttribute.ValueType  # 12340
global___DeviceDoubleAttribute = DeviceDoubleAttribute

class _DeviceDoubleArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceDoubleArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceDoubleArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: _DeviceDoubleArrayAttribute.ValueType  # 0
    DEVICE_ATTRIBUTE_AI_VOLTAGE_RNGS: _DeviceDoubleArrayAttribute.ValueType  # 10640
    DEVICE_ATTRIBUTE_AI_CURRENT_RNGS: _DeviceDoubleArrayAttribute.ValueType  # 10641
    DEVICE_ATTRIBUTE_AI_FREQ_RNGS: _DeviceDoubleArrayAttribute.ValueType  # 10642
    DEVICE_ATTRIBUTE_AI_GAINS: _DeviceDoubleArrayAttribute.ValueType  # 10643
    DEVICE_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ_DISCRETE_VALS: _DeviceDoubleArrayAttribute.ValueType  # 10645
    DEVICE_ATTRIBUTE_AO_VOLTAGE_RNGS: _DeviceDoubleArrayAttribute.ValueType  # 10651
    DEVICE_ATTRIBUTE_AO_CURRENT_RNGS: _DeviceDoubleArrayAttribute.ValueType  # 10652
    DEVICE_ATTRIBUTE_AO_GAINS: _DeviceDoubleArrayAttribute.ValueType  # 10653
    DEVICE_ATTRIBUTE_AI_VOLTAGE_INT_EXCIT_DISCRETE_VALS: _DeviceDoubleArrayAttribute.ValueType  # 10697
    DEVICE_ATTRIBUTE_AI_VOLTAGE_INT_EXCIT_RANGE_VALS: _DeviceDoubleArrayAttribute.ValueType  # 10698
    DEVICE_ATTRIBUTE_AI_CURRENT_INT_EXCIT_DISCRETE_VALS: _DeviceDoubleArrayAttribute.ValueType  # 10699
    DEVICE_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ_RANGE_VALS: _DeviceDoubleArrayAttribute.ValueType  # 10703
    DEVICE_ATTRIBUTE_AI_RESISTANCE_RNGS: _DeviceDoubleArrayAttribute.ValueType  # 10773
    DEVICE_ATTRIBUTE_AI_BRIDGE_RNGS: _DeviceDoubleArrayAttribute.ValueType  # 12240
    DEVICE_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ_DISCRETE_VALS: _DeviceDoubleArrayAttribute.ValueType  # 12488
    DEVICE_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ_RANGE_VALS: _DeviceDoubleArrayAttribute.ValueType  # 12489
    DEVICE_ATTRIBUTE_AI_CHARGE_RNGS: _DeviceDoubleArrayAttribute.ValueType  # 12561

class DeviceDoubleArrayAttribute(_DeviceDoubleArrayAttribute, metaclass=_DeviceDoubleArrayAttributeEnumTypeWrapper): ...

DEVICE_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: DeviceDoubleArrayAttribute.ValueType  # 0
DEVICE_ATTRIBUTE_AI_VOLTAGE_RNGS: DeviceDoubleArrayAttribute.ValueType  # 10640
DEVICE_ATTRIBUTE_AI_CURRENT_RNGS: DeviceDoubleArrayAttribute.ValueType  # 10641
DEVICE_ATTRIBUTE_AI_FREQ_RNGS: DeviceDoubleArrayAttribute.ValueType  # 10642
DEVICE_ATTRIBUTE_AI_GAINS: DeviceDoubleArrayAttribute.ValueType  # 10643
DEVICE_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ_DISCRETE_VALS: DeviceDoubleArrayAttribute.ValueType  # 10645
DEVICE_ATTRIBUTE_AO_VOLTAGE_RNGS: DeviceDoubleArrayAttribute.ValueType  # 10651
DEVICE_ATTRIBUTE_AO_CURRENT_RNGS: DeviceDoubleArrayAttribute.ValueType  # 10652
DEVICE_ATTRIBUTE_AO_GAINS: DeviceDoubleArrayAttribute.ValueType  # 10653
DEVICE_ATTRIBUTE_AI_VOLTAGE_INT_EXCIT_DISCRETE_VALS: DeviceDoubleArrayAttribute.ValueType  # 10697
DEVICE_ATTRIBUTE_AI_VOLTAGE_INT_EXCIT_RANGE_VALS: DeviceDoubleArrayAttribute.ValueType  # 10698
DEVICE_ATTRIBUTE_AI_CURRENT_INT_EXCIT_DISCRETE_VALS: DeviceDoubleArrayAttribute.ValueType  # 10699
DEVICE_ATTRIBUTE_AI_LOWPASS_CUTOFF_FREQ_RANGE_VALS: DeviceDoubleArrayAttribute.ValueType  # 10703
DEVICE_ATTRIBUTE_AI_RESISTANCE_RNGS: DeviceDoubleArrayAttribute.ValueType  # 10773
DEVICE_ATTRIBUTE_AI_BRIDGE_RNGS: DeviceDoubleArrayAttribute.ValueType  # 12240
DEVICE_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ_DISCRETE_VALS: DeviceDoubleArrayAttribute.ValueType  # 12488
DEVICE_ATTRIBUTE_AI_DIG_FLTR_LOWPASS_CUTOFF_FREQ_RANGE_VALS: DeviceDoubleArrayAttribute.ValueType  # 12489
DEVICE_ATTRIBUTE_AI_CHARGE_RNGS: DeviceDoubleArrayAttribute.ValueType  # 12561
global___DeviceDoubleArrayAttribute = DeviceDoubleArrayAttribute

class _DeviceUInt32ArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceUInt32ArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceUInt32ArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_UINT32_ARRAY_ATTRIBUTE_UNSPECIFIED: _DeviceUInt32ArrayAttribute.ValueType  # 0
    DEVICE_ATTRIBUTE_ACCESSORY_PRODUCT_NUMS: _DeviceUInt32ArrayAttribute.ValueType  # 12142
    DEVICE_ATTRIBUTE_ACCESSORY_SERIAL_NUMS: _DeviceUInt32ArrayAttribute.ValueType  # 12143

class DeviceUInt32ArrayAttribute(_DeviceUInt32ArrayAttribute, metaclass=_DeviceUInt32ArrayAttributeEnumTypeWrapper): ...

DEVICE_UINT32_ARRAY_ATTRIBUTE_UNSPECIFIED: DeviceUInt32ArrayAttribute.ValueType  # 0
DEVICE_ATTRIBUTE_ACCESSORY_PRODUCT_NUMS: DeviceUInt32ArrayAttribute.ValueType  # 12142
DEVICE_ATTRIBUTE_ACCESSORY_SERIAL_NUMS: DeviceUInt32ArrayAttribute.ValueType  # 12143
global___DeviceUInt32ArrayAttribute = DeviceUInt32ArrayAttribute

class _DeviceInt32ArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceInt32ArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceInt32ArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED: _DeviceInt32ArrayAttribute.ValueType  # 0
    DEVICE_ATTRIBUTE_AI_SUPPORTED_MEAS_TYPES: _DeviceInt32ArrayAttribute.ValueType  # 12242
    DEVICE_ATTRIBUTE_AO_SUPPORTED_OUTPUT_TYPES: _DeviceInt32ArrayAttribute.ValueType  # 12243
    DEVICE_ATTRIBUTE_CI_SUPPORTED_MEAS_TYPES: _DeviceInt32ArrayAttribute.ValueType  # 12244
    DEVICE_ATTRIBUTE_CO_SUPPORTED_OUTPUT_TYPES: _DeviceInt32ArrayAttribute.ValueType  # 12245
    DEVICE_ATTRIBUTE_AI_SAMP_MODES: _DeviceInt32ArrayAttribute.ValueType  # 12252
    DEVICE_ATTRIBUTE_AO_SAMP_MODES: _DeviceInt32ArrayAttribute.ValueType  # 12253
    DEVICE_ATTRIBUTE_CI_SAMP_MODES: _DeviceInt32ArrayAttribute.ValueType  # 12254
    DEVICE_ATTRIBUTE_CO_SAMP_MODES: _DeviceInt32ArrayAttribute.ValueType  # 12255
    DEVICE_ATTRIBUTE_NAV_SUPPORTED_MEAS_TYPES: _DeviceInt32ArrayAttribute.ValueType  # 12323
    DEVICE_ATTRIBUTE_NAV_TRIG_USAGE: _DeviceInt32ArrayAttribute.ValueType  # 12324
    DEVICE_ATTRIBUTE_AI_DIG_FLTR_TYPES: _DeviceInt32ArrayAttribute.ValueType  # 12551

class DeviceInt32ArrayAttribute(_DeviceInt32ArrayAttribute, metaclass=_DeviceInt32ArrayAttributeEnumTypeWrapper): ...

DEVICE_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED: DeviceInt32ArrayAttribute.ValueType  # 0
DEVICE_ATTRIBUTE_AI_SUPPORTED_MEAS_TYPES: DeviceInt32ArrayAttribute.ValueType  # 12242
DEVICE_ATTRIBUTE_AO_SUPPORTED_OUTPUT_TYPES: DeviceInt32ArrayAttribute.ValueType  # 12243
DEVICE_ATTRIBUTE_CI_SUPPORTED_MEAS_TYPES: DeviceInt32ArrayAttribute.ValueType  # 12244
DEVICE_ATTRIBUTE_CO_SUPPORTED_OUTPUT_TYPES: DeviceInt32ArrayAttribute.ValueType  # 12245
DEVICE_ATTRIBUTE_AI_SAMP_MODES: DeviceInt32ArrayAttribute.ValueType  # 12252
DEVICE_ATTRIBUTE_AO_SAMP_MODES: DeviceInt32ArrayAttribute.ValueType  # 12253
DEVICE_ATTRIBUTE_CI_SAMP_MODES: DeviceInt32ArrayAttribute.ValueType  # 12254
DEVICE_ATTRIBUTE_CO_SAMP_MODES: DeviceInt32ArrayAttribute.ValueType  # 12255
DEVICE_ATTRIBUTE_NAV_SUPPORTED_MEAS_TYPES: DeviceInt32ArrayAttribute.ValueType  # 12323
DEVICE_ATTRIBUTE_NAV_TRIG_USAGE: DeviceInt32ArrayAttribute.ValueType  # 12324
DEVICE_ATTRIBUTE_AI_DIG_FLTR_TYPES: DeviceInt32ArrayAttribute.ValueType  # 12551
global___DeviceInt32ArrayAttribute = DeviceInt32ArrayAttribute

class _ExportSignalDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExportSignalDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExportSignalDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXPORTSIGNAL_DOUBLE_ATTRIBUTE_UNSPECIFIED: _ExportSignalDoubleAttribute.ValueType  # 0
    EXPORTSIGNAL_ATTRIBUTE_START_TRIG_DELAY: _ExportSignalDoubleAttribute.ValueType  # 1409
    EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 1414
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5668
    EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5704
    EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5716
    EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5728
    EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5734
    EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5776
    EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5908
    EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5920
    EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 5944
    EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_DELAY: _ExportSignalDoubleAttribute.ValueType  # 5975
    EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_DELAY_OFFSET: _ExportSignalDoubleAttribute.ValueType  # 8644
    EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_DELAY: _ExportSignalDoubleAttribute.ValueType  # 8892
    EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_DEASSERT_DELAY: _ExportSignalDoubleAttribute.ValueType  # 8895
    EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_PULSE_WIDTH: _ExportSignalDoubleAttribute.ValueType  # 8897

class ExportSignalDoubleAttribute(_ExportSignalDoubleAttribute, metaclass=_ExportSignalDoubleAttributeEnumTypeWrapper): ...

EXPORTSIGNAL_DOUBLE_ATTRIBUTE_UNSPECIFIED: ExportSignalDoubleAttribute.ValueType  # 0
EXPORTSIGNAL_ATTRIBUTE_START_TRIG_DELAY: ExportSignalDoubleAttribute.ValueType  # 1409
EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 1414
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5668
EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5704
EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5716
EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5728
EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5734
EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5776
EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5908
EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5920
EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 5944
EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_DELAY: ExportSignalDoubleAttribute.ValueType  # 5975
EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_DELAY_OFFSET: ExportSignalDoubleAttribute.ValueType  # 8644
EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_DELAY: ExportSignalDoubleAttribute.ValueType  # 8892
EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_DEASSERT_DELAY: ExportSignalDoubleAttribute.ValueType  # 8895
EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_PULSE_WIDTH: ExportSignalDoubleAttribute.ValueType  # 8897
global___ExportSignalDoubleAttribute = ExportSignalDoubleAttribute

class _ExportSignalStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExportSignalStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExportSignalStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXPORTSIGNAL_STRING_ATTRIBUTE_UNSPECIFIED: _ExportSignalStringAttribute.ValueType  # 0
    EXPORTSIGNAL_ATTRIBUTE_START_TRIG_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 1412
    EXPORTSIGNAL_ATTRIBUTE_REF_TRIG_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 1424
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_START_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5641
    EXPORTSIGNAL_ATTRIBUTE_PAUSE_TRIG_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5653
    EXPORTSIGNAL_ATTRIBUTE_DATA_ACTIVE_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5683
    EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5701
    EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5713
    EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5719
    EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5731
    EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5767
    EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 5911
    EXPORTSIGNAL_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 6381
    EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_TIMEBASE_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 6393
    EXPORTSIGNAL_ATTRIBUTE_CHANGE_DETECT_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 8599
    EXPORTSIGNAL_ATTRIBUTE_DIVIDED_SAMP_CLK_TIMEBASE_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 8609
    EXPORTSIGNAL_ATTRIBUTE_WATCHDOG_EXPIRED_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 8618
    EXPORTSIGNAL_ATTRIBUTE_SYNC_PULSE_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 8764
    EXPORTSIGNAL_ATTRIBUTE_10_MHZ_REF_CLK_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 8814
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 8885
    EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_OUTPUT_TERM: _ExportSignalStringAttribute.ValueType  # 8890

class ExportSignalStringAttribute(_ExportSignalStringAttribute, metaclass=_ExportSignalStringAttributeEnumTypeWrapper): ...

EXPORTSIGNAL_STRING_ATTRIBUTE_UNSPECIFIED: ExportSignalStringAttribute.ValueType  # 0
EXPORTSIGNAL_ATTRIBUTE_START_TRIG_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 1412
EXPORTSIGNAL_ATTRIBUTE_REF_TRIG_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 1424
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_START_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5641
EXPORTSIGNAL_ATTRIBUTE_PAUSE_TRIG_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5653
EXPORTSIGNAL_ATTRIBUTE_DATA_ACTIVE_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5683
EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5701
EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5713
EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5719
EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5731
EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5767
EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 5911
EXPORTSIGNAL_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 6381
EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_TIMEBASE_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 6393
EXPORTSIGNAL_ATTRIBUTE_CHANGE_DETECT_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 8599
EXPORTSIGNAL_ATTRIBUTE_DIVIDED_SAMP_CLK_TIMEBASE_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 8609
EXPORTSIGNAL_ATTRIBUTE_WATCHDOG_EXPIRED_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 8618
EXPORTSIGNAL_ATTRIBUTE_SYNC_PULSE_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 8764
EXPORTSIGNAL_ATTRIBUTE_10_MHZ_REF_CLK_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 8814
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 8885
EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_OUTPUT_TERM: ExportSignalStringAttribute.ValueType  # 8890
global___ExportSignalStringAttribute = ExportSignalStringAttribute

class _ExportSignalResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExportSignalResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExportSignalResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXPORTSIGNAL_RESET_ATTRIBUTE_UNSPECIFIED: _ExportSignalResetAttribute.ValueType  # 0
    EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 1412
    EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_PULSE_POLARITY: _ExportSignalResetAttribute.ValueType  # 1413
    EXPORTSIGNAL_RESET_ATTRIBUTE_REF_TRIG_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 1424
    EXPORTSIGNAL_RESET_ATTRIBUTE_REF_TRIG_PULSE_POLARITY: _ExportSignalResetAttribute.ValueType  # 1425
    EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5634
    EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_START_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5641
    EXPORTSIGNAL_RESET_ATTRIBUTE_PAUSE_TRIG_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5653
    EXPORTSIGNAL_RESET_ATTRIBUTE_PAUSE_TRIG_LVL_ACTIVE_LVL: _ExportSignalResetAttribute.ValueType  # 5654
    EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5667
    EXPORTSIGNAL_RESET_ATTRIBUTE_DATA_ACTIVE_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5683
    EXPORTSIGNAL_RESET_ATTRIBUTE_DATA_ACTIVE_EVENT_LVL_ACTIVE_LVL: _ExportSignalResetAttribute.ValueType  # 5684
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5701
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5703
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH: _ExportSignalResetAttribute.ValueType  # 5704
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_ENABLE: _ExportSignalResetAttribute.ValueType  # 5706
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5713
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_POLARITY: _ExportSignalResetAttribute.ValueType  # 5714
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5715
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH: _ExportSignalResetAttribute.ValueType  # 5716
    EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_DIVIDE_DOWN_BY_N: _ExportSignalResetAttribute.ValueType  # 5718
    EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5719
    EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5721
    EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5731
    EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_PULSE_POLARITY: _ExportSignalResetAttribute.ValueType  # 5732
    EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5733
    EXPORTSIGNAL_RESET_ATTRIBUTE_AI_CONV_CLK_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5767
    EXPORTSIGNAL_RESET_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5769
    EXPORTSIGNAL_RESET_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5907
    EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 5911
    EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_PULSE_POLARITY: _ExportSignalResetAttribute.ValueType  # 5912
    EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5913
    EXPORTSIGNAL_RESET_ATTRIBUTE_REF_CLK_PULSE_WIDTH_UNITS: _ExportSignalResetAttribute.ValueType  # 5943
    EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_OUTPUT_BEHAVIOR: _ExportSignalResetAttribute.ValueType  # 5955
    EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_TOGGLE_INITIAL_STATE: _ExportSignalResetAttribute.ValueType  # 5956
    EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_DELAY_UNITS: _ExportSignalResetAttribute.ValueType  # 5965
    EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_BEHAVIOR: _ExportSignalResetAttribute.ValueType  # 5967
    EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_START_EVENT_LVL_ACTIVE_LVL: _ExportSignalResetAttribute.ValueType  # 5969
    EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_DELAY: _ExportSignalResetAttribute.ValueType  # 5975
    EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_TOGGLE_IDLE_STATE: _ExportSignalResetAttribute.ValueType  # 6250
    EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_OUTPUT_BEHAVIOR: _ExportSignalResetAttribute.ValueType  # 6251
    EXPORTSIGNAL_RESET_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 6381
    EXPORTSIGNAL_RESET_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_PULSE_POLARITY: _ExportSignalResetAttribute.ValueType  # 6382
    EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 6393
    EXPORTSIGNAL_RESET_ATTRIBUTE_CHANGE_DETECT_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 8599
    EXPORTSIGNAL_RESET_ATTRIBUTE_DIVIDED_SAMP_CLK_TIMEBASE_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 8609
    EXPORTSIGNAL_RESET_ATTRIBUTE_WATCHDOG_EXPIRED_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 8618
    EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_DELAY_OFFSET: _ExportSignalResetAttribute.ValueType  # 8644
    EXPORTSIGNAL_RESET_ATTRIBUTE_SYNC_PULSE_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 8764
    EXPORTSIGNAL_RESET_ATTRIBUTE_10_MHZ_REF_CLK_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 8814
    EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 8885
    EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_LVL_ACTIVE_LVL: _ExportSignalResetAttribute.ValueType  # 8886
    EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_OUTPUT_TERM: _ExportSignalResetAttribute.ValueType  # 8890
    EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_OUTPUT_BEHAVIOR: _ExportSignalResetAttribute.ValueType  # 8891
    EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_DELAY: _ExportSignalResetAttribute.ValueType  # 8892
    EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERTED_LVL: _ExportSignalResetAttribute.ValueType  # 8893
    EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERT_ON_START: _ExportSignalResetAttribute.ValueType  # 8894
    EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_DEASSERT_DELAY: _ExportSignalResetAttribute.ValueType  # 8895
    EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_PULSE_POLARITY: _ExportSignalResetAttribute.ValueType  # 8896
    EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_PULSE_WIDTH: _ExportSignalResetAttribute.ValueType  # 8897
    EXPORTSIGNAL_RESET_ATTRIBUTE_CHANGE_DETECT_EVENT_PULSE_POLARITY: _ExportSignalResetAttribute.ValueType  # 8963
    EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND: _ExportSignalResetAttribute.ValueType  # 10595
    EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND_CUSTOM_THRESHOLD: _ExportSignalResetAttribute.ValueType  # 10596

class ExportSignalResetAttribute(_ExportSignalResetAttribute, metaclass=_ExportSignalResetAttributeEnumTypeWrapper): ...

EXPORTSIGNAL_RESET_ATTRIBUTE_UNSPECIFIED: ExportSignalResetAttribute.ValueType  # 0
EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 1412
EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_PULSE_POLARITY: ExportSignalResetAttribute.ValueType  # 1413
EXPORTSIGNAL_RESET_ATTRIBUTE_REF_TRIG_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 1424
EXPORTSIGNAL_RESET_ATTRIBUTE_REF_TRIG_PULSE_POLARITY: ExportSignalResetAttribute.ValueType  # 1425
EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5634
EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_START_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5641
EXPORTSIGNAL_RESET_ATTRIBUTE_PAUSE_TRIG_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5653
EXPORTSIGNAL_RESET_ATTRIBUTE_PAUSE_TRIG_LVL_ACTIVE_LVL: ExportSignalResetAttribute.ValueType  # 5654
EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5667
EXPORTSIGNAL_RESET_ATTRIBUTE_DATA_ACTIVE_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5683
EXPORTSIGNAL_RESET_ATTRIBUTE_DATA_ACTIVE_EVENT_LVL_ACTIVE_LVL: ExportSignalResetAttribute.ValueType  # 5684
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5701
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5703
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH: ExportSignalResetAttribute.ValueType  # 5704
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_ENABLE: ExportSignalResetAttribute.ValueType  # 5706
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5713
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_POLARITY: ExportSignalResetAttribute.ValueType  # 5714
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5715
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH: ExportSignalResetAttribute.ValueType  # 5716
EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_DIVIDE_DOWN_BY_N: ExportSignalResetAttribute.ValueType  # 5718
EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5719
EXPORTSIGNAL_RESET_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5721
EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5731
EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_PULSE_POLARITY: ExportSignalResetAttribute.ValueType  # 5732
EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5733
EXPORTSIGNAL_RESET_ATTRIBUTE_AI_CONV_CLK_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5767
EXPORTSIGNAL_RESET_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5769
EXPORTSIGNAL_RESET_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5907
EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 5911
EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_PULSE_POLARITY: ExportSignalResetAttribute.ValueType  # 5912
EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5913
EXPORTSIGNAL_RESET_ATTRIBUTE_REF_CLK_PULSE_WIDTH_UNITS: ExportSignalResetAttribute.ValueType  # 5943
EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_OUTPUT_BEHAVIOR: ExportSignalResetAttribute.ValueType  # 5955
EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_TOGGLE_INITIAL_STATE: ExportSignalResetAttribute.ValueType  # 5956
EXPORTSIGNAL_RESET_ATTRIBUTE_START_TRIG_DELAY_UNITS: ExportSignalResetAttribute.ValueType  # 5965
EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_BEHAVIOR: ExportSignalResetAttribute.ValueType  # 5967
EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_START_EVENT_LVL_ACTIVE_LVL: ExportSignalResetAttribute.ValueType  # 5969
EXPORTSIGNAL_RESET_ATTRIBUTE_ADV_CMPLT_EVENT_DELAY: ExportSignalResetAttribute.ValueType  # 5975
EXPORTSIGNAL_RESET_ATTRIBUTE_CTR_OUT_EVENT_TOGGLE_IDLE_STATE: ExportSignalResetAttribute.ValueType  # 6250
EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_OUTPUT_BEHAVIOR: ExportSignalResetAttribute.ValueType  # 6251
EXPORTSIGNAL_RESET_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 6381
EXPORTSIGNAL_RESET_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_PULSE_POLARITY: ExportSignalResetAttribute.ValueType  # 6382
EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 6393
EXPORTSIGNAL_RESET_ATTRIBUTE_CHANGE_DETECT_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 8599
EXPORTSIGNAL_RESET_ATTRIBUTE_DIVIDED_SAMP_CLK_TIMEBASE_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 8609
EXPORTSIGNAL_RESET_ATTRIBUTE_WATCHDOG_EXPIRED_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 8618
EXPORTSIGNAL_RESET_ATTRIBUTE_SAMP_CLK_DELAY_OFFSET: ExportSignalResetAttribute.ValueType  # 8644
EXPORTSIGNAL_RESET_ATTRIBUTE_SYNC_PULSE_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 8764
EXPORTSIGNAL_RESET_ATTRIBUTE_10_MHZ_REF_CLK_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 8814
EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 8885
EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_LVL_ACTIVE_LVL: ExportSignalResetAttribute.ValueType  # 8886
EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_OUTPUT_TERM: ExportSignalResetAttribute.ValueType  # 8890
EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_OUTPUT_BEHAVIOR: ExportSignalResetAttribute.ValueType  # 8891
EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_DELAY: ExportSignalResetAttribute.ValueType  # 8892
EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERTED_LVL: ExportSignalResetAttribute.ValueType  # 8893
EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERT_ON_START: ExportSignalResetAttribute.ValueType  # 8894
EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_DEASSERT_DELAY: ExportSignalResetAttribute.ValueType  # 8895
EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_PULSE_POLARITY: ExportSignalResetAttribute.ValueType  # 8896
EXPORTSIGNAL_RESET_ATTRIBUTE_HSHK_EVENT_PULSE_WIDTH: ExportSignalResetAttribute.ValueType  # 8897
EXPORTSIGNAL_RESET_ATTRIBUTE_CHANGE_DETECT_EVENT_PULSE_POLARITY: ExportSignalResetAttribute.ValueType  # 8963
EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND: ExportSignalResetAttribute.ValueType  # 10595
EXPORTSIGNAL_RESET_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND_CUSTOM_THRESHOLD: ExportSignalResetAttribute.ValueType  # 10596
global___ExportSignalResetAttribute = ExportSignalResetAttribute

class _ExportSignalInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExportSignalInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExportSignalInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXPORTSIGNAL_INT32_ATTRIBUTE_UNSPECIFIED: _ExportSignalInt32Attribute.ValueType  # 0
    EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 1413
    EXPORTSIGNAL_ATTRIBUTE_REF_TRIG_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 1425
    EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5634
    EXPORTSIGNAL_ATTRIBUTE_PAUSE_TRIG_LVL_ACTIVE_LVL: _ExportSignalInt32Attribute.ValueType  # 5654
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5666
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5667
    EXPORTSIGNAL_ATTRIBUTE_DATA_ACTIVE_EVENT_LVL_ACTIVE_LVL: _ExportSignalInt32Attribute.ValueType  # 5684
    EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5702
    EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5703
    EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5714
    EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5715
    EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5720
    EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5721
    EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5732
    EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5733
    EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5768
    EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5769
    EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5906
    EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5907
    EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5912
    EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5913
    EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5942
    EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_WIDTH_UNITS: _ExportSignalInt32Attribute.ValueType  # 5943
    EXPORTSIGNAL_ATTRIBUTE_START_TRIG_OUTPUT_BEHAVIOR: _ExportSignalInt32Attribute.ValueType  # 5955
    EXPORTSIGNAL_ATTRIBUTE_START_TRIG_TOGGLE_INITIAL_STATE: _ExportSignalInt32Attribute.ValueType  # 5956
    EXPORTSIGNAL_ATTRIBUTE_START_TRIG_DELAY_UNITS: _ExportSignalInt32Attribute.ValueType  # 5965
    EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_BEHAVIOR: _ExportSignalInt32Attribute.ValueType  # 5967
    EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_LVL_POLARITY: _ExportSignalInt32Attribute.ValueType  # 5968
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_START_EVENT_LVL_ACTIVE_LVL: _ExportSignalInt32Attribute.ValueType  # 5969
    EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_TOGGLE_IDLE_STATE: _ExportSignalInt32Attribute.ValueType  # 6250
    EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_OUTPUT_BEHAVIOR: _ExportSignalInt32Attribute.ValueType  # 6251
    EXPORTSIGNAL_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 6382
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_LVL_ACTIVE_LVL: _ExportSignalInt32Attribute.ValueType  # 8886
    EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_OUTPUT_BEHAVIOR: _ExportSignalInt32Attribute.ValueType  # 8891
    EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERTED_LVL: _ExportSignalInt32Attribute.ValueType  # 8893
    EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 8896
    EXPORTSIGNAL_ATTRIBUTE_CHANGE_DETECT_EVENT_PULSE_POLARITY: _ExportSignalInt32Attribute.ValueType  # 8963
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND: _ExportSignalInt32Attribute.ValueType  # 10595

class ExportSignalInt32Attribute(_ExportSignalInt32Attribute, metaclass=_ExportSignalInt32AttributeEnumTypeWrapper): ...

EXPORTSIGNAL_INT32_ATTRIBUTE_UNSPECIFIED: ExportSignalInt32Attribute.ValueType  # 0
EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 1413
EXPORTSIGNAL_ATTRIBUTE_REF_TRIG_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 1425
EXPORTSIGNAL_ATTRIBUTE_START_TRIG_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5634
EXPORTSIGNAL_ATTRIBUTE_PAUSE_TRIG_LVL_ACTIVE_LVL: ExportSignalInt32Attribute.ValueType  # 5654
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5666
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_REF_EVENT_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5667
EXPORTSIGNAL_ATTRIBUTE_DATA_ACTIVE_EVENT_LVL_ACTIVE_LVL: ExportSignalInt32Attribute.ValueType  # 5684
EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5702
EXPORTSIGNAL_ATTRIBUTE_ADV_TRIG_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5703
EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5714
EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5715
EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5720
EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5721
EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5732
EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5733
EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5768
EXPORTSIGNAL_ATTRIBUTE_AI_CONV_CLK_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5769
EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5906
EXPORTSIGNAL_ATTRIBUTE_FREQ_OUT_CLK_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5907
EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5912
EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5913
EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 5942
EXPORTSIGNAL_ATTRIBUTE_REF_CLK_PULSE_WIDTH_UNITS: ExportSignalInt32Attribute.ValueType  # 5943
EXPORTSIGNAL_ATTRIBUTE_START_TRIG_OUTPUT_BEHAVIOR: ExportSignalInt32Attribute.ValueType  # 5955
EXPORTSIGNAL_ATTRIBUTE_START_TRIG_TOGGLE_INITIAL_STATE: ExportSignalInt32Attribute.ValueType  # 5956
EXPORTSIGNAL_ATTRIBUTE_START_TRIG_DELAY_UNITS: ExportSignalInt32Attribute.ValueType  # 5965
EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_OUTPUT_BEHAVIOR: ExportSignalInt32Attribute.ValueType  # 5967
EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_LVL_POLARITY: ExportSignalInt32Attribute.ValueType  # 5968
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_START_EVENT_LVL_ACTIVE_LVL: ExportSignalInt32Attribute.ValueType  # 5969
EXPORTSIGNAL_ATTRIBUTE_CTR_OUT_EVENT_TOGGLE_IDLE_STATE: ExportSignalInt32Attribute.ValueType  # 6250
EXPORTSIGNAL_ATTRIBUTE_SAMP_CLK_OUTPUT_BEHAVIOR: ExportSignalInt32Attribute.ValueType  # 6251
EXPORTSIGNAL_ATTRIBUTE_AI_HOLD_CMPLT_EVENT_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 6382
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_LVL_ACTIVE_LVL: ExportSignalInt32Attribute.ValueType  # 8886
EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_OUTPUT_BEHAVIOR: ExportSignalInt32Attribute.ValueType  # 8891
EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERTED_LVL: ExportSignalInt32Attribute.ValueType  # 8893
EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 8896
EXPORTSIGNAL_ATTRIBUTE_CHANGE_DETECT_EVENT_PULSE_POLARITY: ExportSignalInt32Attribute.ValueType  # 8963
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND: ExportSignalInt32Attribute.ValueType  # 10595
global___ExportSignalInt32Attribute = ExportSignalInt32Attribute

class _ExportSignalBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExportSignalBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExportSignalBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXPORTSIGNAL_BOOL_ATTRIBUTE_UNSPECIFIED: _ExportSignalBoolAttribute.ValueType  # 0
    EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_ENABLE: _ExportSignalBoolAttribute.ValueType  # 5706
    EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERT_ON_START: _ExportSignalBoolAttribute.ValueType  # 8894

class ExportSignalBoolAttribute(_ExportSignalBoolAttribute, metaclass=_ExportSignalBoolAttributeEnumTypeWrapper): ...

EXPORTSIGNAL_BOOL_ATTRIBUTE_UNSPECIFIED: ExportSignalBoolAttribute.ValueType  # 0
EXPORTSIGNAL_ATTRIBUTE_ADV_CMPLT_EVENT_ENABLE: ExportSignalBoolAttribute.ValueType  # 5706
EXPORTSIGNAL_ATTRIBUTE_HSHK_EVENT_INTERLOCKED_ASSERT_ON_START: ExportSignalBoolAttribute.ValueType  # 8894
global___ExportSignalBoolAttribute = ExportSignalBoolAttribute

class _ExportSignalUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExportSignalUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExportSignalUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXPORTSIGNAL_UINT32_ATTRIBUTE_UNSPECIFIED: _ExportSignalUInt32Attribute.ValueType  # 0
    EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_DIVIDE_DOWN_BY_N: _ExportSignalUInt32Attribute.ValueType  # 5718
    EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND_CUSTOM_THRESHOLD: _ExportSignalUInt32Attribute.ValueType  # 10596

class ExportSignalUInt32Attribute(_ExportSignalUInt32Attribute, metaclass=_ExportSignalUInt32AttributeEnumTypeWrapper): ...

EXPORTSIGNAL_UINT32_ATTRIBUTE_UNSPECIFIED: ExportSignalUInt32Attribute.ValueType  # 0
EXPORTSIGNAL_ATTRIBUTE_20_MHZ_TIMEBASE_DIVIDE_DOWN_BY_N: ExportSignalUInt32Attribute.ValueType  # 5718
EXPORTSIGNAL_ATTRIBUTE_RDY_FOR_XFER_EVENT_DEASSERT_COND_CUSTOM_THRESHOLD: ExportSignalUInt32Attribute.ValueType  # 10596
global___ExportSignalUInt32Attribute = ExportSignalUInt32Attribute

class _PersistedChannelStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PersistedChannelStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PersistedChannelStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PERSISTEDCHANNEL_STRING_ATTRIBUTE_UNSPECIFIED: _PersistedChannelStringAttribute.ValueType  # 0
    PERSISTEDCHANNEL_ATTRIBUTE_ACTIVE_CHAN: _PersistedChannelStringAttribute.ValueType  # 8911
    PERSISTEDCHANNEL_ATTRIBUTE_AUTHOR: _PersistedChannelStringAttribute.ValueType  # 8912

class PersistedChannelStringAttribute(_PersistedChannelStringAttribute, metaclass=_PersistedChannelStringAttributeEnumTypeWrapper): ...

PERSISTEDCHANNEL_STRING_ATTRIBUTE_UNSPECIFIED: PersistedChannelStringAttribute.ValueType  # 0
PERSISTEDCHANNEL_ATTRIBUTE_ACTIVE_CHAN: PersistedChannelStringAttribute.ValueType  # 8911
PERSISTEDCHANNEL_ATTRIBUTE_AUTHOR: PersistedChannelStringAttribute.ValueType  # 8912
global___PersistedChannelStringAttribute = PersistedChannelStringAttribute

class _PersistedChannelBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PersistedChannelBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PersistedChannelBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PERSISTEDCHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED: _PersistedChannelBoolAttribute.ValueType  # 0
    PERSISTEDCHANNEL_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING: _PersistedChannelBoolAttribute.ValueType  # 8913
    PERSISTEDCHANNEL_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION: _PersistedChannelBoolAttribute.ValueType  # 8914

class PersistedChannelBoolAttribute(_PersistedChannelBoolAttribute, metaclass=_PersistedChannelBoolAttributeEnumTypeWrapper): ...

PERSISTEDCHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED: PersistedChannelBoolAttribute.ValueType  # 0
PERSISTEDCHANNEL_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING: PersistedChannelBoolAttribute.ValueType  # 8913
PERSISTEDCHANNEL_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION: PersistedChannelBoolAttribute.ValueType  # 8914
global___PersistedChannelBoolAttribute = PersistedChannelBoolAttribute

class _PersistedScaleStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PersistedScaleStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PersistedScaleStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PERSISTEDSCALE_STRING_ATTRIBUTE_UNSPECIFIED: _PersistedScaleStringAttribute.ValueType  # 0
    PERSISTEDSCALE_ATTRIBUTE_ACTIVE_SCALE: _PersistedScaleStringAttribute.ValueType  # 8915
    PERSISTEDSCALE_ATTRIBUTE_AUTHOR: _PersistedScaleStringAttribute.ValueType  # 8916

class PersistedScaleStringAttribute(_PersistedScaleStringAttribute, metaclass=_PersistedScaleStringAttributeEnumTypeWrapper): ...

PERSISTEDSCALE_STRING_ATTRIBUTE_UNSPECIFIED: PersistedScaleStringAttribute.ValueType  # 0
PERSISTEDSCALE_ATTRIBUTE_ACTIVE_SCALE: PersistedScaleStringAttribute.ValueType  # 8915
PERSISTEDSCALE_ATTRIBUTE_AUTHOR: PersistedScaleStringAttribute.ValueType  # 8916
global___PersistedScaleStringAttribute = PersistedScaleStringAttribute

class _PersistedScaleBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PersistedScaleBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PersistedScaleBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PERSISTEDSCALE_BOOL_ATTRIBUTE_UNSPECIFIED: _PersistedScaleBoolAttribute.ValueType  # 0
    PERSISTEDSCALE_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING: _PersistedScaleBoolAttribute.ValueType  # 8917
    PERSISTEDSCALE_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION: _PersistedScaleBoolAttribute.ValueType  # 8918

class PersistedScaleBoolAttribute(_PersistedScaleBoolAttribute, metaclass=_PersistedScaleBoolAttributeEnumTypeWrapper): ...

PERSISTEDSCALE_BOOL_ATTRIBUTE_UNSPECIFIED: PersistedScaleBoolAttribute.ValueType  # 0
PERSISTEDSCALE_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING: PersistedScaleBoolAttribute.ValueType  # 8917
PERSISTEDSCALE_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION: PersistedScaleBoolAttribute.ValueType  # 8918
global___PersistedScaleBoolAttribute = PersistedScaleBoolAttribute

class _PersistedTaskStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PersistedTaskStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PersistedTaskStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PERSISTEDTASK_STRING_ATTRIBUTE_UNSPECIFIED: _PersistedTaskStringAttribute.ValueType  # 0
    PERSISTEDTASK_ATTRIBUTE_ACTIVE_TASK: _PersistedTaskStringAttribute.ValueType  # 8907
    PERSISTEDTASK_ATTRIBUTE_AUTHOR: _PersistedTaskStringAttribute.ValueType  # 8908

class PersistedTaskStringAttribute(_PersistedTaskStringAttribute, metaclass=_PersistedTaskStringAttributeEnumTypeWrapper): ...

PERSISTEDTASK_STRING_ATTRIBUTE_UNSPECIFIED: PersistedTaskStringAttribute.ValueType  # 0
PERSISTEDTASK_ATTRIBUTE_ACTIVE_TASK: PersistedTaskStringAttribute.ValueType  # 8907
PERSISTEDTASK_ATTRIBUTE_AUTHOR: PersistedTaskStringAttribute.ValueType  # 8908
global___PersistedTaskStringAttribute = PersistedTaskStringAttribute

class _PersistedTaskBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PersistedTaskBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PersistedTaskBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PERSISTEDTASK_BOOL_ATTRIBUTE_UNSPECIFIED: _PersistedTaskBoolAttribute.ValueType  # 0
    PERSISTEDTASK_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING: _PersistedTaskBoolAttribute.ValueType  # 8909
    PERSISTEDTASK_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION: _PersistedTaskBoolAttribute.ValueType  # 8910

class PersistedTaskBoolAttribute(_PersistedTaskBoolAttribute, metaclass=_PersistedTaskBoolAttributeEnumTypeWrapper): ...

PERSISTEDTASK_BOOL_ATTRIBUTE_UNSPECIFIED: PersistedTaskBoolAttribute.ValueType  # 0
PERSISTEDTASK_ATTRIBUTE_ALLOW_INTERACTIVE_EDITING: PersistedTaskBoolAttribute.ValueType  # 8909
PERSISTEDTASK_ATTRIBUTE_ALLOW_INTERACTIVE_DELETION: PersistedTaskBoolAttribute.ValueType  # 8910
global___PersistedTaskBoolAttribute = PersistedTaskBoolAttribute

class _PhysicalChannelUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_UINT32_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelUInt32Attribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_MFG_ID: _PhysicalChannelUInt32Attribute.ValueType  # 8666
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_MODEL_NUM: _PhysicalChannelUInt32Attribute.ValueType  # 8667
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_SERIAL_NUM: _PhysicalChannelUInt32Attribute.ValueType  # 8668
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_VERSION_NUM: _PhysicalChannelUInt32Attribute.ValueType  # 8669
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_PORT_WIDTH: _PhysicalChannelUInt32Attribute.ValueType  # 10660
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_PORT_WIDTH: _PhysicalChannelUInt32Attribute.ValueType  # 10663

class PhysicalChannelUInt32Attribute(_PhysicalChannelUInt32Attribute, metaclass=_PhysicalChannelUInt32AttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_UINT32_ATTRIBUTE_UNSPECIFIED: PhysicalChannelUInt32Attribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_MFG_ID: PhysicalChannelUInt32Attribute.ValueType  # 8666
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_MODEL_NUM: PhysicalChannelUInt32Attribute.ValueType  # 8667
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_SERIAL_NUM: PhysicalChannelUInt32Attribute.ValueType  # 8668
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_VERSION_NUM: PhysicalChannelUInt32Attribute.ValueType  # 8669
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_PORT_WIDTH: PhysicalChannelUInt32Attribute.ValueType  # 10660
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_PORT_WIDTH: PhysicalChannelUInt32Attribute.ValueType  # 10663
global___PhysicalChannelUInt32Attribute = PhysicalChannelUInt32Attribute

class _PhysicalChannelStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_STRING_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelStringAttribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_VERSION_LETTER: _PhysicalChannelStringAttribute.ValueType  # 8670
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_INPUT_SRCS: _PhysicalChannelStringAttribute.ValueType  # 12248

class PhysicalChannelStringAttribute(_PhysicalChannelStringAttribute, metaclass=_PhysicalChannelStringAttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_STRING_ATTRIBUTE_UNSPECIFIED: PhysicalChannelStringAttribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_VERSION_LETTER: PhysicalChannelStringAttribute.ValueType  # 8670
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_INPUT_SRCS: PhysicalChannelStringAttribute.ValueType  # 12248
global___PhysicalChannelStringAttribute = PhysicalChannelStringAttribute

class _PhysicalChannelBytesAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelBytesAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelBytesAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_BYTES_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelBytesAttribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_BIT_STREAM: _PhysicalChannelBytesAttribute.ValueType  # 8671

class PhysicalChannelBytesAttribute(_PhysicalChannelBytesAttribute, metaclass=_PhysicalChannelBytesAttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_BYTES_ATTRIBUTE_UNSPECIFIED: PhysicalChannelBytesAttribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_BIT_STREAM: PhysicalChannelBytesAttribute.ValueType  # 8671
global___PhysicalChannelBytesAttribute = PhysicalChannelBytesAttribute

class _PhysicalChannelUInt32ArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelUInt32ArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelUInt32ArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_UINT32_ARRAY_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelUInt32ArrayAttribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_TEMPLATE_I_DS: _PhysicalChannelUInt32ArrayAttribute.ValueType  # 8847

class PhysicalChannelUInt32ArrayAttribute(_PhysicalChannelUInt32ArrayAttribute, metaclass=_PhysicalChannelUInt32ArrayAttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_UINT32_ARRAY_ATTRIBUTE_UNSPECIFIED: PhysicalChannelUInt32ArrayAttribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_TEDS_TEMPLATE_I_DS: PhysicalChannelUInt32ArrayAttribute.ValueType  # 8847
global___PhysicalChannelUInt32ArrayAttribute = PhysicalChannelUInt32ArrayAttribute

class _PhysicalChannelInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_INT32_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelInt32Attribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_TERM_CFGS: _PhysicalChannelInt32Attribute.ValueType  # 9026
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_TERM_CFGS: _PhysicalChannelInt32Attribute.ValueType  # 10659
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_TYPE: _PhysicalChannelInt32Attribute.ValueType  # 12654

class PhysicalChannelInt32Attribute(_PhysicalChannelInt32Attribute, metaclass=_PhysicalChannelInt32AttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_INT32_ATTRIBUTE_UNSPECIFIED: PhysicalChannelInt32Attribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_TERM_CFGS: PhysicalChannelInt32Attribute.ValueType  # 9026
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_TERM_CFGS: PhysicalChannelInt32Attribute.ValueType  # 10659
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_TYPE: PhysicalChannelInt32Attribute.ValueType  # 12654
global___PhysicalChannelInt32Attribute = PhysicalChannelInt32Attribute

class _PhysicalChannelBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelBoolAttribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_SAMP_CLK_SUPPORTED: _PhysicalChannelBoolAttribute.ValueType  # 10661
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_CHANGE_DETECT_SUPPORTED: _PhysicalChannelBoolAttribute.ValueType  # 10662
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_SAMP_CLK_SUPPORTED: _PhysicalChannelBoolAttribute.ValueType  # 10664
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_ENABLE: _PhysicalChannelBoolAttribute.ValueType  # 10782
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_SHORT_DETECTED: _PhysicalChannelBoolAttribute.ValueType  # 11971
    PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_CHANNEL_ENABLE: _PhysicalChannelBoolAttribute.ValueType  # 12386
    PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_OVERCURRENT: _PhysicalChannelBoolAttribute.ValueType  # 12388
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_ENABLE: _PhysicalChannelBoolAttribute.ValueType  # 12653
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_OPEN_CHAN: _PhysicalChannelBoolAttribute.ValueType  # 12668
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_OVERCURRENT: _PhysicalChannelBoolAttribute.ValueType  # 12669

class PhysicalChannelBoolAttribute(_PhysicalChannelBoolAttribute, metaclass=_PhysicalChannelBoolAttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_BOOL_ATTRIBUTE_UNSPECIFIED: PhysicalChannelBoolAttribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_SAMP_CLK_SUPPORTED: PhysicalChannelBoolAttribute.ValueType  # 10661
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_CHANGE_DETECT_SUPPORTED: PhysicalChannelBoolAttribute.ValueType  # 10662
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_SAMP_CLK_SUPPORTED: PhysicalChannelBoolAttribute.ValueType  # 10664
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_ENABLE: PhysicalChannelBoolAttribute.ValueType  # 10782
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_SHORT_DETECTED: PhysicalChannelBoolAttribute.ValueType  # 11971
PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_CHANNEL_ENABLE: PhysicalChannelBoolAttribute.ValueType  # 12386
PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_OVERCURRENT: PhysicalChannelBoolAttribute.ValueType  # 12388
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_ENABLE: PhysicalChannelBoolAttribute.ValueType  # 12653
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_OPEN_CHAN: PhysicalChannelBoolAttribute.ValueType  # 12668
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_OVERCURRENT: PhysicalChannelBoolAttribute.ValueType  # 12669
global___PhysicalChannelBoolAttribute = PhysicalChannelBoolAttribute

class _PhysicalChannelResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_RESET_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelResetAttribute.ValueType  # 0
    PHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_ENABLE: _PhysicalChannelResetAttribute.ValueType  # 10782
    PHYSICALCHANNEL_RESET_ATTRIBUTE_AO_POWER_AMP_CHANNEL_ENABLE: _PhysicalChannelResetAttribute.ValueType  # 12386
    PHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_VOLTAGE: _PhysicalChannelResetAttribute.ValueType  # 12652
    PHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_ENABLE: _PhysicalChannelResetAttribute.ValueType  # 12653
    PHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_TYPE: _PhysicalChannelResetAttribute.ValueType  # 12654

class PhysicalChannelResetAttribute(_PhysicalChannelResetAttribute, metaclass=_PhysicalChannelResetAttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_RESET_ATTRIBUTE_UNSPECIFIED: PhysicalChannelResetAttribute.ValueType  # 0
PHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_ENABLE: PhysicalChannelResetAttribute.ValueType  # 10782
PHYSICALCHANNEL_RESET_ATTRIBUTE_AO_POWER_AMP_CHANNEL_ENABLE: PhysicalChannelResetAttribute.ValueType  # 12386
PHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_VOLTAGE: PhysicalChannelResetAttribute.ValueType  # 12652
PHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_ENABLE: PhysicalChannelResetAttribute.ValueType  # 12653
PHYSICALCHANNEL_RESET_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_TYPE: PhysicalChannelResetAttribute.ValueType  # 12654
global___PhysicalChannelResetAttribute = PhysicalChannelResetAttribute

class _PhysicalChannelDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_DOUBLE_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelDoubleAttribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_AMPLITUDE: _PhysicalChannelDoubleAttribute.ValueType  # 10783
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_FREQ: _PhysicalChannelDoubleAttribute.ValueType  # 10784
    PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_GAIN: _PhysicalChannelDoubleAttribute.ValueType  # 12389
    PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_OFFSET: _PhysicalChannelDoubleAttribute.ValueType  # 12390
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_VOLTAGE: _PhysicalChannelDoubleAttribute.ValueType  # 12652

class PhysicalChannelDoubleAttribute(_PhysicalChannelDoubleAttribute, metaclass=_PhysicalChannelDoubleAttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_DOUBLE_ATTRIBUTE_UNSPECIFIED: PhysicalChannelDoubleAttribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_AMPLITUDE: PhysicalChannelDoubleAttribute.ValueType  # 10783
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_MANUAL_CONTROL_FREQ: PhysicalChannelDoubleAttribute.ValueType  # 10784
PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_GAIN: PhysicalChannelDoubleAttribute.ValueType  # 12389
PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_OFFSET: PhysicalChannelDoubleAttribute.ValueType  # 12390
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_POWER_CONTROL_VOLTAGE: PhysicalChannelDoubleAttribute.ValueType  # 12652
global___PhysicalChannelDoubleAttribute = PhysicalChannelDoubleAttribute

class _PhysicalChannelInt32ArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelInt32ArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelInt32ArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelInt32ArrayAttribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SUPPORTED_MEAS_TYPES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12247
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_SUPPORTED_OUTPUT_TYPES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12249
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_CI_SUPPORTED_MEAS_TYPES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12250
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_CO_SUPPORTED_OUTPUT_TYPES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12251
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_SAMP_MODES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12256
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_SAMP_MODES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12257
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_NAV_SUPPORTED_MEAS_TYPES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12343
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_SUPPORTED_POWER_UP_OUTPUT_TYPES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12366
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_TYPES: _PhysicalChannelInt32ArrayAttribute.ValueType  # 12665

class PhysicalChannelInt32ArrayAttribute(_PhysicalChannelInt32ArrayAttribute, metaclass=_PhysicalChannelInt32ArrayAttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED: PhysicalChannelInt32ArrayAttribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SUPPORTED_MEAS_TYPES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12247
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_SUPPORTED_OUTPUT_TYPES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12249
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_CI_SUPPORTED_MEAS_TYPES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12250
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_CO_SUPPORTED_OUTPUT_TYPES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12251
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DI_SAMP_MODES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12256
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_DO_SAMP_MODES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12257
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_NAV_SUPPORTED_MEAS_TYPES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12343
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AO_SUPPORTED_POWER_UP_OUTPUT_TYPES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12366
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_TYPES: PhysicalChannelInt32ArrayAttribute.ValueType  # 12665
global___PhysicalChannelInt32ArrayAttribute = PhysicalChannelInt32ArrayAttribute

class _PhysicalChannelDoubleArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelDoubleArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelDoubleArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: _PhysicalChannelDoubleArrayAttribute.ValueType  # 0
    PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_SCALING_COEFF: _PhysicalChannelDoubleArrayAttribute.ValueType  # 12387
    PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_VOLTAGE_RANGE_VALS: _PhysicalChannelDoubleArrayAttribute.ValueType  # 12666

class PhysicalChannelDoubleArrayAttribute(_PhysicalChannelDoubleArrayAttribute, metaclass=_PhysicalChannelDoubleArrayAttributeEnumTypeWrapper): ...

PHYSICALCHANNEL_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: PhysicalChannelDoubleArrayAttribute.ValueType  # 0
PHYSICALCHANNEL_ATTRIBUTE_AO_POWER_AMP_SCALING_COEFF: PhysicalChannelDoubleArrayAttribute.ValueType  # 12387
PHYSICALCHANNEL_ATTRIBUTE_PHYSICAL_CHAN_AI_SENSOR_POWER_VOLTAGE_RANGE_VALS: PhysicalChannelDoubleArrayAttribute.ValueType  # 12666
global___PhysicalChannelDoubleArrayAttribute = PhysicalChannelDoubleArrayAttribute

class _ReadInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReadInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReadInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    READ_INT32_ATTRIBUTE_UNSPECIFIED: _ReadInt32Attribute.ValueType  # 0
    READ_ATTRIBUTE_OVERWRITE: _ReadInt32Attribute.ValueType  # 4625
    READ_ATTRIBUTE_RELATIVE_TO: _ReadInt32Attribute.ValueType  # 6410
    READ_ATTRIBUTE_OFFSET: _ReadInt32Attribute.ValueType  # 6411
    READ_ATTRIBUTE_WAIT_MODE: _ReadInt32Attribute.ValueType  # 8754
    READ_ATTRIBUTE_LOGGING_MODE: _ReadInt32Attribute.ValueType  # 11973
    READ_ATTRIBUTE_LOGGING_TDMS_OPERATION: _ReadInt32Attribute.ValueType  # 11975

class ReadInt32Attribute(_ReadInt32Attribute, metaclass=_ReadInt32AttributeEnumTypeWrapper): ...

READ_INT32_ATTRIBUTE_UNSPECIFIED: ReadInt32Attribute.ValueType  # 0
READ_ATTRIBUTE_OVERWRITE: ReadInt32Attribute.ValueType  # 4625
READ_ATTRIBUTE_RELATIVE_TO: ReadInt32Attribute.ValueType  # 6410
READ_ATTRIBUTE_OFFSET: ReadInt32Attribute.ValueType  # 6411
READ_ATTRIBUTE_WAIT_MODE: ReadInt32Attribute.ValueType  # 8754
READ_ATTRIBUTE_LOGGING_MODE: ReadInt32Attribute.ValueType  # 11973
READ_ATTRIBUTE_LOGGING_TDMS_OPERATION: ReadInt32Attribute.ValueType  # 11975
global___ReadInt32Attribute = ReadInt32Attribute

class _ReadResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReadResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReadResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    READ_RESET_ATTRIBUTE_UNSPECIFIED: _ReadResetAttribute.ValueType  # 0
    READ_RESET_ATTRIBUTE_OVERWRITE: _ReadResetAttribute.ValueType  # 4625
    READ_RESET_ATTRIBUTE_READ_ALL_AVAIL_SAMP: _ReadResetAttribute.ValueType  # 4629
    READ_RESET_ATTRIBUTE_CHANNELS_TO_READ: _ReadResetAttribute.ValueType  # 6179
    READ_RESET_ATTRIBUTE_AUTO_START: _ReadResetAttribute.ValueType  # 6182
    READ_RESET_ATTRIBUTE_RELATIVE_TO: _ReadResetAttribute.ValueType  # 6410
    READ_RESET_ATTRIBUTE_OFFSET: _ReadResetAttribute.ValueType  # 6411
    READ_RESET_ATTRIBUTE_WAIT_MODE: _ReadResetAttribute.ValueType  # 8754
    READ_RESET_ATTRIBUTE_SLEEP_TIME: _ReadResetAttribute.ValueType  # 8880
    READ_RESET_ATTRIBUTE_LOGGING_FILE_PATH: _ReadResetAttribute.ValueType  # 11972
    READ_RESET_ATTRIBUTE_LOGGING_MODE: _ReadResetAttribute.ValueType  # 11973
    READ_RESET_ATTRIBUTE_LOGGING_TDMS_GROUP_NAME: _ReadResetAttribute.ValueType  # 11974
    READ_RESET_ATTRIBUTE_LOGGING_TDMS_OPERATION: _ReadResetAttribute.ValueType  # 11975
    READ_RESET_ATTRIBUTE_LOGGING_FILE_WRITE_SIZE: _ReadResetAttribute.ValueType  # 12227
    READ_RESET_ATTRIBUTE_LOGGING_FILE_PREALLOCATION_SIZE: _ReadResetAttribute.ValueType  # 12230
    READ_RESET_ATTRIBUTE_LOGGING_PAUSE: _ReadResetAttribute.ValueType  # 12259
    READ_RESET_ATTRIBUTE_LOGGING_SAMPS_PER_FILE: _ReadResetAttribute.ValueType  # 12260

class ReadResetAttribute(_ReadResetAttribute, metaclass=_ReadResetAttributeEnumTypeWrapper): ...

READ_RESET_ATTRIBUTE_UNSPECIFIED: ReadResetAttribute.ValueType  # 0
READ_RESET_ATTRIBUTE_OVERWRITE: ReadResetAttribute.ValueType  # 4625
READ_RESET_ATTRIBUTE_READ_ALL_AVAIL_SAMP: ReadResetAttribute.ValueType  # 4629
READ_RESET_ATTRIBUTE_CHANNELS_TO_READ: ReadResetAttribute.ValueType  # 6179
READ_RESET_ATTRIBUTE_AUTO_START: ReadResetAttribute.ValueType  # 6182
READ_RESET_ATTRIBUTE_RELATIVE_TO: ReadResetAttribute.ValueType  # 6410
READ_RESET_ATTRIBUTE_OFFSET: ReadResetAttribute.ValueType  # 6411
READ_RESET_ATTRIBUTE_WAIT_MODE: ReadResetAttribute.ValueType  # 8754
READ_RESET_ATTRIBUTE_SLEEP_TIME: ReadResetAttribute.ValueType  # 8880
READ_RESET_ATTRIBUTE_LOGGING_FILE_PATH: ReadResetAttribute.ValueType  # 11972
READ_RESET_ATTRIBUTE_LOGGING_MODE: ReadResetAttribute.ValueType  # 11973
READ_RESET_ATTRIBUTE_LOGGING_TDMS_GROUP_NAME: ReadResetAttribute.ValueType  # 11974
READ_RESET_ATTRIBUTE_LOGGING_TDMS_OPERATION: ReadResetAttribute.ValueType  # 11975
READ_RESET_ATTRIBUTE_LOGGING_FILE_WRITE_SIZE: ReadResetAttribute.ValueType  # 12227
READ_RESET_ATTRIBUTE_LOGGING_FILE_PREALLOCATION_SIZE: ReadResetAttribute.ValueType  # 12230
READ_RESET_ATTRIBUTE_LOGGING_PAUSE: ReadResetAttribute.ValueType  # 12259
READ_RESET_ATTRIBUTE_LOGGING_SAMPS_PER_FILE: ReadResetAttribute.ValueType  # 12260
global___ReadResetAttribute = ReadResetAttribute

class _ReadBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReadBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReadBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    READ_BOOL_ATTRIBUTE_UNSPECIFIED: _ReadBoolAttribute.ValueType  # 0
    READ_ATTRIBUTE_READ_ALL_AVAIL_SAMP: _ReadBoolAttribute.ValueType  # 4629
    READ_ATTRIBUTE_AUTO_START: _ReadBoolAttribute.ValueType  # 6182
    READ_ATTRIBUTE_OVERLOADED_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 8564
    READ_ATTRIBUTE_CHANGE_DETECT_HAS_OVERFLOWED: _ReadBoolAttribute.ValueType  # 8596
    READ_ATTRIBUTE_OVERCURRENT_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 10726
    READ_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 10761
    READ_ATTRIBUTE_OPEN_THRMCPL_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 10902
    READ_ATTRIBUTE_COMMON_MODE_RANGE_ERROR_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 10904
    READ_ATTRIBUTE_ACCESSORY_INSERTION_OR_REMOVAL_DETECTED: _ReadBoolAttribute.ValueType  # 12144
    READ_ATTRIBUTE_LOGGING_PAUSE: _ReadBoolAttribute.ValueType  # 12259
    READ_ATTRIBUTE_NAV_FIX_LOST: _ReadBoolAttribute.ValueType  # 12341
    READ_ATTRIBUTE_OVERTEMPERATURE_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12417
    READ_ATTRIBUTE_EXCIT_FAULT_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12424
    READ_ATTRIBUTE_OPEN_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12544
    READ_ATTRIBUTE_PLL_UNLOCKED_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12568
    READ_ATTRIBUTE_SYNC_UNLOCKED_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12605
    READ_ATTRIBUTE_INPUT_LIMITS_FAULT_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12687
    READ_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12690
    READ_ATTRIBUTE_REMOTE_SENSE_ERROR_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12765
    READ_ATTRIBUTE_AUX_POWER_ERROR_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12767
    READ_ATTRIBUTE_REVERSE_VOLTAGE_ERROR_CHANS_EXIST: _ReadBoolAttribute.ValueType  # 12774

class ReadBoolAttribute(_ReadBoolAttribute, metaclass=_ReadBoolAttributeEnumTypeWrapper): ...

READ_BOOL_ATTRIBUTE_UNSPECIFIED: ReadBoolAttribute.ValueType  # 0
READ_ATTRIBUTE_READ_ALL_AVAIL_SAMP: ReadBoolAttribute.ValueType  # 4629
READ_ATTRIBUTE_AUTO_START: ReadBoolAttribute.ValueType  # 6182
READ_ATTRIBUTE_OVERLOADED_CHANS_EXIST: ReadBoolAttribute.ValueType  # 8564
READ_ATTRIBUTE_CHANGE_DETECT_HAS_OVERFLOWED: ReadBoolAttribute.ValueType  # 8596
READ_ATTRIBUTE_OVERCURRENT_CHANS_EXIST: ReadBoolAttribute.ValueType  # 10726
READ_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS_EXIST: ReadBoolAttribute.ValueType  # 10761
READ_ATTRIBUTE_OPEN_THRMCPL_CHANS_EXIST: ReadBoolAttribute.ValueType  # 10902
READ_ATTRIBUTE_COMMON_MODE_RANGE_ERROR_CHANS_EXIST: ReadBoolAttribute.ValueType  # 10904
READ_ATTRIBUTE_ACCESSORY_INSERTION_OR_REMOVAL_DETECTED: ReadBoolAttribute.ValueType  # 12144
READ_ATTRIBUTE_LOGGING_PAUSE: ReadBoolAttribute.ValueType  # 12259
READ_ATTRIBUTE_NAV_FIX_LOST: ReadBoolAttribute.ValueType  # 12341
READ_ATTRIBUTE_OVERTEMPERATURE_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12417
READ_ATTRIBUTE_EXCIT_FAULT_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12424
READ_ATTRIBUTE_OPEN_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12544
READ_ATTRIBUTE_PLL_UNLOCKED_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12568
READ_ATTRIBUTE_SYNC_UNLOCKED_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12605
READ_ATTRIBUTE_INPUT_LIMITS_FAULT_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12687
READ_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12690
READ_ATTRIBUTE_REMOTE_SENSE_ERROR_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12765
READ_ATTRIBUTE_AUX_POWER_ERROR_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12767
READ_ATTRIBUTE_REVERSE_VOLTAGE_ERROR_CHANS_EXIST: ReadBoolAttribute.ValueType  # 12774
global___ReadBoolAttribute = ReadBoolAttribute

class _ReadUInt64Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReadUInt64AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReadUInt64Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    READ_UINT64_ATTRIBUTE_UNSPECIFIED: _ReadUInt64Attribute.ValueType  # 0
    READ_ATTRIBUTE_CURR_READ_POS: _ReadUInt64Attribute.ValueType  # 4641
    READ_ATTRIBUTE_TOTAL_SAMP_PER_CHAN_ACQUIRED: _ReadUInt64Attribute.ValueType  # 6442
    READ_ATTRIBUTE_LOGGING_FILE_PREALLOCATION_SIZE: _ReadUInt64Attribute.ValueType  # 12230
    READ_ATTRIBUTE_LOGGING_SAMPS_PER_FILE: _ReadUInt64Attribute.ValueType  # 12260

class ReadUInt64Attribute(_ReadUInt64Attribute, metaclass=_ReadUInt64AttributeEnumTypeWrapper): ...

READ_UINT64_ATTRIBUTE_UNSPECIFIED: ReadUInt64Attribute.ValueType  # 0
READ_ATTRIBUTE_CURR_READ_POS: ReadUInt64Attribute.ValueType  # 4641
READ_ATTRIBUTE_TOTAL_SAMP_PER_CHAN_ACQUIRED: ReadUInt64Attribute.ValueType  # 6442
READ_ATTRIBUTE_LOGGING_FILE_PREALLOCATION_SIZE: ReadUInt64Attribute.ValueType  # 12230
READ_ATTRIBUTE_LOGGING_SAMPS_PER_FILE: ReadUInt64Attribute.ValueType  # 12260
global___ReadUInt64Attribute = ReadUInt64Attribute

class _ReadUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReadUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReadUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    READ_UINT32_ATTRIBUTE_UNSPECIFIED: _ReadUInt32Attribute.ValueType  # 0
    READ_ATTRIBUTE_AVAIL_SAMP_PER_CHAN: _ReadUInt32Attribute.ValueType  # 4643
    READ_ATTRIBUTE_RAW_DATA_WIDTH: _ReadUInt32Attribute.ValueType  # 8570
    READ_ATTRIBUTE_NUM_CHANS: _ReadUInt32Attribute.ValueType  # 8571
    READ_ATTRIBUTE_DIGITAL_LINES_BYTES_PER_CHAN: _ReadUInt32Attribute.ValueType  # 8572
    READ_ATTRIBUTE_LOGGING_FILE_WRITE_SIZE: _ReadUInt32Attribute.ValueType  # 12227

class ReadUInt32Attribute(_ReadUInt32Attribute, metaclass=_ReadUInt32AttributeEnumTypeWrapper): ...

READ_UINT32_ATTRIBUTE_UNSPECIFIED: ReadUInt32Attribute.ValueType  # 0
READ_ATTRIBUTE_AVAIL_SAMP_PER_CHAN: ReadUInt32Attribute.ValueType  # 4643
READ_ATTRIBUTE_RAW_DATA_WIDTH: ReadUInt32Attribute.ValueType  # 8570
READ_ATTRIBUTE_NUM_CHANS: ReadUInt32Attribute.ValueType  # 8571
READ_ATTRIBUTE_DIGITAL_LINES_BYTES_PER_CHAN: ReadUInt32Attribute.ValueType  # 8572
READ_ATTRIBUTE_LOGGING_FILE_WRITE_SIZE: ReadUInt32Attribute.ValueType  # 12227
global___ReadUInt32Attribute = ReadUInt32Attribute

class _ReadStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReadStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReadStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    READ_STRING_ATTRIBUTE_UNSPECIFIED: _ReadStringAttribute.ValueType  # 0
    READ_ATTRIBUTE_CHANNELS_TO_READ: _ReadStringAttribute.ValueType  # 6179
    READ_ATTRIBUTE_OVERLOADED_CHANS: _ReadStringAttribute.ValueType  # 8565
    READ_ATTRIBUTE_OVERCURRENT_CHANS: _ReadStringAttribute.ValueType  # 10727
    READ_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS: _ReadStringAttribute.ValueType  # 10762
    READ_ATTRIBUTE_OPEN_THRMCPL_CHANS: _ReadStringAttribute.ValueType  # 10903
    READ_ATTRIBUTE_COMMON_MODE_RANGE_ERROR_CHANS: _ReadStringAttribute.ValueType  # 10905
    READ_ATTRIBUTE_LOGGING_FILE_PATH: _ReadStringAttribute.ValueType  # 11972
    READ_ATTRIBUTE_LOGGING_TDMS_GROUP_NAME: _ReadStringAttribute.ValueType  # 11974
    READ_ATTRIBUTE_DEVS_WITH_INSERTED_OR_REMOVED_ACCESSORIES: _ReadStringAttribute.ValueType  # 12145
    READ_ATTRIBUTE_OVERTEMPERATURE_CHANS: _ReadStringAttribute.ValueType  # 12418
    READ_ATTRIBUTE_EXCIT_FAULT_CHANS: _ReadStringAttribute.ValueType  # 12425
    READ_ATTRIBUTE_OPEN_CHANS: _ReadStringAttribute.ValueType  # 12545
    READ_ATTRIBUTE_OPEN_CHANS_DETAILS: _ReadStringAttribute.ValueType  # 12546
    READ_ATTRIBUTE_PLL_UNLOCKED_CHANS: _ReadStringAttribute.ValueType  # 12569
    READ_ATTRIBUTE_SYNC_UNLOCKED_CHANS: _ReadStringAttribute.ValueType  # 12606
    READ_ATTRIBUTE_INPUT_LIMITS_FAULT_CHANS: _ReadStringAttribute.ValueType  # 12688
    READ_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS: _ReadStringAttribute.ValueType  # 12691
    READ_ATTRIBUTE_REMOTE_SENSE_ERROR_CHANS: _ReadStringAttribute.ValueType  # 12766
    READ_ATTRIBUTE_AUX_POWER_ERROR_CHANS: _ReadStringAttribute.ValueType  # 12768
    READ_ATTRIBUTE_REVERSE_VOLTAGE_ERROR_CHANS: _ReadStringAttribute.ValueType  # 12775

class ReadStringAttribute(_ReadStringAttribute, metaclass=_ReadStringAttributeEnumTypeWrapper): ...

READ_STRING_ATTRIBUTE_UNSPECIFIED: ReadStringAttribute.ValueType  # 0
READ_ATTRIBUTE_CHANNELS_TO_READ: ReadStringAttribute.ValueType  # 6179
READ_ATTRIBUTE_OVERLOADED_CHANS: ReadStringAttribute.ValueType  # 8565
READ_ATTRIBUTE_OVERCURRENT_CHANS: ReadStringAttribute.ValueType  # 10727
READ_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS: ReadStringAttribute.ValueType  # 10762
READ_ATTRIBUTE_OPEN_THRMCPL_CHANS: ReadStringAttribute.ValueType  # 10903
READ_ATTRIBUTE_COMMON_MODE_RANGE_ERROR_CHANS: ReadStringAttribute.ValueType  # 10905
READ_ATTRIBUTE_LOGGING_FILE_PATH: ReadStringAttribute.ValueType  # 11972
READ_ATTRIBUTE_LOGGING_TDMS_GROUP_NAME: ReadStringAttribute.ValueType  # 11974
READ_ATTRIBUTE_DEVS_WITH_INSERTED_OR_REMOVED_ACCESSORIES: ReadStringAttribute.ValueType  # 12145
READ_ATTRIBUTE_OVERTEMPERATURE_CHANS: ReadStringAttribute.ValueType  # 12418
READ_ATTRIBUTE_EXCIT_FAULT_CHANS: ReadStringAttribute.ValueType  # 12425
READ_ATTRIBUTE_OPEN_CHANS: ReadStringAttribute.ValueType  # 12545
READ_ATTRIBUTE_OPEN_CHANS_DETAILS: ReadStringAttribute.ValueType  # 12546
READ_ATTRIBUTE_PLL_UNLOCKED_CHANS: ReadStringAttribute.ValueType  # 12569
READ_ATTRIBUTE_SYNC_UNLOCKED_CHANS: ReadStringAttribute.ValueType  # 12606
READ_ATTRIBUTE_INPUT_LIMITS_FAULT_CHANS: ReadStringAttribute.ValueType  # 12688
READ_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS: ReadStringAttribute.ValueType  # 12691
READ_ATTRIBUTE_REMOTE_SENSE_ERROR_CHANS: ReadStringAttribute.ValueType  # 12766
READ_ATTRIBUTE_AUX_POWER_ERROR_CHANS: ReadStringAttribute.ValueType  # 12768
READ_ATTRIBUTE_REVERSE_VOLTAGE_ERROR_CHANS: ReadStringAttribute.ValueType  # 12775
global___ReadStringAttribute = ReadStringAttribute

class _ReadDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReadDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReadDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    READ_DOUBLE_ATTRIBUTE_UNSPECIFIED: _ReadDoubleAttribute.ValueType  # 0
    READ_ATTRIBUTE_SLEEP_TIME: _ReadDoubleAttribute.ValueType  # 8880

class ReadDoubleAttribute(_ReadDoubleAttribute, metaclass=_ReadDoubleAttributeEnumTypeWrapper): ...

READ_DOUBLE_ATTRIBUTE_UNSPECIFIED: ReadDoubleAttribute.ValueType  # 0
READ_ATTRIBUTE_SLEEP_TIME: ReadDoubleAttribute.ValueType  # 8880
global___ReadDoubleAttribute = ReadDoubleAttribute

class _RealTimeUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RealTimeUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RealTimeUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REALTIME_UINT32_ATTRIBUTE_UNSPECIFIED: _RealTimeUInt32Attribute.ValueType  # 0
    REALTIME_ATTRIBUTE_NUM_OF_WARMUP_ITERS: _RealTimeUInt32Attribute.ValueType  # 8941

class RealTimeUInt32Attribute(_RealTimeUInt32Attribute, metaclass=_RealTimeUInt32AttributeEnumTypeWrapper): ...

REALTIME_UINT32_ATTRIBUTE_UNSPECIFIED: RealTimeUInt32Attribute.ValueType  # 0
REALTIME_ATTRIBUTE_NUM_OF_WARMUP_ITERS: RealTimeUInt32Attribute.ValueType  # 8941
global___RealTimeUInt32Attribute = RealTimeUInt32Attribute

class _RealTimeResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RealTimeResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RealTimeResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REALTIME_RESET_ATTRIBUTE_UNSPECIFIED: _RealTimeResetAttribute.ValueType  # 0
    REALTIME_RESET_ATTRIBUTE_NUM_OF_WARMUP_ITERS: _RealTimeResetAttribute.ValueType  # 8941
    REALTIME_RESET_ATTRIBUTE_CONV_LATE_ERRORS_TO_WARNINGS: _RealTimeResetAttribute.ValueType  # 8942
    REALTIME_RESET_ATTRIBUTE_WAIT_FOR_NEXT_SAMP_CLK_WAIT_MODE: _RealTimeResetAttribute.ValueType  # 8943
    REALTIME_RESET_ATTRIBUTE_REPORT_MISSED_SAMP: _RealTimeResetAttribute.ValueType  # 8985
    REALTIME_RESET_ATTRIBUTE_WRITE_RECOVERY_MODE: _RealTimeResetAttribute.ValueType  # 8986

class RealTimeResetAttribute(_RealTimeResetAttribute, metaclass=_RealTimeResetAttributeEnumTypeWrapper): ...

REALTIME_RESET_ATTRIBUTE_UNSPECIFIED: RealTimeResetAttribute.ValueType  # 0
REALTIME_RESET_ATTRIBUTE_NUM_OF_WARMUP_ITERS: RealTimeResetAttribute.ValueType  # 8941
REALTIME_RESET_ATTRIBUTE_CONV_LATE_ERRORS_TO_WARNINGS: RealTimeResetAttribute.ValueType  # 8942
REALTIME_RESET_ATTRIBUTE_WAIT_FOR_NEXT_SAMP_CLK_WAIT_MODE: RealTimeResetAttribute.ValueType  # 8943
REALTIME_RESET_ATTRIBUTE_REPORT_MISSED_SAMP: RealTimeResetAttribute.ValueType  # 8985
REALTIME_RESET_ATTRIBUTE_WRITE_RECOVERY_MODE: RealTimeResetAttribute.ValueType  # 8986
global___RealTimeResetAttribute = RealTimeResetAttribute

class _RealTimeBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RealTimeBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RealTimeBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REALTIME_BOOL_ATTRIBUTE_UNSPECIFIED: _RealTimeBoolAttribute.ValueType  # 0
    REALTIME_ATTRIBUTE_CONV_LATE_ERRORS_TO_WARNINGS: _RealTimeBoolAttribute.ValueType  # 8942
    REALTIME_ATTRIBUTE_REPORT_MISSED_SAMP: _RealTimeBoolAttribute.ValueType  # 8985

class RealTimeBoolAttribute(_RealTimeBoolAttribute, metaclass=_RealTimeBoolAttributeEnumTypeWrapper): ...

REALTIME_BOOL_ATTRIBUTE_UNSPECIFIED: RealTimeBoolAttribute.ValueType  # 0
REALTIME_ATTRIBUTE_CONV_LATE_ERRORS_TO_WARNINGS: RealTimeBoolAttribute.ValueType  # 8942
REALTIME_ATTRIBUTE_REPORT_MISSED_SAMP: RealTimeBoolAttribute.ValueType  # 8985
global___RealTimeBoolAttribute = RealTimeBoolAttribute

class _RealTimeInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RealTimeInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RealTimeInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REALTIME_INT32_ATTRIBUTE_UNSPECIFIED: _RealTimeInt32Attribute.ValueType  # 0
    REALTIME_ATTRIBUTE_WAIT_FOR_NEXT_SAMP_CLK_WAIT_MODE: _RealTimeInt32Attribute.ValueType  # 8943
    REALTIME_ATTRIBUTE_WRITE_RECOVERY_MODE: _RealTimeInt32Attribute.ValueType  # 8986

class RealTimeInt32Attribute(_RealTimeInt32Attribute, metaclass=_RealTimeInt32AttributeEnumTypeWrapper): ...

REALTIME_INT32_ATTRIBUTE_UNSPECIFIED: RealTimeInt32Attribute.ValueType  # 0
REALTIME_ATTRIBUTE_WAIT_FOR_NEXT_SAMP_CLK_WAIT_MODE: RealTimeInt32Attribute.ValueType  # 8943
REALTIME_ATTRIBUTE_WRITE_RECOVERY_MODE: RealTimeInt32Attribute.ValueType  # 8986
global___RealTimeInt32Attribute = RealTimeInt32Attribute

class _ScaleStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ScaleStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ScaleStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SCALE_STRING_ATTRIBUTE_UNSPECIFIED: _ScaleStringAttribute.ValueType  # 0
    SCALE_ATTRIBUTE_DESCR: _ScaleStringAttribute.ValueType  # 4646
    SCALE_ATTRIBUTE_SCALED_UNITS: _ScaleStringAttribute.ValueType  # 6427

class ScaleStringAttribute(_ScaleStringAttribute, metaclass=_ScaleStringAttributeEnumTypeWrapper): ...

SCALE_STRING_ATTRIBUTE_UNSPECIFIED: ScaleStringAttribute.ValueType  # 0
SCALE_ATTRIBUTE_DESCR: ScaleStringAttribute.ValueType  # 4646
SCALE_ATTRIBUTE_SCALED_UNITS: ScaleStringAttribute.ValueType  # 6427
global___ScaleStringAttribute = ScaleStringAttribute

class _ScaleDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ScaleDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ScaleDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SCALE_DOUBLE_ATTRIBUTE_UNSPECIFIED: _ScaleDoubleAttribute.ValueType  # 0
    SCALE_ATTRIBUTE_LIN_SLOPE: _ScaleDoubleAttribute.ValueType  # 4647
    SCALE_ATTRIBUTE_LIN_Y_INTERCEPT: _ScaleDoubleAttribute.ValueType  # 4648
    SCALE_ATTRIBUTE_MAP_SCALED_MAX: _ScaleDoubleAttribute.ValueType  # 4649
    SCALE_ATTRIBUTE_MAP_SCALED_MIN: _ScaleDoubleAttribute.ValueType  # 4656
    SCALE_ATTRIBUTE_MAP_PRE_SCALED_MAX: _ScaleDoubleAttribute.ValueType  # 4657
    SCALE_ATTRIBUTE_MAP_PRE_SCALED_MIN: _ScaleDoubleAttribute.ValueType  # 4658

class ScaleDoubleAttribute(_ScaleDoubleAttribute, metaclass=_ScaleDoubleAttributeEnumTypeWrapper): ...

SCALE_DOUBLE_ATTRIBUTE_UNSPECIFIED: ScaleDoubleAttribute.ValueType  # 0
SCALE_ATTRIBUTE_LIN_SLOPE: ScaleDoubleAttribute.ValueType  # 4647
SCALE_ATTRIBUTE_LIN_Y_INTERCEPT: ScaleDoubleAttribute.ValueType  # 4648
SCALE_ATTRIBUTE_MAP_SCALED_MAX: ScaleDoubleAttribute.ValueType  # 4649
SCALE_ATTRIBUTE_MAP_SCALED_MIN: ScaleDoubleAttribute.ValueType  # 4656
SCALE_ATTRIBUTE_MAP_PRE_SCALED_MAX: ScaleDoubleAttribute.ValueType  # 4657
SCALE_ATTRIBUTE_MAP_PRE_SCALED_MIN: ScaleDoubleAttribute.ValueType  # 4658
global___ScaleDoubleAttribute = ScaleDoubleAttribute

class _ScaleDoubleArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ScaleDoubleArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ScaleDoubleArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SCALE_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: _ScaleDoubleArrayAttribute.ValueType  # 0
    SCALE_ATTRIBUTE_POLY_FORWARD_COEFF: _ScaleDoubleArrayAttribute.ValueType  # 4660
    SCALE_ATTRIBUTE_POLY_REVERSE_COEFF: _ScaleDoubleArrayAttribute.ValueType  # 4661
    SCALE_ATTRIBUTE_TABLE_SCALED_VALS: _ScaleDoubleArrayAttribute.ValueType  # 4662
    SCALE_ATTRIBUTE_TABLE_PRE_SCALED_VALS: _ScaleDoubleArrayAttribute.ValueType  # 4663

class ScaleDoubleArrayAttribute(_ScaleDoubleArrayAttribute, metaclass=_ScaleDoubleArrayAttributeEnumTypeWrapper): ...

SCALE_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: ScaleDoubleArrayAttribute.ValueType  # 0
SCALE_ATTRIBUTE_POLY_FORWARD_COEFF: ScaleDoubleArrayAttribute.ValueType  # 4660
SCALE_ATTRIBUTE_POLY_REVERSE_COEFF: ScaleDoubleArrayAttribute.ValueType  # 4661
SCALE_ATTRIBUTE_TABLE_SCALED_VALS: ScaleDoubleArrayAttribute.ValueType  # 4662
SCALE_ATTRIBUTE_TABLE_PRE_SCALED_VALS: ScaleDoubleArrayAttribute.ValueType  # 4663
global___ScaleDoubleArrayAttribute = ScaleDoubleArrayAttribute

class _ScaleInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ScaleInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ScaleInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SCALE_INT32_ATTRIBUTE_UNSPECIFIED: _ScaleInt32Attribute.ValueType  # 0
    SCALE_ATTRIBUTE_PRE_SCALED_UNITS: _ScaleInt32Attribute.ValueType  # 6391
    SCALE_ATTRIBUTE_TYPE: _ScaleInt32Attribute.ValueType  # 6441

class ScaleInt32Attribute(_ScaleInt32Attribute, metaclass=_ScaleInt32AttributeEnumTypeWrapper): ...

SCALE_INT32_ATTRIBUTE_UNSPECIFIED: ScaleInt32Attribute.ValueType  # 0
SCALE_ATTRIBUTE_PRE_SCALED_UNITS: ScaleInt32Attribute.ValueType  # 6391
SCALE_ATTRIBUTE_TYPE: ScaleInt32Attribute.ValueType  # 6441
global___ScaleInt32Attribute = ScaleInt32Attribute

class _SystemStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SystemStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SystemStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SYSTEM_STRING_ATTRIBUTE_UNSPECIFIED: _SystemStringAttribute.ValueType  # 0
    SYSTEM_ATTRIBUTE_GLOBAL_CHANS: _SystemStringAttribute.ValueType  # 4709
    SYSTEM_ATTRIBUTE_SCALES: _SystemStringAttribute.ValueType  # 4710
    SYSTEM_ATTRIBUTE_TASKS: _SystemStringAttribute.ValueType  # 4711
    SYSTEM_ATTRIBUTE_DEV_NAMES: _SystemStringAttribute.ValueType  # 6459

class SystemStringAttribute(_SystemStringAttribute, metaclass=_SystemStringAttributeEnumTypeWrapper): ...

SYSTEM_STRING_ATTRIBUTE_UNSPECIFIED: SystemStringAttribute.ValueType  # 0
SYSTEM_ATTRIBUTE_GLOBAL_CHANS: SystemStringAttribute.ValueType  # 4709
SYSTEM_ATTRIBUTE_SCALES: SystemStringAttribute.ValueType  # 4710
SYSTEM_ATTRIBUTE_TASKS: SystemStringAttribute.ValueType  # 4711
SYSTEM_ATTRIBUTE_DEV_NAMES: SystemStringAttribute.ValueType  # 6459
global___SystemStringAttribute = SystemStringAttribute

class _SystemUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SystemUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SystemUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SYSTEM_UINT32_ATTRIBUTE_UNSPECIFIED: _SystemUInt32Attribute.ValueType  # 0
    SYSTEM_ATTRIBUTE_NIDAQ_MAJOR_VERSION: _SystemUInt32Attribute.ValueType  # 4722
    SYSTEM_ATTRIBUTE_NIDAQ_MINOR_VERSION: _SystemUInt32Attribute.ValueType  # 6435
    SYSTEM_ATTRIBUTE_NIDAQ_UPDATE_VERSION: _SystemUInt32Attribute.ValueType  # 12066

class SystemUInt32Attribute(_SystemUInt32Attribute, metaclass=_SystemUInt32AttributeEnumTypeWrapper): ...

SYSTEM_UINT32_ATTRIBUTE_UNSPECIFIED: SystemUInt32Attribute.ValueType  # 0
SYSTEM_ATTRIBUTE_NIDAQ_MAJOR_VERSION: SystemUInt32Attribute.ValueType  # 4722
SYSTEM_ATTRIBUTE_NIDAQ_MINOR_VERSION: SystemUInt32Attribute.ValueType  # 6435
SYSTEM_ATTRIBUTE_NIDAQ_UPDATE_VERSION: SystemUInt32Attribute.ValueType  # 12066
global___SystemUInt32Attribute = SystemUInt32Attribute

class _TaskStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TaskStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TASK_STRING_ATTRIBUTE_UNSPECIFIED: _TaskStringAttribute.ValueType  # 0
    TASK_ATTRIBUTE_CHANNELS: _TaskStringAttribute.ValueType  # 4723
    TASK_ATTRIBUTE_NAME: _TaskStringAttribute.ValueType  # 4726
    TASK_ATTRIBUTE_DEVICES: _TaskStringAttribute.ValueType  # 8974

class TaskStringAttribute(_TaskStringAttribute, metaclass=_TaskStringAttributeEnumTypeWrapper): ...

TASK_STRING_ATTRIBUTE_UNSPECIFIED: TaskStringAttribute.ValueType  # 0
TASK_ATTRIBUTE_CHANNELS: TaskStringAttribute.ValueType  # 4723
TASK_ATTRIBUTE_NAME: TaskStringAttribute.ValueType  # 4726
TASK_ATTRIBUTE_DEVICES: TaskStringAttribute.ValueType  # 8974
global___TaskStringAttribute = TaskStringAttribute

class _TaskBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TaskBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TASK_BOOL_ATTRIBUTE_UNSPECIFIED: _TaskBoolAttribute.ValueType  # 0
    TASK_ATTRIBUTE_COMPLETE: _TaskBoolAttribute.ValueType  # 4724

class TaskBoolAttribute(_TaskBoolAttribute, metaclass=_TaskBoolAttributeEnumTypeWrapper): ...

TASK_BOOL_ATTRIBUTE_UNSPECIFIED: TaskBoolAttribute.ValueType  # 0
TASK_ATTRIBUTE_COMPLETE: TaskBoolAttribute.ValueType  # 4724
global___TaskBoolAttribute = TaskBoolAttribute

class _TaskUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TaskUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TASK_UINT32_ATTRIBUTE_UNSPECIFIED: _TaskUInt32Attribute.ValueType  # 0
    TASK_ATTRIBUTE_NUM_CHANS: _TaskUInt32Attribute.ValueType  # 8577
    TASK_ATTRIBUTE_NUM_DEVICES: _TaskUInt32Attribute.ValueType  # 10682

class TaskUInt32Attribute(_TaskUInt32Attribute, metaclass=_TaskUInt32AttributeEnumTypeWrapper): ...

TASK_UINT32_ATTRIBUTE_UNSPECIFIED: TaskUInt32Attribute.ValueType  # 0
TASK_ATTRIBUTE_NUM_CHANS: TaskUInt32Attribute.ValueType  # 8577
TASK_ATTRIBUTE_NUM_DEVICES: TaskUInt32Attribute.ValueType  # 10682
global___TaskUInt32Attribute = TaskUInt32Attribute

class _TimingInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_INT32_ATTRIBUTE_UNSPECIFIED: _TimingInt32Attribute.ValueType  # 0
    TIMING_ATTRIBUTE_SAMP_QUANT_SAMP_MODE: _TimingInt32Attribute.ValueType  # 4864
    TIMING_ATTRIBUTE_SAMP_CLK_ACTIVE_EDGE: _TimingInt32Attribute.ValueType  # 4865
    TIMING_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY_UNITS: _TimingInt32Attribute.ValueType  # 4868
    TIMING_ATTRIBUTE_AI_CONV_TIMEBASE_SRC: _TimingInt32Attribute.ValueType  # 4921
    TIMING_ATTRIBUTE_SAMP_TIMING_TYPE: _TimingInt32Attribute.ValueType  # 4935
    TIMING_ATTRIBUTE_AI_CONV_ACTIVE_EDGE: _TimingInt32Attribute.ValueType  # 6227
    TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_ACTIVE_EDGE: _TimingInt32Attribute.ValueType  # 6380
    TIMING_ATTRIBUTE_HSHK_START_COND: _TimingInt32Attribute.ValueType  # 8899
    TIMING_ATTRIBUTE_HSHK_SAMPLE_INPUT_DATA_WHEN: _TimingInt32Attribute.ValueType  # 8900
    TIMING_ATTRIBUTE_SAMP_CLK_UNDERFLOW_BEHAVIOR: _TimingInt32Attribute.ValueType  # 10593
    TIMING_ATTRIBUTE_SAMP_CLK_OVERRUN_BEHAVIOR: _TimingInt32Attribute.ValueType  # 12028
    TIMING_ATTRIBUTE_IMPLICIT_UNDERFLOW_BEHAVIOR: _TimingInt32Attribute.ValueType  # 12029
    TIMING_ATTRIBUTE_SYNC_PULSE_TYPE: _TimingInt32Attribute.ValueType  # 12598
    TIMING_ATTRIBUTE_SYNC_PULSE_TIME_TIMESCALE: _TimingInt32Attribute.ValueType  # 12600
    TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_TIMESCALE: _TimingInt32Attribute.ValueType  # 12603
    TIMING_ATTRIBUTE_FIRST_SAMP_CLK_TIMESCALE: _TimingInt32Attribute.ValueType  # 12675

class TimingInt32Attribute(_TimingInt32Attribute, metaclass=_TimingInt32AttributeEnumTypeWrapper): ...

TIMING_INT32_ATTRIBUTE_UNSPECIFIED: TimingInt32Attribute.ValueType  # 0
TIMING_ATTRIBUTE_SAMP_QUANT_SAMP_MODE: TimingInt32Attribute.ValueType  # 4864
TIMING_ATTRIBUTE_SAMP_CLK_ACTIVE_EDGE: TimingInt32Attribute.ValueType  # 4865
TIMING_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY_UNITS: TimingInt32Attribute.ValueType  # 4868
TIMING_ATTRIBUTE_AI_CONV_TIMEBASE_SRC: TimingInt32Attribute.ValueType  # 4921
TIMING_ATTRIBUTE_SAMP_TIMING_TYPE: TimingInt32Attribute.ValueType  # 4935
TIMING_ATTRIBUTE_AI_CONV_ACTIVE_EDGE: TimingInt32Attribute.ValueType  # 6227
TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_ACTIVE_EDGE: TimingInt32Attribute.ValueType  # 6380
TIMING_ATTRIBUTE_HSHK_START_COND: TimingInt32Attribute.ValueType  # 8899
TIMING_ATTRIBUTE_HSHK_SAMPLE_INPUT_DATA_WHEN: TimingInt32Attribute.ValueType  # 8900
TIMING_ATTRIBUTE_SAMP_CLK_UNDERFLOW_BEHAVIOR: TimingInt32Attribute.ValueType  # 10593
TIMING_ATTRIBUTE_SAMP_CLK_OVERRUN_BEHAVIOR: TimingInt32Attribute.ValueType  # 12028
TIMING_ATTRIBUTE_IMPLICIT_UNDERFLOW_BEHAVIOR: TimingInt32Attribute.ValueType  # 12029
TIMING_ATTRIBUTE_SYNC_PULSE_TYPE: TimingInt32Attribute.ValueType  # 12598
TIMING_ATTRIBUTE_SYNC_PULSE_TIME_TIMESCALE: TimingInt32Attribute.ValueType  # 12600
TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_TIMESCALE: TimingInt32Attribute.ValueType  # 12603
TIMING_ATTRIBUTE_FIRST_SAMP_CLK_TIMESCALE: TimingInt32Attribute.ValueType  # 12675
global___TimingInt32Attribute = TimingInt32Attribute

class _TimingResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_RESET_ATTRIBUTE_UNSPECIFIED: _TimingResetAttribute.ValueType  # 0
    TIMING_RESET_ATTRIBUTE_SAMP_QUANT_SAMP_MODE: _TimingResetAttribute.ValueType  # 4864
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_ACTIVE_EDGE: _TimingResetAttribute.ValueType  # 4865
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_RATE: _TimingResetAttribute.ValueType  # 4867
    TIMING_RESET_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY_UNITS: _TimingResetAttribute.ValueType  # 4868
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_MASTER_TIMEBASE_DIV: _TimingResetAttribute.ValueType  # 4869
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_SRC: _TimingResetAttribute.ValueType  # 4872
    TIMING_RESET_ATTRIBUTE_SAMP_QUANT_SAMP_PER_CHAN: _TimingResetAttribute.ValueType  # 4880
    TIMING_RESET_ATTRIBUTE_REF_CLK_RATE: _TimingResetAttribute.ValueType  # 4885
    TIMING_RESET_ATTRIBUTE_REF_CLK_SRC: _TimingResetAttribute.ValueType  # 4886
    TIMING_RESET_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY: _TimingResetAttribute.ValueType  # 4887
    TIMING_RESET_ATTRIBUTE_AI_CONV_TIMEBASE_DIV: _TimingResetAttribute.ValueType  # 4917
    TIMING_RESET_ATTRIBUTE_AI_CONV_TIMEBASE_SRC: _TimingResetAttribute.ValueType  # 4921
    TIMING_RESET_ATTRIBUTE_MASTER_TIMEBASE_SRC: _TimingResetAttribute.ValueType  # 4931
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_RATE: _TimingResetAttribute.ValueType  # 4932
    TIMING_RESET_ATTRIBUTE_SAMP_TIMING_TYPE: _TimingResetAttribute.ValueType  # 4935
    TIMING_RESET_ATTRIBUTE_MASTER_TIMEBASE_RATE: _TimingResetAttribute.ValueType  # 5269
    TIMING_RESET_ATTRIBUTE_AI_CONV_SRC: _TimingResetAttribute.ValueType  # 5378
    TIMING_RESET_ATTRIBUTE_AI_CONV_RATE: _TimingResetAttribute.ValueType  # 6216
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_SRC: _TimingResetAttribute.ValueType  # 6226
    TIMING_RESET_ATTRIBUTE_AI_CONV_ACTIVE_EDGE: _TimingResetAttribute.ValueType  # 6227
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_DIV: _TimingResetAttribute.ValueType  # 6379
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_ACTIVE_EDGE: _TimingResetAttribute.ValueType  # 6380
    TIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_RISING_EDGE_PHYSICAL_CHANS: _TimingResetAttribute.ValueType  # 8597
    TIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_FALLING_EDGE_PHYSICAL_CHANS: _TimingResetAttribute.ValueType  # 8598
    TIMING_RESET_ATTRIBUTE_ON_DEMAND_SIMULTANEOUS_AO_ENABLE: _TimingResetAttribute.ValueType  # 8608
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_ENABLE: _TimingResetAttribute.ValueType  # 8734
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_MIN_PULSE_WIDTH: _TimingResetAttribute.ValueType  # 8735
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_SRC: _TimingResetAttribute.ValueType  # 8736
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_RATE: _TimingResetAttribute.ValueType  # 8737
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_SYNC_ENABLE: _TimingResetAttribute.ValueType  # 8738
    TIMING_RESET_ATTRIBUTE_SYNC_PULSE_SRC: _TimingResetAttribute.ValueType  # 8765
    TIMING_RESET_ATTRIBUTE_SYNC_PULSE_MIN_DELAY_TO_START: _TimingResetAttribute.ValueType  # 8767
    TIMING_RESET_ATTRIBUTE_HSHK_DELAY_AFTER_XFER: _TimingResetAttribute.ValueType  # 8898
    TIMING_RESET_ATTRIBUTE_HSHK_START_COND: _TimingResetAttribute.ValueType  # 8899
    TIMING_RESET_ATTRIBUTE_HSHK_SAMPLE_INPUT_DATA_WHEN: _TimingResetAttribute.ValueType  # 8900
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_UNDERFLOW_BEHAVIOR: _TimingResetAttribute.ValueType  # 10593
    TIMING_RESET_ATTRIBUTE_SAMP_TIMING_ENGINE: _TimingResetAttribute.ValueType  # 10790
    TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_ENABLE: _TimingResetAttribute.ValueType  # 11996
    TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_MIN_PULSE_WIDTH: _TimingResetAttribute.ValueType  # 11997
    TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_SRC: _TimingResetAttribute.ValueType  # 11998
    TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_RATE: _TimingResetAttribute.ValueType  # 11999
    TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_SYNC_ENABLE: _TimingResetAttribute.ValueType  # 12000
    TIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_TRISTATE: _TimingResetAttribute.ValueType  # 12026
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_OVERRUN_BEHAVIOR: _TimingResetAttribute.ValueType  # 12028
    TIMING_RESET_ATTRIBUTE_IMPLICIT_UNDERFLOW_BEHAVIOR: _TimingResetAttribute.ValueType  # 12029
    TIMING_RESET_ATTRIBUTE_SYNC_PULSE_RESET_DELAY: _TimingResetAttribute.ValueType  # 12157
    TIMING_RESET_ATTRIBUTE_SYNC_CLK_INTERVAL: _TimingResetAttribute.ValueType  # 12158
    TIMING_RESET_ATTRIBUTE_TIMING_SYNC_PULSE_FORCE: _TimingResetAttribute.ValueType  # 12474
    TIMING_RESET_ATTRIBUTE_SAMP_CLK_WRITE_WFM_USE_INITIAL_WFM_DT: _TimingResetAttribute.ValueType  # 12540
    TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TYPE: _TimingResetAttribute.ValueType  # 12598
    TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TIME_WHEN: _TimingResetAttribute.ValueType  # 12599
    TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TIME_TIMESCALE: _TimingResetAttribute.ValueType  # 12600
    TIMING_RESET_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_ENABLE: _TimingResetAttribute.ValueType  # 12601
    TIMING_RESET_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_TIMESCALE: _TimingResetAttribute.ValueType  # 12603
    TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_WHEN: _TimingResetAttribute.ValueType  # 12674
    TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_TIMESCALE: _TimingResetAttribute.ValueType  # 12675
    TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_OFFSET: _TimingResetAttribute.ValueType  # 12714

class TimingResetAttribute(_TimingResetAttribute, metaclass=_TimingResetAttributeEnumTypeWrapper): ...

TIMING_RESET_ATTRIBUTE_UNSPECIFIED: TimingResetAttribute.ValueType  # 0
TIMING_RESET_ATTRIBUTE_SAMP_QUANT_SAMP_MODE: TimingResetAttribute.ValueType  # 4864
TIMING_RESET_ATTRIBUTE_SAMP_CLK_ACTIVE_EDGE: TimingResetAttribute.ValueType  # 4865
TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_RATE: TimingResetAttribute.ValueType  # 4867
TIMING_RESET_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY_UNITS: TimingResetAttribute.ValueType  # 4868
TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_MASTER_TIMEBASE_DIV: TimingResetAttribute.ValueType  # 4869
TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_SRC: TimingResetAttribute.ValueType  # 4872
TIMING_RESET_ATTRIBUTE_SAMP_QUANT_SAMP_PER_CHAN: TimingResetAttribute.ValueType  # 4880
TIMING_RESET_ATTRIBUTE_REF_CLK_RATE: TimingResetAttribute.ValueType  # 4885
TIMING_RESET_ATTRIBUTE_REF_CLK_SRC: TimingResetAttribute.ValueType  # 4886
TIMING_RESET_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY: TimingResetAttribute.ValueType  # 4887
TIMING_RESET_ATTRIBUTE_AI_CONV_TIMEBASE_DIV: TimingResetAttribute.ValueType  # 4917
TIMING_RESET_ATTRIBUTE_AI_CONV_TIMEBASE_SRC: TimingResetAttribute.ValueType  # 4921
TIMING_RESET_ATTRIBUTE_MASTER_TIMEBASE_SRC: TimingResetAttribute.ValueType  # 4931
TIMING_RESET_ATTRIBUTE_SAMP_CLK_RATE: TimingResetAttribute.ValueType  # 4932
TIMING_RESET_ATTRIBUTE_SAMP_TIMING_TYPE: TimingResetAttribute.ValueType  # 4935
TIMING_RESET_ATTRIBUTE_MASTER_TIMEBASE_RATE: TimingResetAttribute.ValueType  # 5269
TIMING_RESET_ATTRIBUTE_AI_CONV_SRC: TimingResetAttribute.ValueType  # 5378
TIMING_RESET_ATTRIBUTE_AI_CONV_RATE: TimingResetAttribute.ValueType  # 6216
TIMING_RESET_ATTRIBUTE_SAMP_CLK_SRC: TimingResetAttribute.ValueType  # 6226
TIMING_RESET_ATTRIBUTE_AI_CONV_ACTIVE_EDGE: TimingResetAttribute.ValueType  # 6227
TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_DIV: TimingResetAttribute.ValueType  # 6379
TIMING_RESET_ATTRIBUTE_SAMP_CLK_TIMEBASE_ACTIVE_EDGE: TimingResetAttribute.ValueType  # 6380
TIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_RISING_EDGE_PHYSICAL_CHANS: TimingResetAttribute.ValueType  # 8597
TIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_FALLING_EDGE_PHYSICAL_CHANS: TimingResetAttribute.ValueType  # 8598
TIMING_RESET_ATTRIBUTE_ON_DEMAND_SIMULTANEOUS_AO_ENABLE: TimingResetAttribute.ValueType  # 8608
TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_ENABLE: TimingResetAttribute.ValueType  # 8734
TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_MIN_PULSE_WIDTH: TimingResetAttribute.ValueType  # 8735
TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_SRC: TimingResetAttribute.ValueType  # 8736
TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_RATE: TimingResetAttribute.ValueType  # 8737
TIMING_RESET_ATTRIBUTE_SAMP_CLK_DIG_SYNC_ENABLE: TimingResetAttribute.ValueType  # 8738
TIMING_RESET_ATTRIBUTE_SYNC_PULSE_SRC: TimingResetAttribute.ValueType  # 8765
TIMING_RESET_ATTRIBUTE_SYNC_PULSE_MIN_DELAY_TO_START: TimingResetAttribute.ValueType  # 8767
TIMING_RESET_ATTRIBUTE_HSHK_DELAY_AFTER_XFER: TimingResetAttribute.ValueType  # 8898
TIMING_RESET_ATTRIBUTE_HSHK_START_COND: TimingResetAttribute.ValueType  # 8899
TIMING_RESET_ATTRIBUTE_HSHK_SAMPLE_INPUT_DATA_WHEN: TimingResetAttribute.ValueType  # 8900
TIMING_RESET_ATTRIBUTE_SAMP_CLK_UNDERFLOW_BEHAVIOR: TimingResetAttribute.ValueType  # 10593
TIMING_RESET_ATTRIBUTE_SAMP_TIMING_ENGINE: TimingResetAttribute.ValueType  # 10790
TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_ENABLE: TimingResetAttribute.ValueType  # 11996
TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_MIN_PULSE_WIDTH: TimingResetAttribute.ValueType  # 11997
TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_SRC: TimingResetAttribute.ValueType  # 11998
TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_RATE: TimingResetAttribute.ValueType  # 11999
TIMING_RESET_ATTRIBUTE_AI_CONV_DIG_SYNC_ENABLE: TimingResetAttribute.ValueType  # 12000
TIMING_RESET_ATTRIBUTE_CHANGE_DETECT_DI_TRISTATE: TimingResetAttribute.ValueType  # 12026
TIMING_RESET_ATTRIBUTE_SAMP_CLK_OVERRUN_BEHAVIOR: TimingResetAttribute.ValueType  # 12028
TIMING_RESET_ATTRIBUTE_IMPLICIT_UNDERFLOW_BEHAVIOR: TimingResetAttribute.ValueType  # 12029
TIMING_RESET_ATTRIBUTE_SYNC_PULSE_RESET_DELAY: TimingResetAttribute.ValueType  # 12157
TIMING_RESET_ATTRIBUTE_SYNC_CLK_INTERVAL: TimingResetAttribute.ValueType  # 12158
TIMING_RESET_ATTRIBUTE_TIMING_SYNC_PULSE_FORCE: TimingResetAttribute.ValueType  # 12474
TIMING_RESET_ATTRIBUTE_SAMP_CLK_WRITE_WFM_USE_INITIAL_WFM_DT: TimingResetAttribute.ValueType  # 12540
TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TYPE: TimingResetAttribute.ValueType  # 12598
TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TIME_WHEN: TimingResetAttribute.ValueType  # 12599
TIMING_RESET_ATTRIBUTE_SYNC_PULSE_TIME_TIMESCALE: TimingResetAttribute.ValueType  # 12600
TIMING_RESET_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_ENABLE: TimingResetAttribute.ValueType  # 12601
TIMING_RESET_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_TIMESCALE: TimingResetAttribute.ValueType  # 12603
TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_WHEN: TimingResetAttribute.ValueType  # 12674
TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_TIMESCALE: TimingResetAttribute.ValueType  # 12675
TIMING_RESET_ATTRIBUTE_FIRST_SAMP_CLK_OFFSET: TimingResetAttribute.ValueType  # 12714
global___TimingResetAttribute = TimingResetAttribute

class _TimingDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_DOUBLE_ATTRIBUTE_UNSPECIFIED: _TimingDoubleAttribute.ValueType  # 0
    TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_RATE: _TimingDoubleAttribute.ValueType  # 4867
    TIMING_ATTRIBUTE_REF_CLK_RATE: _TimingDoubleAttribute.ValueType  # 4885
    TIMING_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY: _TimingDoubleAttribute.ValueType  # 4887
    TIMING_ATTRIBUTE_SAMP_CLK_RATE: _TimingDoubleAttribute.ValueType  # 4932
    TIMING_ATTRIBUTE_MASTER_TIMEBASE_RATE: _TimingDoubleAttribute.ValueType  # 5269
    TIMING_ATTRIBUTE_AI_CONV_RATE: _TimingDoubleAttribute.ValueType  # 6216
    TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_MIN_PULSE_WIDTH: _TimingDoubleAttribute.ValueType  # 8735
    TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_RATE: _TimingDoubleAttribute.ValueType  # 8737
    TIMING_ATTRIBUTE_SYNC_PULSE_SYNC_TIME: _TimingDoubleAttribute.ValueType  # 8766
    TIMING_ATTRIBUTE_SYNC_PULSE_MIN_DELAY_TO_START: _TimingDoubleAttribute.ValueType  # 8767
    TIMING_ATTRIBUTE_HSHK_DELAY_AFTER_XFER: _TimingDoubleAttribute.ValueType  # 8898
    TIMING_ATTRIBUTE_SAMP_CLK_MAX_RATE: _TimingDoubleAttribute.ValueType  # 8904
    TIMING_ATTRIBUTE_AI_CONV_MAX_RATE: _TimingDoubleAttribute.ValueType  # 8905
    TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_MIN_PULSE_WIDTH: _TimingDoubleAttribute.ValueType  # 11997
    TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_RATE: _TimingDoubleAttribute.ValueType  # 11999
    TIMING_ATTRIBUTE_SYNC_PULSE_RESET_TIME: _TimingDoubleAttribute.ValueType  # 12156
    TIMING_ATTRIBUTE_SYNC_PULSE_RESET_DELAY: _TimingDoubleAttribute.ValueType  # 12157
    TIMING_ATTRIBUTE_FIRST_SAMP_CLK_OFFSET: _TimingDoubleAttribute.ValueType  # 12714

class TimingDoubleAttribute(_TimingDoubleAttribute, metaclass=_TimingDoubleAttributeEnumTypeWrapper): ...

TIMING_DOUBLE_ATTRIBUTE_UNSPECIFIED: TimingDoubleAttribute.ValueType  # 0
TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_RATE: TimingDoubleAttribute.ValueType  # 4867
TIMING_ATTRIBUTE_REF_CLK_RATE: TimingDoubleAttribute.ValueType  # 4885
TIMING_ATTRIBUTE_DELAY_FROM_SAMP_CLK_DELAY: TimingDoubleAttribute.ValueType  # 4887
TIMING_ATTRIBUTE_SAMP_CLK_RATE: TimingDoubleAttribute.ValueType  # 4932
TIMING_ATTRIBUTE_MASTER_TIMEBASE_RATE: TimingDoubleAttribute.ValueType  # 5269
TIMING_ATTRIBUTE_AI_CONV_RATE: TimingDoubleAttribute.ValueType  # 6216
TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_MIN_PULSE_WIDTH: TimingDoubleAttribute.ValueType  # 8735
TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_RATE: TimingDoubleAttribute.ValueType  # 8737
TIMING_ATTRIBUTE_SYNC_PULSE_SYNC_TIME: TimingDoubleAttribute.ValueType  # 8766
TIMING_ATTRIBUTE_SYNC_PULSE_MIN_DELAY_TO_START: TimingDoubleAttribute.ValueType  # 8767
TIMING_ATTRIBUTE_HSHK_DELAY_AFTER_XFER: TimingDoubleAttribute.ValueType  # 8898
TIMING_ATTRIBUTE_SAMP_CLK_MAX_RATE: TimingDoubleAttribute.ValueType  # 8904
TIMING_ATTRIBUTE_AI_CONV_MAX_RATE: TimingDoubleAttribute.ValueType  # 8905
TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_MIN_PULSE_WIDTH: TimingDoubleAttribute.ValueType  # 11997
TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_RATE: TimingDoubleAttribute.ValueType  # 11999
TIMING_ATTRIBUTE_SYNC_PULSE_RESET_TIME: TimingDoubleAttribute.ValueType  # 12156
TIMING_ATTRIBUTE_SYNC_PULSE_RESET_DELAY: TimingDoubleAttribute.ValueType  # 12157
TIMING_ATTRIBUTE_FIRST_SAMP_CLK_OFFSET: TimingDoubleAttribute.ValueType  # 12714
global___TimingDoubleAttribute = TimingDoubleAttribute

class _TimingUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_UINT32_ATTRIBUTE_UNSPECIFIED: _TimingUInt32Attribute.ValueType  # 0
    TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_MASTER_TIMEBASE_DIV: _TimingUInt32Attribute.ValueType  # 4869
    TIMING_ATTRIBUTE_AI_CONV_TIMEBASE_DIV: _TimingUInt32Attribute.ValueType  # 4917
    TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_DIV: _TimingUInt32Attribute.ValueType  # 6379
    TIMING_ATTRIBUTE_SAMP_TIMING_ENGINE: _TimingUInt32Attribute.ValueType  # 10790
    TIMING_ATTRIBUTE_SYNC_CLK_INTERVAL: _TimingUInt32Attribute.ValueType  # 12158

class TimingUInt32Attribute(_TimingUInt32Attribute, metaclass=_TimingUInt32AttributeEnumTypeWrapper): ...

TIMING_UINT32_ATTRIBUTE_UNSPECIFIED: TimingUInt32Attribute.ValueType  # 0
TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_MASTER_TIMEBASE_DIV: TimingUInt32Attribute.ValueType  # 4869
TIMING_ATTRIBUTE_AI_CONV_TIMEBASE_DIV: TimingUInt32Attribute.ValueType  # 4917
TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_DIV: TimingUInt32Attribute.ValueType  # 6379
TIMING_ATTRIBUTE_SAMP_TIMING_ENGINE: TimingUInt32Attribute.ValueType  # 10790
TIMING_ATTRIBUTE_SYNC_CLK_INTERVAL: TimingUInt32Attribute.ValueType  # 12158
global___TimingUInt32Attribute = TimingUInt32Attribute

class _TimingStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_STRING_ATTRIBUTE_UNSPECIFIED: _TimingStringAttribute.ValueType  # 0
    TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_SRC: _TimingStringAttribute.ValueType  # 4872
    TIMING_ATTRIBUTE_REF_CLK_SRC: _TimingStringAttribute.ValueType  # 4886
    TIMING_ATTRIBUTE_MASTER_TIMEBASE_SRC: _TimingStringAttribute.ValueType  # 4931
    TIMING_ATTRIBUTE_AI_CONV_SRC: _TimingStringAttribute.ValueType  # 5378
    TIMING_ATTRIBUTE_SAMP_CLK_SRC: _TimingStringAttribute.ValueType  # 6226
    TIMING_ATTRIBUTE_CHANGE_DETECT_DI_RISING_EDGE_PHYSICAL_CHANS: _TimingStringAttribute.ValueType  # 8597
    TIMING_ATTRIBUTE_CHANGE_DETECT_DI_FALLING_EDGE_PHYSICAL_CHANS: _TimingStringAttribute.ValueType  # 8598
    TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_SRC: _TimingStringAttribute.ValueType  # 8736
    TIMING_ATTRIBUTE_SYNC_PULSE_SRC: _TimingStringAttribute.ValueType  # 8765
    TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_SRC: _TimingStringAttribute.ValueType  # 11998
    TIMING_ATTRIBUTE_SAMP_CLK_TERM: _TimingStringAttribute.ValueType  # 12059
    TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_TERM: _TimingStringAttribute.ValueType  # 12060
    TIMING_ATTRIBUTE_SYNC_PULSE_TERM: _TimingStringAttribute.ValueType  # 12165

class TimingStringAttribute(_TimingStringAttribute, metaclass=_TimingStringAttributeEnumTypeWrapper): ...

TIMING_STRING_ATTRIBUTE_UNSPECIFIED: TimingStringAttribute.ValueType  # 0
TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_SRC: TimingStringAttribute.ValueType  # 4872
TIMING_ATTRIBUTE_REF_CLK_SRC: TimingStringAttribute.ValueType  # 4886
TIMING_ATTRIBUTE_MASTER_TIMEBASE_SRC: TimingStringAttribute.ValueType  # 4931
TIMING_ATTRIBUTE_AI_CONV_SRC: TimingStringAttribute.ValueType  # 5378
TIMING_ATTRIBUTE_SAMP_CLK_SRC: TimingStringAttribute.ValueType  # 6226
TIMING_ATTRIBUTE_CHANGE_DETECT_DI_RISING_EDGE_PHYSICAL_CHANS: TimingStringAttribute.ValueType  # 8597
TIMING_ATTRIBUTE_CHANGE_DETECT_DI_FALLING_EDGE_PHYSICAL_CHANS: TimingStringAttribute.ValueType  # 8598
TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_TIMEBASE_SRC: TimingStringAttribute.ValueType  # 8736
TIMING_ATTRIBUTE_SYNC_PULSE_SRC: TimingStringAttribute.ValueType  # 8765
TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_TIMEBASE_SRC: TimingStringAttribute.ValueType  # 11998
TIMING_ATTRIBUTE_SAMP_CLK_TERM: TimingStringAttribute.ValueType  # 12059
TIMING_ATTRIBUTE_SAMP_CLK_TIMEBASE_TERM: TimingStringAttribute.ValueType  # 12060
TIMING_ATTRIBUTE_SYNC_PULSE_TERM: TimingStringAttribute.ValueType  # 12165
global___TimingStringAttribute = TimingStringAttribute

class _TimingUInt64Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingUInt64AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingUInt64Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_UINT64_ATTRIBUTE_UNSPECIFIED: _TimingUInt64Attribute.ValueType  # 0
    TIMING_ATTRIBUTE_SAMP_QUANT_SAMP_PER_CHAN: _TimingUInt64Attribute.ValueType  # 4880

class TimingUInt64Attribute(_TimingUInt64Attribute, metaclass=_TimingUInt64AttributeEnumTypeWrapper): ...

TIMING_UINT64_ATTRIBUTE_UNSPECIFIED: TimingUInt64Attribute.ValueType  # 0
TIMING_ATTRIBUTE_SAMP_QUANT_SAMP_PER_CHAN: TimingUInt64Attribute.ValueType  # 4880
global___TimingUInt64Attribute = TimingUInt64Attribute

class _TimingBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_BOOL_ATTRIBUTE_UNSPECIFIED: _TimingBoolAttribute.ValueType  # 0
    TIMING_ATTRIBUTE_ON_DEMAND_SIMULTANEOUS_AO_ENABLE: _TimingBoolAttribute.ValueType  # 8608
    TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_ENABLE: _TimingBoolAttribute.ValueType  # 8734
    TIMING_ATTRIBUTE_SAMP_CLK_DIG_SYNC_ENABLE: _TimingBoolAttribute.ValueType  # 8738
    TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_ENABLE: _TimingBoolAttribute.ValueType  # 11996
    TIMING_ATTRIBUTE_AI_CONV_DIG_SYNC_ENABLE: _TimingBoolAttribute.ValueType  # 12000
    TIMING_ATTRIBUTE_CHANGE_DETECT_DI_TRISTATE: _TimingBoolAttribute.ValueType  # 12026
    TIMING_ATTRIBUTE_TIMING_SYNC_PULSE_FORCE: _TimingBoolAttribute.ValueType  # 12474
    TIMING_ATTRIBUTE_SAMP_CLK_WRITE_WFM_USE_INITIAL_WFM_DT: _TimingBoolAttribute.ValueType  # 12540
    TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_ENABLE: _TimingBoolAttribute.ValueType  # 12601

class TimingBoolAttribute(_TimingBoolAttribute, metaclass=_TimingBoolAttributeEnumTypeWrapper): ...

TIMING_BOOL_ATTRIBUTE_UNSPECIFIED: TimingBoolAttribute.ValueType  # 0
TIMING_ATTRIBUTE_ON_DEMAND_SIMULTANEOUS_AO_ENABLE: TimingBoolAttribute.ValueType  # 8608
TIMING_ATTRIBUTE_SAMP_CLK_DIG_FLTR_ENABLE: TimingBoolAttribute.ValueType  # 8734
TIMING_ATTRIBUTE_SAMP_CLK_DIG_SYNC_ENABLE: TimingBoolAttribute.ValueType  # 8738
TIMING_ATTRIBUTE_AI_CONV_DIG_FLTR_ENABLE: TimingBoolAttribute.ValueType  # 11996
TIMING_ATTRIBUTE_AI_CONV_DIG_SYNC_ENABLE: TimingBoolAttribute.ValueType  # 12000
TIMING_ATTRIBUTE_CHANGE_DETECT_DI_TRISTATE: TimingBoolAttribute.ValueType  # 12026
TIMING_ATTRIBUTE_TIMING_SYNC_PULSE_FORCE: TimingBoolAttribute.ValueType  # 12474
TIMING_ATTRIBUTE_SAMP_CLK_WRITE_WFM_USE_INITIAL_WFM_DT: TimingBoolAttribute.ValueType  # 12540
TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_ENABLE: TimingBoolAttribute.ValueType  # 12601
global___TimingBoolAttribute = TimingBoolAttribute

class _TimingTimestampAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingTimestampAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingTimestampAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_TIMESTAMP_ATTRIBUTE_UNSPECIFIED: _TimingTimestampAttribute.ValueType  # 0
    TIMING_ATTRIBUTE_SYNC_PULSE_TIME_WHEN: _TimingTimestampAttribute.ValueType  # 12599
    TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_VAL: _TimingTimestampAttribute.ValueType  # 12602
    TIMING_ATTRIBUTE_FIRST_SAMP_CLK_WHEN: _TimingTimestampAttribute.ValueType  # 12674

class TimingTimestampAttribute(_TimingTimestampAttribute, metaclass=_TimingTimestampAttributeEnumTypeWrapper): ...

TIMING_TIMESTAMP_ATTRIBUTE_UNSPECIFIED: TimingTimestampAttribute.ValueType  # 0
TIMING_ATTRIBUTE_SYNC_PULSE_TIME_WHEN: TimingTimestampAttribute.ValueType  # 12599
TIMING_ATTRIBUTE_FIRST_SAMP_TIMESTAMP_VAL: TimingTimestampAttribute.ValueType  # 12602
TIMING_ATTRIBUTE_FIRST_SAMP_CLK_WHEN: TimingTimestampAttribute.ValueType  # 12674
global___TimingTimestampAttribute = TimingTimestampAttribute

class _TriggerInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_INT32_ATTRIBUTE_UNSPECIFIED: _TriggerInt32Attribute.ValueType  # 0
    TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_EDGE: _TriggerInt32Attribute.ValueType  # 4960
    TRIGGER_ATTRIBUTE_ADV_TRIG_TYPE: _TriggerInt32Attribute.ValueType  # 4965
    TRIGGER_ATTRIBUTE_PAUSE_TRIG_TYPE: _TriggerInt32Attribute.ValueType  # 4966
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_WHEN: _TriggerInt32Attribute.ValueType  # 4977
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_WHEN: _TriggerInt32Attribute.ValueType  # 4980
    TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_WHEN: _TriggerInt32Attribute.ValueType  # 4992
    TRIGGER_ATTRIBUTE_START_TRIG_TYPE: _TriggerInt32Attribute.ValueType  # 5011
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_SLOPE: _TriggerInt32Attribute.ValueType  # 5015
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_WHEN: _TriggerInt32Attribute.ValueType  # 5121
    TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_EDGE: _TriggerInt32Attribute.ValueType  # 5124
    TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_WHEN: _TriggerInt32Attribute.ValueType  # 5137
    TRIGGER_ATTRIBUTE_ARM_START_TRIG_TYPE: _TriggerInt32Attribute.ValueType  # 5140
    TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_EDGE: _TriggerInt32Attribute.ValueType  # 5141
    TRIGGER_ATTRIBUTE_REF_TRIG_TYPE: _TriggerInt32Attribute.ValueType  # 5145
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SLOPE: _TriggerInt32Attribute.ValueType  # 5155
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_WHEN: _TriggerInt32Attribute.ValueType  # 5159
    TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_EDGE: _TriggerInt32Attribute.ValueType  # 5168
    TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_WHEN: _TriggerInt32Attribute.ValueType  # 5176
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_COUPLING: _TriggerInt32Attribute.ValueType  # 6231
    TRIGGER_ATTRIBUTE_START_TRIG_DELAY_UNITS: _TriggerInt32Attribute.ValueType  # 6344
    TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_WHEN: _TriggerInt32Attribute.ValueType  # 8560
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_COUPLING: _TriggerInt32Attribute.ValueType  # 8755
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_COUPLING: _TriggerInt32Attribute.ValueType  # 8756
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_COUPLING: _TriggerInt32Attribute.ValueType  # 8757
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_COUPLING: _TriggerInt32Attribute.ValueType  # 8758
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_COUPLING: _TriggerInt32Attribute.ValueType  # 8759
    TRIGGER_ATTRIBUTE_HSHK_TRIG_TYPE: _TriggerInt32Attribute.ValueType  # 8887
    TRIGGER_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_ASSERTED_LVL: _TriggerInt32Attribute.ValueType  # 8889
    TRIGGER_ATTRIBUTE_TRIGGER_SYNC_TYPE: _TriggerInt32Attribute.ValueType  # 12160
    TRIGGER_ATTRIBUTE_START_TRIG_TIMESCALE: _TriggerInt32Attribute.ValueType  # 12342
    TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_TIMESCALE: _TriggerInt32Attribute.ValueType  # 12589
    TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_TIMESCALE: _TriggerInt32Attribute.ValueType  # 12592
    TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESCALE: _TriggerInt32Attribute.ValueType  # 12594
    TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_TIMESCALE: _TriggerInt32Attribute.ValueType  # 12597

class TriggerInt32Attribute(_TriggerInt32Attribute, metaclass=_TriggerInt32AttributeEnumTypeWrapper): ...

TRIGGER_INT32_ATTRIBUTE_UNSPECIFIED: TriggerInt32Attribute.ValueType  # 0
TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_EDGE: TriggerInt32Attribute.ValueType  # 4960
TRIGGER_ATTRIBUTE_ADV_TRIG_TYPE: TriggerInt32Attribute.ValueType  # 4965
TRIGGER_ATTRIBUTE_PAUSE_TRIG_TYPE: TriggerInt32Attribute.ValueType  # 4966
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_WHEN: TriggerInt32Attribute.ValueType  # 4977
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_WHEN: TriggerInt32Attribute.ValueType  # 4980
TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_WHEN: TriggerInt32Attribute.ValueType  # 4992
TRIGGER_ATTRIBUTE_START_TRIG_TYPE: TriggerInt32Attribute.ValueType  # 5011
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_SLOPE: TriggerInt32Attribute.ValueType  # 5015
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_WHEN: TriggerInt32Attribute.ValueType  # 5121
TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_EDGE: TriggerInt32Attribute.ValueType  # 5124
TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_WHEN: TriggerInt32Attribute.ValueType  # 5137
TRIGGER_ATTRIBUTE_ARM_START_TRIG_TYPE: TriggerInt32Attribute.ValueType  # 5140
TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_EDGE: TriggerInt32Attribute.ValueType  # 5141
TRIGGER_ATTRIBUTE_REF_TRIG_TYPE: TriggerInt32Attribute.ValueType  # 5145
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SLOPE: TriggerInt32Attribute.ValueType  # 5155
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_WHEN: TriggerInt32Attribute.ValueType  # 5159
TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_EDGE: TriggerInt32Attribute.ValueType  # 5168
TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_WHEN: TriggerInt32Attribute.ValueType  # 5176
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_COUPLING: TriggerInt32Attribute.ValueType  # 6231
TRIGGER_ATTRIBUTE_START_TRIG_DELAY_UNITS: TriggerInt32Attribute.ValueType  # 6344
TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_WHEN: TriggerInt32Attribute.ValueType  # 8560
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_COUPLING: TriggerInt32Attribute.ValueType  # 8755
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_COUPLING: TriggerInt32Attribute.ValueType  # 8756
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_COUPLING: TriggerInt32Attribute.ValueType  # 8757
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_COUPLING: TriggerInt32Attribute.ValueType  # 8758
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_COUPLING: TriggerInt32Attribute.ValueType  # 8759
TRIGGER_ATTRIBUTE_HSHK_TRIG_TYPE: TriggerInt32Attribute.ValueType  # 8887
TRIGGER_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_ASSERTED_LVL: TriggerInt32Attribute.ValueType  # 8889
TRIGGER_ATTRIBUTE_TRIGGER_SYNC_TYPE: TriggerInt32Attribute.ValueType  # 12160
TRIGGER_ATTRIBUTE_START_TRIG_TIMESCALE: TriggerInt32Attribute.ValueType  # 12342
TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_TIMESCALE: TriggerInt32Attribute.ValueType  # 12589
TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_TIMESCALE: TriggerInt32Attribute.ValueType  # 12592
TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESCALE: TriggerInt32Attribute.ValueType  # 12594
TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_TIMESCALE: TriggerInt32Attribute.ValueType  # 12597
global___TriggerInt32Attribute = TriggerInt32Attribute

class _TriggerResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_RESET_ATTRIBUTE_UNSPECIFIED: _TriggerResetAttribute.ValueType  # 0
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_EDGE: _TriggerResetAttribute.ValueType  # 4960
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_SRC: _TriggerResetAttribute.ValueType  # 4962
    TRIGGER_RESET_ATTRIBUTE_ADV_TRIG_TYPE: _TriggerResetAttribute.ValueType  # 4965
    TRIGGER_RESET_ATTRIBUTE_PAUSE_TRIG_TYPE: _TriggerResetAttribute.ValueType  # 4966
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_HYST: _TriggerResetAttribute.ValueType  # 4968
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_LVL: _TriggerResetAttribute.ValueType  # 4969
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_SRC: _TriggerResetAttribute.ValueType  # 4976
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 4977
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_SRC: _TriggerResetAttribute.ValueType  # 4979
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 4980
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_BTM: _TriggerResetAttribute.ValueType  # 4981
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_TOP: _TriggerResetAttribute.ValueType  # 4982
    TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_SRC: _TriggerResetAttribute.ValueType  # 4985
    TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 4992
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_TYPE: _TriggerResetAttribute.ValueType  # 5011
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_HYST: _TriggerResetAttribute.ValueType  # 5013
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_LVL: _TriggerResetAttribute.ValueType  # 5014
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_SLOPE: _TriggerResetAttribute.ValueType  # 5015
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5016
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5120
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 5121
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_BTM: _TriggerResetAttribute.ValueType  # 5122
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_TOP: _TriggerResetAttribute.ValueType  # 5123
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_EDGE: _TriggerResetAttribute.ValueType  # 5124
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5127
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5136
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 5137
    TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TYPE: _TriggerResetAttribute.ValueType  # 5140
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_EDGE: _TriggerResetAttribute.ValueType  # 5141
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5143
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TYPE: _TriggerResetAttribute.ValueType  # 5145
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_HYST: _TriggerResetAttribute.ValueType  # 5153
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_LVL: _TriggerResetAttribute.ValueType  # 5154
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SLOPE: _TriggerResetAttribute.ValueType  # 5155
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5156
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5158
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 5159
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_BTM: _TriggerResetAttribute.ValueType  # 5160
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_TOP: _TriggerResetAttribute.ValueType  # 5161
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_EDGE: _TriggerResetAttribute.ValueType  # 5168
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5172
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_SRC: _TriggerResetAttribute.ValueType  # 5175
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 5176
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_PRETRIG_SAMPLES: _TriggerResetAttribute.ValueType  # 5189
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_DELAY: _TriggerResetAttribute.ValueType  # 5251
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_DELAY: _TriggerResetAttribute.ValueType  # 6230
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_COUPLING: _TriggerResetAttribute.ValueType  # 6231
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_DELAY_UNITS: _TriggerResetAttribute.ValueType  # 6344
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_RETRIGGERABLE: _TriggerResetAttribute.ValueType  # 6415
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_SRC: _TriggerResetAttribute.ValueType  # 8559
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 8560
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_PATTERN: _TriggerResetAttribute.ValueType  # 8582
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_PATTERN: _TriggerResetAttribute.ValueType  # 8583
    TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_PATTERN: _TriggerResetAttribute.ValueType  # 8584
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 8739
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 8740
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 8741
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 8742
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 8743
    TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 8744
    TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 8745
    TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 8746
    TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 8747
    TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 8748
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 8749
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 8750
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 8751
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 8752
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 8753
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_COUPLING: _TriggerResetAttribute.ValueType  # 8755
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_COUPLING: _TriggerResetAttribute.ValueType  # 8756
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_COUPLING: _TriggerResetAttribute.ValueType  # 8757
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_COUPLING: _TriggerResetAttribute.ValueType  # 8758
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_COUPLING: _TriggerResetAttribute.ValueType  # 8759
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 8760
    TRIGGER_RESET_ATTRIBUTE_HSHK_TRIG_TYPE: _TriggerResetAttribute.ValueType  # 8887
    TRIGGER_RESET_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_SRC: _TriggerResetAttribute.ValueType  # 8888
    TRIGGER_RESET_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_ASSERTED_LVL: _TriggerResetAttribute.ValueType  # 8889
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_AUTO_TRIG_ENABLE: _TriggerResetAttribute.ValueType  # 11969
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 11991
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 11992
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 11993
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 11994
    TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 11995
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 12001
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 12002
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 12003
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 12004
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 12005
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 12006
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 12007
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 12008
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 12009
    TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 12010
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 12011
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 12012
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 12013
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 12014
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 12015
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 12016
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 12017
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 12018
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 12019
    TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 12020
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 12021
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 12022
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 12023
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 12024
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 12025
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_ENABLE: _TriggerResetAttribute.ValueType  # 12031
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerResetAttribute.ValueType  # 12032
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerResetAttribute.ValueType  # 12033
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerResetAttribute.ValueType  # 12034
    TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_SYNC_ENABLE: _TriggerResetAttribute.ValueType  # 12035
    TRIGGER_RESET_ATTRIBUTE_TRIGGER_SYNC_TYPE: _TriggerResetAttribute.ValueType  # 12160
    TRIGGER_RESET_ATTRIBUTE_TIME_START_TRIG_SRC: _TriggerResetAttribute.ValueType  # 12317
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESCALE: _TriggerResetAttribute.ValueType  # 12342
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 12365
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_TRIG_WIN: _TriggerResetAttribute.ValueType  # 12570
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_RETRIGGER_WIN: _TriggerResetAttribute.ValueType  # 12571
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_MAX_NUM_TRIGS_TO_DETECT: _TriggerResetAttribute.ValueType  # 12572
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_RETRIGGERABLE: _TriggerResetAttribute.ValueType  # 12573
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TRIG_WIN: _TriggerResetAttribute.ValueType  # 12574
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_RETRIGGER_WIN: _TriggerResetAttribute.ValueType  # 12575
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_MAX_NUM_TRIGS_TO_DETECT: _TriggerResetAttribute.ValueType  # 12576
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SRCS: _TriggerResetAttribute.ValueType  # 12577
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SLOPES: _TriggerResetAttribute.ValueType  # 12578
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_LVLS: _TriggerResetAttribute.ValueType  # 12579
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_HYSTS: _TriggerResetAttribute.ValueType  # 12580
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_COUPLINGS: _TriggerResetAttribute.ValueType  # 12581
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SRCS: _TriggerResetAttribute.ValueType  # 12582
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SLOPES: _TriggerResetAttribute.ValueType  # 12583
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_LVLS: _TriggerResetAttribute.ValueType  # 12584
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_HYSTS: _TriggerResetAttribute.ValueType  # 12585
    TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_COUPLINGS: _TriggerResetAttribute.ValueType  # 12586
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESTAMP_TIMESCALE: _TriggerResetAttribute.ValueType  # 12589
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TIMESTAMP_ENABLE: _TriggerResetAttribute.ValueType  # 12590
    TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TIMESTAMP_TIMESCALE: _TriggerResetAttribute.ValueType  # 12592
    TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TRIG_WHEN: _TriggerResetAttribute.ValueType  # 12593
    TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESCALE: _TriggerResetAttribute.ValueType  # 12594
    TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_ENABLE: _TriggerResetAttribute.ValueType  # 12595
    TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_TIMESCALE: _TriggerResetAttribute.ValueType  # 12597
    TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESTAMP_ENABLE: _TriggerResetAttribute.ValueType  # 12618

class TriggerResetAttribute(_TriggerResetAttribute, metaclass=_TriggerResetAttributeEnumTypeWrapper): ...

TRIGGER_RESET_ATTRIBUTE_UNSPECIFIED: TriggerResetAttribute.ValueType  # 0
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_EDGE: TriggerResetAttribute.ValueType  # 4960
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_SRC: TriggerResetAttribute.ValueType  # 4962
TRIGGER_RESET_ATTRIBUTE_ADV_TRIG_TYPE: TriggerResetAttribute.ValueType  # 4965
TRIGGER_RESET_ATTRIBUTE_PAUSE_TRIG_TYPE: TriggerResetAttribute.ValueType  # 4966
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_HYST: TriggerResetAttribute.ValueType  # 4968
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_LVL: TriggerResetAttribute.ValueType  # 4969
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_SRC: TriggerResetAttribute.ValueType  # 4976
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_WHEN: TriggerResetAttribute.ValueType  # 4977
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_SRC: TriggerResetAttribute.ValueType  # 4979
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_WHEN: TriggerResetAttribute.ValueType  # 4980
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_BTM: TriggerResetAttribute.ValueType  # 4981
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_TOP: TriggerResetAttribute.ValueType  # 4982
TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_SRC: TriggerResetAttribute.ValueType  # 4985
TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_WHEN: TriggerResetAttribute.ValueType  # 4992
TRIGGER_RESET_ATTRIBUTE_START_TRIG_TYPE: TriggerResetAttribute.ValueType  # 5011
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_HYST: TriggerResetAttribute.ValueType  # 5013
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_LVL: TriggerResetAttribute.ValueType  # 5014
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_SLOPE: TriggerResetAttribute.ValueType  # 5015
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_SRC: TriggerResetAttribute.ValueType  # 5016
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_SRC: TriggerResetAttribute.ValueType  # 5120
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_WHEN: TriggerResetAttribute.ValueType  # 5121
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_BTM: TriggerResetAttribute.ValueType  # 5122
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_TOP: TriggerResetAttribute.ValueType  # 5123
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_EDGE: TriggerResetAttribute.ValueType  # 5124
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_SRC: TriggerResetAttribute.ValueType  # 5127
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_SRC: TriggerResetAttribute.ValueType  # 5136
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_WHEN: TriggerResetAttribute.ValueType  # 5137
TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TYPE: TriggerResetAttribute.ValueType  # 5140
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_EDGE: TriggerResetAttribute.ValueType  # 5141
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_SRC: TriggerResetAttribute.ValueType  # 5143
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TYPE: TriggerResetAttribute.ValueType  # 5145
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_HYST: TriggerResetAttribute.ValueType  # 5153
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_LVL: TriggerResetAttribute.ValueType  # 5154
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SLOPE: TriggerResetAttribute.ValueType  # 5155
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SRC: TriggerResetAttribute.ValueType  # 5156
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_SRC: TriggerResetAttribute.ValueType  # 5158
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_WHEN: TriggerResetAttribute.ValueType  # 5159
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_BTM: TriggerResetAttribute.ValueType  # 5160
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_TOP: TriggerResetAttribute.ValueType  # 5161
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_EDGE: TriggerResetAttribute.ValueType  # 5168
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_SRC: TriggerResetAttribute.ValueType  # 5172
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_SRC: TriggerResetAttribute.ValueType  # 5175
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_WHEN: TriggerResetAttribute.ValueType  # 5176
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_PRETRIG_SAMPLES: TriggerResetAttribute.ValueType  # 5189
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_DELAY: TriggerResetAttribute.ValueType  # 5251
TRIGGER_RESET_ATTRIBUTE_START_TRIG_DELAY: TriggerResetAttribute.ValueType  # 6230
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_COUPLING: TriggerResetAttribute.ValueType  # 6231
TRIGGER_RESET_ATTRIBUTE_START_TRIG_DELAY_UNITS: TriggerResetAttribute.ValueType  # 6344
TRIGGER_RESET_ATTRIBUTE_START_TRIG_RETRIGGERABLE: TriggerResetAttribute.ValueType  # 6415
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_SRC: TriggerResetAttribute.ValueType  # 8559
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_WHEN: TriggerResetAttribute.ValueType  # 8560
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_START_TRIG_PATTERN: TriggerResetAttribute.ValueType  # 8582
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_REF_TRIG_PATTERN: TriggerResetAttribute.ValueType  # 8583
TRIGGER_RESET_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_PATTERN: TriggerResetAttribute.ValueType  # 8584
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 8739
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 8740
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 8741
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 8742
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 8743
TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 8744
TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 8745
TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 8746
TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 8747
TRIGGER_RESET_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 8748
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 8749
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 8750
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 8751
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 8752
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 8753
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_COUPLING: TriggerResetAttribute.ValueType  # 8755
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_COUPLING: TriggerResetAttribute.ValueType  # 8756
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_COUPLING: TriggerResetAttribute.ValueType  # 8757
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_COUPLING: TriggerResetAttribute.ValueType  # 8758
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_COUPLING: TriggerResetAttribute.ValueType  # 8759
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_ADV_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 8760
TRIGGER_RESET_ATTRIBUTE_HSHK_TRIG_TYPE: TriggerResetAttribute.ValueType  # 8887
TRIGGER_RESET_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_SRC: TriggerResetAttribute.ValueType  # 8888
TRIGGER_RESET_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_ASSERTED_LVL: TriggerResetAttribute.ValueType  # 8889
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_AUTO_TRIG_ENABLE: TriggerResetAttribute.ValueType  # 11969
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 11991
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 11992
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 11993
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 11994
TRIGGER_RESET_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 11995
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 12001
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 12002
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 12003
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 12004
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 12005
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 12006
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 12007
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 12008
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 12009
TRIGGER_RESET_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 12010
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 12011
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 12012
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 12013
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 12014
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 12015
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 12016
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 12017
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 12018
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 12019
TRIGGER_RESET_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 12020
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 12021
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 12022
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 12023
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 12024
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 12025
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_ENABLE: TriggerResetAttribute.ValueType  # 12031
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerResetAttribute.ValueType  # 12032
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerResetAttribute.ValueType  # 12033
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerResetAttribute.ValueType  # 12034
TRIGGER_RESET_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_SYNC_ENABLE: TriggerResetAttribute.ValueType  # 12035
TRIGGER_RESET_ATTRIBUTE_TRIGGER_SYNC_TYPE: TriggerResetAttribute.ValueType  # 12160
TRIGGER_RESET_ATTRIBUTE_TIME_START_TRIG_SRC: TriggerResetAttribute.ValueType  # 12317
TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESCALE: TriggerResetAttribute.ValueType  # 12342
TRIGGER_RESET_ATTRIBUTE_START_TRIG_TRIG_WHEN: TriggerResetAttribute.ValueType  # 12365
TRIGGER_RESET_ATTRIBUTE_START_TRIG_TRIG_WIN: TriggerResetAttribute.ValueType  # 12570
TRIGGER_RESET_ATTRIBUTE_START_TRIG_RETRIGGER_WIN: TriggerResetAttribute.ValueType  # 12571
TRIGGER_RESET_ATTRIBUTE_START_TRIG_MAX_NUM_TRIGS_TO_DETECT: TriggerResetAttribute.ValueType  # 12572
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_RETRIGGERABLE: TriggerResetAttribute.ValueType  # 12573
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TRIG_WIN: TriggerResetAttribute.ValueType  # 12574
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_RETRIGGER_WIN: TriggerResetAttribute.ValueType  # 12575
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_MAX_NUM_TRIGS_TO_DETECT: TriggerResetAttribute.ValueType  # 12576
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SRCS: TriggerResetAttribute.ValueType  # 12577
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SLOPES: TriggerResetAttribute.ValueType  # 12578
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_LVLS: TriggerResetAttribute.ValueType  # 12579
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_HYSTS: TriggerResetAttribute.ValueType  # 12580
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_COUPLINGS: TriggerResetAttribute.ValueType  # 12581
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SRCS: TriggerResetAttribute.ValueType  # 12582
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SLOPES: TriggerResetAttribute.ValueType  # 12583
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_LVLS: TriggerResetAttribute.ValueType  # 12584
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_HYSTS: TriggerResetAttribute.ValueType  # 12585
TRIGGER_RESET_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_COUPLINGS: TriggerResetAttribute.ValueType  # 12586
TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESTAMP_TIMESCALE: TriggerResetAttribute.ValueType  # 12589
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TIMESTAMP_ENABLE: TriggerResetAttribute.ValueType  # 12590
TRIGGER_RESET_ATTRIBUTE_REF_TRIG_TIMESTAMP_TIMESCALE: TriggerResetAttribute.ValueType  # 12592
TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TRIG_WHEN: TriggerResetAttribute.ValueType  # 12593
TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESCALE: TriggerResetAttribute.ValueType  # 12594
TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_ENABLE: TriggerResetAttribute.ValueType  # 12595
TRIGGER_RESET_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_TIMESCALE: TriggerResetAttribute.ValueType  # 12597
TRIGGER_RESET_ATTRIBUTE_START_TRIG_TIMESTAMP_ENABLE: TriggerResetAttribute.ValueType  # 12618
global___TriggerResetAttribute = TriggerResetAttribute

class _TriggerStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_STRING_ATTRIBUTE_UNSPECIFIED: _TriggerStringAttribute.ValueType  # 0
    TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_SRC: _TriggerStringAttribute.ValueType  # 4962
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_SRC: _TriggerStringAttribute.ValueType  # 4976
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_SRC: _TriggerStringAttribute.ValueType  # 4979
    TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_SRC: _TriggerStringAttribute.ValueType  # 4985
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5016
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5120
    TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5127
    TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5136
    TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5143
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5156
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5158
    TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5172
    TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_SRC: _TriggerStringAttribute.ValueType  # 5175
    TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_SRC: _TriggerStringAttribute.ValueType  # 8559
    TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_PATTERN: _TriggerStringAttribute.ValueType  # 8582
    TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_PATTERN: _TriggerStringAttribute.ValueType  # 8583
    TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_PATTERN: _TriggerStringAttribute.ValueType  # 8584
    TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 8741
    TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 8746
    TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 8751
    TRIGGER_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_SRC: _TriggerStringAttribute.ValueType  # 8888
    TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 11993
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 12003
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 12008
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 12013
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 12018
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 12023
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_SRC: _TriggerStringAttribute.ValueType  # 12033
    TRIGGER_ATTRIBUTE_START_TRIG_TERM: _TriggerStringAttribute.ValueType  # 12062
    TRIGGER_ATTRIBUTE_REF_TRIG_TERM: _TriggerStringAttribute.ValueType  # 12063
    TRIGGER_ATTRIBUTE_PAUSE_TRIG_TERM: _TriggerStringAttribute.ValueType  # 12064
    TRIGGER_ATTRIBUTE_ARM_START_TERM: _TriggerStringAttribute.ValueType  # 12159
    TRIGGER_ATTRIBUTE_TIME_START_TRIG_SRC: _TriggerStringAttribute.ValueType  # 12317
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SRCS: _TriggerStringAttribute.ValueType  # 12577
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SRCS: _TriggerStringAttribute.ValueType  # 12582

class TriggerStringAttribute(_TriggerStringAttribute, metaclass=_TriggerStringAttributeEnumTypeWrapper): ...

TRIGGER_STRING_ATTRIBUTE_UNSPECIFIED: TriggerStringAttribute.ValueType  # 0
TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_SRC: TriggerStringAttribute.ValueType  # 4962
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_SRC: TriggerStringAttribute.ValueType  # 4976
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_SRC: TriggerStringAttribute.ValueType  # 4979
TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_SRC: TriggerStringAttribute.ValueType  # 4985
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_SRC: TriggerStringAttribute.ValueType  # 5016
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_SRC: TriggerStringAttribute.ValueType  # 5120
TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_SRC: TriggerStringAttribute.ValueType  # 5127
TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_SRC: TriggerStringAttribute.ValueType  # 5136
TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_SRC: TriggerStringAttribute.ValueType  # 5143
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_SRC: TriggerStringAttribute.ValueType  # 5156
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_SRC: TriggerStringAttribute.ValueType  # 5158
TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_SRC: TriggerStringAttribute.ValueType  # 5172
TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_SRC: TriggerStringAttribute.ValueType  # 5175
TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_SRC: TriggerStringAttribute.ValueType  # 8559
TRIGGER_ATTRIBUTE_DIG_PATTERN_START_TRIG_PATTERN: TriggerStringAttribute.ValueType  # 8582
TRIGGER_ATTRIBUTE_DIG_PATTERN_REF_TRIG_PATTERN: TriggerStringAttribute.ValueType  # 8583
TRIGGER_ATTRIBUTE_DIG_PATTERN_PAUSE_TRIG_PATTERN: TriggerStringAttribute.ValueType  # 8584
TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 8741
TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 8746
TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 8751
TRIGGER_ATTRIBUTE_INTERLOCKED_HSHK_TRIG_SRC: TriggerStringAttribute.ValueType  # 8888
TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 11993
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 12003
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 12008
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 12013
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 12018
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 12023
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_SRC: TriggerStringAttribute.ValueType  # 12033
TRIGGER_ATTRIBUTE_START_TRIG_TERM: TriggerStringAttribute.ValueType  # 12062
TRIGGER_ATTRIBUTE_REF_TRIG_TERM: TriggerStringAttribute.ValueType  # 12063
TRIGGER_ATTRIBUTE_PAUSE_TRIG_TERM: TriggerStringAttribute.ValueType  # 12064
TRIGGER_ATTRIBUTE_ARM_START_TERM: TriggerStringAttribute.ValueType  # 12159
TRIGGER_ATTRIBUTE_TIME_START_TRIG_SRC: TriggerStringAttribute.ValueType  # 12317
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SRCS: TriggerStringAttribute.ValueType  # 12577
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SRCS: TriggerStringAttribute.ValueType  # 12582
global___TriggerStringAttribute = TriggerStringAttribute

class _TriggerDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_DOUBLE_ATTRIBUTE_UNSPECIFIED: _TriggerDoubleAttribute.ValueType  # 0
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_HYST: _TriggerDoubleAttribute.ValueType  # 4968
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_LVL: _TriggerDoubleAttribute.ValueType  # 4969
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_BTM: _TriggerDoubleAttribute.ValueType  # 4981
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_TOP: _TriggerDoubleAttribute.ValueType  # 4982
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_HYST: _TriggerDoubleAttribute.ValueType  # 5013
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_LVL: _TriggerDoubleAttribute.ValueType  # 5014
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_BTM: _TriggerDoubleAttribute.ValueType  # 5122
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_TOP: _TriggerDoubleAttribute.ValueType  # 5123
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_HYST: _TriggerDoubleAttribute.ValueType  # 5153
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_LVL: _TriggerDoubleAttribute.ValueType  # 5154
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_BTM: _TriggerDoubleAttribute.ValueType  # 5160
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_TOP: _TriggerDoubleAttribute.ValueType  # 5161
    TRIGGER_ATTRIBUTE_REF_TRIG_DELAY: _TriggerDoubleAttribute.ValueType  # 5251
    TRIGGER_ATTRIBUTE_START_TRIG_DELAY: _TriggerDoubleAttribute.ValueType  # 6230
    TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 8740
    TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 8742
    TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 8745
    TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 8747
    TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 8750
    TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 8752
    TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 11992
    TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 11994
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 12002
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 12004
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 12007
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 12009
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 12012
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 12014
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 12017
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 12019
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 12022
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 12024
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: _TriggerDoubleAttribute.ValueType  # 12032
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_RATE: _TriggerDoubleAttribute.ValueType  # 12034
    TRIGGER_ATTRIBUTE_START_TRIG_TRIG_WIN: _TriggerDoubleAttribute.ValueType  # 12570
    TRIGGER_ATTRIBUTE_START_TRIG_RETRIGGER_WIN: _TriggerDoubleAttribute.ValueType  # 12571
    TRIGGER_ATTRIBUTE_REF_TRIG_TRIG_WIN: _TriggerDoubleAttribute.ValueType  # 12574
    TRIGGER_ATTRIBUTE_REF_TRIG_RETRIGGER_WIN: _TriggerDoubleAttribute.ValueType  # 12575

class TriggerDoubleAttribute(_TriggerDoubleAttribute, metaclass=_TriggerDoubleAttributeEnumTypeWrapper): ...

TRIGGER_DOUBLE_ATTRIBUTE_UNSPECIFIED: TriggerDoubleAttribute.ValueType  # 0
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_HYST: TriggerDoubleAttribute.ValueType  # 4968
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_LVL: TriggerDoubleAttribute.ValueType  # 4969
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_BTM: TriggerDoubleAttribute.ValueType  # 4981
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_TOP: TriggerDoubleAttribute.ValueType  # 4982
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_HYST: TriggerDoubleAttribute.ValueType  # 5013
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_LVL: TriggerDoubleAttribute.ValueType  # 5014
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_BTM: TriggerDoubleAttribute.ValueType  # 5122
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_TOP: TriggerDoubleAttribute.ValueType  # 5123
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_HYST: TriggerDoubleAttribute.ValueType  # 5153
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_LVL: TriggerDoubleAttribute.ValueType  # 5154
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_BTM: TriggerDoubleAttribute.ValueType  # 5160
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_TOP: TriggerDoubleAttribute.ValueType  # 5161
TRIGGER_ATTRIBUTE_REF_TRIG_DELAY: TriggerDoubleAttribute.ValueType  # 5251
TRIGGER_ATTRIBUTE_START_TRIG_DELAY: TriggerDoubleAttribute.ValueType  # 6230
TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 8740
TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 8742
TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 8745
TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 8747
TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 8750
TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 8752
TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 11992
TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 11994
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 12002
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 12004
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 12007
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 12009
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 12012
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 12014
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 12017
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 12019
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 12022
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 12024
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_MIN_PULSE_WIDTH: TriggerDoubleAttribute.ValueType  # 12032
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_TIMEBASE_RATE: TriggerDoubleAttribute.ValueType  # 12034
TRIGGER_ATTRIBUTE_START_TRIG_TRIG_WIN: TriggerDoubleAttribute.ValueType  # 12570
TRIGGER_ATTRIBUTE_START_TRIG_RETRIGGER_WIN: TriggerDoubleAttribute.ValueType  # 12571
TRIGGER_ATTRIBUTE_REF_TRIG_TRIG_WIN: TriggerDoubleAttribute.ValueType  # 12574
TRIGGER_ATTRIBUTE_REF_TRIG_RETRIGGER_WIN: TriggerDoubleAttribute.ValueType  # 12575
global___TriggerDoubleAttribute = TriggerDoubleAttribute

class _TriggerUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_UINT32_ATTRIBUTE_UNSPECIFIED: _TriggerUInt32Attribute.ValueType  # 0
    TRIGGER_ATTRIBUTE_REF_TRIG_PRETRIG_SAMPLES: _TriggerUInt32Attribute.ValueType  # 5189
    TRIGGER_ATTRIBUTE_START_TRIG_MAX_NUM_TRIGS_TO_DETECT: _TriggerUInt32Attribute.ValueType  # 12572
    TRIGGER_ATTRIBUTE_REF_TRIG_MAX_NUM_TRIGS_TO_DETECT: _TriggerUInt32Attribute.ValueType  # 12576

class TriggerUInt32Attribute(_TriggerUInt32Attribute, metaclass=_TriggerUInt32AttributeEnumTypeWrapper): ...

TRIGGER_UINT32_ATTRIBUTE_UNSPECIFIED: TriggerUInt32Attribute.ValueType  # 0
TRIGGER_ATTRIBUTE_REF_TRIG_PRETRIG_SAMPLES: TriggerUInt32Attribute.ValueType  # 5189
TRIGGER_ATTRIBUTE_START_TRIG_MAX_NUM_TRIGS_TO_DETECT: TriggerUInt32Attribute.ValueType  # 12572
TRIGGER_ATTRIBUTE_REF_TRIG_MAX_NUM_TRIGS_TO_DETECT: TriggerUInt32Attribute.ValueType  # 12576
global___TriggerUInt32Attribute = TriggerUInt32Attribute

class _TriggerBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_BOOL_ATTRIBUTE_UNSPECIFIED: _TriggerBoolAttribute.ValueType  # 0
    TRIGGER_ATTRIBUTE_START_TRIG_RETRIGGERABLE: _TriggerBoolAttribute.ValueType  # 6415
    TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 8739
    TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 8743
    TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 8744
    TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 8748
    TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 8749
    TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 8753
    TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 8760
    TRIGGER_ATTRIBUTE_REF_TRIG_AUTO_TRIG_ENABLE: _TriggerBoolAttribute.ValueType  # 11969
    TRIGGER_ATTRIBUTE_REF_TRIG_AUTO_TRIGGERED: _TriggerBoolAttribute.ValueType  # 11970
    TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 11991
    TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 11995
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 12001
    TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 12005
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 12006
    TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 12010
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 12011
    TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 12015
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 12016
    TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 12020
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 12021
    TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 12025
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_ENABLE: _TriggerBoolAttribute.ValueType  # 12031
    TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_SYNC_ENABLE: _TriggerBoolAttribute.ValueType  # 12035
    TRIGGER_ATTRIBUTE_REF_TRIG_RETRIGGERABLE: _TriggerBoolAttribute.ValueType  # 12573
    TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_ENABLE: _TriggerBoolAttribute.ValueType  # 12590
    TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_ENABLE: _TriggerBoolAttribute.ValueType  # 12595
    TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_ENABLE: _TriggerBoolAttribute.ValueType  # 12618

class TriggerBoolAttribute(_TriggerBoolAttribute, metaclass=_TriggerBoolAttributeEnumTypeWrapper): ...

TRIGGER_BOOL_ATTRIBUTE_UNSPECIFIED: TriggerBoolAttribute.ValueType  # 0
TRIGGER_ATTRIBUTE_START_TRIG_RETRIGGERABLE: TriggerBoolAttribute.ValueType  # 6415
TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 8739
TRIGGER_ATTRIBUTE_DIG_EDGE_START_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 8743
TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 8744
TRIGGER_ATTRIBUTE_DIG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 8748
TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 8749
TRIGGER_ATTRIBUTE_DIG_EDGE_ARM_START_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 8753
TRIGGER_ATTRIBUTE_DIG_EDGE_ADV_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 8760
TRIGGER_ATTRIBUTE_REF_TRIG_AUTO_TRIG_ENABLE: TriggerBoolAttribute.ValueType  # 11969
TRIGGER_ATTRIBUTE_REF_TRIG_AUTO_TRIGGERED: TriggerBoolAttribute.ValueType  # 11970
TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 11991
TRIGGER_ATTRIBUTE_DIG_EDGE_REF_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 11995
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 12001
TRIGGER_ATTRIBUTE_ANLG_EDGE_START_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 12005
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 12006
TRIGGER_ATTRIBUTE_ANLG_EDGE_REF_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 12010
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 12011
TRIGGER_ATTRIBUTE_ANLG_WIN_REF_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 12015
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 12016
TRIGGER_ATTRIBUTE_ANLG_LVL_PAUSE_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 12020
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 12021
TRIGGER_ATTRIBUTE_ANLG_WIN_PAUSE_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 12025
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_FLTR_ENABLE: TriggerBoolAttribute.ValueType  # 12031
TRIGGER_ATTRIBUTE_ANLG_WIN_START_TRIG_DIG_SYNC_ENABLE: TriggerBoolAttribute.ValueType  # 12035
TRIGGER_ATTRIBUTE_REF_TRIG_RETRIGGERABLE: TriggerBoolAttribute.ValueType  # 12573
TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_ENABLE: TriggerBoolAttribute.ValueType  # 12590
TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_ENABLE: TriggerBoolAttribute.ValueType  # 12595
TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_ENABLE: TriggerBoolAttribute.ValueType  # 12618
global___TriggerBoolAttribute = TriggerBoolAttribute

class _TriggerTimestampAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerTimestampAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerTimestampAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_TIMESTAMP_ATTRIBUTE_UNSPECIFIED: _TriggerTimestampAttribute.ValueType  # 0
    TRIGGER_ATTRIBUTE_START_TRIG_TRIG_WHEN: _TriggerTimestampAttribute.ValueType  # 12365
    TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_VAL: _TriggerTimestampAttribute.ValueType  # 12591
    TRIGGER_ATTRIBUTE_ARM_START_TRIG_TRIG_WHEN: _TriggerTimestampAttribute.ValueType  # 12593
    TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_VAL: _TriggerTimestampAttribute.ValueType  # 12596
    TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_VAL: _TriggerTimestampAttribute.ValueType  # 12619

class TriggerTimestampAttribute(_TriggerTimestampAttribute, metaclass=_TriggerTimestampAttributeEnumTypeWrapper): ...

TRIGGER_TIMESTAMP_ATTRIBUTE_UNSPECIFIED: TriggerTimestampAttribute.ValueType  # 0
TRIGGER_ATTRIBUTE_START_TRIG_TRIG_WHEN: TriggerTimestampAttribute.ValueType  # 12365
TRIGGER_ATTRIBUTE_REF_TRIG_TIMESTAMP_VAL: TriggerTimestampAttribute.ValueType  # 12591
TRIGGER_ATTRIBUTE_ARM_START_TRIG_TRIG_WHEN: TriggerTimestampAttribute.ValueType  # 12593
TRIGGER_ATTRIBUTE_ARM_START_TRIG_TIMESTAMP_VAL: TriggerTimestampAttribute.ValueType  # 12596
TRIGGER_ATTRIBUTE_START_TRIG_TIMESTAMP_VAL: TriggerTimestampAttribute.ValueType  # 12619
global___TriggerTimestampAttribute = TriggerTimestampAttribute

class _TriggerInt32ArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerInt32ArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerInt32ArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED: _TriggerInt32ArrayAttribute.ValueType  # 0
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SLOPES: _TriggerInt32ArrayAttribute.ValueType  # 12578
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_COUPLINGS: _TriggerInt32ArrayAttribute.ValueType  # 12581
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SLOPES: _TriggerInt32ArrayAttribute.ValueType  # 12583
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_COUPLINGS: _TriggerInt32ArrayAttribute.ValueType  # 12586

class TriggerInt32ArrayAttribute(_TriggerInt32ArrayAttribute, metaclass=_TriggerInt32ArrayAttributeEnumTypeWrapper): ...

TRIGGER_INT32_ARRAY_ATTRIBUTE_UNSPECIFIED: TriggerInt32ArrayAttribute.ValueType  # 0
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_SLOPES: TriggerInt32ArrayAttribute.ValueType  # 12578
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_COUPLINGS: TriggerInt32ArrayAttribute.ValueType  # 12581
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_SLOPES: TriggerInt32ArrayAttribute.ValueType  # 12583
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_COUPLINGS: TriggerInt32ArrayAttribute.ValueType  # 12586
global___TriggerInt32ArrayAttribute = TriggerInt32ArrayAttribute

class _TriggerDoubleArrayAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerDoubleArrayAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerDoubleArrayAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: _TriggerDoubleArrayAttribute.ValueType  # 0
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_LVLS: _TriggerDoubleArrayAttribute.ValueType  # 12579
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_HYSTS: _TriggerDoubleArrayAttribute.ValueType  # 12580
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_LVLS: _TriggerDoubleArrayAttribute.ValueType  # 12584
    TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_HYSTS: _TriggerDoubleArrayAttribute.ValueType  # 12585

class TriggerDoubleArrayAttribute(_TriggerDoubleArrayAttribute, metaclass=_TriggerDoubleArrayAttributeEnumTypeWrapper): ...

TRIGGER_DOUBLE_ARRAY_ATTRIBUTE_UNSPECIFIED: TriggerDoubleArrayAttribute.ValueType  # 0
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_LVLS: TriggerDoubleArrayAttribute.ValueType  # 12579
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_START_TRIG_HYSTS: TriggerDoubleArrayAttribute.ValueType  # 12580
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_LVLS: TriggerDoubleArrayAttribute.ValueType  # 12584
TRIGGER_ATTRIBUTE_ANLG_MULTI_EDGE_REF_TRIG_HYSTS: TriggerDoubleArrayAttribute.ValueType  # 12585
global___TriggerDoubleArrayAttribute = TriggerDoubleArrayAttribute

class _WatchdogInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_INT32_ATTRIBUTE_UNSPECIFIED: _WatchdogInt32Attribute.ValueType  # 0
    WATCHDOG_ATTRIBUTE_EXPIR_TRIG_TYPE: _WatchdogInt32Attribute.ValueType  # 8611
    WATCHDOG_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_EDGE: _WatchdogInt32Attribute.ValueType  # 8613
    WATCHDOG_ATTRIBUTE_DO_EXPIR_STATE: _WatchdogInt32Attribute.ValueType  # 8615
    WATCHDOG_ATTRIBUTE_AO_OUTPUT_TYPE: _WatchdogInt32Attribute.ValueType  # 12382
    WATCHDOG_ATTRIBUTE_CO_EXPIR_STATE: _WatchdogInt32Attribute.ValueType  # 12384

class WatchdogInt32Attribute(_WatchdogInt32Attribute, metaclass=_WatchdogInt32AttributeEnumTypeWrapper): ...

WATCHDOG_INT32_ATTRIBUTE_UNSPECIFIED: WatchdogInt32Attribute.ValueType  # 0
WATCHDOG_ATTRIBUTE_EXPIR_TRIG_TYPE: WatchdogInt32Attribute.ValueType  # 8611
WATCHDOG_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_EDGE: WatchdogInt32Attribute.ValueType  # 8613
WATCHDOG_ATTRIBUTE_DO_EXPIR_STATE: WatchdogInt32Attribute.ValueType  # 8615
WATCHDOG_ATTRIBUTE_AO_OUTPUT_TYPE: WatchdogInt32Attribute.ValueType  # 12382
WATCHDOG_ATTRIBUTE_CO_EXPIR_STATE: WatchdogInt32Attribute.ValueType  # 12384
global___WatchdogInt32Attribute = WatchdogInt32Attribute

class _WatchdogResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_RESET_ATTRIBUTE_UNSPECIFIED: _WatchdogResetAttribute.ValueType  # 0
    WATCHDOG_RESET_ATTRIBUTE_EXPIR_TRIG_TYPE: _WatchdogResetAttribute.ValueType  # 8611
    WATCHDOG_RESET_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_SRC: _WatchdogResetAttribute.ValueType  # 8612
    WATCHDOG_RESET_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_EDGE: _WatchdogResetAttribute.ValueType  # 8613
    WATCHDOG_RESET_ATTRIBUTE_DO_EXPIR_STATE: _WatchdogResetAttribute.ValueType  # 8615
    WATCHDOG_RESET_ATTRIBUTE_TIMEOUT: _WatchdogResetAttribute.ValueType  # 8617
    WATCHDOG_RESET_ATTRIBUTE_EXPIR_TRIG_TRIG_ON_NETWORK_CONN_LOSS: _WatchdogResetAttribute.ValueType  # 12381
    WATCHDOG_RESET_ATTRIBUTE_AO_OUTPUT_TYPE: _WatchdogResetAttribute.ValueType  # 12382
    WATCHDOG_RESET_ATTRIBUTE_AO_EXPIR_STATE: _WatchdogResetAttribute.ValueType  # 12383
    WATCHDOG_RESET_ATTRIBUTE_CO_EXPIR_STATE: _WatchdogResetAttribute.ValueType  # 12384

class WatchdogResetAttribute(_WatchdogResetAttribute, metaclass=_WatchdogResetAttributeEnumTypeWrapper): ...

WATCHDOG_RESET_ATTRIBUTE_UNSPECIFIED: WatchdogResetAttribute.ValueType  # 0
WATCHDOG_RESET_ATTRIBUTE_EXPIR_TRIG_TYPE: WatchdogResetAttribute.ValueType  # 8611
WATCHDOG_RESET_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_SRC: WatchdogResetAttribute.ValueType  # 8612
WATCHDOG_RESET_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_EDGE: WatchdogResetAttribute.ValueType  # 8613
WATCHDOG_RESET_ATTRIBUTE_DO_EXPIR_STATE: WatchdogResetAttribute.ValueType  # 8615
WATCHDOG_RESET_ATTRIBUTE_TIMEOUT: WatchdogResetAttribute.ValueType  # 8617
WATCHDOG_RESET_ATTRIBUTE_EXPIR_TRIG_TRIG_ON_NETWORK_CONN_LOSS: WatchdogResetAttribute.ValueType  # 12381
WATCHDOG_RESET_ATTRIBUTE_AO_OUTPUT_TYPE: WatchdogResetAttribute.ValueType  # 12382
WATCHDOG_RESET_ATTRIBUTE_AO_EXPIR_STATE: WatchdogResetAttribute.ValueType  # 12383
WATCHDOG_RESET_ATTRIBUTE_CO_EXPIR_STATE: WatchdogResetAttribute.ValueType  # 12384
global___WatchdogResetAttribute = WatchdogResetAttribute

class _WatchdogStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_STRING_ATTRIBUTE_UNSPECIFIED: _WatchdogStringAttribute.ValueType  # 0
    WATCHDOG_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_SRC: _WatchdogStringAttribute.ValueType  # 8612

class WatchdogStringAttribute(_WatchdogStringAttribute, metaclass=_WatchdogStringAttributeEnumTypeWrapper): ...

WATCHDOG_STRING_ATTRIBUTE_UNSPECIFIED: WatchdogStringAttribute.ValueType  # 0
WATCHDOG_ATTRIBUTE_DIG_EDGE_WATCHDOG_EXPIR_TRIG_SRC: WatchdogStringAttribute.ValueType  # 8612
global___WatchdogStringAttribute = WatchdogStringAttribute

class _WatchdogBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_BOOL_ATTRIBUTE_UNSPECIFIED: _WatchdogBoolAttribute.ValueType  # 0
    WATCHDOG_ATTRIBUTE_HAS_EXPIRED: _WatchdogBoolAttribute.ValueType  # 8616
    WATCHDOG_ATTRIBUTE_EXPIR_TRIG_TRIG_ON_NETWORK_CONN_LOSS: _WatchdogBoolAttribute.ValueType  # 12381

class WatchdogBoolAttribute(_WatchdogBoolAttribute, metaclass=_WatchdogBoolAttributeEnumTypeWrapper): ...

WATCHDOG_BOOL_ATTRIBUTE_UNSPECIFIED: WatchdogBoolAttribute.ValueType  # 0
WATCHDOG_ATTRIBUTE_HAS_EXPIRED: WatchdogBoolAttribute.ValueType  # 8616
WATCHDOG_ATTRIBUTE_EXPIR_TRIG_TRIG_ON_NETWORK_CONN_LOSS: WatchdogBoolAttribute.ValueType  # 12381
global___WatchdogBoolAttribute = WatchdogBoolAttribute

class _WatchdogDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_DOUBLE_ATTRIBUTE_UNSPECIFIED: _WatchdogDoubleAttribute.ValueType  # 0
    WATCHDOG_ATTRIBUTE_TIMEOUT: _WatchdogDoubleAttribute.ValueType  # 8617
    WATCHDOG_ATTRIBUTE_AO_EXPIR_STATE: _WatchdogDoubleAttribute.ValueType  # 12383

class WatchdogDoubleAttribute(_WatchdogDoubleAttribute, metaclass=_WatchdogDoubleAttributeEnumTypeWrapper): ...

WATCHDOG_DOUBLE_ATTRIBUTE_UNSPECIFIED: WatchdogDoubleAttribute.ValueType  # 0
WATCHDOG_ATTRIBUTE_TIMEOUT: WatchdogDoubleAttribute.ValueType  # 8617
WATCHDOG_ATTRIBUTE_AO_EXPIR_STATE: WatchdogDoubleAttribute.ValueType  # 12383
global___WatchdogDoubleAttribute = WatchdogDoubleAttribute

class _WriteInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_INT32_ATTRIBUTE_UNSPECIFIED: _WriteInt32Attribute.ValueType  # 0
    WRITE_ATTRIBUTE_REGEN_MODE: _WriteInt32Attribute.ValueType  # 5203
    WRITE_ATTRIBUTE_RELATIVE_TO: _WriteInt32Attribute.ValueType  # 6412
    WRITE_ATTRIBUTE_OFFSET: _WriteInt32Attribute.ValueType  # 6413
    WRITE_ATTRIBUTE_WAIT_MODE: _WriteInt32Attribute.ValueType  # 8881

class WriteInt32Attribute(_WriteInt32Attribute, metaclass=_WriteInt32AttributeEnumTypeWrapper): ...

WRITE_INT32_ATTRIBUTE_UNSPECIFIED: WriteInt32Attribute.ValueType  # 0
WRITE_ATTRIBUTE_REGEN_MODE: WriteInt32Attribute.ValueType  # 5203
WRITE_ATTRIBUTE_RELATIVE_TO: WriteInt32Attribute.ValueType  # 6412
WRITE_ATTRIBUTE_OFFSET: WriteInt32Attribute.ValueType  # 6413
WRITE_ATTRIBUTE_WAIT_MODE: WriteInt32Attribute.ValueType  # 8881
global___WriteInt32Attribute = WriteInt32Attribute

class _WriteResetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteResetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteResetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_RESET_ATTRIBUTE_UNSPECIFIED: _WriteResetAttribute.ValueType  # 0
    WRITE_RESET_ATTRIBUTE_REGEN_MODE: _WriteResetAttribute.ValueType  # 5203
    WRITE_RESET_ATTRIBUTE_RELATIVE_TO: _WriteResetAttribute.ValueType  # 6412
    WRITE_RESET_ATTRIBUTE_OFFSET: _WriteResetAttribute.ValueType  # 6413
    WRITE_RESET_ATTRIBUTE_WAIT_MODE: _WriteResetAttribute.ValueType  # 8881
    WRITE_RESET_ATTRIBUTE_SLEEP_TIME: _WriteResetAttribute.ValueType  # 8882
    WRITE_RESET_ATTRIBUTE_NEXT_WRITE_IS_LAST: _WriteResetAttribute.ValueType  # 10604

class WriteResetAttribute(_WriteResetAttribute, metaclass=_WriteResetAttributeEnumTypeWrapper): ...

WRITE_RESET_ATTRIBUTE_UNSPECIFIED: WriteResetAttribute.ValueType  # 0
WRITE_RESET_ATTRIBUTE_REGEN_MODE: WriteResetAttribute.ValueType  # 5203
WRITE_RESET_ATTRIBUTE_RELATIVE_TO: WriteResetAttribute.ValueType  # 6412
WRITE_RESET_ATTRIBUTE_OFFSET: WriteResetAttribute.ValueType  # 6413
WRITE_RESET_ATTRIBUTE_WAIT_MODE: WriteResetAttribute.ValueType  # 8881
WRITE_RESET_ATTRIBUTE_SLEEP_TIME: WriteResetAttribute.ValueType  # 8882
WRITE_RESET_ATTRIBUTE_NEXT_WRITE_IS_LAST: WriteResetAttribute.ValueType  # 10604
global___WriteResetAttribute = WriteResetAttribute

class _WriteUInt64Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteUInt64AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteUInt64Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_UINT64_ATTRIBUTE_UNSPECIFIED: _WriteUInt64Attribute.ValueType  # 0
    WRITE_ATTRIBUTE_CURR_WRITE_POS: _WriteUInt64Attribute.ValueType  # 5208
    WRITE_ATTRIBUTE_TOTAL_SAMP_PER_CHAN_GENERATED: _WriteUInt64Attribute.ValueType  # 6443

class WriteUInt64Attribute(_WriteUInt64Attribute, metaclass=_WriteUInt64AttributeEnumTypeWrapper): ...

WRITE_UINT64_ATTRIBUTE_UNSPECIFIED: WriteUInt64Attribute.ValueType  # 0
WRITE_ATTRIBUTE_CURR_WRITE_POS: WriteUInt64Attribute.ValueType  # 5208
WRITE_ATTRIBUTE_TOTAL_SAMP_PER_CHAN_GENERATED: WriteUInt64Attribute.ValueType  # 6443
global___WriteUInt64Attribute = WriteUInt64Attribute

class _WriteUInt32Attribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteUInt32AttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteUInt32Attribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_UINT32_ATTRIBUTE_UNSPECIFIED: _WriteUInt32Attribute.ValueType  # 0
    WRITE_ATTRIBUTE_SPACE_AVAIL: _WriteUInt32Attribute.ValueType  # 5216
    WRITE_ATTRIBUTE_RAW_DATA_WIDTH: _WriteUInt32Attribute.ValueType  # 8573
    WRITE_ATTRIBUTE_NUM_CHANS: _WriteUInt32Attribute.ValueType  # 8574
    WRITE_ATTRIBUTE_DIGITAL_LINES_BYTES_PER_CHAN: _WriteUInt32Attribute.ValueType  # 8575

class WriteUInt32Attribute(_WriteUInt32Attribute, metaclass=_WriteUInt32AttributeEnumTypeWrapper): ...

WRITE_UINT32_ATTRIBUTE_UNSPECIFIED: WriteUInt32Attribute.ValueType  # 0
WRITE_ATTRIBUTE_SPACE_AVAIL: WriteUInt32Attribute.ValueType  # 5216
WRITE_ATTRIBUTE_RAW_DATA_WIDTH: WriteUInt32Attribute.ValueType  # 8573
WRITE_ATTRIBUTE_NUM_CHANS: WriteUInt32Attribute.ValueType  # 8574
WRITE_ATTRIBUTE_DIGITAL_LINES_BYTES_PER_CHAN: WriteUInt32Attribute.ValueType  # 8575
global___WriteUInt32Attribute = WriteUInt32Attribute

class _WriteDoubleAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteDoubleAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteDoubleAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_DOUBLE_ATTRIBUTE_UNSPECIFIED: _WriteDoubleAttribute.ValueType  # 0
    WRITE_ATTRIBUTE_SLEEP_TIME: _WriteDoubleAttribute.ValueType  # 8882

class WriteDoubleAttribute(_WriteDoubleAttribute, metaclass=_WriteDoubleAttributeEnumTypeWrapper): ...

WRITE_DOUBLE_ATTRIBUTE_UNSPECIFIED: WriteDoubleAttribute.ValueType  # 0
WRITE_ATTRIBUTE_SLEEP_TIME: WriteDoubleAttribute.ValueType  # 8882
global___WriteDoubleAttribute = WriteDoubleAttribute

class _WriteBoolAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteBoolAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteBoolAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_BOOL_ATTRIBUTE_UNSPECIFIED: _WriteBoolAttribute.ValueType  # 0
    WRITE_ATTRIBUTE_NEXT_WRITE_IS_LAST: _WriteBoolAttribute.ValueType  # 10604
    WRITE_ATTRIBUTE_OVERCURRENT_CHANS_EXIST: _WriteBoolAttribute.ValueType  # 10728
    WRITE_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS_EXIST: _WriteBoolAttribute.ValueType  # 10730
    WRITE_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS_EXIST: _WriteBoolAttribute.ValueType  # 10732
    WRITE_ATTRIBUTE_OVERTEMPERATURE_CHANS_EXIST: _WriteBoolAttribute.ValueType  # 10884
    WRITE_ATTRIBUTE_ACCESSORY_INSERTION_OR_REMOVAL_DETECTED: _WriteBoolAttribute.ValueType  # 12371
    WRITE_ATTRIBUTE_OVERLOADED_CHANS_EXIST: _WriteBoolAttribute.ValueType  # 12420
    WRITE_ATTRIBUTE_EXTERNAL_OVERVOLTAGE_CHANS_EXIST: _WriteBoolAttribute.ValueType  # 12475
    WRITE_ATTRIBUTE_SYNC_UNLOCKED_CHANS_EXIST: _WriteBoolAttribute.ValueType  # 12607

class WriteBoolAttribute(_WriteBoolAttribute, metaclass=_WriteBoolAttributeEnumTypeWrapper): ...

WRITE_BOOL_ATTRIBUTE_UNSPECIFIED: WriteBoolAttribute.ValueType  # 0
WRITE_ATTRIBUTE_NEXT_WRITE_IS_LAST: WriteBoolAttribute.ValueType  # 10604
WRITE_ATTRIBUTE_OVERCURRENT_CHANS_EXIST: WriteBoolAttribute.ValueType  # 10728
WRITE_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS_EXIST: WriteBoolAttribute.ValueType  # 10730
WRITE_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS_EXIST: WriteBoolAttribute.ValueType  # 10732
WRITE_ATTRIBUTE_OVERTEMPERATURE_CHANS_EXIST: WriteBoolAttribute.ValueType  # 10884
WRITE_ATTRIBUTE_ACCESSORY_INSERTION_OR_REMOVAL_DETECTED: WriteBoolAttribute.ValueType  # 12371
WRITE_ATTRIBUTE_OVERLOADED_CHANS_EXIST: WriteBoolAttribute.ValueType  # 12420
WRITE_ATTRIBUTE_EXTERNAL_OVERVOLTAGE_CHANS_EXIST: WriteBoolAttribute.ValueType  # 12475
WRITE_ATTRIBUTE_SYNC_UNLOCKED_CHANS_EXIST: WriteBoolAttribute.ValueType  # 12607
global___WriteBoolAttribute = WriteBoolAttribute

class _WriteStringAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteStringAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteStringAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_STRING_ATTRIBUTE_UNSPECIFIED: _WriteStringAttribute.ValueType  # 0
    WRITE_ATTRIBUTE_OVERCURRENT_CHANS: _WriteStringAttribute.ValueType  # 10729
    WRITE_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS: _WriteStringAttribute.ValueType  # 10731
    WRITE_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS: _WriteStringAttribute.ValueType  # 10733
    WRITE_ATTRIBUTE_DEVS_WITH_INSERTED_OR_REMOVED_ACCESSORIES: _WriteStringAttribute.ValueType  # 12372
    WRITE_ATTRIBUTE_OVERTEMPERATURE_CHANS: _WriteStringAttribute.ValueType  # 12419
    WRITE_ATTRIBUTE_OVERLOADED_CHANS: _WriteStringAttribute.ValueType  # 12421
    WRITE_ATTRIBUTE_EXTERNAL_OVERVOLTAGE_CHANS: _WriteStringAttribute.ValueType  # 12476
    WRITE_ATTRIBUTE_SYNC_UNLOCKED_CHANS: _WriteStringAttribute.ValueType  # 12608

class WriteStringAttribute(_WriteStringAttribute, metaclass=_WriteStringAttributeEnumTypeWrapper): ...

WRITE_STRING_ATTRIBUTE_UNSPECIFIED: WriteStringAttribute.ValueType  # 0
WRITE_ATTRIBUTE_OVERCURRENT_CHANS: WriteStringAttribute.ValueType  # 10729
WRITE_ATTRIBUTE_OPEN_CURRENT_LOOP_CHANS: WriteStringAttribute.ValueType  # 10731
WRITE_ATTRIBUTE_POWER_SUPPLY_FAULT_CHANS: WriteStringAttribute.ValueType  # 10733
WRITE_ATTRIBUTE_DEVS_WITH_INSERTED_OR_REMOVED_ACCESSORIES: WriteStringAttribute.ValueType  # 12372
WRITE_ATTRIBUTE_OVERTEMPERATURE_CHANS: WriteStringAttribute.ValueType  # 12419
WRITE_ATTRIBUTE_OVERLOADED_CHANS: WriteStringAttribute.ValueType  # 12421
WRITE_ATTRIBUTE_EXTERNAL_OVERVOLTAGE_CHANS: WriteStringAttribute.ValueType  # 12476
WRITE_ATTRIBUTE_SYNC_UNLOCKED_CHANS: WriteStringAttribute.ValueType  # 12608
global___WriteStringAttribute = WriteStringAttribute

class _ACExcitWireMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ACExcitWireModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ACExcitWireMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AC_EXCIT_WIRE_MODE_UNSPECIFIED: _ACExcitWireMode.ValueType  # 0
    AC_EXCIT_WIRE_MODE_4_WIRE: _ACExcitWireMode.ValueType  # 4
    AC_EXCIT_WIRE_MODE_5_WIRE: _ACExcitWireMode.ValueType  # 5
    AC_EXCIT_WIRE_MODE_6_WIRE: _ACExcitWireMode.ValueType  # 6

class ACExcitWireMode(_ACExcitWireMode, metaclass=_ACExcitWireModeEnumTypeWrapper): ...

AC_EXCIT_WIRE_MODE_UNSPECIFIED: ACExcitWireMode.ValueType  # 0
AC_EXCIT_WIRE_MODE_4_WIRE: ACExcitWireMode.ValueType  # 4
AC_EXCIT_WIRE_MODE_5_WIRE: ACExcitWireMode.ValueType  # 5
AC_EXCIT_WIRE_MODE_6_WIRE: ACExcitWireMode.ValueType  # 6
global___ACExcitWireMode = ACExcitWireMode

class _AccelChargeSensitivityUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AccelChargeSensitivityUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AccelChargeSensitivityUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACCEL_CHARGE_SENSITIVITY_UNITS_UNSPECIFIED: _AccelChargeSensitivityUnits.ValueType  # 0
    ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_G: _AccelChargeSensitivityUnits.ValueType  # 16099
    ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_METERS_PER_SECOND_SQUARED: _AccelChargeSensitivityUnits.ValueType  # 16100
    ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_INCHES_PER_SECOND_SQUARED: _AccelChargeSensitivityUnits.ValueType  # 16101

class AccelChargeSensitivityUnits(_AccelChargeSensitivityUnits, metaclass=_AccelChargeSensitivityUnitsEnumTypeWrapper): ...

ACCEL_CHARGE_SENSITIVITY_UNITS_UNSPECIFIED: AccelChargeSensitivityUnits.ValueType  # 0
ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_G: AccelChargeSensitivityUnits.ValueType  # 16099
ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_METERS_PER_SECOND_SQUARED: AccelChargeSensitivityUnits.ValueType  # 16100
ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_INCHES_PER_SECOND_SQUARED: AccelChargeSensitivityUnits.ValueType  # 16101
global___AccelChargeSensitivityUnits = AccelChargeSensitivityUnits

class _AccelSensitivityUnits1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AccelSensitivityUnits1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AccelSensitivityUnits1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACCEL_SENSITIVITY_UNITS1_UNSPECIFIED: _AccelSensitivityUnits1.ValueType  # 0
    ACCEL_SENSITIVITY_UNITS1_M_VOLTS_PER_G: _AccelSensitivityUnits1.ValueType  # 12509
    ACCEL_SENSITIVITY_UNITS1_VOLTS_PER_G: _AccelSensitivityUnits1.ValueType  # 12510

class AccelSensitivityUnits1(_AccelSensitivityUnits1, metaclass=_AccelSensitivityUnits1EnumTypeWrapper): ...

ACCEL_SENSITIVITY_UNITS1_UNSPECIFIED: AccelSensitivityUnits1.ValueType  # 0
ACCEL_SENSITIVITY_UNITS1_M_VOLTS_PER_G: AccelSensitivityUnits1.ValueType  # 12509
ACCEL_SENSITIVITY_UNITS1_VOLTS_PER_G: AccelSensitivityUnits1.ValueType  # 12510
global___AccelSensitivityUnits1 = AccelSensitivityUnits1

class _AccelUnits2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AccelUnits2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AccelUnits2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACCEL_UNITS2_UNSPECIFIED: _AccelUnits2.ValueType  # 0
    ACCEL_UNITS2_ACCEL_UNIT_G: _AccelUnits2.ValueType  # 10186
    ACCEL_UNITS2_METERS_PER_SECOND_SQUARED: _AccelUnits2.ValueType  # 12470
    ACCEL_UNITS2_INCHES_PER_SECOND_SQUARED: _AccelUnits2.ValueType  # 12471
    ACCEL_UNITS2_FROM_CUSTOM_SCALE: _AccelUnits2.ValueType  # 10065

class AccelUnits2(_AccelUnits2, metaclass=_AccelUnits2EnumTypeWrapper): ...

ACCEL_UNITS2_UNSPECIFIED: AccelUnits2.ValueType  # 0
ACCEL_UNITS2_ACCEL_UNIT_G: AccelUnits2.ValueType  # 10186
ACCEL_UNITS2_METERS_PER_SECOND_SQUARED: AccelUnits2.ValueType  # 12470
ACCEL_UNITS2_INCHES_PER_SECOND_SQUARED: AccelUnits2.ValueType  # 12471
ACCEL_UNITS2_FROM_CUSTOM_SCALE: AccelUnits2.ValueType  # 10065
global___AccelUnits2 = AccelUnits2

class _AcquisitionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AcquisitionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AcquisitionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACQUISITION_TYPE_UNSPECIFIED: _AcquisitionType.ValueType  # 0
    ACQUISITION_TYPE_FINITE_SAMPS: _AcquisitionType.ValueType  # 10178
    ACQUISITION_TYPE_CONT_SAMPS: _AcquisitionType.ValueType  # 10123
    ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT: _AcquisitionType.ValueType  # 12522

class AcquisitionType(_AcquisitionType, metaclass=_AcquisitionTypeEnumTypeWrapper): ...

ACQUISITION_TYPE_UNSPECIFIED: AcquisitionType.ValueType  # 0
ACQUISITION_TYPE_FINITE_SAMPS: AcquisitionType.ValueType  # 10178
ACQUISITION_TYPE_CONT_SAMPS: AcquisitionType.ValueType  # 10123
ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT: AcquisitionType.ValueType  # 12522
global___AcquisitionType = AcquisitionType

class _AngleUnits1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AngleUnits1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AngleUnits1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ANGLE_UNITS1_UNSPECIFIED: _AngleUnits1.ValueType  # 0
    ANGLE_UNITS1_DEGREES: _AngleUnits1.ValueType  # 10146
    ANGLE_UNITS1_RADIANS: _AngleUnits1.ValueType  # 10273
    ANGLE_UNITS1_FROM_CUSTOM_SCALE: _AngleUnits1.ValueType  # 10065

class AngleUnits1(_AngleUnits1, metaclass=_AngleUnits1EnumTypeWrapper): ...

ANGLE_UNITS1_UNSPECIFIED: AngleUnits1.ValueType  # 0
ANGLE_UNITS1_DEGREES: AngleUnits1.ValueType  # 10146
ANGLE_UNITS1_RADIANS: AngleUnits1.ValueType  # 10273
ANGLE_UNITS1_FROM_CUSTOM_SCALE: AngleUnits1.ValueType  # 10065
global___AngleUnits1 = AngleUnits1

class _AngleUnits2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AngleUnits2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AngleUnits2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ANGLE_UNITS2_UNSPECIFIED: _AngleUnits2.ValueType  # 0
    ANGLE_UNITS2_DEGREES: _AngleUnits2.ValueType  # 10146
    ANGLE_UNITS2_RADIANS: _AngleUnits2.ValueType  # 10273
    ANGLE_UNITS2_TICKS: _AngleUnits2.ValueType  # 10304
    ANGLE_UNITS2_FROM_CUSTOM_SCALE: _AngleUnits2.ValueType  # 10065

class AngleUnits2(_AngleUnits2, metaclass=_AngleUnits2EnumTypeWrapper): ...

ANGLE_UNITS2_UNSPECIFIED: AngleUnits2.ValueType  # 0
ANGLE_UNITS2_DEGREES: AngleUnits2.ValueType  # 10146
ANGLE_UNITS2_RADIANS: AngleUnits2.ValueType  # 10273
ANGLE_UNITS2_TICKS: AngleUnits2.ValueType  # 10304
ANGLE_UNITS2_FROM_CUSTOM_SCALE: AngleUnits2.ValueType  # 10065
global___AngleUnits2 = AngleUnits2

class _AngularVelocityUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AngularVelocityUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AngularVelocityUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ANGULAR_VELOCITY_UNITS_UNSPECIFIED: _AngularVelocityUnits.ValueType  # 0
    ANGULAR_VELOCITY_UNITS_RPM: _AngularVelocityUnits.ValueType  # 16080
    ANGULAR_VELOCITY_UNITS_RADIANS_PER_SECOND: _AngularVelocityUnits.ValueType  # 16081
    ANGULAR_VELOCITY_UNITS_DEGREES_PER_SECOND: _AngularVelocityUnits.ValueType  # 16082
    ANGULAR_VELOCITY_UNITS_FROM_CUSTOM_SCALE: _AngularVelocityUnits.ValueType  # 10065

class AngularVelocityUnits(_AngularVelocityUnits, metaclass=_AngularVelocityUnitsEnumTypeWrapper): ...

ANGULAR_VELOCITY_UNITS_UNSPECIFIED: AngularVelocityUnits.ValueType  # 0
ANGULAR_VELOCITY_UNITS_RPM: AngularVelocityUnits.ValueType  # 16080
ANGULAR_VELOCITY_UNITS_RADIANS_PER_SECOND: AngularVelocityUnits.ValueType  # 16081
ANGULAR_VELOCITY_UNITS_DEGREES_PER_SECOND: AngularVelocityUnits.ValueType  # 16082
ANGULAR_VELOCITY_UNITS_FROM_CUSTOM_SCALE: AngularVelocityUnits.ValueType  # 10065
global___AngularVelocityUnits = AngularVelocityUnits

class _BridgeConfiguration1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BridgeConfiguration1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BridgeConfiguration1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BRIDGE_CONFIGURATION1_UNSPECIFIED: _BridgeConfiguration1.ValueType  # 0
    BRIDGE_CONFIGURATION1_FULL_BRIDGE: _BridgeConfiguration1.ValueType  # 10182
    BRIDGE_CONFIGURATION1_HALF_BRIDGE: _BridgeConfiguration1.ValueType  # 10187
    BRIDGE_CONFIGURATION1_QUARTER_BRIDGE: _BridgeConfiguration1.ValueType  # 10270
    BRIDGE_CONFIGURATION1_NO_BRIDGE: _BridgeConfiguration1.ValueType  # 10228

class BridgeConfiguration1(_BridgeConfiguration1, metaclass=_BridgeConfiguration1EnumTypeWrapper): ...

BRIDGE_CONFIGURATION1_UNSPECIFIED: BridgeConfiguration1.ValueType  # 0
BRIDGE_CONFIGURATION1_FULL_BRIDGE: BridgeConfiguration1.ValueType  # 10182
BRIDGE_CONFIGURATION1_HALF_BRIDGE: BridgeConfiguration1.ValueType  # 10187
BRIDGE_CONFIGURATION1_QUARTER_BRIDGE: BridgeConfiguration1.ValueType  # 10270
BRIDGE_CONFIGURATION1_NO_BRIDGE: BridgeConfiguration1.ValueType  # 10228
global___BridgeConfiguration1 = BridgeConfiguration1

class _BridgeElectricalUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BridgeElectricalUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BridgeElectricalUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BRIDGE_ELECTRICAL_UNITS_UNSPECIFIED: _BridgeElectricalUnits.ValueType  # 0
    BRIDGE_ELECTRICAL_UNITS_VOLTS_PER_VOLT: _BridgeElectricalUnits.ValueType  # 15896
    BRIDGE_ELECTRICAL_UNITS_M_VOLTS_PER_VOLT: _BridgeElectricalUnits.ValueType  # 15897

class BridgeElectricalUnits(_BridgeElectricalUnits, metaclass=_BridgeElectricalUnitsEnumTypeWrapper): ...

BRIDGE_ELECTRICAL_UNITS_UNSPECIFIED: BridgeElectricalUnits.ValueType  # 0
BRIDGE_ELECTRICAL_UNITS_VOLTS_PER_VOLT: BridgeElectricalUnits.ValueType  # 15896
BRIDGE_ELECTRICAL_UNITS_M_VOLTS_PER_VOLT: BridgeElectricalUnits.ValueType  # 15897
global___BridgeElectricalUnits = BridgeElectricalUnits

class _BridgePhysicalUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BridgePhysicalUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BridgePhysicalUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BRIDGE_PHYSICAL_UNITS_UNSPECIFIED: _BridgePhysicalUnits.ValueType  # 0
    BRIDGE_PHYSICAL_UNITS_NEWTONS: _BridgePhysicalUnits.ValueType  # 15875
    BRIDGE_PHYSICAL_UNITS_POUNDS: _BridgePhysicalUnits.ValueType  # 15876
    BRIDGE_PHYSICAL_UNITS_KILOGRAM_FORCE: _BridgePhysicalUnits.ValueType  # 15877
    BRIDGE_PHYSICAL_UNITS_PASCALS: _BridgePhysicalUnits.ValueType  # 10081
    BRIDGE_PHYSICAL_UNITS_POUNDS_PER_SQUARE_INCH: _BridgePhysicalUnits.ValueType  # 15879
    BRIDGE_PHYSICAL_UNITS_BAR: _BridgePhysicalUnits.ValueType  # 15880
    BRIDGE_PHYSICAL_UNITS_NEWTON_METERS: _BridgePhysicalUnits.ValueType  # 15881
    BRIDGE_PHYSICAL_UNITS_INCH_OUNCES: _BridgePhysicalUnits.ValueType  # 15882
    BRIDGE_PHYSICAL_UNITS_INCH_POUNDS: _BridgePhysicalUnits.ValueType  # 15883
    BRIDGE_PHYSICAL_UNITS_FOOT_POUNDS: _BridgePhysicalUnits.ValueType  # 15884

class BridgePhysicalUnits(_BridgePhysicalUnits, metaclass=_BridgePhysicalUnitsEnumTypeWrapper): ...

BRIDGE_PHYSICAL_UNITS_UNSPECIFIED: BridgePhysicalUnits.ValueType  # 0
BRIDGE_PHYSICAL_UNITS_NEWTONS: BridgePhysicalUnits.ValueType  # 15875
BRIDGE_PHYSICAL_UNITS_POUNDS: BridgePhysicalUnits.ValueType  # 15876
BRIDGE_PHYSICAL_UNITS_KILOGRAM_FORCE: BridgePhysicalUnits.ValueType  # 15877
BRIDGE_PHYSICAL_UNITS_PASCALS: BridgePhysicalUnits.ValueType  # 10081
BRIDGE_PHYSICAL_UNITS_POUNDS_PER_SQUARE_INCH: BridgePhysicalUnits.ValueType  # 15879
BRIDGE_PHYSICAL_UNITS_BAR: BridgePhysicalUnits.ValueType  # 15880
BRIDGE_PHYSICAL_UNITS_NEWTON_METERS: BridgePhysicalUnits.ValueType  # 15881
BRIDGE_PHYSICAL_UNITS_INCH_OUNCES: BridgePhysicalUnits.ValueType  # 15882
BRIDGE_PHYSICAL_UNITS_INCH_POUNDS: BridgePhysicalUnits.ValueType  # 15883
BRIDGE_PHYSICAL_UNITS_FOOT_POUNDS: BridgePhysicalUnits.ValueType  # 15884
global___BridgePhysicalUnits = BridgePhysicalUnits

class _BridgeUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BridgeUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BridgeUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BRIDGE_UNITS_UNSPECIFIED: _BridgeUnits.ValueType  # 0
    BRIDGE_UNITS_VOLTS_PER_VOLT: _BridgeUnits.ValueType  # 15896
    BRIDGE_UNITS_M_VOLTS_PER_VOLT: _BridgeUnits.ValueType  # 15897
    BRIDGE_UNITS_FROM_CUSTOM_SCALE: _BridgeUnits.ValueType  # 10065
    BRIDGE_UNITS_FROM_TEDS: _BridgeUnits.ValueType  # 12516

class BridgeUnits(_BridgeUnits, metaclass=_BridgeUnitsEnumTypeWrapper): ...

BRIDGE_UNITS_UNSPECIFIED: BridgeUnits.ValueType  # 0
BRIDGE_UNITS_VOLTS_PER_VOLT: BridgeUnits.ValueType  # 15896
BRIDGE_UNITS_M_VOLTS_PER_VOLT: BridgeUnits.ValueType  # 15897
BRIDGE_UNITS_FROM_CUSTOM_SCALE: BridgeUnits.ValueType  # 10065
BRIDGE_UNITS_FROM_TEDS: BridgeUnits.ValueType  # 12516
global___BridgeUnits = BridgeUnits

class _CJCSource1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CJCSource1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CJCSource1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CJC_SOURCE1_UNSPECIFIED: _CJCSource1.ValueType  # 0
    CJC_SOURCE1_BUILT_IN: _CJCSource1.ValueType  # 10200
    CJC_SOURCE1_CONST_VAL: _CJCSource1.ValueType  # 10116
    CJC_SOURCE1_CHAN: _CJCSource1.ValueType  # 10113

class CJCSource1(_CJCSource1, metaclass=_CJCSource1EnumTypeWrapper): ...

CJC_SOURCE1_UNSPECIFIED: CJCSource1.ValueType  # 0
CJC_SOURCE1_BUILT_IN: CJCSource1.ValueType  # 10200
CJC_SOURCE1_CONST_VAL: CJCSource1.ValueType  # 10116
CJC_SOURCE1_CHAN: CJCSource1.ValueType  # 10113
global___CJCSource1 = CJCSource1

class _ChargeUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChargeUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChargeUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHARGE_UNITS_UNSPECIFIED: _ChargeUnits.ValueType  # 0
    CHARGE_UNITS_COULOMBS: _ChargeUnits.ValueType  # 16102
    CHARGE_UNITS_PICO_COULOMBS: _ChargeUnits.ValueType  # 16103
    CHARGE_UNITS_FROM_CUSTOM_SCALE: _ChargeUnits.ValueType  # 10065

class ChargeUnits(_ChargeUnits, metaclass=_ChargeUnitsEnumTypeWrapper): ...

CHARGE_UNITS_UNSPECIFIED: ChargeUnits.ValueType  # 0
CHARGE_UNITS_COULOMBS: ChargeUnits.ValueType  # 16102
CHARGE_UNITS_PICO_COULOMBS: ChargeUnits.ValueType  # 16103
CHARGE_UNITS_FROM_CUSTOM_SCALE: ChargeUnits.ValueType  # 10065
global___ChargeUnits = ChargeUnits

class _CountDirection1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CountDirection1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CountDirection1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COUNT_DIRECTION1_UNSPECIFIED: _CountDirection1.ValueType  # 0
    COUNT_DIRECTION1_COUNT_UP: _CountDirection1.ValueType  # 10128
    COUNT_DIRECTION1_COUNT_DOWN: _CountDirection1.ValueType  # 10124
    COUNT_DIRECTION1_EXT_CONTROLLED: _CountDirection1.ValueType  # 10326

class CountDirection1(_CountDirection1, metaclass=_CountDirection1EnumTypeWrapper): ...

COUNT_DIRECTION1_UNSPECIFIED: CountDirection1.ValueType  # 0
COUNT_DIRECTION1_COUNT_UP: CountDirection1.ValueType  # 10128
COUNT_DIRECTION1_COUNT_DOWN: CountDirection1.ValueType  # 10124
COUNT_DIRECTION1_EXT_CONTROLLED: CountDirection1.ValueType  # 10326
global___CountDirection1 = CountDirection1

class _CounterFrequencyMethod:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CounterFrequencyMethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CounterFrequencyMethod.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COUNTER_FREQUENCY_METHOD_UNSPECIFIED: _CounterFrequencyMethod.ValueType  # 0
    COUNTER_FREQUENCY_METHOD_LOW_FREQ_1_CTR: _CounterFrequencyMethod.ValueType  # 10105
    COUNTER_FREQUENCY_METHOD_HIGH_FREQ_2_CTR: _CounterFrequencyMethod.ValueType  # 10157
    COUNTER_FREQUENCY_METHOD_LARGE_RNG_2_CTR: _CounterFrequencyMethod.ValueType  # 10205
    COUNTER_FREQUENCY_METHOD_DYN_AVG: _CounterFrequencyMethod.ValueType  # 16065

class CounterFrequencyMethod(_CounterFrequencyMethod, metaclass=_CounterFrequencyMethodEnumTypeWrapper): ...

COUNTER_FREQUENCY_METHOD_UNSPECIFIED: CounterFrequencyMethod.ValueType  # 0
COUNTER_FREQUENCY_METHOD_LOW_FREQ_1_CTR: CounterFrequencyMethod.ValueType  # 10105
COUNTER_FREQUENCY_METHOD_HIGH_FREQ_2_CTR: CounterFrequencyMethod.ValueType  # 10157
COUNTER_FREQUENCY_METHOD_LARGE_RNG_2_CTR: CounterFrequencyMethod.ValueType  # 10205
COUNTER_FREQUENCY_METHOD_DYN_AVG: CounterFrequencyMethod.ValueType  # 16065
global___CounterFrequencyMethod = CounterFrequencyMethod

class _CurrentShuntResistorLocationWithDefault:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CurrentShuntResistorLocationWithDefaultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CurrentShuntResistorLocationWithDefault.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_UNSPECIFIED: _CurrentShuntResistorLocationWithDefault.ValueType  # 0
    CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_DEFAULT: _CurrentShuntResistorLocationWithDefault.ValueType  # -1
    CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_INTERNAL: _CurrentShuntResistorLocationWithDefault.ValueType  # 10200
    CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_EXTERNAL: _CurrentShuntResistorLocationWithDefault.ValueType  # 10167

class CurrentShuntResistorLocationWithDefault(_CurrentShuntResistorLocationWithDefault, metaclass=_CurrentShuntResistorLocationWithDefaultEnumTypeWrapper): ...

CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_UNSPECIFIED: CurrentShuntResistorLocationWithDefault.ValueType  # 0
CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_DEFAULT: CurrentShuntResistorLocationWithDefault.ValueType  # -1
CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_INTERNAL: CurrentShuntResistorLocationWithDefault.ValueType  # 10200
CURRENT_SHUNT_RESISTOR_LOCATION_WITH_DEFAULT_EXTERNAL: CurrentShuntResistorLocationWithDefault.ValueType  # 10167
global___CurrentShuntResistorLocationWithDefault = CurrentShuntResistorLocationWithDefault

class _CurrentUnits2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CurrentUnits2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CurrentUnits2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CURRENT_UNITS2_UNSPECIFIED: _CurrentUnits2.ValueType  # 0
    CURRENT_UNITS2_AMPS: _CurrentUnits2.ValueType  # 10342
    CURRENT_UNITS2_FROM_CUSTOM_SCALE: _CurrentUnits2.ValueType  # 10065

class CurrentUnits2(_CurrentUnits2, metaclass=_CurrentUnits2EnumTypeWrapper): ...

CURRENT_UNITS2_UNSPECIFIED: CurrentUnits2.ValueType  # 0
CURRENT_UNITS2_AMPS: CurrentUnits2.ValueType  # 10342
CURRENT_UNITS2_FROM_CUSTOM_SCALE: CurrentUnits2.ValueType  # 10065
global___CurrentUnits2 = CurrentUnits2

class _DigitalLineState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DigitalLineStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DigitalLineState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DIGITAL_LINE_STATE_UNSPECIFIED: _DigitalLineState.ValueType  # 0
    DIGITAL_LINE_STATE_HIGH: _DigitalLineState.ValueType  # 10192
    DIGITAL_LINE_STATE_LOW: _DigitalLineState.ValueType  # 10214
    DIGITAL_LINE_STATE_TRISTATE: _DigitalLineState.ValueType  # 10310
    DIGITAL_LINE_STATE_NO_CHANGE: _DigitalLineState.ValueType  # 10160

class DigitalLineState(_DigitalLineState, metaclass=_DigitalLineStateEnumTypeWrapper): ...

DIGITAL_LINE_STATE_UNSPECIFIED: DigitalLineState.ValueType  # 0
DIGITAL_LINE_STATE_HIGH: DigitalLineState.ValueType  # 10192
DIGITAL_LINE_STATE_LOW: DigitalLineState.ValueType  # 10214
DIGITAL_LINE_STATE_TRISTATE: DigitalLineState.ValueType  # 10310
DIGITAL_LINE_STATE_NO_CHANGE: DigitalLineState.ValueType  # 10160
global___DigitalLineState = DigitalLineState

class _DigitalPatternCondition1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DigitalPatternCondition1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DigitalPatternCondition1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DIGITAL_PATTERN_CONDITION1_UNSPECIFIED: _DigitalPatternCondition1.ValueType  # 0
    DIGITAL_PATTERN_CONDITION1_PATTERN_MATCHES: _DigitalPatternCondition1.ValueType  # 10254
    DIGITAL_PATTERN_CONDITION1_PATTERN_DOES_NOT_MATCH: _DigitalPatternCondition1.ValueType  # 10253

class DigitalPatternCondition1(_DigitalPatternCondition1, metaclass=_DigitalPatternCondition1EnumTypeWrapper): ...

DIGITAL_PATTERN_CONDITION1_UNSPECIFIED: DigitalPatternCondition1.ValueType  # 0
DIGITAL_PATTERN_CONDITION1_PATTERN_MATCHES: DigitalPatternCondition1.ValueType  # 10254
DIGITAL_PATTERN_CONDITION1_PATTERN_DOES_NOT_MATCH: DigitalPatternCondition1.ValueType  # 10253
global___DigitalPatternCondition1 = DigitalPatternCondition1

class _DigitalWidthUnits3:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DigitalWidthUnits3EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DigitalWidthUnits3.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DIGITAL_WIDTH_UNITS3_UNSPECIFIED: _DigitalWidthUnits3.ValueType  # 0
    DIGITAL_WIDTH_UNITS3_SECONDS: _DigitalWidthUnits3.ValueType  # 10364

class DigitalWidthUnits3(_DigitalWidthUnits3, metaclass=_DigitalWidthUnits3EnumTypeWrapper): ...

DIGITAL_WIDTH_UNITS3_UNSPECIFIED: DigitalWidthUnits3.ValueType  # 0
DIGITAL_WIDTH_UNITS3_SECONDS: DigitalWidthUnits3.ValueType  # 10364
global___DigitalWidthUnits3 = DigitalWidthUnits3

class _EddyCurrentProxProbeSensitivityUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EddyCurrentProxProbeSensitivityUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EddyCurrentProxProbeSensitivityUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_UNSPECIFIED: _EddyCurrentProxProbeSensitivityUnits.ValueType  # 0
    EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MIL: _EddyCurrentProxProbeSensitivityUnits.ValueType  # 14836
    EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MIL: _EddyCurrentProxProbeSensitivityUnits.ValueType  # 14837
    EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MILLIMETER: _EddyCurrentProxProbeSensitivityUnits.ValueType  # 14838
    EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MILLIMETER: _EddyCurrentProxProbeSensitivityUnits.ValueType  # 14839
    EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MICRON: _EddyCurrentProxProbeSensitivityUnits.ValueType  # 14840

class EddyCurrentProxProbeSensitivityUnits(_EddyCurrentProxProbeSensitivityUnits, metaclass=_EddyCurrentProxProbeSensitivityUnitsEnumTypeWrapper): ...

EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_UNSPECIFIED: EddyCurrentProxProbeSensitivityUnits.ValueType  # 0
EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MIL: EddyCurrentProxProbeSensitivityUnits.ValueType  # 14836
EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MIL: EddyCurrentProxProbeSensitivityUnits.ValueType  # 14837
EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MILLIMETER: EddyCurrentProxProbeSensitivityUnits.ValueType  # 14838
EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MILLIMETER: EddyCurrentProxProbeSensitivityUnits.ValueType  # 14839
EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MICRON: EddyCurrentProxProbeSensitivityUnits.ValueType  # 14840
global___EddyCurrentProxProbeSensitivityUnits = EddyCurrentProxProbeSensitivityUnits

class _Edge1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _Edge1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Edge1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EDGE1_UNSPECIFIED: _Edge1.ValueType  # 0
    EDGE1_RISING: _Edge1.ValueType  # 10280
    EDGE1_FALLING: _Edge1.ValueType  # 10171

class Edge1(_Edge1, metaclass=_Edge1EnumTypeWrapper): ...

EDGE1_UNSPECIFIED: Edge1.ValueType  # 0
EDGE1_RISING: Edge1.ValueType  # 10280
EDGE1_FALLING: Edge1.ValueType  # 10171
global___Edge1 = Edge1

class _EncoderType2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EncoderType2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EncoderType2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ENCODER_TYPE2_UNSPECIFIED: _EncoderType2.ValueType  # 0
    ENCODER_TYPE2_X1: _EncoderType2.ValueType  # 10090
    ENCODER_TYPE2_X2: _EncoderType2.ValueType  # 10091
    ENCODER_TYPE2_X4: _EncoderType2.ValueType  # 10092
    ENCODER_TYPE2_TWO_PULSE_COUNTING: _EncoderType2.ValueType  # 10313

class EncoderType2(_EncoderType2, metaclass=_EncoderType2EnumTypeWrapper): ...

ENCODER_TYPE2_UNSPECIFIED: EncoderType2.ValueType  # 0
ENCODER_TYPE2_X1: EncoderType2.ValueType  # 10090
ENCODER_TYPE2_X2: EncoderType2.ValueType  # 10091
ENCODER_TYPE2_X4: EncoderType2.ValueType  # 10092
ENCODER_TYPE2_TWO_PULSE_COUNTING: EncoderType2.ValueType  # 10313
global___EncoderType2 = EncoderType2

class _EncoderZIndexPhase1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EncoderZIndexPhase1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EncoderZIndexPhase1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ENCODER_Z_INDEX_PHASE1_UNSPECIFIED: _EncoderZIndexPhase1.ValueType  # 0
    ENCODER_Z_INDEX_PHASE1_A_HIGH_B_HIGH: _EncoderZIndexPhase1.ValueType  # 10040
    ENCODER_Z_INDEX_PHASE1_A_HIGH_B_LOW: _EncoderZIndexPhase1.ValueType  # 10041
    ENCODER_Z_INDEX_PHASE1_A_LOW_B_HIGH: _EncoderZIndexPhase1.ValueType  # 10042
    ENCODER_Z_INDEX_PHASE1_A_LOW_B_LOW: _EncoderZIndexPhase1.ValueType  # 10043

class EncoderZIndexPhase1(_EncoderZIndexPhase1, metaclass=_EncoderZIndexPhase1EnumTypeWrapper): ...

ENCODER_Z_INDEX_PHASE1_UNSPECIFIED: EncoderZIndexPhase1.ValueType  # 0
ENCODER_Z_INDEX_PHASE1_A_HIGH_B_HIGH: EncoderZIndexPhase1.ValueType  # 10040
ENCODER_Z_INDEX_PHASE1_A_HIGH_B_LOW: EncoderZIndexPhase1.ValueType  # 10041
ENCODER_Z_INDEX_PHASE1_A_LOW_B_HIGH: EncoderZIndexPhase1.ValueType  # 10042
ENCODER_Z_INDEX_PHASE1_A_LOW_B_LOW: EncoderZIndexPhase1.ValueType  # 10043
global___EncoderZIndexPhase1 = EncoderZIndexPhase1

class _EveryNSamplesEventType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EveryNSamplesEventTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EveryNSamplesEventType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EVERY_N_SAMPLES_EVENT_TYPE_UNSPECIFIED: _EveryNSamplesEventType.ValueType  # 0
    EVERY_N_SAMPLES_EVENT_TYPE_ACQUIRED_INTO_BUFFER: _EveryNSamplesEventType.ValueType  # 1
    EVERY_N_SAMPLES_EVENT_TYPE_TRANSFERRED_FROM_BUFFER: _EveryNSamplesEventType.ValueType  # 2

class EveryNSamplesEventType(_EveryNSamplesEventType, metaclass=_EveryNSamplesEventTypeEnumTypeWrapper): ...

EVERY_N_SAMPLES_EVENT_TYPE_UNSPECIFIED: EveryNSamplesEventType.ValueType  # 0
EVERY_N_SAMPLES_EVENT_TYPE_ACQUIRED_INTO_BUFFER: EveryNSamplesEventType.ValueType  # 1
EVERY_N_SAMPLES_EVENT_TYPE_TRANSFERRED_FROM_BUFFER: EveryNSamplesEventType.ValueType  # 2
global___EveryNSamplesEventType = EveryNSamplesEventType

class _ExcitationSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExcitationSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExcitationSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXCITATION_SOURCE_UNSPECIFIED: _ExcitationSource.ValueType  # 0
    EXCITATION_SOURCE_INTERNAL: _ExcitationSource.ValueType  # 10200
    EXCITATION_SOURCE_EXTERNAL: _ExcitationSource.ValueType  # 10167
    EXCITATION_SOURCE_NONE: _ExcitationSource.ValueType  # 10230

class ExcitationSource(_ExcitationSource, metaclass=_ExcitationSourceEnumTypeWrapper): ...

EXCITATION_SOURCE_UNSPECIFIED: ExcitationSource.ValueType  # 0
EXCITATION_SOURCE_INTERNAL: ExcitationSource.ValueType  # 10200
EXCITATION_SOURCE_EXTERNAL: ExcitationSource.ValueType  # 10167
EXCITATION_SOURCE_NONE: ExcitationSource.ValueType  # 10230
global___ExcitationSource = ExcitationSource

class _ForceIEPESensorSensitivityUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ForceIEPESensorSensitivityUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ForceIEPESensorSensitivityUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_UNSPECIFIED: _ForceIEPESensorSensitivityUnits.ValueType  # 0
    FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_NEWTON: _ForceIEPESensorSensitivityUnits.ValueType  # 15891
    FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_POUND: _ForceIEPESensorSensitivityUnits.ValueType  # 15892

class ForceIEPESensorSensitivityUnits(_ForceIEPESensorSensitivityUnits, metaclass=_ForceIEPESensorSensitivityUnitsEnumTypeWrapper): ...

FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_UNSPECIFIED: ForceIEPESensorSensitivityUnits.ValueType  # 0
FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_NEWTON: ForceIEPESensorSensitivityUnits.ValueType  # 15891
FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_POUND: ForceIEPESensorSensitivityUnits.ValueType  # 15892
global___ForceIEPESensorSensitivityUnits = ForceIEPESensorSensitivityUnits

class _ForceIEPEUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ForceIEPEUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ForceIEPEUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FORCE_IEPE_UNITS_UNSPECIFIED: _ForceIEPEUnits.ValueType  # 0
    FORCE_IEPE_UNITS_NEWTONS: _ForceIEPEUnits.ValueType  # 15875
    FORCE_IEPE_UNITS_POUNDS: _ForceIEPEUnits.ValueType  # 15876
    FORCE_IEPE_UNITS_FROM_CUSTOM_SCALE: _ForceIEPEUnits.ValueType  # 10065

class ForceIEPEUnits(_ForceIEPEUnits, metaclass=_ForceIEPEUnitsEnumTypeWrapper): ...

FORCE_IEPE_UNITS_UNSPECIFIED: ForceIEPEUnits.ValueType  # 0
FORCE_IEPE_UNITS_NEWTONS: ForceIEPEUnits.ValueType  # 15875
FORCE_IEPE_UNITS_POUNDS: ForceIEPEUnits.ValueType  # 15876
FORCE_IEPE_UNITS_FROM_CUSTOM_SCALE: ForceIEPEUnits.ValueType  # 10065
global___ForceIEPEUnits = ForceIEPEUnits

class _ForceUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ForceUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ForceUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FORCE_UNITS_UNSPECIFIED: _ForceUnits.ValueType  # 0
    FORCE_UNITS_NEWTONS: _ForceUnits.ValueType  # 15875
    FORCE_UNITS_POUNDS: _ForceUnits.ValueType  # 15876
    FORCE_UNITS_KILOGRAM_FORCE: _ForceUnits.ValueType  # 15877
    FORCE_UNITS_FROM_CUSTOM_SCALE: _ForceUnits.ValueType  # 10065

class ForceUnits(_ForceUnits, metaclass=_ForceUnitsEnumTypeWrapper): ...

FORCE_UNITS_UNSPECIFIED: ForceUnits.ValueType  # 0
FORCE_UNITS_NEWTONS: ForceUnits.ValueType  # 15875
FORCE_UNITS_POUNDS: ForceUnits.ValueType  # 15876
FORCE_UNITS_KILOGRAM_FORCE: ForceUnits.ValueType  # 15877
FORCE_UNITS_FROM_CUSTOM_SCALE: ForceUnits.ValueType  # 10065
global___ForceUnits = ForceUnits

class _FrequencyUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FrequencyUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FrequencyUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FREQUENCY_UNITS_UNSPECIFIED: _FrequencyUnits.ValueType  # 0
    FREQUENCY_UNITS_HZ: _FrequencyUnits.ValueType  # 10373
    FREQUENCY_UNITS_FROM_CUSTOM_SCALE: _FrequencyUnits.ValueType  # 10065

class FrequencyUnits(_FrequencyUnits, metaclass=_FrequencyUnitsEnumTypeWrapper): ...

FREQUENCY_UNITS_UNSPECIFIED: FrequencyUnits.ValueType  # 0
FREQUENCY_UNITS_HZ: FrequencyUnits.ValueType  # 10373
FREQUENCY_UNITS_FROM_CUSTOM_SCALE: FrequencyUnits.ValueType  # 10065
global___FrequencyUnits = FrequencyUnits

class _FrequencyUnits2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FrequencyUnits2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FrequencyUnits2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FREQUENCY_UNITS2_UNSPECIFIED: _FrequencyUnits2.ValueType  # 0
    FREQUENCY_UNITS2_HZ: _FrequencyUnits2.ValueType  # 10373

class FrequencyUnits2(_FrequencyUnits2, metaclass=_FrequencyUnits2EnumTypeWrapper): ...

FREQUENCY_UNITS2_UNSPECIFIED: FrequencyUnits2.ValueType  # 0
FREQUENCY_UNITS2_HZ: FrequencyUnits2.ValueType  # 10373
global___FrequencyUnits2 = FrequencyUnits2

class _FrequencyUnits3:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FrequencyUnits3EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FrequencyUnits3.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FREQUENCY_UNITS3_UNSPECIFIED: _FrequencyUnits3.ValueType  # 0
    FREQUENCY_UNITS3_HZ: _FrequencyUnits3.ValueType  # 10373
    FREQUENCY_UNITS3_TICKS: _FrequencyUnits3.ValueType  # 10304
    FREQUENCY_UNITS3_FROM_CUSTOM_SCALE: _FrequencyUnits3.ValueType  # 10065

class FrequencyUnits3(_FrequencyUnits3, metaclass=_FrequencyUnits3EnumTypeWrapper): ...

FREQUENCY_UNITS3_UNSPECIFIED: FrequencyUnits3.ValueType  # 0
FREQUENCY_UNITS3_HZ: FrequencyUnits3.ValueType  # 10373
FREQUENCY_UNITS3_TICKS: FrequencyUnits3.ValueType  # 10304
FREQUENCY_UNITS3_FROM_CUSTOM_SCALE: FrequencyUnits3.ValueType  # 10065
global___FrequencyUnits3 = FrequencyUnits3

class _FuncGenType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FuncGenTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FuncGenType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FUNC_GEN_TYPE_UNSPECIFIED: _FuncGenType.ValueType  # 0
    FUNC_GEN_TYPE_SINE: _FuncGenType.ValueType  # 14751
    FUNC_GEN_TYPE_TRIANGLE: _FuncGenType.ValueType  # 14752
    FUNC_GEN_TYPE_SQUARE: _FuncGenType.ValueType  # 14753
    FUNC_GEN_TYPE_SAWTOOTH: _FuncGenType.ValueType  # 14754

class FuncGenType(_FuncGenType, metaclass=_FuncGenTypeEnumTypeWrapper): ...

FUNC_GEN_TYPE_UNSPECIFIED: FuncGenType.ValueType  # 0
FUNC_GEN_TYPE_SINE: FuncGenType.ValueType  # 14751
FUNC_GEN_TYPE_TRIANGLE: FuncGenType.ValueType  # 14752
FUNC_GEN_TYPE_SQUARE: FuncGenType.ValueType  # 14753
FUNC_GEN_TYPE_SAWTOOTH: FuncGenType.ValueType  # 14754
global___FuncGenType = FuncGenType

class _GpsSignalType1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GpsSignalType1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GpsSignalType1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GPS_SIGNAL_TYPE1_UNSPECIFIED: _GpsSignalType1.ValueType  # 0
    GPS_SIGNAL_TYPE1_IRIGB: _GpsSignalType1.ValueType  # 10070
    GPS_SIGNAL_TYPE1_PPS: _GpsSignalType1.ValueType  # 10080
    GPS_SIGNAL_TYPE1_NONE: _GpsSignalType1.ValueType  # 10230

class GpsSignalType1(_GpsSignalType1, metaclass=_GpsSignalType1EnumTypeWrapper): ...

GPS_SIGNAL_TYPE1_UNSPECIFIED: GpsSignalType1.ValueType  # 0
GPS_SIGNAL_TYPE1_IRIGB: GpsSignalType1.ValueType  # 10070
GPS_SIGNAL_TYPE1_PPS: GpsSignalType1.ValueType  # 10080
GPS_SIGNAL_TYPE1_NONE: GpsSignalType1.ValueType  # 10230
global___GpsSignalType1 = GpsSignalType1

class _GroupBy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GroupByEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GroupBy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GROUP_BY_GROUP_BY_CHANNEL: _GroupBy.ValueType  # 0
    GROUP_BY_GROUP_BY_SCAN_NUMBER: _GroupBy.ValueType  # 1

class GroupBy(_GroupBy, metaclass=_GroupByEnumTypeWrapper): ...

GROUP_BY_GROUP_BY_CHANNEL: GroupBy.ValueType  # 0
GROUP_BY_GROUP_BY_SCAN_NUMBER: GroupBy.ValueType  # 1
global___GroupBy = GroupBy

class _InputTermCfgWithDefault:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InputTermCfgWithDefaultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InputTermCfgWithDefault.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INPUT_TERM_CFG_WITH_DEFAULT_UNSPECIFIED: _InputTermCfgWithDefault.ValueType  # 0
    INPUT_TERM_CFG_WITH_DEFAULT_CFG_DEFAULT: _InputTermCfgWithDefault.ValueType  # -1
    INPUT_TERM_CFG_WITH_DEFAULT_RSE: _InputTermCfgWithDefault.ValueType  # 10083
    INPUT_TERM_CFG_WITH_DEFAULT_NRSE: _InputTermCfgWithDefault.ValueType  # 10078
    INPUT_TERM_CFG_WITH_DEFAULT_DIFF: _InputTermCfgWithDefault.ValueType  # 10106
    INPUT_TERM_CFG_WITH_DEFAULT_PSEUDO_DIFF: _InputTermCfgWithDefault.ValueType  # 12529

class InputTermCfgWithDefault(_InputTermCfgWithDefault, metaclass=_InputTermCfgWithDefaultEnumTypeWrapper): ...

INPUT_TERM_CFG_WITH_DEFAULT_UNSPECIFIED: InputTermCfgWithDefault.ValueType  # 0
INPUT_TERM_CFG_WITH_DEFAULT_CFG_DEFAULT: InputTermCfgWithDefault.ValueType  # -1
INPUT_TERM_CFG_WITH_DEFAULT_RSE: InputTermCfgWithDefault.ValueType  # 10083
INPUT_TERM_CFG_WITH_DEFAULT_NRSE: InputTermCfgWithDefault.ValueType  # 10078
INPUT_TERM_CFG_WITH_DEFAULT_DIFF: InputTermCfgWithDefault.ValueType  # 10106
INPUT_TERM_CFG_WITH_DEFAULT_PSEUDO_DIFF: InputTermCfgWithDefault.ValueType  # 12529
global___InputTermCfgWithDefault = InputTermCfgWithDefault

class _InvertPolarity:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InvertPolarityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InvertPolarity.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVERT_POLARITY_DO_NOT_INVERT_POLARITY: _InvertPolarity.ValueType  # 0
    INVERT_POLARITY_INVERT_POLARITY: _InvertPolarity.ValueType  # 1

class InvertPolarity(_InvertPolarity, metaclass=_InvertPolarityEnumTypeWrapper): ...

INVERT_POLARITY_DO_NOT_INVERT_POLARITY: InvertPolarity.ValueType  # 0
INVERT_POLARITY_INVERT_POLARITY: InvertPolarity.ValueType  # 1
global___InvertPolarity = InvertPolarity

class _LVDTSensitivityUnits1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LVDTSensitivityUnits1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LVDTSensitivityUnits1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LVDT_SENSITIVITY_UNITS1_UNSPECIFIED: _LVDTSensitivityUnits1.ValueType  # 0
    LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLIMETER: _LVDTSensitivityUnits1.ValueType  # 12506
    LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLI_INCH: _LVDTSensitivityUnits1.ValueType  # 12505

class LVDTSensitivityUnits1(_LVDTSensitivityUnits1, metaclass=_LVDTSensitivityUnits1EnumTypeWrapper): ...

LVDT_SENSITIVITY_UNITS1_UNSPECIFIED: LVDTSensitivityUnits1.ValueType  # 0
LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLIMETER: LVDTSensitivityUnits1.ValueType  # 12506
LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLI_INCH: LVDTSensitivityUnits1.ValueType  # 12505
global___LVDTSensitivityUnits1 = LVDTSensitivityUnits1

class _LengthUnits2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LengthUnits2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LengthUnits2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LENGTH_UNITS2_UNSPECIFIED: _LengthUnits2.ValueType  # 0
    LENGTH_UNITS2_METERS: _LengthUnits2.ValueType  # 10219
    LENGTH_UNITS2_INCHES: _LengthUnits2.ValueType  # 10379
    LENGTH_UNITS2_FROM_CUSTOM_SCALE: _LengthUnits2.ValueType  # 10065

class LengthUnits2(_LengthUnits2, metaclass=_LengthUnits2EnumTypeWrapper): ...

LENGTH_UNITS2_UNSPECIFIED: LengthUnits2.ValueType  # 0
LENGTH_UNITS2_METERS: LengthUnits2.ValueType  # 10219
LENGTH_UNITS2_INCHES: LengthUnits2.ValueType  # 10379
LENGTH_UNITS2_FROM_CUSTOM_SCALE: LengthUnits2.ValueType  # 10065
global___LengthUnits2 = LengthUnits2

class _LengthUnits3:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LengthUnits3EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LengthUnits3.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LENGTH_UNITS3_UNSPECIFIED: _LengthUnits3.ValueType  # 0
    LENGTH_UNITS3_METERS: _LengthUnits3.ValueType  # 10219
    LENGTH_UNITS3_INCHES: _LengthUnits3.ValueType  # 10379
    LENGTH_UNITS3_TICKS: _LengthUnits3.ValueType  # 10304
    LENGTH_UNITS3_FROM_CUSTOM_SCALE: _LengthUnits3.ValueType  # 10065

class LengthUnits3(_LengthUnits3, metaclass=_LengthUnits3EnumTypeWrapper): ...

LENGTH_UNITS3_UNSPECIFIED: LengthUnits3.ValueType  # 0
LENGTH_UNITS3_METERS: LengthUnits3.ValueType  # 10219
LENGTH_UNITS3_INCHES: LengthUnits3.ValueType  # 10379
LENGTH_UNITS3_TICKS: LengthUnits3.ValueType  # 10304
LENGTH_UNITS3_FROM_CUSTOM_SCALE: LengthUnits3.ValueType  # 10065
global___LengthUnits3 = LengthUnits3

class _Level1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _Level1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Level1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LEVEL1_UNSPECIFIED: _Level1.ValueType  # 0
    LEVEL1_HIGH: _Level1.ValueType  # 10192
    LEVEL1_LOW: _Level1.ValueType  # 10214

class Level1(_Level1, metaclass=_Level1EnumTypeWrapper): ...

LEVEL1_UNSPECIFIED: Level1.ValueType  # 0
LEVEL1_HIGH: Level1.ValueType  # 10192
LEVEL1_LOW: Level1.ValueType  # 10214
global___Level1 = Level1

class _LineGrouping:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LineGroupingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LineGrouping.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LINE_GROUPING_CHAN_PER_LINE: _LineGrouping.ValueType  # 0
    LINE_GROUPING_CHAN_FOR_ALL_LINES: _LineGrouping.ValueType  # 1

class LineGrouping(_LineGrouping, metaclass=_LineGroupingEnumTypeWrapper): ...

LINE_GROUPING_CHAN_PER_LINE: LineGrouping.ValueType  # 0
LINE_GROUPING_CHAN_FOR_ALL_LINES: LineGrouping.ValueType  # 1
global___LineGrouping = LineGrouping

class _LoggingMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LoggingModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LoggingMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOGGING_MODE_UNSPECIFIED: _LoggingMode.ValueType  # 0
    LOGGING_MODE_OFF: _LoggingMode.ValueType  # 10231
    LOGGING_MODE_LOG: _LoggingMode.ValueType  # 15844
    LOGGING_MODE_LOG_AND_READ: _LoggingMode.ValueType  # 15842

class LoggingMode(_LoggingMode, metaclass=_LoggingModeEnumTypeWrapper): ...

LOGGING_MODE_UNSPECIFIED: LoggingMode.ValueType  # 0
LOGGING_MODE_OFF: LoggingMode.ValueType  # 10231
LOGGING_MODE_LOG: LoggingMode.ValueType  # 15844
LOGGING_MODE_LOG_AND_READ: LoggingMode.ValueType  # 15842
global___LoggingMode = LoggingMode

class _LoggingOperation:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LoggingOperationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LoggingOperation.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOGGING_OPERATION_UNSPECIFIED: _LoggingOperation.ValueType  # 0
    LOGGING_OPERATION_OPEN: _LoggingOperation.ValueType  # 10437
    LOGGING_OPERATION_OPEN_OR_CREATE: _LoggingOperation.ValueType  # 15846
    LOGGING_OPERATION_CREATE_OR_REPLACE: _LoggingOperation.ValueType  # 15847
    LOGGING_OPERATION_CREATE: _LoggingOperation.ValueType  # 15848

class LoggingOperation(_LoggingOperation, metaclass=_LoggingOperationEnumTypeWrapper): ...

LOGGING_OPERATION_UNSPECIFIED: LoggingOperation.ValueType  # 0
LOGGING_OPERATION_OPEN: LoggingOperation.ValueType  # 10437
LOGGING_OPERATION_OPEN_OR_CREATE: LoggingOperation.ValueType  # 15846
LOGGING_OPERATION_CREATE_OR_REPLACE: LoggingOperation.ValueType  # 15847
LOGGING_OPERATION_CREATE: LoggingOperation.ValueType  # 15848
global___LoggingOperation = LoggingOperation

class _LogicFamily:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogicFamilyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogicFamily.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOGIC_FAMILY_UNSPECIFIED: _LogicFamily.ValueType  # 0
    LOGIC_FAMILY_2POINT_5_V: _LogicFamily.ValueType  # 14620
    LOGIC_FAMILY_3POINT_3_V: _LogicFamily.ValueType  # 14621
    LOGIC_FAMILY_5_V: _LogicFamily.ValueType  # 14619

class LogicFamily(_LogicFamily, metaclass=_LogicFamilyEnumTypeWrapper): ...

LOGIC_FAMILY_UNSPECIFIED: LogicFamily.ValueType  # 0
LOGIC_FAMILY_2POINT_5_V: LogicFamily.ValueType  # 14620
LOGIC_FAMILY_3POINT_3_V: LogicFamily.ValueType  # 14621
LOGIC_FAMILY_5_V: LogicFamily.ValueType  # 14619
global___LogicFamily = LogicFamily

class _Polarity2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _Polarity2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Polarity2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    POLARITY2_UNSPECIFIED: _Polarity2.ValueType  # 0
    POLARITY2_ACTIVE_HIGH: _Polarity2.ValueType  # 10095
    POLARITY2_ACTIVE_LOW: _Polarity2.ValueType  # 10096

class Polarity2(_Polarity2, metaclass=_Polarity2EnumTypeWrapper): ...

POLARITY2_UNSPECIFIED: Polarity2.ValueType  # 0
POLARITY2_ACTIVE_HIGH: Polarity2.ValueType  # 10095
POLARITY2_ACTIVE_LOW: Polarity2.ValueType  # 10096
global___Polarity2 = Polarity2

class _PowerUpChannelType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PowerUpChannelTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PowerUpChannelType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    POWER_UP_CHANNEL_TYPE_CHANNEL_VOLTAGE: _PowerUpChannelType.ValueType  # 0
    POWER_UP_CHANNEL_TYPE_CHANNEL_CURRENT: _PowerUpChannelType.ValueType  # 1
    POWER_UP_CHANNEL_TYPE_CHANNEL_HIGH_IMPEDANCE: _PowerUpChannelType.ValueType  # 2

class PowerUpChannelType(_PowerUpChannelType, metaclass=_PowerUpChannelTypeEnumTypeWrapper): ...

POWER_UP_CHANNEL_TYPE_CHANNEL_VOLTAGE: PowerUpChannelType.ValueType  # 0
POWER_UP_CHANNEL_TYPE_CHANNEL_CURRENT: PowerUpChannelType.ValueType  # 1
POWER_UP_CHANNEL_TYPE_CHANNEL_HIGH_IMPEDANCE: PowerUpChannelType.ValueType  # 2
global___PowerUpChannelType = PowerUpChannelType

class _PowerUpStates:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PowerUpStatesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PowerUpStates.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    POWER_UP_STATES_UNSPECIFIED: _PowerUpStates.ValueType  # 0
    POWER_UP_STATES_HIGH: _PowerUpStates.ValueType  # 10192
    POWER_UP_STATES_LOW: _PowerUpStates.ValueType  # 10214
    POWER_UP_STATES_TRISTATE: _PowerUpStates.ValueType  # 10310

class PowerUpStates(_PowerUpStates, metaclass=_PowerUpStatesEnumTypeWrapper): ...

POWER_UP_STATES_UNSPECIFIED: PowerUpStates.ValueType  # 0
POWER_UP_STATES_HIGH: PowerUpStates.ValueType  # 10192
POWER_UP_STATES_LOW: PowerUpStates.ValueType  # 10214
POWER_UP_STATES_TRISTATE: PowerUpStates.ValueType  # 10310
global___PowerUpStates = PowerUpStates

class _PressureUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PressureUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PressureUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PRESSURE_UNITS_UNSPECIFIED: _PressureUnits.ValueType  # 0
    PRESSURE_UNITS_PASCALS: _PressureUnits.ValueType  # 10081
    PRESSURE_UNITS_POUNDS_PER_SQUARE_INCH: _PressureUnits.ValueType  # 15879
    PRESSURE_UNITS_BAR: _PressureUnits.ValueType  # 15880
    PRESSURE_UNITS_FROM_CUSTOM_SCALE: _PressureUnits.ValueType  # 10065

class PressureUnits(_PressureUnits, metaclass=_PressureUnitsEnumTypeWrapper): ...

PRESSURE_UNITS_UNSPECIFIED: PressureUnits.ValueType  # 0
PRESSURE_UNITS_PASCALS: PressureUnits.ValueType  # 10081
PRESSURE_UNITS_POUNDS_PER_SQUARE_INCH: PressureUnits.ValueType  # 15879
PRESSURE_UNITS_BAR: PressureUnits.ValueType  # 15880
PRESSURE_UNITS_FROM_CUSTOM_SCALE: PressureUnits.ValueType  # 10065
global___PressureUnits = PressureUnits

class _RTDType1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RTDType1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RTDType1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RTD_TYPE1_UNSPECIFIED: _RTDType1.ValueType  # 0
    RTD_TYPE1_PT_3750: _RTDType1.ValueType  # 12481
    RTD_TYPE1_PT_3851: _RTDType1.ValueType  # 10071
    RTD_TYPE1_PT_3911: _RTDType1.ValueType  # 12482
    RTD_TYPE1_PT_3916: _RTDType1.ValueType  # 10069
    RTD_TYPE1_PT_3920: _RTDType1.ValueType  # 10053
    RTD_TYPE1_PT_3928: _RTDType1.ValueType  # 12483
    RTD_TYPE1_CUSTOM: _RTDType1.ValueType  # 10137

class RTDType1(_RTDType1, metaclass=_RTDType1EnumTypeWrapper): ...

RTD_TYPE1_UNSPECIFIED: RTDType1.ValueType  # 0
RTD_TYPE1_PT_3750: RTDType1.ValueType  # 12481
RTD_TYPE1_PT_3851: RTDType1.ValueType  # 10071
RTD_TYPE1_PT_3911: RTDType1.ValueType  # 12482
RTD_TYPE1_PT_3916: RTDType1.ValueType  # 10069
RTD_TYPE1_PT_3920: RTDType1.ValueType  # 10053
RTD_TYPE1_PT_3928: RTDType1.ValueType  # 12483
RTD_TYPE1_CUSTOM: RTDType1.ValueType  # 10137
global___RTDType1 = RTDType1

class _RVDTSensitivityUnits1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RVDTSensitivityUnits1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RVDTSensitivityUnits1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RVDT_SENSITIVITY_UNITS1_UNSPECIFIED: _RVDTSensitivityUnits1.ValueType  # 0
    RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_DEGREE: _RVDTSensitivityUnits1.ValueType  # 12507
    RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_RADIAN: _RVDTSensitivityUnits1.ValueType  # 12508

class RVDTSensitivityUnits1(_RVDTSensitivityUnits1, metaclass=_RVDTSensitivityUnits1EnumTypeWrapper): ...

RVDT_SENSITIVITY_UNITS1_UNSPECIFIED: RVDTSensitivityUnits1.ValueType  # 0
RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_DEGREE: RVDTSensitivityUnits1.ValueType  # 12507
RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_RADIAN: RVDTSensitivityUnits1.ValueType  # 12508
global___RVDTSensitivityUnits1 = RVDTSensitivityUnits1

class _ResistanceConfiguration:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResistanceConfigurationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResistanceConfiguration.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESISTANCE_CONFIGURATION_UNSPECIFIED: _ResistanceConfiguration.ValueType  # 0
    RESISTANCE_CONFIGURATION_2_WIRE: _ResistanceConfiguration.ValueType  # 2
    RESISTANCE_CONFIGURATION_3_WIRE: _ResistanceConfiguration.ValueType  # 3
    RESISTANCE_CONFIGURATION_4_WIRE: _ResistanceConfiguration.ValueType  # 4

class ResistanceConfiguration(_ResistanceConfiguration, metaclass=_ResistanceConfigurationEnumTypeWrapper): ...

RESISTANCE_CONFIGURATION_UNSPECIFIED: ResistanceConfiguration.ValueType  # 0
RESISTANCE_CONFIGURATION_2_WIRE: ResistanceConfiguration.ValueType  # 2
RESISTANCE_CONFIGURATION_3_WIRE: ResistanceConfiguration.ValueType  # 3
RESISTANCE_CONFIGURATION_4_WIRE: ResistanceConfiguration.ValueType  # 4
global___ResistanceConfiguration = ResistanceConfiguration

class _ResistanceUnits2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResistanceUnits2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResistanceUnits2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESISTANCE_UNITS2_UNSPECIFIED: _ResistanceUnits2.ValueType  # 0
    RESISTANCE_UNITS2_OHMS: _ResistanceUnits2.ValueType  # 10384
    RESISTANCE_UNITS2_FROM_CUSTOM_SCALE: _ResistanceUnits2.ValueType  # 10065

class ResistanceUnits2(_ResistanceUnits2, metaclass=_ResistanceUnits2EnumTypeWrapper): ...

RESISTANCE_UNITS2_UNSPECIFIED: ResistanceUnits2.ValueType  # 0
RESISTANCE_UNITS2_OHMS: ResistanceUnits2.ValueType  # 10384
RESISTANCE_UNITS2_FROM_CUSTOM_SCALE: ResistanceUnits2.ValueType  # 10065
global___ResistanceUnits2 = ResistanceUnits2

class _ResistorState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResistorStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResistorState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESISTOR_STATE_UNSPECIFIED: _ResistorState.ValueType  # 0
    RESISTOR_STATE_PULL_UP: _ResistorState.ValueType  # 15950
    RESISTOR_STATE_PULL_DOWN: _ResistorState.ValueType  # 15951

class ResistorState(_ResistorState, metaclass=_ResistorStateEnumTypeWrapper): ...

RESISTOR_STATE_UNSPECIFIED: ResistorState.ValueType  # 0
RESISTOR_STATE_PULL_UP: ResistorState.ValueType  # 15950
RESISTOR_STATE_PULL_DOWN: ResistorState.ValueType  # 15951
global___ResistorState = ResistorState

class _SaveOptions:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SaveOptionsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SaveOptions.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SAVE_OPTIONS_UNSPECIFIED: _SaveOptions.ValueType  # 0
    SAVE_OPTIONS_OVERWRITE: _SaveOptions.ValueType  # 1
    SAVE_OPTIONS_ALLOW_INTERACTIVE_EDITING: _SaveOptions.ValueType  # 2
    SAVE_OPTIONS_ALLOW_INTERACTIVE_DELETION: _SaveOptions.ValueType  # 4

class SaveOptions(_SaveOptions, metaclass=_SaveOptionsEnumTypeWrapper): ...

SAVE_OPTIONS_UNSPECIFIED: SaveOptions.ValueType  # 0
SAVE_OPTIONS_OVERWRITE: SaveOptions.ValueType  # 1
SAVE_OPTIONS_ALLOW_INTERACTIVE_EDITING: SaveOptions.ValueType  # 2
SAVE_OPTIONS_ALLOW_INTERACTIVE_DELETION: SaveOptions.ValueType  # 4
global___SaveOptions = SaveOptions

class _ShuntCalSelect:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ShuntCalSelectEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ShuntCalSelect.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SHUNT_CAL_SELECT_UNSPECIFIED: _ShuntCalSelect.ValueType  # 0
    SHUNT_CAL_SELECT_A: _ShuntCalSelect.ValueType  # 12513
    SHUNT_CAL_SELECT_B: _ShuntCalSelect.ValueType  # 12514
    SHUNT_CAL_SELECT_A_AND_B: _ShuntCalSelect.ValueType  # 12515

class ShuntCalSelect(_ShuntCalSelect, metaclass=_ShuntCalSelectEnumTypeWrapper): ...

SHUNT_CAL_SELECT_UNSPECIFIED: ShuntCalSelect.ValueType  # 0
SHUNT_CAL_SELECT_A: ShuntCalSelect.ValueType  # 12513
SHUNT_CAL_SELECT_B: ShuntCalSelect.ValueType  # 12514
SHUNT_CAL_SELECT_A_AND_B: ShuntCalSelect.ValueType  # 12515
global___ShuntCalSelect = ShuntCalSelect

class _ShuntCalSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ShuntCalSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ShuntCalSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SHUNT_CAL_SOURCE_UNSPECIFIED: _ShuntCalSource.ValueType  # 0
    SHUNT_CAL_SOURCE_DEFAULT: _ShuntCalSource.ValueType  # -1
    SHUNT_CAL_SOURCE_BUILT_IN: _ShuntCalSource.ValueType  # 10200
    SHUNT_CAL_SOURCE_USER_PROVIDED: _ShuntCalSource.ValueType  # 10167

class ShuntCalSource(_ShuntCalSource, metaclass=_ShuntCalSourceEnumTypeWrapper): ...

SHUNT_CAL_SOURCE_UNSPECIFIED: ShuntCalSource.ValueType  # 0
SHUNT_CAL_SOURCE_DEFAULT: ShuntCalSource.ValueType  # -1
SHUNT_CAL_SOURCE_BUILT_IN: ShuntCalSource.ValueType  # 10200
SHUNT_CAL_SOURCE_USER_PROVIDED: ShuntCalSource.ValueType  # 10167
global___ShuntCalSource = ShuntCalSource

class _ShuntElementLocation:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ShuntElementLocationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ShuntElementLocation.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SHUNT_ELEMENT_LOCATION_UNSPECIFIED: _ShuntElementLocation.ValueType  # 0
    SHUNT_ELEMENT_LOCATION_R1: _ShuntElementLocation.ValueType  # 12465
    SHUNT_ELEMENT_LOCATION_R2: _ShuntElementLocation.ValueType  # 12466
    SHUNT_ELEMENT_LOCATION_R3: _ShuntElementLocation.ValueType  # 12467
    SHUNT_ELEMENT_LOCATION_R4: _ShuntElementLocation.ValueType  # 14813
    SHUNT_ELEMENT_LOCATION_NONE: _ShuntElementLocation.ValueType  # 10230

class ShuntElementLocation(_ShuntElementLocation, metaclass=_ShuntElementLocationEnumTypeWrapper): ...

SHUNT_ELEMENT_LOCATION_UNSPECIFIED: ShuntElementLocation.ValueType  # 0
SHUNT_ELEMENT_LOCATION_R1: ShuntElementLocation.ValueType  # 12465
SHUNT_ELEMENT_LOCATION_R2: ShuntElementLocation.ValueType  # 12466
SHUNT_ELEMENT_LOCATION_R3: ShuntElementLocation.ValueType  # 12467
SHUNT_ELEMENT_LOCATION_R4: ShuntElementLocation.ValueType  # 14813
SHUNT_ELEMENT_LOCATION_NONE: ShuntElementLocation.ValueType  # 10230
global___ShuntElementLocation = ShuntElementLocation

class _Signal:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SignalEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Signal.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SIGNAL_UNSPECIFIED: _Signal.ValueType  # 0
    SIGNAL_AI_CONVERT_CLOCK: _Signal.ValueType  # 12484
    SIGNAL_10_MHZ_REF_CLOCK: _Signal.ValueType  # 12536
    SIGNAL_20_MHZ_TIMEBASE_CLOCK: _Signal.ValueType  # 12486
    SIGNAL_SAMPLE_CLOCK: _Signal.ValueType  # 12487
    SIGNAL_ADVANCE_TRIGGER: _Signal.ValueType  # 12488
    SIGNAL_REFERENCE_TRIGGER: _Signal.ValueType  # 12490
    SIGNAL_START_TRIGGER: _Signal.ValueType  # 12491
    SIGNAL_ADV_CMPLT_EVENT: _Signal.ValueType  # 12492
    SIGNAL_AI_HOLD_CMPLT_EVENT: _Signal.ValueType  # 12493
    SIGNAL_COUNTER_OUTPUT_EVENT: _Signal.ValueType  # 12494
    SIGNAL_CHANGE_DETECTION_EVENT: _Signal.ValueType  # 12511
    SIGNAL_WDT_EXPIRED_EVENT: _Signal.ValueType  # 12512

class Signal(_Signal, metaclass=_SignalEnumTypeWrapper): ...

SIGNAL_UNSPECIFIED: Signal.ValueType  # 0
SIGNAL_AI_CONVERT_CLOCK: Signal.ValueType  # 12484
SIGNAL_10_MHZ_REF_CLOCK: Signal.ValueType  # 12536
SIGNAL_20_MHZ_TIMEBASE_CLOCK: Signal.ValueType  # 12486
SIGNAL_SAMPLE_CLOCK: Signal.ValueType  # 12487
SIGNAL_ADVANCE_TRIGGER: Signal.ValueType  # 12488
SIGNAL_REFERENCE_TRIGGER: Signal.ValueType  # 12490
SIGNAL_START_TRIGGER: Signal.ValueType  # 12491
SIGNAL_ADV_CMPLT_EVENT: Signal.ValueType  # 12492
SIGNAL_AI_HOLD_CMPLT_EVENT: Signal.ValueType  # 12493
SIGNAL_COUNTER_OUTPUT_EVENT: Signal.ValueType  # 12494
SIGNAL_CHANGE_DETECTION_EVENT: Signal.ValueType  # 12511
SIGNAL_WDT_EXPIRED_EVENT: Signal.ValueType  # 12512
global___Signal = Signal

class _Signal2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _Signal2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Signal2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SIGNAL2_UNSPECIFIED: _Signal2.ValueType  # 0
    SIGNAL2_SAMPLE_COMPLETE_EVENT: _Signal2.ValueType  # 12530
    SIGNAL2_COUNTER_OUTPUT_EVENT: _Signal2.ValueType  # 12494
    SIGNAL2_CHANGE_DETECTION_EVENT: _Signal2.ValueType  # 12511
    SIGNAL2_SAMPLE_CLOCK: _Signal2.ValueType  # 12487

class Signal2(_Signal2, metaclass=_Signal2EnumTypeWrapper): ...

SIGNAL2_UNSPECIFIED: Signal2.ValueType  # 0
SIGNAL2_SAMPLE_COMPLETE_EVENT: Signal2.ValueType  # 12530
SIGNAL2_COUNTER_OUTPUT_EVENT: Signal2.ValueType  # 12494
SIGNAL2_CHANGE_DETECTION_EVENT: Signal2.ValueType  # 12511
SIGNAL2_SAMPLE_CLOCK: Signal2.ValueType  # 12487
global___Signal2 = Signal2

class _Slope1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _Slope1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Slope1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SLOPE1_UNSPECIFIED: _Slope1.ValueType  # 0
    SLOPE1_RISING_SLOPE: _Slope1.ValueType  # 10280
    SLOPE1_FALLING_SLOPE: _Slope1.ValueType  # 10171

class Slope1(_Slope1, metaclass=_Slope1EnumTypeWrapper): ...

SLOPE1_UNSPECIFIED: Slope1.ValueType  # 0
SLOPE1_RISING_SLOPE: Slope1.ValueType  # 10280
SLOPE1_FALLING_SLOPE: Slope1.ValueType  # 10171
global___Slope1 = Slope1

class _SoundPressureUnits1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SoundPressureUnits1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SoundPressureUnits1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SOUND_PRESSURE_UNITS1_UNSPECIFIED: _SoundPressureUnits1.ValueType  # 0
    SOUND_PRESSURE_UNITS1_PASCALS: _SoundPressureUnits1.ValueType  # 10081
    SOUND_PRESSURE_UNITS1_FROM_CUSTOM_SCALE: _SoundPressureUnits1.ValueType  # 10065

class SoundPressureUnits1(_SoundPressureUnits1, metaclass=_SoundPressureUnits1EnumTypeWrapper): ...

SOUND_PRESSURE_UNITS1_UNSPECIFIED: SoundPressureUnits1.ValueType  # 0
SOUND_PRESSURE_UNITS1_PASCALS: SoundPressureUnits1.ValueType  # 10081
SOUND_PRESSURE_UNITS1_FROM_CUSTOM_SCALE: SoundPressureUnits1.ValueType  # 10065
global___SoundPressureUnits1 = SoundPressureUnits1

class _StrainGageBridgeType1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StrainGageBridgeType1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_StrainGageBridgeType1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STRAIN_GAGE_BRIDGE_TYPE1_UNSPECIFIED: _StrainGageBridgeType1.ValueType  # 0
    STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_I: _StrainGageBridgeType1.ValueType  # 10183
    STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_II: _StrainGageBridgeType1.ValueType  # 10184
    STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_III: _StrainGageBridgeType1.ValueType  # 10185
    STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_I: _StrainGageBridgeType1.ValueType  # 10188
    STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_II: _StrainGageBridgeType1.ValueType  # 10189
    STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_I: _StrainGageBridgeType1.ValueType  # 10271
    STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_II: _StrainGageBridgeType1.ValueType  # 10272

class StrainGageBridgeType1(_StrainGageBridgeType1, metaclass=_StrainGageBridgeType1EnumTypeWrapper): ...

STRAIN_GAGE_BRIDGE_TYPE1_UNSPECIFIED: StrainGageBridgeType1.ValueType  # 0
STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_I: StrainGageBridgeType1.ValueType  # 10183
STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_II: StrainGageBridgeType1.ValueType  # 10184
STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_III: StrainGageBridgeType1.ValueType  # 10185
STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_I: StrainGageBridgeType1.ValueType  # 10188
STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_II: StrainGageBridgeType1.ValueType  # 10189
STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_I: StrainGageBridgeType1.ValueType  # 10271
STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_II: StrainGageBridgeType1.ValueType  # 10272
global___StrainGageBridgeType1 = StrainGageBridgeType1

class _StrainGageRosetteType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StrainGageRosetteTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_StrainGageRosetteType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STRAIN_GAGE_ROSETTE_TYPE_UNSPECIFIED: _StrainGageRosetteType.ValueType  # 0
    STRAIN_GAGE_ROSETTE_TYPE_RECTANGULAR_ROSETTE: _StrainGageRosetteType.ValueType  # 15968
    STRAIN_GAGE_ROSETTE_TYPE_DELTA_ROSETTE: _StrainGageRosetteType.ValueType  # 15969
    STRAIN_GAGE_ROSETTE_TYPE_TEE_ROSETTE: _StrainGageRosetteType.ValueType  # 15970

class StrainGageRosetteType(_StrainGageRosetteType, metaclass=_StrainGageRosetteTypeEnumTypeWrapper): ...

STRAIN_GAGE_ROSETTE_TYPE_UNSPECIFIED: StrainGageRosetteType.ValueType  # 0
STRAIN_GAGE_ROSETTE_TYPE_RECTANGULAR_ROSETTE: StrainGageRosetteType.ValueType  # 15968
STRAIN_GAGE_ROSETTE_TYPE_DELTA_ROSETTE: StrainGageRosetteType.ValueType  # 15969
STRAIN_GAGE_ROSETTE_TYPE_TEE_ROSETTE: StrainGageRosetteType.ValueType  # 15970
global___StrainGageRosetteType = StrainGageRosetteType

class _StrainUnits1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StrainUnits1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_StrainUnits1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STRAIN_UNITS1_UNSPECIFIED: _StrainUnits1.ValueType  # 0
    STRAIN_UNITS1_STRAIN: _StrainUnits1.ValueType  # 10299
    STRAIN_UNITS1_FROM_CUSTOM_SCALE: _StrainUnits1.ValueType  # 10065

class StrainUnits1(_StrainUnits1, metaclass=_StrainUnits1EnumTypeWrapper): ...

STRAIN_UNITS1_UNSPECIFIED: StrainUnits1.ValueType  # 0
STRAIN_UNITS1_STRAIN: StrainUnits1.ValueType  # 10299
STRAIN_UNITS1_FROM_CUSTOM_SCALE: StrainUnits1.ValueType  # 10065
global___StrainUnits1 = StrainUnits1

class _TEDSUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TEDSUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TEDSUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TEDS_UNITS_UNSPECIFIED: _TEDSUnits.ValueType  # 0
    TEDS_UNITS_FROM_CUSTOM_SCALE: _TEDSUnits.ValueType  # 10065
    TEDS_UNITS_FROM_TEDS: _TEDSUnits.ValueType  # 12516

class TEDSUnits(_TEDSUnits, metaclass=_TEDSUnitsEnumTypeWrapper): ...

TEDS_UNITS_UNSPECIFIED: TEDSUnits.ValueType  # 0
TEDS_UNITS_FROM_CUSTOM_SCALE: TEDSUnits.ValueType  # 10065
TEDS_UNITS_FROM_TEDS: TEDSUnits.ValueType  # 12516
global___TEDSUnits = TEDSUnits

class _TaskControlAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskControlActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TaskControlAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TASK_CONTROL_ACTION_TASK_START: _TaskControlAction.ValueType  # 0
    TASK_CONTROL_ACTION_TASK_STOP: _TaskControlAction.ValueType  # 1
    TASK_CONTROL_ACTION_TASK_VERIFY: _TaskControlAction.ValueType  # 2
    TASK_CONTROL_ACTION_TASK_COMMIT: _TaskControlAction.ValueType  # 3
    TASK_CONTROL_ACTION_TASK_RESERVE: _TaskControlAction.ValueType  # 4
    TASK_CONTROL_ACTION_TASK_UNRESERVE: _TaskControlAction.ValueType  # 5
    TASK_CONTROL_ACTION_TASK_ABORT: _TaskControlAction.ValueType  # 6

class TaskControlAction(_TaskControlAction, metaclass=_TaskControlActionEnumTypeWrapper): ...

TASK_CONTROL_ACTION_TASK_START: TaskControlAction.ValueType  # 0
TASK_CONTROL_ACTION_TASK_STOP: TaskControlAction.ValueType  # 1
TASK_CONTROL_ACTION_TASK_VERIFY: TaskControlAction.ValueType  # 2
TASK_CONTROL_ACTION_TASK_COMMIT: TaskControlAction.ValueType  # 3
TASK_CONTROL_ACTION_TASK_RESERVE: TaskControlAction.ValueType  # 4
TASK_CONTROL_ACTION_TASK_UNRESERVE: TaskControlAction.ValueType  # 5
TASK_CONTROL_ACTION_TASK_ABORT: TaskControlAction.ValueType  # 6
global___TaskControlAction = TaskControlAction

class _TemperatureUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TemperatureUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TemperatureUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TEMPERATURE_UNITS_UNSPECIFIED: _TemperatureUnits.ValueType  # 0
    TEMPERATURE_UNITS_DEG_C: _TemperatureUnits.ValueType  # 10143
    TEMPERATURE_UNITS_DEG_F: _TemperatureUnits.ValueType  # 10144
    TEMPERATURE_UNITS_KELVINS: _TemperatureUnits.ValueType  # 10325
    TEMPERATURE_UNITS_DEG_R: _TemperatureUnits.ValueType  # 10145

class TemperatureUnits(_TemperatureUnits, metaclass=_TemperatureUnitsEnumTypeWrapper): ...

TEMPERATURE_UNITS_UNSPECIFIED: TemperatureUnits.ValueType  # 0
TEMPERATURE_UNITS_DEG_C: TemperatureUnits.ValueType  # 10143
TEMPERATURE_UNITS_DEG_F: TemperatureUnits.ValueType  # 10144
TEMPERATURE_UNITS_KELVINS: TemperatureUnits.ValueType  # 10325
TEMPERATURE_UNITS_DEG_R: TemperatureUnits.ValueType  # 10145
global___TemperatureUnits = TemperatureUnits

class _ThermocoupleType1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThermocoupleType1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThermocoupleType1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    THERMOCOUPLE_TYPE1_UNSPECIFIED: _ThermocoupleType1.ValueType  # 0
    THERMOCOUPLE_TYPE1_J_TYPE_TC: _ThermocoupleType1.ValueType  # 10072
    THERMOCOUPLE_TYPE1_K_TYPE_TC: _ThermocoupleType1.ValueType  # 10073
    THERMOCOUPLE_TYPE1_N_TYPE_TC: _ThermocoupleType1.ValueType  # 10077
    THERMOCOUPLE_TYPE1_R_TYPE_TC: _ThermocoupleType1.ValueType  # 10082
    THERMOCOUPLE_TYPE1_S_TYPE_TC: _ThermocoupleType1.ValueType  # 10085
    THERMOCOUPLE_TYPE1_T_TYPE_TC: _ThermocoupleType1.ValueType  # 10086
    THERMOCOUPLE_TYPE1_B_TYPE_TC: _ThermocoupleType1.ValueType  # 10047
    THERMOCOUPLE_TYPE1_E_TYPE_TC: _ThermocoupleType1.ValueType  # 10055

class ThermocoupleType1(_ThermocoupleType1, metaclass=_ThermocoupleType1EnumTypeWrapper): ...

THERMOCOUPLE_TYPE1_UNSPECIFIED: ThermocoupleType1.ValueType  # 0
THERMOCOUPLE_TYPE1_J_TYPE_TC: ThermocoupleType1.ValueType  # 10072
THERMOCOUPLE_TYPE1_K_TYPE_TC: ThermocoupleType1.ValueType  # 10073
THERMOCOUPLE_TYPE1_N_TYPE_TC: ThermocoupleType1.ValueType  # 10077
THERMOCOUPLE_TYPE1_R_TYPE_TC: ThermocoupleType1.ValueType  # 10082
THERMOCOUPLE_TYPE1_S_TYPE_TC: ThermocoupleType1.ValueType  # 10085
THERMOCOUPLE_TYPE1_T_TYPE_TC: ThermocoupleType1.ValueType  # 10086
THERMOCOUPLE_TYPE1_B_TYPE_TC: ThermocoupleType1.ValueType  # 10047
THERMOCOUPLE_TYPE1_E_TYPE_TC: ThermocoupleType1.ValueType  # 10055
global___ThermocoupleType1 = ThermocoupleType1

class _TimeUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimeUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimeUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIME_UNITS_UNSPECIFIED: _TimeUnits.ValueType  # 0
    TIME_UNITS_SECONDS: _TimeUnits.ValueType  # 10364
    TIME_UNITS_FROM_CUSTOM_SCALE: _TimeUnits.ValueType  # 10065

class TimeUnits(_TimeUnits, metaclass=_TimeUnitsEnumTypeWrapper): ...

TIME_UNITS_UNSPECIFIED: TimeUnits.ValueType  # 0
TIME_UNITS_SECONDS: TimeUnits.ValueType  # 10364
TIME_UNITS_FROM_CUSTOM_SCALE: TimeUnits.ValueType  # 10065
global___TimeUnits = TimeUnits

class _TimeUnits3:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimeUnits3EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimeUnits3.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIME_UNITS3_UNSPECIFIED: _TimeUnits3.ValueType  # 0
    TIME_UNITS3_SECONDS: _TimeUnits3.ValueType  # 10364
    TIME_UNITS3_TICKS: _TimeUnits3.ValueType  # 10304
    TIME_UNITS3_FROM_CUSTOM_SCALE: _TimeUnits3.ValueType  # 10065

class TimeUnits3(_TimeUnits3, metaclass=_TimeUnits3EnumTypeWrapper): ...

TIME_UNITS3_UNSPECIFIED: TimeUnits3.ValueType  # 0
TIME_UNITS3_SECONDS: TimeUnits3.ValueType  # 10364
TIME_UNITS3_TICKS: TimeUnits3.ValueType  # 10304
TIME_UNITS3_FROM_CUSTOM_SCALE: TimeUnits3.ValueType  # 10065
global___TimeUnits3 = TimeUnits3

class _Timescale2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _Timescale2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Timescale2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMESCALE2_UNSPECIFIED: _Timescale2.ValueType  # 0
    TIMESCALE2_HOST_TIME: _Timescale2.ValueType  # 16126
    TIMESCALE2_IO_DEVICE_TIME: _Timescale2.ValueType  # 16127

class Timescale2(_Timescale2, metaclass=_Timescale2EnumTypeWrapper): ...

TIMESCALE2_UNSPECIFIED: Timescale2.ValueType  # 0
TIMESCALE2_HOST_TIME: Timescale2.ValueType  # 16126
TIMESCALE2_IO_DEVICE_TIME: Timescale2.ValueType  # 16127
global___Timescale2 = Timescale2

class _TimestampEvent:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimestampEventEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimestampEvent.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMESTAMP_EVENT_UNSPECIFIED: _TimestampEvent.ValueType  # 0
    TIMESTAMP_EVENT_START_TRIGGER: _TimestampEvent.ValueType  # 12491
    TIMESTAMP_EVENT_REFERENCE_TRIGGER: _TimestampEvent.ValueType  # 12490
    TIMESTAMP_EVENT_ARM_START_TRIGGER: _TimestampEvent.ValueType  # 14641
    TIMESTAMP_EVENT_FIRST_SAMPLE_TIMESTAMP: _TimestampEvent.ValueType  # 16130

class TimestampEvent(_TimestampEvent, metaclass=_TimestampEventEnumTypeWrapper): ...

TIMESTAMP_EVENT_UNSPECIFIED: TimestampEvent.ValueType  # 0
TIMESTAMP_EVENT_START_TRIGGER: TimestampEvent.ValueType  # 12491
TIMESTAMP_EVENT_REFERENCE_TRIGGER: TimestampEvent.ValueType  # 12490
TIMESTAMP_EVENT_ARM_START_TRIGGER: TimestampEvent.ValueType  # 14641
TIMESTAMP_EVENT_FIRST_SAMPLE_TIMESTAMP: TimestampEvent.ValueType  # 16130
global___TimestampEvent = TimestampEvent

class _TorqueUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TorqueUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TorqueUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TORQUE_UNITS_UNSPECIFIED: _TorqueUnits.ValueType  # 0
    TORQUE_UNITS_NEWTON_METERS: _TorqueUnits.ValueType  # 15881
    TORQUE_UNITS_INCH_OUNCES: _TorqueUnits.ValueType  # 15882
    TORQUE_UNITS_INCH_POUNDS: _TorqueUnits.ValueType  # 15883
    TORQUE_UNITS_FOOT_POUNDS: _TorqueUnits.ValueType  # 15884
    TORQUE_UNITS_FROM_CUSTOM_SCALE: _TorqueUnits.ValueType  # 10065

class TorqueUnits(_TorqueUnits, metaclass=_TorqueUnitsEnumTypeWrapper): ...

TORQUE_UNITS_UNSPECIFIED: TorqueUnits.ValueType  # 0
TORQUE_UNITS_NEWTON_METERS: TorqueUnits.ValueType  # 15881
TORQUE_UNITS_INCH_OUNCES: TorqueUnits.ValueType  # 15882
TORQUE_UNITS_INCH_POUNDS: TorqueUnits.ValueType  # 15883
TORQUE_UNITS_FOOT_POUNDS: TorqueUnits.ValueType  # 15884
TORQUE_UNITS_FROM_CUSTOM_SCALE: TorqueUnits.ValueType  # 10065
global___TorqueUnits = TorqueUnits

class _UnitsPreScaled:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UnitsPreScaledEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UnitsPreScaled.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNITS_PRE_SCALED_UNSPECIFIED: _UnitsPreScaled.ValueType  # 0
    UNITS_PRE_SCALED_VOLTS: _UnitsPreScaled.ValueType  # 10348
    UNITS_PRE_SCALED_AMPS: _UnitsPreScaled.ValueType  # 10342
    UNITS_PRE_SCALED_DEG_F: _UnitsPreScaled.ValueType  # 10144
    UNITS_PRE_SCALED_DEG_C: _UnitsPreScaled.ValueType  # 10143
    UNITS_PRE_SCALED_DEG_R: _UnitsPreScaled.ValueType  # 10145
    UNITS_PRE_SCALED_KELVINS: _UnitsPreScaled.ValueType  # 10325
    UNITS_PRE_SCALED_STRAIN: _UnitsPreScaled.ValueType  # 10299
    UNITS_PRE_SCALED_OHMS: _UnitsPreScaled.ValueType  # 10384
    UNITS_PRE_SCALED_HZ: _UnitsPreScaled.ValueType  # 10373
    UNITS_PRE_SCALED_SECONDS: _UnitsPreScaled.ValueType  # 10364
    UNITS_PRE_SCALED_METERS: _UnitsPreScaled.ValueType  # 10219
    UNITS_PRE_SCALED_INCHES: _UnitsPreScaled.ValueType  # 10379
    UNITS_PRE_SCALED_DEGREES: _UnitsPreScaled.ValueType  # 10146
    UNITS_PRE_SCALED_RADIANS: _UnitsPreScaled.ValueType  # 10273
    UNITS_PRE_SCALED_TICKS: _UnitsPreScaled.ValueType  # 10304
    UNITS_PRE_SCALED_RPM: _UnitsPreScaled.ValueType  # 16080
    UNITS_PRE_SCALED_RADIANS_PER_SECOND: _UnitsPreScaled.ValueType  # 16081
    UNITS_PRE_SCALED_DEGREES_PER_SECOND: _UnitsPreScaled.ValueType  # 16082
    UNITS_PRE_SCALED_G: _UnitsPreScaled.ValueType  # 10186
    UNITS_PRE_SCALED_METERS_PER_SECOND_SQUARED: _UnitsPreScaled.ValueType  # 12470
    UNITS_PRE_SCALED_INCHES_PER_SECOND_SQUARED: _UnitsPreScaled.ValueType  # 12471
    UNITS_PRE_SCALED_METERS_PER_SECOND: _UnitsPreScaled.ValueType  # 15959
    UNITS_PRE_SCALED_INCHES_PER_SECOND: _UnitsPreScaled.ValueType  # 15960
    UNITS_PRE_SCALED_PASCALS: _UnitsPreScaled.ValueType  # 10081
    UNITS_PRE_SCALED_NEWTONS: _UnitsPreScaled.ValueType  # 15875
    UNITS_PRE_SCALED_POUNDS: _UnitsPreScaled.ValueType  # 15876
    UNITS_PRE_SCALED_KILOGRAM_FORCE: _UnitsPreScaled.ValueType  # 15877
    UNITS_PRE_SCALED_POUNDS_PER_SQUARE_INCH: _UnitsPreScaled.ValueType  # 15879
    UNITS_PRE_SCALED_BAR: _UnitsPreScaled.ValueType  # 15880
    UNITS_PRE_SCALED_NEWTON_METERS: _UnitsPreScaled.ValueType  # 15881
    UNITS_PRE_SCALED_INCH_OUNCES: _UnitsPreScaled.ValueType  # 15882
    UNITS_PRE_SCALED_INCH_POUNDS: _UnitsPreScaled.ValueType  # 15883
    UNITS_PRE_SCALED_FOOT_POUNDS: _UnitsPreScaled.ValueType  # 15884
    UNITS_PRE_SCALED_VOLTS_PER_VOLT: _UnitsPreScaled.ValueType  # 15896
    UNITS_PRE_SCALED_M_VOLTS_PER_VOLT: _UnitsPreScaled.ValueType  # 15897
    UNITS_PRE_SCALED_COULOMBS: _UnitsPreScaled.ValueType  # 16102
    UNITS_PRE_SCALED_PICO_COULOMBS: _UnitsPreScaled.ValueType  # 16103
    UNITS_PRE_SCALED_FROM_TEDS: _UnitsPreScaled.ValueType  # 12516

class UnitsPreScaled(_UnitsPreScaled, metaclass=_UnitsPreScaledEnumTypeWrapper): ...

UNITS_PRE_SCALED_UNSPECIFIED: UnitsPreScaled.ValueType  # 0
UNITS_PRE_SCALED_VOLTS: UnitsPreScaled.ValueType  # 10348
UNITS_PRE_SCALED_AMPS: UnitsPreScaled.ValueType  # 10342
UNITS_PRE_SCALED_DEG_F: UnitsPreScaled.ValueType  # 10144
UNITS_PRE_SCALED_DEG_C: UnitsPreScaled.ValueType  # 10143
UNITS_PRE_SCALED_DEG_R: UnitsPreScaled.ValueType  # 10145
UNITS_PRE_SCALED_KELVINS: UnitsPreScaled.ValueType  # 10325
UNITS_PRE_SCALED_STRAIN: UnitsPreScaled.ValueType  # 10299
UNITS_PRE_SCALED_OHMS: UnitsPreScaled.ValueType  # 10384
UNITS_PRE_SCALED_HZ: UnitsPreScaled.ValueType  # 10373
UNITS_PRE_SCALED_SECONDS: UnitsPreScaled.ValueType  # 10364
UNITS_PRE_SCALED_METERS: UnitsPreScaled.ValueType  # 10219
UNITS_PRE_SCALED_INCHES: UnitsPreScaled.ValueType  # 10379
UNITS_PRE_SCALED_DEGREES: UnitsPreScaled.ValueType  # 10146
UNITS_PRE_SCALED_RADIANS: UnitsPreScaled.ValueType  # 10273
UNITS_PRE_SCALED_TICKS: UnitsPreScaled.ValueType  # 10304
UNITS_PRE_SCALED_RPM: UnitsPreScaled.ValueType  # 16080
UNITS_PRE_SCALED_RADIANS_PER_SECOND: UnitsPreScaled.ValueType  # 16081
UNITS_PRE_SCALED_DEGREES_PER_SECOND: UnitsPreScaled.ValueType  # 16082
UNITS_PRE_SCALED_G: UnitsPreScaled.ValueType  # 10186
UNITS_PRE_SCALED_METERS_PER_SECOND_SQUARED: UnitsPreScaled.ValueType  # 12470
UNITS_PRE_SCALED_INCHES_PER_SECOND_SQUARED: UnitsPreScaled.ValueType  # 12471
UNITS_PRE_SCALED_METERS_PER_SECOND: UnitsPreScaled.ValueType  # 15959
UNITS_PRE_SCALED_INCHES_PER_SECOND: UnitsPreScaled.ValueType  # 15960
UNITS_PRE_SCALED_PASCALS: UnitsPreScaled.ValueType  # 10081
UNITS_PRE_SCALED_NEWTONS: UnitsPreScaled.ValueType  # 15875
UNITS_PRE_SCALED_POUNDS: UnitsPreScaled.ValueType  # 15876
UNITS_PRE_SCALED_KILOGRAM_FORCE: UnitsPreScaled.ValueType  # 15877
UNITS_PRE_SCALED_POUNDS_PER_SQUARE_INCH: UnitsPreScaled.ValueType  # 15879
UNITS_PRE_SCALED_BAR: UnitsPreScaled.ValueType  # 15880
UNITS_PRE_SCALED_NEWTON_METERS: UnitsPreScaled.ValueType  # 15881
UNITS_PRE_SCALED_INCH_OUNCES: UnitsPreScaled.ValueType  # 15882
UNITS_PRE_SCALED_INCH_POUNDS: UnitsPreScaled.ValueType  # 15883
UNITS_PRE_SCALED_FOOT_POUNDS: UnitsPreScaled.ValueType  # 15884
UNITS_PRE_SCALED_VOLTS_PER_VOLT: UnitsPreScaled.ValueType  # 15896
UNITS_PRE_SCALED_M_VOLTS_PER_VOLT: UnitsPreScaled.ValueType  # 15897
UNITS_PRE_SCALED_COULOMBS: UnitsPreScaled.ValueType  # 16102
UNITS_PRE_SCALED_PICO_COULOMBS: UnitsPreScaled.ValueType  # 16103
UNITS_PRE_SCALED_FROM_TEDS: UnitsPreScaled.ValueType  # 12516
global___UnitsPreScaled = UnitsPreScaled

class _VelocityIEPESensorSensitivityUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VelocityIEPESensorSensitivityUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VelocityIEPESensorSensitivityUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_UNSPECIFIED: _VelocityIEPESensorSensitivityUnits.ValueType  # 0
    VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLIVOLTS_PER_MILLIMETER_PER_SECOND: _VelocityIEPESensorSensitivityUnits.ValueType  # 15963
    VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLI_VOLTS_PER_INCH_PER_SECOND: _VelocityIEPESensorSensitivityUnits.ValueType  # 15964

class VelocityIEPESensorSensitivityUnits(_VelocityIEPESensorSensitivityUnits, metaclass=_VelocityIEPESensorSensitivityUnitsEnumTypeWrapper): ...

VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_UNSPECIFIED: VelocityIEPESensorSensitivityUnits.ValueType  # 0
VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLIVOLTS_PER_MILLIMETER_PER_SECOND: VelocityIEPESensorSensitivityUnits.ValueType  # 15963
VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLI_VOLTS_PER_INCH_PER_SECOND: VelocityIEPESensorSensitivityUnits.ValueType  # 15964
global___VelocityIEPESensorSensitivityUnits = VelocityIEPESensorSensitivityUnits

class _VelocityUnits:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VelocityUnitsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VelocityUnits.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VELOCITY_UNITS_UNSPECIFIED: _VelocityUnits.ValueType  # 0
    VELOCITY_UNITS_METERS_PER_SECOND: _VelocityUnits.ValueType  # 15959
    VELOCITY_UNITS_INCHES_PER_SECOND: _VelocityUnits.ValueType  # 15960
    VELOCITY_UNITS_FROM_CUSTOM_SCALE: _VelocityUnits.ValueType  # 10065

class VelocityUnits(_VelocityUnits, metaclass=_VelocityUnitsEnumTypeWrapper): ...

VELOCITY_UNITS_UNSPECIFIED: VelocityUnits.ValueType  # 0
VELOCITY_UNITS_METERS_PER_SECOND: VelocityUnits.ValueType  # 15959
VELOCITY_UNITS_INCHES_PER_SECOND: VelocityUnits.ValueType  # 15960
VELOCITY_UNITS_FROM_CUSTOM_SCALE: VelocityUnits.ValueType  # 10065
global___VelocityUnits = VelocityUnits

class _VoltageUnits2:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VoltageUnits2EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VoltageUnits2.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VOLTAGE_UNITS2_UNSPECIFIED: _VoltageUnits2.ValueType  # 0
    VOLTAGE_UNITS2_VOLTS: _VoltageUnits2.ValueType  # 10348
    VOLTAGE_UNITS2_FROM_CUSTOM_SCALE: _VoltageUnits2.ValueType  # 10065

class VoltageUnits2(_VoltageUnits2, metaclass=_VoltageUnits2EnumTypeWrapper): ...

VOLTAGE_UNITS2_UNSPECIFIED: VoltageUnits2.ValueType  # 0
VOLTAGE_UNITS2_VOLTS: VoltageUnits2.ValueType  # 10348
VOLTAGE_UNITS2_FROM_CUSTOM_SCALE: VoltageUnits2.ValueType  # 10065
global___VoltageUnits2 = VoltageUnits2

class _WatchdogAOOutputType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogAOOutputTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogAOOutputType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_AO_OUTPUT_TYPE_UNSPECIFIED: _WatchdogAOOutputType.ValueType  # 0
    WATCHDOG_AO_OUTPUT_TYPE_VOLTAGE: _WatchdogAOOutputType.ValueType  # 10322
    WATCHDOG_AO_OUTPUT_TYPE_CURRENT: _WatchdogAOOutputType.ValueType  # 10134
    WATCHDOG_AO_OUTPUT_TYPE_NO_CHANGE: _WatchdogAOOutputType.ValueType  # 10160

class WatchdogAOOutputType(_WatchdogAOOutputType, metaclass=_WatchdogAOOutputTypeEnumTypeWrapper): ...

WATCHDOG_AO_OUTPUT_TYPE_UNSPECIFIED: WatchdogAOOutputType.ValueType  # 0
WATCHDOG_AO_OUTPUT_TYPE_VOLTAGE: WatchdogAOOutputType.ValueType  # 10322
WATCHDOG_AO_OUTPUT_TYPE_CURRENT: WatchdogAOOutputType.ValueType  # 10134
WATCHDOG_AO_OUTPUT_TYPE_NO_CHANGE: WatchdogAOOutputType.ValueType  # 10160
global___WatchdogAOOutputType = WatchdogAOOutputType

class _WatchdogCOExpirState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogCOExpirStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogCOExpirState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_CO_EXPIR_STATE_UNSPECIFIED: _WatchdogCOExpirState.ValueType  # 0
    WATCHDOG_CO_EXPIR_STATE_LOW: _WatchdogCOExpirState.ValueType  # 10214
    WATCHDOG_CO_EXPIR_STATE_HIGH: _WatchdogCOExpirState.ValueType  # 10192
    WATCHDOG_CO_EXPIR_STATE_NO_CHANGE: _WatchdogCOExpirState.ValueType  # 10160

class WatchdogCOExpirState(_WatchdogCOExpirState, metaclass=_WatchdogCOExpirStateEnumTypeWrapper): ...

WATCHDOG_CO_EXPIR_STATE_UNSPECIFIED: WatchdogCOExpirState.ValueType  # 0
WATCHDOG_CO_EXPIR_STATE_LOW: WatchdogCOExpirState.ValueType  # 10214
WATCHDOG_CO_EXPIR_STATE_HIGH: WatchdogCOExpirState.ValueType  # 10192
WATCHDOG_CO_EXPIR_STATE_NO_CHANGE: WatchdogCOExpirState.ValueType  # 10160
global___WatchdogCOExpirState = WatchdogCOExpirState

class _WatchdogControlAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogControlActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogControlAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_CONTROL_ACTION_RESET_TIMER: _WatchdogControlAction.ValueType  # 0
    WATCHDOG_CONTROL_ACTION_CLEAR_EXPIRATION: _WatchdogControlAction.ValueType  # 1

class WatchdogControlAction(_WatchdogControlAction, metaclass=_WatchdogControlActionEnumTypeWrapper): ...

WATCHDOG_CONTROL_ACTION_RESET_TIMER: WatchdogControlAction.ValueType  # 0
WATCHDOG_CONTROL_ACTION_CLEAR_EXPIRATION: WatchdogControlAction.ValueType  # 1
global___WatchdogControlAction = WatchdogControlAction

class _WindowTriggerCondition1:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WindowTriggerCondition1EnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WindowTriggerCondition1.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WINDOW_TRIGGER_CONDITION1_UNSPECIFIED: _WindowTriggerCondition1.ValueType  # 0
    WINDOW_TRIGGER_CONDITION1_ENTERING_WIN: _WindowTriggerCondition1.ValueType  # 10163
    WINDOW_TRIGGER_CONDITION1_LEAVING_WIN: _WindowTriggerCondition1.ValueType  # 10208

class WindowTriggerCondition1(_WindowTriggerCondition1, metaclass=_WindowTriggerCondition1EnumTypeWrapper): ...

WINDOW_TRIGGER_CONDITION1_UNSPECIFIED: WindowTriggerCondition1.ValueType  # 0
WINDOW_TRIGGER_CONDITION1_ENTERING_WIN: WindowTriggerCondition1.ValueType  # 10163
WINDOW_TRIGGER_CONDITION1_LEAVING_WIN: WindowTriggerCondition1.ValueType  # 10208
global___WindowTriggerCondition1 = WindowTriggerCondition1

class _WriteBasicTEDSOptions:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteBasicTEDSOptionsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteBasicTEDSOptions.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_BASIC_TEDS_OPTIONS_UNSPECIFIED: _WriteBasicTEDSOptions.ValueType  # 0
    WRITE_BASIC_TEDS_OPTIONS_WRITE_TO_EEPROM: _WriteBasicTEDSOptions.ValueType  # 12538
    WRITE_BASIC_TEDS_OPTIONS_WRITE_TO_PROM: _WriteBasicTEDSOptions.ValueType  # 12539
    WRITE_BASIC_TEDS_OPTIONS_DO_NOT_WRITE: _WriteBasicTEDSOptions.ValueType  # 12540

class WriteBasicTEDSOptions(_WriteBasicTEDSOptions, metaclass=_WriteBasicTEDSOptionsEnumTypeWrapper): ...

WRITE_BASIC_TEDS_OPTIONS_UNSPECIFIED: WriteBasicTEDSOptions.ValueType  # 0
WRITE_BASIC_TEDS_OPTIONS_WRITE_TO_EEPROM: WriteBasicTEDSOptions.ValueType  # 12538
WRITE_BASIC_TEDS_OPTIONS_WRITE_TO_PROM: WriteBasicTEDSOptions.ValueType  # 12539
WRITE_BASIC_TEDS_OPTIONS_DO_NOT_WRITE: WriteBasicTEDSOptions.ValueType  # 12540
global___WriteBasicTEDSOptions = WriteBasicTEDSOptions

class _ChannelInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChannelInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChannelInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANNEL_INT32_UNSPECIFIED: _ChannelInt32AttributeValues.ValueType  # 0
    CHANNEL_INT32_AC_EXCIT_WIRE_MODE_4_WIRE: _ChannelInt32AttributeValues.ValueType  # 4
    CHANNEL_INT32_AC_EXCIT_WIRE_MODE_5_WIRE: _ChannelInt32AttributeValues.ValueType  # 5
    CHANNEL_INT32_AC_EXCIT_WIRE_MODE_6_WIRE: _ChannelInt32AttributeValues.ValueType  # 6
    CHANNEL_INT32_ADC_TIMING_MODE_AUTOMATIC: _ChannelInt32AttributeValues.ValueType  # 16097
    CHANNEL_INT32_ADC_TIMING_MODE_HIGH_RESOLUTION: _ChannelInt32AttributeValues.ValueType  # 10195
    CHANNEL_INT32_ADC_TIMING_MODE_HIGH_SPEED: _ChannelInt32AttributeValues.ValueType  # 14712
    CHANNEL_INT32_ADC_TIMING_MODE_BEST_50_HZ_REJECTION: _ChannelInt32AttributeValues.ValueType  # 14713
    CHANNEL_INT32_ADC_TIMING_MODE_BEST_60_HZ_REJECTION: _ChannelInt32AttributeValues.ValueType  # 14714
    CHANNEL_INT32_ADC_TIMING_MODE_CUSTOM: _ChannelInt32AttributeValues.ValueType  # 10137
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE: _ChannelInt32AttributeValues.ValueType  # 10322
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS: _ChannelInt32AttributeValues.ValueType  # 10350
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT: _ChannelInt32AttributeValues.ValueType  # 10134
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS: _ChannelInt32AttributeValues.ValueType  # 10351
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION: _ChannelInt32AttributeValues.ValueType  # 10323
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_BRIDGE: _ChannelInt32AttributeValues.ValueType  # 15908
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE: _ChannelInt32AttributeValues.ValueType  # 10181
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_RESISTANCE: _ChannelInt32AttributeValues.ValueType  # 10278
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_TC: _ChannelInt32AttributeValues.ValueType  # 10303
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR: _ChannelInt32AttributeValues.ValueType  # 10302
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD: _ChannelInt32AttributeValues.ValueType  # 10301
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR: _ChannelInt32AttributeValues.ValueType  # 10311
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE: _ChannelInt32AttributeValues.ValueType  # 10300
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE: _ChannelInt32AttributeValues.ValueType  # 15980
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT: _ChannelInt32AttributeValues.ValueType  # 10352
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT: _ChannelInt32AttributeValues.ValueType  # 10353
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE: _ChannelInt32AttributeValues.ValueType  # 14835
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER: _ChannelInt32AttributeValues.ValueType  # 10356
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE: _ChannelInt32AttributeValues.ValueType  # 16104
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE: _ChannelInt32AttributeValues.ValueType  # 16106
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR: _ChannelInt32AttributeValues.ValueType  # 15966
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE: _ChannelInt32AttributeValues.ValueType  # 15899
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR: _ChannelInt32AttributeValues.ValueType  # 15895
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE: _ChannelInt32AttributeValues.ValueType  # 15902
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE: _ChannelInt32AttributeValues.ValueType  # 10354
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE: _ChannelInt32AttributeValues.ValueType  # 15905
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR: _ChannelInt32AttributeValues.ValueType  # 12531
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_CHARGE: _ChannelInt32AttributeValues.ValueType  # 16105
    CHANNEL_INT32_AI_MEASUREMENT_TYPE_POWER: _ChannelInt32AttributeValues.ValueType  # 16201
    CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_ZERO_VOLTS: _ChannelInt32AttributeValues.ValueType  # 12526
    CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_HIGH_IMPEDANCE: _ChannelInt32AttributeValues.ValueType  # 12527
    CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE: _ChannelInt32AttributeValues.ValueType  # 12528
    CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE: _ChannelInt32AttributeValues.ValueType  # 10322
    CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT: _ChannelInt32AttributeValues.ValueType  # 10134
    CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN: _ChannelInt32AttributeValues.ValueType  # 14750
    CHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_G: _ChannelInt32AttributeValues.ValueType  # 16099
    CHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_METERS_PER_SECOND_SQUARED: _ChannelInt32AttributeValues.ValueType  # 16100
    CHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_INCHES_PER_SECOND_SQUARED: _ChannelInt32AttributeValues.ValueType  # 16101
    CHANNEL_INT32_ACCEL_SENSITIVITY_UNITS1_M_VOLTS_PER_G: _ChannelInt32AttributeValues.ValueType  # 12509
    CHANNEL_INT32_ACCEL_SENSITIVITY_UNITS1_VOLTS_PER_G: _ChannelInt32AttributeValues.ValueType  # 12510
    CHANNEL_INT32_ACCEL_UNITS2_ACCEL_UNIT_G: _ChannelInt32AttributeValues.ValueType  # 10186
    CHANNEL_INT32_ACCEL_UNITS2_METERS_PER_SECOND_SQUARED: _ChannelInt32AttributeValues.ValueType  # 12470
    CHANNEL_INT32_ACCEL_UNITS2_INCHES_PER_SECOND_SQUARED: _ChannelInt32AttributeValues.ValueType  # 12471
    CHANNEL_INT32_ACCEL_UNITS2_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_ANGLE_UNITS1_DEGREES: _ChannelInt32AttributeValues.ValueType  # 10146
    CHANNEL_INT32_ANGLE_UNITS1_RADIANS: _ChannelInt32AttributeValues.ValueType  # 10273
    CHANNEL_INT32_ANGLE_UNITS1_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_ANGLE_UNITS2_DEGREES: _ChannelInt32AttributeValues.ValueType  # 10146
    CHANNEL_INT32_ANGLE_UNITS2_RADIANS: _ChannelInt32AttributeValues.ValueType  # 10273
    CHANNEL_INT32_ANGLE_UNITS2_TICKS: _ChannelInt32AttributeValues.ValueType  # 10304
    CHANNEL_INT32_ANGLE_UNITS2_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_ANGLE_UNITS3_DEGREES: _ChannelInt32AttributeValues.ValueType  # 10146
    CHANNEL_INT32_ANGLE_UNITS3_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_RPM: _ChannelInt32AttributeValues.ValueType  # 16080
    CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_RADIANS_PER_SECOND: _ChannelInt32AttributeValues.ValueType  # 16081
    CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_DEGREES_PER_SECOND: _ChannelInt32AttributeValues.ValueType  # 16082
    CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_AUTO_ZERO_TYPE1_NONE: _ChannelInt32AttributeValues.ValueType  # 10230
    CHANNEL_INT32_AUTO_ZERO_TYPE1_ONCE: _ChannelInt32AttributeValues.ValueType  # 10244
    CHANNEL_INT32_AUTO_ZERO_TYPE1_EVERY_SAMPLE: _ChannelInt32AttributeValues.ValueType  # 10164
    CHANNEL_INT32_BRIDGE_CONFIGURATION1_FULL_BRIDGE: _ChannelInt32AttributeValues.ValueType  # 10182
    CHANNEL_INT32_BRIDGE_CONFIGURATION1_HALF_BRIDGE: _ChannelInt32AttributeValues.ValueType  # 10187
    CHANNEL_INT32_BRIDGE_CONFIGURATION1_QUARTER_BRIDGE: _ChannelInt32AttributeValues.ValueType  # 10270
    CHANNEL_INT32_BRIDGE_CONFIGURATION1_NO_BRIDGE: _ChannelInt32AttributeValues.ValueType  # 10228
    CHANNEL_INT32_BRIDGE_ELECTRICAL_UNITS_VOLTS_PER_VOLT: _ChannelInt32AttributeValues.ValueType  # 15896
    CHANNEL_INT32_BRIDGE_ELECTRICAL_UNITS_M_VOLTS_PER_VOLT: _ChannelInt32AttributeValues.ValueType  # 15897
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_NEWTONS: _ChannelInt32AttributeValues.ValueType  # 15875
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_POUNDS: _ChannelInt32AttributeValues.ValueType  # 15876
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_KILOGRAM_FORCE: _ChannelInt32AttributeValues.ValueType  # 15877
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_PASCALS: _ChannelInt32AttributeValues.ValueType  # 10081
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_POUNDS_PER_SQUARE_INCH: _ChannelInt32AttributeValues.ValueType  # 15879
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_BAR: _ChannelInt32AttributeValues.ValueType  # 15880
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_NEWTON_METERS: _ChannelInt32AttributeValues.ValueType  # 15881
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_INCH_OUNCES: _ChannelInt32AttributeValues.ValueType  # 15882
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_INCH_POUNDS: _ChannelInt32AttributeValues.ValueType  # 15883
    CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_FOOT_POUNDS: _ChannelInt32AttributeValues.ValueType  # 15884
    CHANNEL_INT32_BRIDGE_SHUNT_CAL_SOURCE_BUILT_IN: _ChannelInt32AttributeValues.ValueType  # 10200
    CHANNEL_INT32_BRIDGE_SHUNT_CAL_SOURCE_USER_PROVIDED: _ChannelInt32AttributeValues.ValueType  # 10167
    CHANNEL_INT32_BRIDGE_UNITS_VOLTS_PER_VOLT: _ChannelInt32AttributeValues.ValueType  # 15896
    CHANNEL_INT32_BRIDGE_UNITS_M_VOLTS_PER_VOLT: _ChannelInt32AttributeValues.ValueType  # 15897
    CHANNEL_INT32_BRIDGE_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_BRIDGE_UNITS_FROM_TEDS: _ChannelInt32AttributeValues.ValueType  # 12516
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES: _ChannelInt32AttributeValues.ValueType  # 10125
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_FREQ: _ChannelInt32AttributeValues.ValueType  # 10179
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_PERIOD: _ChannelInt32AttributeValues.ValueType  # 10256
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH: _ChannelInt32AttributeValues.ValueType  # 10359
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD: _ChannelInt32AttributeValues.ValueType  # 10289
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY: _ChannelInt32AttributeValues.ValueType  # 15864
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME: _ChannelInt32AttributeValues.ValueType  # 15865
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS: _ChannelInt32AttributeValues.ValueType  # 15866
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE: _ChannelInt32AttributeValues.ValueType  # 16070
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER: _ChannelInt32AttributeValues.ValueType  # 10360
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER: _ChannelInt32AttributeValues.ValueType  # 10361
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER: _ChannelInt32AttributeValues.ValueType  # 16078
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER: _ChannelInt32AttributeValues.ValueType  # 16079
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP: _ChannelInt32AttributeValues.ValueType  # 10267
    CHANNEL_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP: _ChannelInt32AttributeValues.ValueType  # 10362
    CHANNEL_INT32_CJC_SOURCE1_BUILT_IN: _ChannelInt32AttributeValues.ValueType  # 10200
    CHANNEL_INT32_CJC_SOURCE1_CONST_VAL: _ChannelInt32AttributeValues.ValueType  # 10116
    CHANNEL_INT32_CJC_SOURCE1_CHAN: _ChannelInt32AttributeValues.ValueType  # 10113
    CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TIME: _ChannelInt32AttributeValues.ValueType  # 10269
    CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_FREQ: _ChannelInt32AttributeValues.ValueType  # 10119
    CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TICKS: _ChannelInt32AttributeValues.ValueType  # 10268
    CHANNEL_INT32_CHANNEL_TYPE_AI: _ChannelInt32AttributeValues.ValueType  # 10100
    CHANNEL_INT32_CHANNEL_TYPE_AO: _ChannelInt32AttributeValues.ValueType  # 10102
    CHANNEL_INT32_CHANNEL_TYPE_DI: _ChannelInt32AttributeValues.ValueType  # 10151
    CHANNEL_INT32_CHANNEL_TYPE_DO: _ChannelInt32AttributeValues.ValueType  # 10153
    CHANNEL_INT32_CHANNEL_TYPE_CI: _ChannelInt32AttributeValues.ValueType  # 10131
    CHANNEL_INT32_CHANNEL_TYPE_CO: _ChannelInt32AttributeValues.ValueType  # 10132
    CHANNEL_INT32_CHARGE_UNITS_COULOMBS: _ChannelInt32AttributeValues.ValueType  # 16102
    CHANNEL_INT32_CHARGE_UNITS_PICO_COULOMBS: _ChannelInt32AttributeValues.ValueType  # 16103
    CHANNEL_INT32_CHARGE_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_CONSTRAINED_GEN_MODE_UNCONSTRAINED: _ChannelInt32AttributeValues.ValueType  # 14708
    CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_HIGH_FREQ: _ChannelInt32AttributeValues.ValueType  # 14709
    CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_LOW_FREQ: _ChannelInt32AttributeValues.ValueType  # 14710
    CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_50_PERCENT_DUTY_CYCLE: _ChannelInt32AttributeValues.ValueType  # 14711
    CHANNEL_INT32_COUNT_DIRECTION1_COUNT_UP: _ChannelInt32AttributeValues.ValueType  # 10128
    CHANNEL_INT32_COUNT_DIRECTION1_COUNT_DOWN: _ChannelInt32AttributeValues.ValueType  # 10124
    CHANNEL_INT32_COUNT_DIRECTION1_EXT_CONTROLLED: _ChannelInt32AttributeValues.ValueType  # 10326
    CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_LOW_FREQ_1_CTR: _ChannelInt32AttributeValues.ValueType  # 10105
    CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_HIGH_FREQ_2_CTR: _ChannelInt32AttributeValues.ValueType  # 10157
    CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_LARGE_RNG_2_CTR: _ChannelInt32AttributeValues.ValueType  # 10205
    CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_DYN_AVG: _ChannelInt32AttributeValues.ValueType  # 16065
    CHANNEL_INT32_COUPLING1_AC: _ChannelInt32AttributeValues.ValueType  # 10045
    CHANNEL_INT32_COUPLING1_DC: _ChannelInt32AttributeValues.ValueType  # 10050
    CHANNEL_INT32_COUPLING1_GND: _ChannelInt32AttributeValues.ValueType  # 10066
    CHANNEL_INT32_CURRENT_SHUNT_RESISTOR_LOCATION1_INTERNAL: _ChannelInt32AttributeValues.ValueType  # 10200
    CHANNEL_INT32_CURRENT_SHUNT_RESISTOR_LOCATION1_EXTERNAL: _ChannelInt32AttributeValues.ValueType  # 10167
    CHANNEL_INT32_CURRENT_UNITS1_AMPS: _ChannelInt32AttributeValues.ValueType  # 10342
    CHANNEL_INT32_CURRENT_UNITS1_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_CURRENT_UNITS1_FROM_TEDS: _ChannelInt32AttributeValues.ValueType  # 12516
    CHANNEL_INT32_DATA_JUSTIFICATION1_RIGHT_JUSTIFIED: _ChannelInt32AttributeValues.ValueType  # 10279
    CHANNEL_INT32_DATA_JUSTIFICATION1_LEFT_JUSTIFIED: _ChannelInt32AttributeValues.ValueType  # 10209
    CHANNEL_INT32_DATA_TRANSFER_MECHANISM_DMA: _ChannelInt32AttributeValues.ValueType  # 10054
    CHANNEL_INT32_DATA_TRANSFER_MECHANISM_INTERRUPTS: _ChannelInt32AttributeValues.ValueType  # 10204
    CHANNEL_INT32_DATA_TRANSFER_MECHANISM_PROGRAMMED_IO: _ChannelInt32AttributeValues.ValueType  # 10264
    CHANNEL_INT32_DATA_TRANSFER_MECHANISM_US_BBULK: _ChannelInt32AttributeValues.ValueType  # 12590
    CHANNEL_INT32_DIGITAL_DRIVE_TYPE_ACTIVE_DRIVE: _ChannelInt32AttributeValues.ValueType  # 12573
    CHANNEL_INT32_DIGITAL_DRIVE_TYPE_OPEN_COLLECTOR: _ChannelInt32AttributeValues.ValueType  # 12574
    CHANNEL_INT32_DIGITAL_LINE_STATE_HIGH: _ChannelInt32AttributeValues.ValueType  # 10192
    CHANNEL_INT32_DIGITAL_LINE_STATE_LOW: _ChannelInt32AttributeValues.ValueType  # 10214
    CHANNEL_INT32_DIGITAL_LINE_STATE_TRISTATE: _ChannelInt32AttributeValues.ValueType  # 10310
    CHANNEL_INT32_DIGITAL_LINE_STATE_NO_CHANGE: _ChannelInt32AttributeValues.ValueType  # 10160
    CHANNEL_INT32_DIGITAL_WIDTH_UNITS4_SECONDS: _ChannelInt32AttributeValues.ValueType  # 10364
    CHANNEL_INT32_DIGITAL_WIDTH_UNITS4_SAMPLE_CLK_PERIODS: _ChannelInt32AttributeValues.ValueType  # 10286
    CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MIL: _ChannelInt32AttributeValues.ValueType  # 14836
    CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MIL: _ChannelInt32AttributeValues.ValueType  # 14837
    CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MILLIMETER: _ChannelInt32AttributeValues.ValueType  # 14838
    CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MILLIMETER: _ChannelInt32AttributeValues.ValueType  # 14839
    CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MICRON: _ChannelInt32AttributeValues.ValueType  # 14840
    CHANNEL_INT32_EDGE1_RISING: _ChannelInt32AttributeValues.ValueType  # 10280
    CHANNEL_INT32_EDGE1_FALLING: _ChannelInt32AttributeValues.ValueType  # 10171
    CHANNEL_INT32_ENCODER_TYPE2_X1: _ChannelInt32AttributeValues.ValueType  # 10090
    CHANNEL_INT32_ENCODER_TYPE2_X2: _ChannelInt32AttributeValues.ValueType  # 10091
    CHANNEL_INT32_ENCODER_TYPE2_X4: _ChannelInt32AttributeValues.ValueType  # 10092
    CHANNEL_INT32_ENCODER_TYPE2_TWO_PULSE_COUNTING: _ChannelInt32AttributeValues.ValueType  # 10313
    CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_HIGH_B_HIGH: _ChannelInt32AttributeValues.ValueType  # 10040
    CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_HIGH_B_LOW: _ChannelInt32AttributeValues.ValueType  # 10041
    CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_LOW_B_HIGH: _ChannelInt32AttributeValues.ValueType  # 10042
    CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_LOW_B_LOW: _ChannelInt32AttributeValues.ValueType  # 10043
    CHANNEL_INT32_EXCITATION_D_COR_AC_DC: _ChannelInt32AttributeValues.ValueType  # 10050
    CHANNEL_INT32_EXCITATION_D_COR_AC_AC: _ChannelInt32AttributeValues.ValueType  # 10045
    CHANNEL_INT32_EXCITATION_IDLE_OUTPUT_BEHAVIOR_ZERO_VOLTS_OR_AMPS: _ChannelInt32AttributeValues.ValueType  # 12526
    CHANNEL_INT32_EXCITATION_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE: _ChannelInt32AttributeValues.ValueType  # 12528
    CHANNEL_INT32_EXCITATION_SOURCE_INTERNAL: _ChannelInt32AttributeValues.ValueType  # 10200
    CHANNEL_INT32_EXCITATION_SOURCE_EXTERNAL: _ChannelInt32AttributeValues.ValueType  # 10167
    CHANNEL_INT32_EXCITATION_SOURCE_NONE: _ChannelInt32AttributeValues.ValueType  # 10230
    CHANNEL_INT32_EXCITATION_VOLTAGE_OR_CURRENT_VOLTAGE: _ChannelInt32AttributeValues.ValueType  # 10322
    CHANNEL_INT32_EXCITATION_VOLTAGE_OR_CURRENT_CURRENT: _ChannelInt32AttributeValues.ValueType  # 10134
    CHANNEL_INT32_FILTER_RESPONSE_CONSTANT_GROUP_DELAY: _ChannelInt32AttributeValues.ValueType  # 16075
    CHANNEL_INT32_FILTER_RESPONSE_BUTTERWORTH: _ChannelInt32AttributeValues.ValueType  # 16076
    CHANNEL_INT32_FILTER_RESPONSE_ELLIPTICAL: _ChannelInt32AttributeValues.ValueType  # 16077
    CHANNEL_INT32_FILTER_RESPONSE_HARDWARE_DEFINED: _ChannelInt32AttributeValues.ValueType  # 10191
    CHANNEL_INT32_FILTER_RESPONSE1_COMB: _ChannelInt32AttributeValues.ValueType  # 16152
    CHANNEL_INT32_FILTER_RESPONSE1_BESSEL: _ChannelInt32AttributeValues.ValueType  # 16153
    CHANNEL_INT32_FILTER_RESPONSE1_BRICKWALL: _ChannelInt32AttributeValues.ValueType  # 16155
    CHANNEL_INT32_FILTER_RESPONSE1_BUTTERWORTH: _ChannelInt32AttributeValues.ValueType  # 16076
    CHANNEL_INT32_FILTER_TYPE1_HARDWARE_DEFINED: _ChannelInt32AttributeValues.ValueType  # 10191
    CHANNEL_INT32_FILTER_TYPE2_LOWPASS: _ChannelInt32AttributeValues.ValueType  # 16071
    CHANNEL_INT32_FILTER_TYPE2_HIGHPASS: _ChannelInt32AttributeValues.ValueType  # 16072
    CHANNEL_INT32_FILTER_TYPE2_BANDPASS: _ChannelInt32AttributeValues.ValueType  # 16073
    CHANNEL_INT32_FILTER_TYPE2_NOTCH: _ChannelInt32AttributeValues.ValueType  # 16074
    CHANNEL_INT32_FILTER_TYPE2_CUSTOM: _ChannelInt32AttributeValues.ValueType  # 10137
    CHANNEL_INT32_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_NEWTON: _ChannelInt32AttributeValues.ValueType  # 15891
    CHANNEL_INT32_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_POUND: _ChannelInt32AttributeValues.ValueType  # 15892
    CHANNEL_INT32_FORCE_UNITS_NEWTONS: _ChannelInt32AttributeValues.ValueType  # 15875
    CHANNEL_INT32_FORCE_UNITS_POUNDS: _ChannelInt32AttributeValues.ValueType  # 15876
    CHANNEL_INT32_FORCE_UNITS_KILOGRAM_FORCE: _ChannelInt32AttributeValues.ValueType  # 15877
    CHANNEL_INT32_FORCE_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_FREQUENCY_UNITS_HZ: _ChannelInt32AttributeValues.ValueType  # 10373
    CHANNEL_INT32_FREQUENCY_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_FREQUENCY_UNITS2_HZ: _ChannelInt32AttributeValues.ValueType  # 10373
    CHANNEL_INT32_FREQUENCY_UNITS3_HZ: _ChannelInt32AttributeValues.ValueType  # 10373
    CHANNEL_INT32_FREQUENCY_UNITS3_TICKS: _ChannelInt32AttributeValues.ValueType  # 10304
    CHANNEL_INT32_FREQUENCY_UNITS3_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_FUNC_GEN_TYPE_SINE: _ChannelInt32AttributeValues.ValueType  # 14751
    CHANNEL_INT32_FUNC_GEN_TYPE_TRIANGLE: _ChannelInt32AttributeValues.ValueType  # 14752
    CHANNEL_INT32_FUNC_GEN_TYPE_SQUARE: _ChannelInt32AttributeValues.ValueType  # 14753
    CHANNEL_INT32_FUNC_GEN_TYPE_SAWTOOTH: _ChannelInt32AttributeValues.ValueType  # 14754
    CHANNEL_INT32_GPS_SIGNAL_TYPE1_IRIGB: _ChannelInt32AttributeValues.ValueType  # 10070
    CHANNEL_INT32_GPS_SIGNAL_TYPE1_PPS: _ChannelInt32AttributeValues.ValueType  # 10080
    CHANNEL_INT32_GPS_SIGNAL_TYPE1_NONE: _ChannelInt32AttributeValues.ValueType  # 10230
    CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_MORE_THAN_HALF_FULL: _ChannelInt32AttributeValues.ValueType  # 10237
    CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_NOT_EMPTY: _ChannelInt32AttributeValues.ValueType  # 10241
    CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ONBRD_MEM_CUSTOM_THRESHOLD: _ChannelInt32AttributeValues.ValueType  # 12577
    CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_WHEN_ACQ_COMPLETE: _ChannelInt32AttributeValues.ValueType  # 12546
    CHANNEL_INT32_INPUT_TERM_CFG_RSE: _ChannelInt32AttributeValues.ValueType  # 10083
    CHANNEL_INT32_INPUT_TERM_CFG_NRSE: _ChannelInt32AttributeValues.ValueType  # 10078
    CHANNEL_INT32_INPUT_TERM_CFG_DIFF: _ChannelInt32AttributeValues.ValueType  # 10106
    CHANNEL_INT32_INPUT_TERM_CFG_PSEUDO_DIFF: _ChannelInt32AttributeValues.ValueType  # 12529
    CHANNEL_INT32_INPUT_TERM_CFG2_DIFF: _ChannelInt32AttributeValues.ValueType  # 10106
    CHANNEL_INT32_INPUT_TERM_CFG2_RSE: _ChannelInt32AttributeValues.ValueType  # 10083
    CHANNEL_INT32_LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLIMETER: _ChannelInt32AttributeValues.ValueType  # 12506
    CHANNEL_INT32_LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLI_INCH: _ChannelInt32AttributeValues.ValueType  # 12505
    CHANNEL_INT32_LENGTH_UNITS2_METERS: _ChannelInt32AttributeValues.ValueType  # 10219
    CHANNEL_INT32_LENGTH_UNITS2_INCHES: _ChannelInt32AttributeValues.ValueType  # 10379
    CHANNEL_INT32_LENGTH_UNITS2_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_LENGTH_UNITS3_METERS: _ChannelInt32AttributeValues.ValueType  # 10219
    CHANNEL_INT32_LENGTH_UNITS3_INCHES: _ChannelInt32AttributeValues.ValueType  # 10379
    CHANNEL_INT32_LENGTH_UNITS3_TICKS: _ChannelInt32AttributeValues.ValueType  # 10304
    CHANNEL_INT32_LENGTH_UNITS3_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_LENGTH_UNITS4_METERS: _ChannelInt32AttributeValues.ValueType  # 10219
    CHANNEL_INT32_LENGTH_UNITS4_FEET: _ChannelInt32AttributeValues.ValueType  # 10380
    CHANNEL_INT32_LENGTH_UNITS4_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_LEVEL1_HIGH: _ChannelInt32AttributeValues.ValueType  # 10192
    CHANNEL_INT32_LEVEL1_LOW: _ChannelInt32AttributeValues.ValueType  # 10214
    CHANNEL_INT32_LOGIC_FAMILY_2POINT_5_V: _ChannelInt32AttributeValues.ValueType  # 14620
    CHANNEL_INT32_LOGIC_FAMILY_3POINT_3_V: _ChannelInt32AttributeValues.ValueType  # 14621
    CHANNEL_INT32_LOGIC_FAMILY_5_V: _ChannelInt32AttributeValues.ValueType  # 14619
    CHANNEL_INT32_LOGIC_LVL_BEHAVIOR_LOGIC_LEVEL_PULL_UP: _ChannelInt32AttributeValues.ValueType  # 16064
    CHANNEL_INT32_LOGIC_LVL_BEHAVIOR_NONE: _ChannelInt32AttributeValues.ValueType  # 10230
    CHANNEL_INT32_MODULATION_TYPE_AM: _ChannelInt32AttributeValues.ValueType  # 14756
    CHANNEL_INT32_MODULATION_TYPE_FM: _ChannelInt32AttributeValues.ValueType  # 14757
    CHANNEL_INT32_MODULATION_TYPE_NONE: _ChannelInt32AttributeValues.ValueType  # 10230
    CHANNEL_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE: _ChannelInt32AttributeValues.ValueType  # 15997
    CHANNEL_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE: _ChannelInt32AttributeValues.ValueType  # 15998
    CHANNEL_INT32_NAV_MEASUREMENT_TYPE_LATITUDE: _ChannelInt32AttributeValues.ValueType  # 15999
    CHANNEL_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND: _ChannelInt32AttributeValues.ValueType  # 16000
    CHANNEL_INT32_NAV_MEASUREMENT_TYPE_TRACK: _ChannelInt32AttributeValues.ValueType  # 16001
    CHANNEL_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP: _ChannelInt32AttributeValues.ValueType  # 15986
    CHANNEL_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY: _ChannelInt32AttributeValues.ValueType  # 16003
    CHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_EMPTY: _ChannelInt32AttributeValues.ValueType  # 10235
    CHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_HALF_FULL_OR_LESS: _ChannelInt32AttributeValues.ValueType  # 10239
    CHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_NOT_FULL: _ChannelInt32AttributeValues.ValueType  # 10242
    CHANNEL_INT32_OUTPUT_TERM_CFG_RSE: _ChannelInt32AttributeValues.ValueType  # 10083
    CHANNEL_INT32_OUTPUT_TERM_CFG_DIFF: _ChannelInt32AttributeValues.ValueType  # 10106
    CHANNEL_INT32_OUTPUT_TERM_CFG_PSEUDO_DIFF: _ChannelInt32AttributeValues.ValueType  # 12529
    CHANNEL_INT32_POWER_IDLE_OUTPUT_BEHAVIOR_OUTPUT_DISABLED: _ChannelInt32AttributeValues.ValueType  # 15503
    CHANNEL_INT32_POWER_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE: _ChannelInt32AttributeValues.ValueType  # 12528
    CHANNEL_INT32_POWER_OUTPUT_STATE_CONSTANT_VOLTAGE: _ChannelInt32AttributeValues.ValueType  # 15500
    CHANNEL_INT32_POWER_OUTPUT_STATE_CONSTANT_CURRENT: _ChannelInt32AttributeValues.ValueType  # 15501
    CHANNEL_INT32_POWER_OUTPUT_STATE_OVERVOLTAGE: _ChannelInt32AttributeValues.ValueType  # 15502
    CHANNEL_INT32_POWER_OUTPUT_STATE_OUTPUT_DISABLED: _ChannelInt32AttributeValues.ValueType  # 15503
    CHANNEL_INT32_PRESSURE_UNITS_PASCALS: _ChannelInt32AttributeValues.ValueType  # 10081
    CHANNEL_INT32_PRESSURE_UNITS_POUNDS_PER_SQUARE_INCH: _ChannelInt32AttributeValues.ValueType  # 15879
    CHANNEL_INT32_PRESSURE_UNITS_BAR: _ChannelInt32AttributeValues.ValueType  # 15880
    CHANNEL_INT32_PRESSURE_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_RTD_TYPE1_PT_3750: _ChannelInt32AttributeValues.ValueType  # 12481
    CHANNEL_INT32_RTD_TYPE1_PT_3851: _ChannelInt32AttributeValues.ValueType  # 10071
    CHANNEL_INT32_RTD_TYPE1_PT_3911: _ChannelInt32AttributeValues.ValueType  # 12482
    CHANNEL_INT32_RTD_TYPE1_PT_3916: _ChannelInt32AttributeValues.ValueType  # 10069
    CHANNEL_INT32_RTD_TYPE1_PT_3920: _ChannelInt32AttributeValues.ValueType  # 10053
    CHANNEL_INT32_RTD_TYPE1_PT_3928: _ChannelInt32AttributeValues.ValueType  # 12483
    CHANNEL_INT32_RTD_TYPE1_CUSTOM: _ChannelInt32AttributeValues.ValueType  # 10137
    CHANNEL_INT32_RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_DEGREE: _ChannelInt32AttributeValues.ValueType  # 12507
    CHANNEL_INT32_RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_RADIAN: _ChannelInt32AttributeValues.ValueType  # 12508
    CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_NONE: _ChannelInt32AttributeValues.ValueType  # 10230
    CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_LOSSLESS_PACKING: _ChannelInt32AttributeValues.ValueType  # 12555
    CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_LOSSY_LSB_REMOVAL: _ChannelInt32AttributeValues.ValueType  # 12556
    CHANNEL_INT32_RESISTANCE_CONFIGURATION_2_WIRE: _ChannelInt32AttributeValues.ValueType  # 2
    CHANNEL_INT32_RESISTANCE_CONFIGURATION_3_WIRE: _ChannelInt32AttributeValues.ValueType  # 3
    CHANNEL_INT32_RESISTANCE_CONFIGURATION_4_WIRE: _ChannelInt32AttributeValues.ValueType  # 4
    CHANNEL_INT32_RESISTANCE_UNITS1_OHMS: _ChannelInt32AttributeValues.ValueType  # 10384
    CHANNEL_INT32_RESISTANCE_UNITS1_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_RESISTANCE_UNITS1_FROM_TEDS: _ChannelInt32AttributeValues.ValueType  # 12516
    CHANNEL_INT32_RESOLUTION_TYPE1_BITS: _ChannelInt32AttributeValues.ValueType  # 10109
    CHANNEL_INT32_SAMP_CLK_OVERRUN_BEHAVIOR_REPEATED_DATA: _ChannelInt32AttributeValues.ValueType  # 16062
    CHANNEL_INT32_SAMP_CLK_OVERRUN_BEHAVIOR_SENTINEL_VALUE: _ChannelInt32AttributeValues.ValueType  # 16063
    CHANNEL_INT32_SAMPLE_CLOCK_ACTIVE_OR_INACTIVE_EDGE_SELECTION_SAMP_CLK_ACTIVE_EDGE: _ChannelInt32AttributeValues.ValueType  # 14617
    CHANNEL_INT32_SAMPLE_CLOCK_ACTIVE_OR_INACTIVE_EDGE_SELECTION_SAMP_CLK_INACTIVE_EDGE: _ChannelInt32AttributeValues.ValueType  # 14618
    CHANNEL_INT32_SCALE_TYPE2_POLYNOMIAL: _ChannelInt32AttributeValues.ValueType  # 10449
    CHANNEL_INT32_SCALE_TYPE2_TABLE: _ChannelInt32AttributeValues.ValueType  # 10450
    CHANNEL_INT32_SCALE_TYPE3_POLYNOMIAL: _ChannelInt32AttributeValues.ValueType  # 10449
    CHANNEL_INT32_SCALE_TYPE3_TABLE: _ChannelInt32AttributeValues.ValueType  # 10450
    CHANNEL_INT32_SCALE_TYPE3_NONE: _ChannelInt32AttributeValues.ValueType  # 10230
    CHANNEL_INT32_SCALE_TYPE4_NONE: _ChannelInt32AttributeValues.ValueType  # 10230
    CHANNEL_INT32_SCALE_TYPE4_TWO_POINT_LINEAR: _ChannelInt32AttributeValues.ValueType  # 15898
    CHANNEL_INT32_SCALE_TYPE4_TABLE: _ChannelInt32AttributeValues.ValueType  # 10450
    CHANNEL_INT32_SCALE_TYPE4_POLYNOMIAL: _ChannelInt32AttributeValues.ValueType  # 10449
    CHANNEL_INT32_SENSE_LOCAL: _ChannelInt32AttributeValues.ValueType  # 16095
    CHANNEL_INT32_SENSE_REMOTE: _ChannelInt32AttributeValues.ValueType  # 16096
    CHANNEL_INT32_SENSOR_POWER_CFG_NO_CHANGE: _ChannelInt32AttributeValues.ValueType  # 10160
    CHANNEL_INT32_SENSOR_POWER_CFG_ENABLED: _ChannelInt32AttributeValues.ValueType  # 16145
    CHANNEL_INT32_SENSOR_POWER_CFG_DISABLED: _ChannelInt32AttributeValues.ValueType  # 16146
    CHANNEL_INT32_SENSOR_POWER_TYPE_DC: _ChannelInt32AttributeValues.ValueType  # 10050
    CHANNEL_INT32_SENSOR_POWER_TYPE_AC: _ChannelInt32AttributeValues.ValueType  # 10045
    CHANNEL_INT32_SENSOR_POWER_TYPE_BIPOLAR_DC: _ChannelInt32AttributeValues.ValueType  # 16147
    CHANNEL_INT32_SHUNT_CAL_SELECT_A: _ChannelInt32AttributeValues.ValueType  # 12513
    CHANNEL_INT32_SHUNT_CAL_SELECT_B: _ChannelInt32AttributeValues.ValueType  # 12514
    CHANNEL_INT32_SHUNT_CAL_SELECT_A_AND_B: _ChannelInt32AttributeValues.ValueType  # 12515
    CHANNEL_INT32_SOUND_PRESSURE_UNITS1_PASCALS: _ChannelInt32AttributeValues.ValueType  # 10081
    CHANNEL_INT32_SOUND_PRESSURE_UNITS1_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_SOURCE_SELECTION_INTERNAL: _ChannelInt32AttributeValues.ValueType  # 10200
    CHANNEL_INT32_SOURCE_SELECTION_EXTERNAL: _ChannelInt32AttributeValues.ValueType  # 10167
    CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_I: _ChannelInt32AttributeValues.ValueType  # 10183
    CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_II: _ChannelInt32AttributeValues.ValueType  # 10184
    CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_III: _ChannelInt32AttributeValues.ValueType  # 10185
    CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_I: _ChannelInt32AttributeValues.ValueType  # 10188
    CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_II: _ChannelInt32AttributeValues.ValueType  # 10189
    CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_I: _ChannelInt32AttributeValues.ValueType  # 10271
    CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_II: _ChannelInt32AttributeValues.ValueType  # 10272
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_1: _ChannelInt32AttributeValues.ValueType  # 15971
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_2: _ChannelInt32AttributeValues.ValueType  # 15972
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_ANGLE: _ChannelInt32AttributeValues.ValueType  # 15973
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_STRAIN_X: _ChannelInt32AttributeValues.ValueType  # 15974
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_STRAIN_Y: _ChannelInt32AttributeValues.ValueType  # 15975
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_SHEAR_STRAIN_XY: _ChannelInt32AttributeValues.ValueType  # 15976
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_MAX_SHEAR_STRAIN: _ChannelInt32AttributeValues.ValueType  # 15977
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_MAX_SHEAR_STRAIN_ANGLE: _ChannelInt32AttributeValues.ValueType  # 15978
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_RECTANGULAR_ROSETTE: _ChannelInt32AttributeValues.ValueType  # 15968
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_DELTA_ROSETTE: _ChannelInt32AttributeValues.ValueType  # 15969
    CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_TEE_ROSETTE: _ChannelInt32AttributeValues.ValueType  # 15970
    CHANNEL_INT32_STRAIN_UNITS1_STRAIN: _ChannelInt32AttributeValues.ValueType  # 10299
    CHANNEL_INT32_STRAIN_UNITS1_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_SYNC_UNLOCK_BEHAVIOR_STOP_TASK_AND_ERROR: _ChannelInt32AttributeValues.ValueType  # 15862
    CHANNEL_INT32_SYNC_UNLOCK_BEHAVIOR_IGNORE_LOST_SYNC_LOCK: _ChannelInt32AttributeValues.ValueType  # 16129
    CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_C: _ChannelInt32AttributeValues.ValueType  # 10143
    CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_F: _ChannelInt32AttributeValues.ValueType  # 10144
    CHANNEL_INT32_TEMPERATURE_UNITS1_KELVINS: _ChannelInt32AttributeValues.ValueType  # 10325
    CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_R: _ChannelInt32AttributeValues.ValueType  # 10145
    CHANNEL_INT32_TEMPERATURE_UNITS1_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_THERMOCOUPLE_TYPE1_J_TYPE_TC: _ChannelInt32AttributeValues.ValueType  # 10072
    CHANNEL_INT32_THERMOCOUPLE_TYPE1_K_TYPE_TC: _ChannelInt32AttributeValues.ValueType  # 10073
    CHANNEL_INT32_THERMOCOUPLE_TYPE1_N_TYPE_TC: _ChannelInt32AttributeValues.ValueType  # 10077
    CHANNEL_INT32_THERMOCOUPLE_TYPE1_R_TYPE_TC: _ChannelInt32AttributeValues.ValueType  # 10082
    CHANNEL_INT32_THERMOCOUPLE_TYPE1_S_TYPE_TC: _ChannelInt32AttributeValues.ValueType  # 10085
    CHANNEL_INT32_THERMOCOUPLE_TYPE1_T_TYPE_TC: _ChannelInt32AttributeValues.ValueType  # 10086
    CHANNEL_INT32_THERMOCOUPLE_TYPE1_B_TYPE_TC: _ChannelInt32AttributeValues.ValueType  # 10047
    CHANNEL_INT32_THERMOCOUPLE_TYPE1_E_TYPE_TC: _ChannelInt32AttributeValues.ValueType  # 10055
    CHANNEL_INT32_TIME_UNITS_SECONDS: _ChannelInt32AttributeValues.ValueType  # 10364
    CHANNEL_INT32_TIME_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_TIME_UNITS2_SECONDS: _ChannelInt32AttributeValues.ValueType  # 10364
    CHANNEL_INT32_TIME_UNITS3_SECONDS: _ChannelInt32AttributeValues.ValueType  # 10364
    CHANNEL_INT32_TIME_UNITS3_TICKS: _ChannelInt32AttributeValues.ValueType  # 10304
    CHANNEL_INT32_TIME_UNITS3_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_TIMESCALE_TAI: _ChannelInt32AttributeValues.ValueType  # 15988
    CHANNEL_INT32_TIMESCALE_UTC: _ChannelInt32AttributeValues.ValueType  # 15987
    CHANNEL_INT32_TORQUE_UNITS_NEWTON_METERS: _ChannelInt32AttributeValues.ValueType  # 15881
    CHANNEL_INT32_TORQUE_UNITS_INCH_OUNCES: _ChannelInt32AttributeValues.ValueType  # 15882
    CHANNEL_INT32_TORQUE_UNITS_INCH_POUNDS: _ChannelInt32AttributeValues.ValueType  # 15883
    CHANNEL_INT32_TORQUE_UNITS_FOOT_POUNDS: _ChannelInt32AttributeValues.ValueType  # 15884
    CHANNEL_INT32_TORQUE_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLIVOLTS_PER_MILLIMETER_PER_SECOND: _ChannelInt32AttributeValues.ValueType  # 15963
    CHANNEL_INT32_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLI_VOLTS_PER_INCH_PER_SECOND: _ChannelInt32AttributeValues.ValueType  # 15964
    CHANNEL_INT32_VELOCITY_UNITS_METERS_PER_SECOND: _ChannelInt32AttributeValues.ValueType  # 15959
    CHANNEL_INT32_VELOCITY_UNITS_INCHES_PER_SECOND: _ChannelInt32AttributeValues.ValueType  # 15960
    CHANNEL_INT32_VELOCITY_UNITS_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_VELOCITY_UNITS2_METERS_PER_SECOND: _ChannelInt32AttributeValues.ValueType  # 15959
    CHANNEL_INT32_VELOCITY_UNITS2_KILOMETERS_PER_HOUR: _ChannelInt32AttributeValues.ValueType  # 16007
    CHANNEL_INT32_VELOCITY_UNITS2_FEET_PER_SECOND: _ChannelInt32AttributeValues.ValueType  # 16008
    CHANNEL_INT32_VELOCITY_UNITS2_MILES_PER_HOUR: _ChannelInt32AttributeValues.ValueType  # 16009
    CHANNEL_INT32_VELOCITY_UNITS2_KNOTS: _ChannelInt32AttributeValues.ValueType  # 16010
    CHANNEL_INT32_VELOCITY_UNITS2_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_VOLTAGE_UNITS1_VOLTS: _ChannelInt32AttributeValues.ValueType  # 10348
    CHANNEL_INT32_VOLTAGE_UNITS1_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065
    CHANNEL_INT32_VOLTAGE_UNITS1_FROM_TEDS: _ChannelInt32AttributeValues.ValueType  # 12516
    CHANNEL_INT32_VOLTAGE_UNITS2_VOLTS: _ChannelInt32AttributeValues.ValueType  # 10348
    CHANNEL_INT32_VOLTAGE_UNITS2_FROM_CUSTOM_SCALE: _ChannelInt32AttributeValues.ValueType  # 10065

class ChannelInt32AttributeValues(_ChannelInt32AttributeValues, metaclass=_ChannelInt32AttributeValuesEnumTypeWrapper): ...

CHANNEL_INT32_UNSPECIFIED: ChannelInt32AttributeValues.ValueType  # 0
CHANNEL_INT32_AC_EXCIT_WIRE_MODE_4_WIRE: ChannelInt32AttributeValues.ValueType  # 4
CHANNEL_INT32_AC_EXCIT_WIRE_MODE_5_WIRE: ChannelInt32AttributeValues.ValueType  # 5
CHANNEL_INT32_AC_EXCIT_WIRE_MODE_6_WIRE: ChannelInt32AttributeValues.ValueType  # 6
CHANNEL_INT32_ADC_TIMING_MODE_AUTOMATIC: ChannelInt32AttributeValues.ValueType  # 16097
CHANNEL_INT32_ADC_TIMING_MODE_HIGH_RESOLUTION: ChannelInt32AttributeValues.ValueType  # 10195
CHANNEL_INT32_ADC_TIMING_MODE_HIGH_SPEED: ChannelInt32AttributeValues.ValueType  # 14712
CHANNEL_INT32_ADC_TIMING_MODE_BEST_50_HZ_REJECTION: ChannelInt32AttributeValues.ValueType  # 14713
CHANNEL_INT32_ADC_TIMING_MODE_BEST_60_HZ_REJECTION: ChannelInt32AttributeValues.ValueType  # 14714
CHANNEL_INT32_ADC_TIMING_MODE_CUSTOM: ChannelInt32AttributeValues.ValueType  # 10137
CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE: ChannelInt32AttributeValues.ValueType  # 10322
CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS: ChannelInt32AttributeValues.ValueType  # 10350
CHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT: ChannelInt32AttributeValues.ValueType  # 10134
CHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS: ChannelInt32AttributeValues.ValueType  # 10351
CHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION: ChannelInt32AttributeValues.ValueType  # 10323
CHANNEL_INT32_AI_MEASUREMENT_TYPE_BRIDGE: ChannelInt32AttributeValues.ValueType  # 15908
CHANNEL_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE: ChannelInt32AttributeValues.ValueType  # 10181
CHANNEL_INT32_AI_MEASUREMENT_TYPE_RESISTANCE: ChannelInt32AttributeValues.ValueType  # 10278
CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_TC: ChannelInt32AttributeValues.ValueType  # 10303
CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR: ChannelInt32AttributeValues.ValueType  # 10302
CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD: ChannelInt32AttributeValues.ValueType  # 10301
CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR: ChannelInt32AttributeValues.ValueType  # 10311
CHANNEL_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE: ChannelInt32AttributeValues.ValueType  # 10300
CHANNEL_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE: ChannelInt32AttributeValues.ValueType  # 15980
CHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT: ChannelInt32AttributeValues.ValueType  # 10352
CHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT: ChannelInt32AttributeValues.ValueType  # 10353
CHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE: ChannelInt32AttributeValues.ValueType  # 14835
CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER: ChannelInt32AttributeValues.ValueType  # 10356
CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE: ChannelInt32AttributeValues.ValueType  # 16104
CHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE: ChannelInt32AttributeValues.ValueType  # 16106
CHANNEL_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR: ChannelInt32AttributeValues.ValueType  # 15966
CHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE: ChannelInt32AttributeValues.ValueType  # 15899
CHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR: ChannelInt32AttributeValues.ValueType  # 15895
CHANNEL_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE: ChannelInt32AttributeValues.ValueType  # 15902
CHANNEL_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE: ChannelInt32AttributeValues.ValueType  # 10354
CHANNEL_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE: ChannelInt32AttributeValues.ValueType  # 15905
CHANNEL_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR: ChannelInt32AttributeValues.ValueType  # 12531
CHANNEL_INT32_AI_MEASUREMENT_TYPE_CHARGE: ChannelInt32AttributeValues.ValueType  # 16105
CHANNEL_INT32_AI_MEASUREMENT_TYPE_POWER: ChannelInt32AttributeValues.ValueType  # 16201
CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_ZERO_VOLTS: ChannelInt32AttributeValues.ValueType  # 12526
CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_HIGH_IMPEDANCE: ChannelInt32AttributeValues.ValueType  # 12527
CHANNEL_INT32_AO_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE: ChannelInt32AttributeValues.ValueType  # 12528
CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE: ChannelInt32AttributeValues.ValueType  # 10322
CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT: ChannelInt32AttributeValues.ValueType  # 10134
CHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN: ChannelInt32AttributeValues.ValueType  # 14750
CHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_G: ChannelInt32AttributeValues.ValueType  # 16099
CHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_METERS_PER_SECOND_SQUARED: ChannelInt32AttributeValues.ValueType  # 16100
CHANNEL_INT32_ACCEL_CHARGE_SENSITIVITY_UNITS_PICO_COULOMBS_PER_INCHES_PER_SECOND_SQUARED: ChannelInt32AttributeValues.ValueType  # 16101
CHANNEL_INT32_ACCEL_SENSITIVITY_UNITS1_M_VOLTS_PER_G: ChannelInt32AttributeValues.ValueType  # 12509
CHANNEL_INT32_ACCEL_SENSITIVITY_UNITS1_VOLTS_PER_G: ChannelInt32AttributeValues.ValueType  # 12510
CHANNEL_INT32_ACCEL_UNITS2_ACCEL_UNIT_G: ChannelInt32AttributeValues.ValueType  # 10186
CHANNEL_INT32_ACCEL_UNITS2_METERS_PER_SECOND_SQUARED: ChannelInt32AttributeValues.ValueType  # 12470
CHANNEL_INT32_ACCEL_UNITS2_INCHES_PER_SECOND_SQUARED: ChannelInt32AttributeValues.ValueType  # 12471
CHANNEL_INT32_ACCEL_UNITS2_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_ANGLE_UNITS1_DEGREES: ChannelInt32AttributeValues.ValueType  # 10146
CHANNEL_INT32_ANGLE_UNITS1_RADIANS: ChannelInt32AttributeValues.ValueType  # 10273
CHANNEL_INT32_ANGLE_UNITS1_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_ANGLE_UNITS2_DEGREES: ChannelInt32AttributeValues.ValueType  # 10146
CHANNEL_INT32_ANGLE_UNITS2_RADIANS: ChannelInt32AttributeValues.ValueType  # 10273
CHANNEL_INT32_ANGLE_UNITS2_TICKS: ChannelInt32AttributeValues.ValueType  # 10304
CHANNEL_INT32_ANGLE_UNITS2_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_ANGLE_UNITS3_DEGREES: ChannelInt32AttributeValues.ValueType  # 10146
CHANNEL_INT32_ANGLE_UNITS3_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_RPM: ChannelInt32AttributeValues.ValueType  # 16080
CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_RADIANS_PER_SECOND: ChannelInt32AttributeValues.ValueType  # 16081
CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_DEGREES_PER_SECOND: ChannelInt32AttributeValues.ValueType  # 16082
CHANNEL_INT32_ANGULAR_VELOCITY_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_AUTO_ZERO_TYPE1_NONE: ChannelInt32AttributeValues.ValueType  # 10230
CHANNEL_INT32_AUTO_ZERO_TYPE1_ONCE: ChannelInt32AttributeValues.ValueType  # 10244
CHANNEL_INT32_AUTO_ZERO_TYPE1_EVERY_SAMPLE: ChannelInt32AttributeValues.ValueType  # 10164
CHANNEL_INT32_BRIDGE_CONFIGURATION1_FULL_BRIDGE: ChannelInt32AttributeValues.ValueType  # 10182
CHANNEL_INT32_BRIDGE_CONFIGURATION1_HALF_BRIDGE: ChannelInt32AttributeValues.ValueType  # 10187
CHANNEL_INT32_BRIDGE_CONFIGURATION1_QUARTER_BRIDGE: ChannelInt32AttributeValues.ValueType  # 10270
CHANNEL_INT32_BRIDGE_CONFIGURATION1_NO_BRIDGE: ChannelInt32AttributeValues.ValueType  # 10228
CHANNEL_INT32_BRIDGE_ELECTRICAL_UNITS_VOLTS_PER_VOLT: ChannelInt32AttributeValues.ValueType  # 15896
CHANNEL_INT32_BRIDGE_ELECTRICAL_UNITS_M_VOLTS_PER_VOLT: ChannelInt32AttributeValues.ValueType  # 15897
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_NEWTONS: ChannelInt32AttributeValues.ValueType  # 15875
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_POUNDS: ChannelInt32AttributeValues.ValueType  # 15876
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_KILOGRAM_FORCE: ChannelInt32AttributeValues.ValueType  # 15877
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_PASCALS: ChannelInt32AttributeValues.ValueType  # 10081
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_POUNDS_PER_SQUARE_INCH: ChannelInt32AttributeValues.ValueType  # 15879
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_BAR: ChannelInt32AttributeValues.ValueType  # 15880
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_NEWTON_METERS: ChannelInt32AttributeValues.ValueType  # 15881
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_INCH_OUNCES: ChannelInt32AttributeValues.ValueType  # 15882
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_INCH_POUNDS: ChannelInt32AttributeValues.ValueType  # 15883
CHANNEL_INT32_BRIDGE_PHYSICAL_UNITS_FOOT_POUNDS: ChannelInt32AttributeValues.ValueType  # 15884
CHANNEL_INT32_BRIDGE_SHUNT_CAL_SOURCE_BUILT_IN: ChannelInt32AttributeValues.ValueType  # 10200
CHANNEL_INT32_BRIDGE_SHUNT_CAL_SOURCE_USER_PROVIDED: ChannelInt32AttributeValues.ValueType  # 10167
CHANNEL_INT32_BRIDGE_UNITS_VOLTS_PER_VOLT: ChannelInt32AttributeValues.ValueType  # 15896
CHANNEL_INT32_BRIDGE_UNITS_M_VOLTS_PER_VOLT: ChannelInt32AttributeValues.ValueType  # 15897
CHANNEL_INT32_BRIDGE_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_BRIDGE_UNITS_FROM_TEDS: ChannelInt32AttributeValues.ValueType  # 12516
CHANNEL_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES: ChannelInt32AttributeValues.ValueType  # 10125
CHANNEL_INT32_CI_MEASUREMENT_TYPE_FREQ: ChannelInt32AttributeValues.ValueType  # 10179
CHANNEL_INT32_CI_MEASUREMENT_TYPE_PERIOD: ChannelInt32AttributeValues.ValueType  # 10256
CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH: ChannelInt32AttributeValues.ValueType  # 10359
CHANNEL_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD: ChannelInt32AttributeValues.ValueType  # 10289
CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY: ChannelInt32AttributeValues.ValueType  # 15864
CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME: ChannelInt32AttributeValues.ValueType  # 15865
CHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS: ChannelInt32AttributeValues.ValueType  # 15866
CHANNEL_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE: ChannelInt32AttributeValues.ValueType  # 16070
CHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER: ChannelInt32AttributeValues.ValueType  # 10360
CHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER: ChannelInt32AttributeValues.ValueType  # 10361
CHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER: ChannelInt32AttributeValues.ValueType  # 16078
CHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER: ChannelInt32AttributeValues.ValueType  # 16079
CHANNEL_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP: ChannelInt32AttributeValues.ValueType  # 10267
CHANNEL_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP: ChannelInt32AttributeValues.ValueType  # 10362
CHANNEL_INT32_CJC_SOURCE1_BUILT_IN: ChannelInt32AttributeValues.ValueType  # 10200
CHANNEL_INT32_CJC_SOURCE1_CONST_VAL: ChannelInt32AttributeValues.ValueType  # 10116
CHANNEL_INT32_CJC_SOURCE1_CHAN: ChannelInt32AttributeValues.ValueType  # 10113
CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TIME: ChannelInt32AttributeValues.ValueType  # 10269
CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_FREQ: ChannelInt32AttributeValues.ValueType  # 10119
CHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TICKS: ChannelInt32AttributeValues.ValueType  # 10268
CHANNEL_INT32_CHANNEL_TYPE_AI: ChannelInt32AttributeValues.ValueType  # 10100
CHANNEL_INT32_CHANNEL_TYPE_AO: ChannelInt32AttributeValues.ValueType  # 10102
CHANNEL_INT32_CHANNEL_TYPE_DI: ChannelInt32AttributeValues.ValueType  # 10151
CHANNEL_INT32_CHANNEL_TYPE_DO: ChannelInt32AttributeValues.ValueType  # 10153
CHANNEL_INT32_CHANNEL_TYPE_CI: ChannelInt32AttributeValues.ValueType  # 10131
CHANNEL_INT32_CHANNEL_TYPE_CO: ChannelInt32AttributeValues.ValueType  # 10132
CHANNEL_INT32_CHARGE_UNITS_COULOMBS: ChannelInt32AttributeValues.ValueType  # 16102
CHANNEL_INT32_CHARGE_UNITS_PICO_COULOMBS: ChannelInt32AttributeValues.ValueType  # 16103
CHANNEL_INT32_CHARGE_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_CONSTRAINED_GEN_MODE_UNCONSTRAINED: ChannelInt32AttributeValues.ValueType  # 14708
CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_HIGH_FREQ: ChannelInt32AttributeValues.ValueType  # 14709
CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_LOW_FREQ: ChannelInt32AttributeValues.ValueType  # 14710
CHANNEL_INT32_CONSTRAINED_GEN_MODE_FIXED_50_PERCENT_DUTY_CYCLE: ChannelInt32AttributeValues.ValueType  # 14711
CHANNEL_INT32_COUNT_DIRECTION1_COUNT_UP: ChannelInt32AttributeValues.ValueType  # 10128
CHANNEL_INT32_COUNT_DIRECTION1_COUNT_DOWN: ChannelInt32AttributeValues.ValueType  # 10124
CHANNEL_INT32_COUNT_DIRECTION1_EXT_CONTROLLED: ChannelInt32AttributeValues.ValueType  # 10326
CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_LOW_FREQ_1_CTR: ChannelInt32AttributeValues.ValueType  # 10105
CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_HIGH_FREQ_2_CTR: ChannelInt32AttributeValues.ValueType  # 10157
CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_LARGE_RNG_2_CTR: ChannelInt32AttributeValues.ValueType  # 10205
CHANNEL_INT32_COUNTER_FREQUENCY_METHOD_DYN_AVG: ChannelInt32AttributeValues.ValueType  # 16065
CHANNEL_INT32_COUPLING1_AC: ChannelInt32AttributeValues.ValueType  # 10045
CHANNEL_INT32_COUPLING1_DC: ChannelInt32AttributeValues.ValueType  # 10050
CHANNEL_INT32_COUPLING1_GND: ChannelInt32AttributeValues.ValueType  # 10066
CHANNEL_INT32_CURRENT_SHUNT_RESISTOR_LOCATION1_INTERNAL: ChannelInt32AttributeValues.ValueType  # 10200
CHANNEL_INT32_CURRENT_SHUNT_RESISTOR_LOCATION1_EXTERNAL: ChannelInt32AttributeValues.ValueType  # 10167
CHANNEL_INT32_CURRENT_UNITS1_AMPS: ChannelInt32AttributeValues.ValueType  # 10342
CHANNEL_INT32_CURRENT_UNITS1_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_CURRENT_UNITS1_FROM_TEDS: ChannelInt32AttributeValues.ValueType  # 12516
CHANNEL_INT32_DATA_JUSTIFICATION1_RIGHT_JUSTIFIED: ChannelInt32AttributeValues.ValueType  # 10279
CHANNEL_INT32_DATA_JUSTIFICATION1_LEFT_JUSTIFIED: ChannelInt32AttributeValues.ValueType  # 10209
CHANNEL_INT32_DATA_TRANSFER_MECHANISM_DMA: ChannelInt32AttributeValues.ValueType  # 10054
CHANNEL_INT32_DATA_TRANSFER_MECHANISM_INTERRUPTS: ChannelInt32AttributeValues.ValueType  # 10204
CHANNEL_INT32_DATA_TRANSFER_MECHANISM_PROGRAMMED_IO: ChannelInt32AttributeValues.ValueType  # 10264
CHANNEL_INT32_DATA_TRANSFER_MECHANISM_US_BBULK: ChannelInt32AttributeValues.ValueType  # 12590
CHANNEL_INT32_DIGITAL_DRIVE_TYPE_ACTIVE_DRIVE: ChannelInt32AttributeValues.ValueType  # 12573
CHANNEL_INT32_DIGITAL_DRIVE_TYPE_OPEN_COLLECTOR: ChannelInt32AttributeValues.ValueType  # 12574
CHANNEL_INT32_DIGITAL_LINE_STATE_HIGH: ChannelInt32AttributeValues.ValueType  # 10192
CHANNEL_INT32_DIGITAL_LINE_STATE_LOW: ChannelInt32AttributeValues.ValueType  # 10214
CHANNEL_INT32_DIGITAL_LINE_STATE_TRISTATE: ChannelInt32AttributeValues.ValueType  # 10310
CHANNEL_INT32_DIGITAL_LINE_STATE_NO_CHANGE: ChannelInt32AttributeValues.ValueType  # 10160
CHANNEL_INT32_DIGITAL_WIDTH_UNITS4_SECONDS: ChannelInt32AttributeValues.ValueType  # 10364
CHANNEL_INT32_DIGITAL_WIDTH_UNITS4_SAMPLE_CLK_PERIODS: ChannelInt32AttributeValues.ValueType  # 10286
CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MIL: ChannelInt32AttributeValues.ValueType  # 14836
CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MIL: ChannelInt32AttributeValues.ValueType  # 14837
CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MILLIMETER: ChannelInt32AttributeValues.ValueType  # 14838
CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_VOLTS_PER_MILLIMETER: ChannelInt32AttributeValues.ValueType  # 14839
CHANNEL_INT32_EDDY_CURRENT_PROX_PROBE_SENSITIVITY_UNITS_M_VOLTS_PER_MICRON: ChannelInt32AttributeValues.ValueType  # 14840
CHANNEL_INT32_EDGE1_RISING: ChannelInt32AttributeValues.ValueType  # 10280
CHANNEL_INT32_EDGE1_FALLING: ChannelInt32AttributeValues.ValueType  # 10171
CHANNEL_INT32_ENCODER_TYPE2_X1: ChannelInt32AttributeValues.ValueType  # 10090
CHANNEL_INT32_ENCODER_TYPE2_X2: ChannelInt32AttributeValues.ValueType  # 10091
CHANNEL_INT32_ENCODER_TYPE2_X4: ChannelInt32AttributeValues.ValueType  # 10092
CHANNEL_INT32_ENCODER_TYPE2_TWO_PULSE_COUNTING: ChannelInt32AttributeValues.ValueType  # 10313
CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_HIGH_B_HIGH: ChannelInt32AttributeValues.ValueType  # 10040
CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_HIGH_B_LOW: ChannelInt32AttributeValues.ValueType  # 10041
CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_LOW_B_HIGH: ChannelInt32AttributeValues.ValueType  # 10042
CHANNEL_INT32_ENCODER_Z_INDEX_PHASE1_A_LOW_B_LOW: ChannelInt32AttributeValues.ValueType  # 10043
CHANNEL_INT32_EXCITATION_D_COR_AC_DC: ChannelInt32AttributeValues.ValueType  # 10050
CHANNEL_INT32_EXCITATION_D_COR_AC_AC: ChannelInt32AttributeValues.ValueType  # 10045
CHANNEL_INT32_EXCITATION_IDLE_OUTPUT_BEHAVIOR_ZERO_VOLTS_OR_AMPS: ChannelInt32AttributeValues.ValueType  # 12526
CHANNEL_INT32_EXCITATION_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE: ChannelInt32AttributeValues.ValueType  # 12528
CHANNEL_INT32_EXCITATION_SOURCE_INTERNAL: ChannelInt32AttributeValues.ValueType  # 10200
CHANNEL_INT32_EXCITATION_SOURCE_EXTERNAL: ChannelInt32AttributeValues.ValueType  # 10167
CHANNEL_INT32_EXCITATION_SOURCE_NONE: ChannelInt32AttributeValues.ValueType  # 10230
CHANNEL_INT32_EXCITATION_VOLTAGE_OR_CURRENT_VOLTAGE: ChannelInt32AttributeValues.ValueType  # 10322
CHANNEL_INT32_EXCITATION_VOLTAGE_OR_CURRENT_CURRENT: ChannelInt32AttributeValues.ValueType  # 10134
CHANNEL_INT32_FILTER_RESPONSE_CONSTANT_GROUP_DELAY: ChannelInt32AttributeValues.ValueType  # 16075
CHANNEL_INT32_FILTER_RESPONSE_BUTTERWORTH: ChannelInt32AttributeValues.ValueType  # 16076
CHANNEL_INT32_FILTER_RESPONSE_ELLIPTICAL: ChannelInt32AttributeValues.ValueType  # 16077
CHANNEL_INT32_FILTER_RESPONSE_HARDWARE_DEFINED: ChannelInt32AttributeValues.ValueType  # 10191
CHANNEL_INT32_FILTER_RESPONSE1_COMB: ChannelInt32AttributeValues.ValueType  # 16152
CHANNEL_INT32_FILTER_RESPONSE1_BESSEL: ChannelInt32AttributeValues.ValueType  # 16153
CHANNEL_INT32_FILTER_RESPONSE1_BRICKWALL: ChannelInt32AttributeValues.ValueType  # 16155
CHANNEL_INT32_FILTER_RESPONSE1_BUTTERWORTH: ChannelInt32AttributeValues.ValueType  # 16076
CHANNEL_INT32_FILTER_TYPE1_HARDWARE_DEFINED: ChannelInt32AttributeValues.ValueType  # 10191
CHANNEL_INT32_FILTER_TYPE2_LOWPASS: ChannelInt32AttributeValues.ValueType  # 16071
CHANNEL_INT32_FILTER_TYPE2_HIGHPASS: ChannelInt32AttributeValues.ValueType  # 16072
CHANNEL_INT32_FILTER_TYPE2_BANDPASS: ChannelInt32AttributeValues.ValueType  # 16073
CHANNEL_INT32_FILTER_TYPE2_NOTCH: ChannelInt32AttributeValues.ValueType  # 16074
CHANNEL_INT32_FILTER_TYPE2_CUSTOM: ChannelInt32AttributeValues.ValueType  # 10137
CHANNEL_INT32_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_NEWTON: ChannelInt32AttributeValues.ValueType  # 15891
CHANNEL_INT32_FORCE_IEPE_SENSOR_SENSITIVITY_UNITS_M_VOLTS_PER_POUND: ChannelInt32AttributeValues.ValueType  # 15892
CHANNEL_INT32_FORCE_UNITS_NEWTONS: ChannelInt32AttributeValues.ValueType  # 15875
CHANNEL_INT32_FORCE_UNITS_POUNDS: ChannelInt32AttributeValues.ValueType  # 15876
CHANNEL_INT32_FORCE_UNITS_KILOGRAM_FORCE: ChannelInt32AttributeValues.ValueType  # 15877
CHANNEL_INT32_FORCE_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_FREQUENCY_UNITS_HZ: ChannelInt32AttributeValues.ValueType  # 10373
CHANNEL_INT32_FREQUENCY_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_FREQUENCY_UNITS2_HZ: ChannelInt32AttributeValues.ValueType  # 10373
CHANNEL_INT32_FREQUENCY_UNITS3_HZ: ChannelInt32AttributeValues.ValueType  # 10373
CHANNEL_INT32_FREQUENCY_UNITS3_TICKS: ChannelInt32AttributeValues.ValueType  # 10304
CHANNEL_INT32_FREQUENCY_UNITS3_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_FUNC_GEN_TYPE_SINE: ChannelInt32AttributeValues.ValueType  # 14751
CHANNEL_INT32_FUNC_GEN_TYPE_TRIANGLE: ChannelInt32AttributeValues.ValueType  # 14752
CHANNEL_INT32_FUNC_GEN_TYPE_SQUARE: ChannelInt32AttributeValues.ValueType  # 14753
CHANNEL_INT32_FUNC_GEN_TYPE_SAWTOOTH: ChannelInt32AttributeValues.ValueType  # 14754
CHANNEL_INT32_GPS_SIGNAL_TYPE1_IRIGB: ChannelInt32AttributeValues.ValueType  # 10070
CHANNEL_INT32_GPS_SIGNAL_TYPE1_PPS: ChannelInt32AttributeValues.ValueType  # 10080
CHANNEL_INT32_GPS_SIGNAL_TYPE1_NONE: ChannelInt32AttributeValues.ValueType  # 10230
CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_MORE_THAN_HALF_FULL: ChannelInt32AttributeValues.ValueType  # 10237
CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_NOT_EMPTY: ChannelInt32AttributeValues.ValueType  # 10241
CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_ONBRD_MEM_CUSTOM_THRESHOLD: ChannelInt32AttributeValues.ValueType  # 12577
CHANNEL_INT32_INPUT_DATA_TRANSFER_CONDITION_WHEN_ACQ_COMPLETE: ChannelInt32AttributeValues.ValueType  # 12546
CHANNEL_INT32_INPUT_TERM_CFG_RSE: ChannelInt32AttributeValues.ValueType  # 10083
CHANNEL_INT32_INPUT_TERM_CFG_NRSE: ChannelInt32AttributeValues.ValueType  # 10078
CHANNEL_INT32_INPUT_TERM_CFG_DIFF: ChannelInt32AttributeValues.ValueType  # 10106
CHANNEL_INT32_INPUT_TERM_CFG_PSEUDO_DIFF: ChannelInt32AttributeValues.ValueType  # 12529
CHANNEL_INT32_INPUT_TERM_CFG2_DIFF: ChannelInt32AttributeValues.ValueType  # 10106
CHANNEL_INT32_INPUT_TERM_CFG2_RSE: ChannelInt32AttributeValues.ValueType  # 10083
CHANNEL_INT32_LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLIMETER: ChannelInt32AttributeValues.ValueType  # 12506
CHANNEL_INT32_LVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_MILLI_INCH: ChannelInt32AttributeValues.ValueType  # 12505
CHANNEL_INT32_LENGTH_UNITS2_METERS: ChannelInt32AttributeValues.ValueType  # 10219
CHANNEL_INT32_LENGTH_UNITS2_INCHES: ChannelInt32AttributeValues.ValueType  # 10379
CHANNEL_INT32_LENGTH_UNITS2_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_LENGTH_UNITS3_METERS: ChannelInt32AttributeValues.ValueType  # 10219
CHANNEL_INT32_LENGTH_UNITS3_INCHES: ChannelInt32AttributeValues.ValueType  # 10379
CHANNEL_INT32_LENGTH_UNITS3_TICKS: ChannelInt32AttributeValues.ValueType  # 10304
CHANNEL_INT32_LENGTH_UNITS3_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_LENGTH_UNITS4_METERS: ChannelInt32AttributeValues.ValueType  # 10219
CHANNEL_INT32_LENGTH_UNITS4_FEET: ChannelInt32AttributeValues.ValueType  # 10380
CHANNEL_INT32_LENGTH_UNITS4_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_LEVEL1_HIGH: ChannelInt32AttributeValues.ValueType  # 10192
CHANNEL_INT32_LEVEL1_LOW: ChannelInt32AttributeValues.ValueType  # 10214
CHANNEL_INT32_LOGIC_FAMILY_2POINT_5_V: ChannelInt32AttributeValues.ValueType  # 14620
CHANNEL_INT32_LOGIC_FAMILY_3POINT_3_V: ChannelInt32AttributeValues.ValueType  # 14621
CHANNEL_INT32_LOGIC_FAMILY_5_V: ChannelInt32AttributeValues.ValueType  # 14619
CHANNEL_INT32_LOGIC_LVL_BEHAVIOR_LOGIC_LEVEL_PULL_UP: ChannelInt32AttributeValues.ValueType  # 16064
CHANNEL_INT32_LOGIC_LVL_BEHAVIOR_NONE: ChannelInt32AttributeValues.ValueType  # 10230
CHANNEL_INT32_MODULATION_TYPE_AM: ChannelInt32AttributeValues.ValueType  # 14756
CHANNEL_INT32_MODULATION_TYPE_FM: ChannelInt32AttributeValues.ValueType  # 14757
CHANNEL_INT32_MODULATION_TYPE_NONE: ChannelInt32AttributeValues.ValueType  # 10230
CHANNEL_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE: ChannelInt32AttributeValues.ValueType  # 15997
CHANNEL_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE: ChannelInt32AttributeValues.ValueType  # 15998
CHANNEL_INT32_NAV_MEASUREMENT_TYPE_LATITUDE: ChannelInt32AttributeValues.ValueType  # 15999
CHANNEL_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND: ChannelInt32AttributeValues.ValueType  # 16000
CHANNEL_INT32_NAV_MEASUREMENT_TYPE_TRACK: ChannelInt32AttributeValues.ValueType  # 16001
CHANNEL_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP: ChannelInt32AttributeValues.ValueType  # 15986
CHANNEL_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY: ChannelInt32AttributeValues.ValueType  # 16003
CHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_EMPTY: ChannelInt32AttributeValues.ValueType  # 10235
CHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_HALF_FULL_OR_LESS: ChannelInt32AttributeValues.ValueType  # 10239
CHANNEL_INT32_OUTPUT_DATA_TRANSFER_CONDITION_ON_BRD_MEM_NOT_FULL: ChannelInt32AttributeValues.ValueType  # 10242
CHANNEL_INT32_OUTPUT_TERM_CFG_RSE: ChannelInt32AttributeValues.ValueType  # 10083
CHANNEL_INT32_OUTPUT_TERM_CFG_DIFF: ChannelInt32AttributeValues.ValueType  # 10106
CHANNEL_INT32_OUTPUT_TERM_CFG_PSEUDO_DIFF: ChannelInt32AttributeValues.ValueType  # 12529
CHANNEL_INT32_POWER_IDLE_OUTPUT_BEHAVIOR_OUTPUT_DISABLED: ChannelInt32AttributeValues.ValueType  # 15503
CHANNEL_INT32_POWER_IDLE_OUTPUT_BEHAVIOR_MAINTAIN_EXISTING_VALUE: ChannelInt32AttributeValues.ValueType  # 12528
CHANNEL_INT32_POWER_OUTPUT_STATE_CONSTANT_VOLTAGE: ChannelInt32AttributeValues.ValueType  # 15500
CHANNEL_INT32_POWER_OUTPUT_STATE_CONSTANT_CURRENT: ChannelInt32AttributeValues.ValueType  # 15501
CHANNEL_INT32_POWER_OUTPUT_STATE_OVERVOLTAGE: ChannelInt32AttributeValues.ValueType  # 15502
CHANNEL_INT32_POWER_OUTPUT_STATE_OUTPUT_DISABLED: ChannelInt32AttributeValues.ValueType  # 15503
CHANNEL_INT32_PRESSURE_UNITS_PASCALS: ChannelInt32AttributeValues.ValueType  # 10081
CHANNEL_INT32_PRESSURE_UNITS_POUNDS_PER_SQUARE_INCH: ChannelInt32AttributeValues.ValueType  # 15879
CHANNEL_INT32_PRESSURE_UNITS_BAR: ChannelInt32AttributeValues.ValueType  # 15880
CHANNEL_INT32_PRESSURE_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_RTD_TYPE1_PT_3750: ChannelInt32AttributeValues.ValueType  # 12481
CHANNEL_INT32_RTD_TYPE1_PT_3851: ChannelInt32AttributeValues.ValueType  # 10071
CHANNEL_INT32_RTD_TYPE1_PT_3911: ChannelInt32AttributeValues.ValueType  # 12482
CHANNEL_INT32_RTD_TYPE1_PT_3916: ChannelInt32AttributeValues.ValueType  # 10069
CHANNEL_INT32_RTD_TYPE1_PT_3920: ChannelInt32AttributeValues.ValueType  # 10053
CHANNEL_INT32_RTD_TYPE1_PT_3928: ChannelInt32AttributeValues.ValueType  # 12483
CHANNEL_INT32_RTD_TYPE1_CUSTOM: ChannelInt32AttributeValues.ValueType  # 10137
CHANNEL_INT32_RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_DEGREE: ChannelInt32AttributeValues.ValueType  # 12507
CHANNEL_INT32_RVDT_SENSITIVITY_UNITS1_M_VOLTS_PER_VOLT_PER_RADIAN: ChannelInt32AttributeValues.ValueType  # 12508
CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_NONE: ChannelInt32AttributeValues.ValueType  # 10230
CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_LOSSLESS_PACKING: ChannelInt32AttributeValues.ValueType  # 12555
CHANNEL_INT32_RAW_DATA_COMPRESSION_TYPE_LOSSY_LSB_REMOVAL: ChannelInt32AttributeValues.ValueType  # 12556
CHANNEL_INT32_RESISTANCE_CONFIGURATION_2_WIRE: ChannelInt32AttributeValues.ValueType  # 2
CHANNEL_INT32_RESISTANCE_CONFIGURATION_3_WIRE: ChannelInt32AttributeValues.ValueType  # 3
CHANNEL_INT32_RESISTANCE_CONFIGURATION_4_WIRE: ChannelInt32AttributeValues.ValueType  # 4
CHANNEL_INT32_RESISTANCE_UNITS1_OHMS: ChannelInt32AttributeValues.ValueType  # 10384
CHANNEL_INT32_RESISTANCE_UNITS1_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_RESISTANCE_UNITS1_FROM_TEDS: ChannelInt32AttributeValues.ValueType  # 12516
CHANNEL_INT32_RESOLUTION_TYPE1_BITS: ChannelInt32AttributeValues.ValueType  # 10109
CHANNEL_INT32_SAMP_CLK_OVERRUN_BEHAVIOR_REPEATED_DATA: ChannelInt32AttributeValues.ValueType  # 16062
CHANNEL_INT32_SAMP_CLK_OVERRUN_BEHAVIOR_SENTINEL_VALUE: ChannelInt32AttributeValues.ValueType  # 16063
CHANNEL_INT32_SAMPLE_CLOCK_ACTIVE_OR_INACTIVE_EDGE_SELECTION_SAMP_CLK_ACTIVE_EDGE: ChannelInt32AttributeValues.ValueType  # 14617
CHANNEL_INT32_SAMPLE_CLOCK_ACTIVE_OR_INACTIVE_EDGE_SELECTION_SAMP_CLK_INACTIVE_EDGE: ChannelInt32AttributeValues.ValueType  # 14618
CHANNEL_INT32_SCALE_TYPE2_POLYNOMIAL: ChannelInt32AttributeValues.ValueType  # 10449
CHANNEL_INT32_SCALE_TYPE2_TABLE: ChannelInt32AttributeValues.ValueType  # 10450
CHANNEL_INT32_SCALE_TYPE3_POLYNOMIAL: ChannelInt32AttributeValues.ValueType  # 10449
CHANNEL_INT32_SCALE_TYPE3_TABLE: ChannelInt32AttributeValues.ValueType  # 10450
CHANNEL_INT32_SCALE_TYPE3_NONE: ChannelInt32AttributeValues.ValueType  # 10230
CHANNEL_INT32_SCALE_TYPE4_NONE: ChannelInt32AttributeValues.ValueType  # 10230
CHANNEL_INT32_SCALE_TYPE4_TWO_POINT_LINEAR: ChannelInt32AttributeValues.ValueType  # 15898
CHANNEL_INT32_SCALE_TYPE4_TABLE: ChannelInt32AttributeValues.ValueType  # 10450
CHANNEL_INT32_SCALE_TYPE4_POLYNOMIAL: ChannelInt32AttributeValues.ValueType  # 10449
CHANNEL_INT32_SENSE_LOCAL: ChannelInt32AttributeValues.ValueType  # 16095
CHANNEL_INT32_SENSE_REMOTE: ChannelInt32AttributeValues.ValueType  # 16096
CHANNEL_INT32_SENSOR_POWER_CFG_NO_CHANGE: ChannelInt32AttributeValues.ValueType  # 10160
CHANNEL_INT32_SENSOR_POWER_CFG_ENABLED: ChannelInt32AttributeValues.ValueType  # 16145
CHANNEL_INT32_SENSOR_POWER_CFG_DISABLED: ChannelInt32AttributeValues.ValueType  # 16146
CHANNEL_INT32_SENSOR_POWER_TYPE_DC: ChannelInt32AttributeValues.ValueType  # 10050
CHANNEL_INT32_SENSOR_POWER_TYPE_AC: ChannelInt32AttributeValues.ValueType  # 10045
CHANNEL_INT32_SENSOR_POWER_TYPE_BIPOLAR_DC: ChannelInt32AttributeValues.ValueType  # 16147
CHANNEL_INT32_SHUNT_CAL_SELECT_A: ChannelInt32AttributeValues.ValueType  # 12513
CHANNEL_INT32_SHUNT_CAL_SELECT_B: ChannelInt32AttributeValues.ValueType  # 12514
CHANNEL_INT32_SHUNT_CAL_SELECT_A_AND_B: ChannelInt32AttributeValues.ValueType  # 12515
CHANNEL_INT32_SOUND_PRESSURE_UNITS1_PASCALS: ChannelInt32AttributeValues.ValueType  # 10081
CHANNEL_INT32_SOUND_PRESSURE_UNITS1_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_SOURCE_SELECTION_INTERNAL: ChannelInt32AttributeValues.ValueType  # 10200
CHANNEL_INT32_SOURCE_SELECTION_EXTERNAL: ChannelInt32AttributeValues.ValueType  # 10167
CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_I: ChannelInt32AttributeValues.ValueType  # 10183
CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_II: ChannelInt32AttributeValues.ValueType  # 10184
CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_FULL_BRIDGE_III: ChannelInt32AttributeValues.ValueType  # 10185
CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_I: ChannelInt32AttributeValues.ValueType  # 10188
CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_HALF_BRIDGE_II: ChannelInt32AttributeValues.ValueType  # 10189
CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_I: ChannelInt32AttributeValues.ValueType  # 10271
CHANNEL_INT32_STRAIN_GAGE_BRIDGE_TYPE1_QUARTER_BRIDGE_II: ChannelInt32AttributeValues.ValueType  # 10272
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_1: ChannelInt32AttributeValues.ValueType  # 15971
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_2: ChannelInt32AttributeValues.ValueType  # 15972
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_PRINCIPAL_STRAIN_ANGLE: ChannelInt32AttributeValues.ValueType  # 15973
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_STRAIN_X: ChannelInt32AttributeValues.ValueType  # 15974
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_STRAIN_Y: ChannelInt32AttributeValues.ValueType  # 15975
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_CARTESIAN_SHEAR_STRAIN_XY: ChannelInt32AttributeValues.ValueType  # 15976
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_MAX_SHEAR_STRAIN: ChannelInt32AttributeValues.ValueType  # 15977
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_MEASUREMENT_TYPE_MAX_SHEAR_STRAIN_ANGLE: ChannelInt32AttributeValues.ValueType  # 15978
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_RECTANGULAR_ROSETTE: ChannelInt32AttributeValues.ValueType  # 15968
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_DELTA_ROSETTE: ChannelInt32AttributeValues.ValueType  # 15969
CHANNEL_INT32_STRAIN_GAGE_ROSETTE_TYPE_TEE_ROSETTE: ChannelInt32AttributeValues.ValueType  # 15970
CHANNEL_INT32_STRAIN_UNITS1_STRAIN: ChannelInt32AttributeValues.ValueType  # 10299
CHANNEL_INT32_STRAIN_UNITS1_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_SYNC_UNLOCK_BEHAVIOR_STOP_TASK_AND_ERROR: ChannelInt32AttributeValues.ValueType  # 15862
CHANNEL_INT32_SYNC_UNLOCK_BEHAVIOR_IGNORE_LOST_SYNC_LOCK: ChannelInt32AttributeValues.ValueType  # 16129
CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_C: ChannelInt32AttributeValues.ValueType  # 10143
CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_F: ChannelInt32AttributeValues.ValueType  # 10144
CHANNEL_INT32_TEMPERATURE_UNITS1_KELVINS: ChannelInt32AttributeValues.ValueType  # 10325
CHANNEL_INT32_TEMPERATURE_UNITS1_DEG_R: ChannelInt32AttributeValues.ValueType  # 10145
CHANNEL_INT32_TEMPERATURE_UNITS1_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_THERMOCOUPLE_TYPE1_J_TYPE_TC: ChannelInt32AttributeValues.ValueType  # 10072
CHANNEL_INT32_THERMOCOUPLE_TYPE1_K_TYPE_TC: ChannelInt32AttributeValues.ValueType  # 10073
CHANNEL_INT32_THERMOCOUPLE_TYPE1_N_TYPE_TC: ChannelInt32AttributeValues.ValueType  # 10077
CHANNEL_INT32_THERMOCOUPLE_TYPE1_R_TYPE_TC: ChannelInt32AttributeValues.ValueType  # 10082
CHANNEL_INT32_THERMOCOUPLE_TYPE1_S_TYPE_TC: ChannelInt32AttributeValues.ValueType  # 10085
CHANNEL_INT32_THERMOCOUPLE_TYPE1_T_TYPE_TC: ChannelInt32AttributeValues.ValueType  # 10086
CHANNEL_INT32_THERMOCOUPLE_TYPE1_B_TYPE_TC: ChannelInt32AttributeValues.ValueType  # 10047
CHANNEL_INT32_THERMOCOUPLE_TYPE1_E_TYPE_TC: ChannelInt32AttributeValues.ValueType  # 10055
CHANNEL_INT32_TIME_UNITS_SECONDS: ChannelInt32AttributeValues.ValueType  # 10364
CHANNEL_INT32_TIME_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_TIME_UNITS2_SECONDS: ChannelInt32AttributeValues.ValueType  # 10364
CHANNEL_INT32_TIME_UNITS3_SECONDS: ChannelInt32AttributeValues.ValueType  # 10364
CHANNEL_INT32_TIME_UNITS3_TICKS: ChannelInt32AttributeValues.ValueType  # 10304
CHANNEL_INT32_TIME_UNITS3_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_TIMESCALE_TAI: ChannelInt32AttributeValues.ValueType  # 15988
CHANNEL_INT32_TIMESCALE_UTC: ChannelInt32AttributeValues.ValueType  # 15987
CHANNEL_INT32_TORQUE_UNITS_NEWTON_METERS: ChannelInt32AttributeValues.ValueType  # 15881
CHANNEL_INT32_TORQUE_UNITS_INCH_OUNCES: ChannelInt32AttributeValues.ValueType  # 15882
CHANNEL_INT32_TORQUE_UNITS_INCH_POUNDS: ChannelInt32AttributeValues.ValueType  # 15883
CHANNEL_INT32_TORQUE_UNITS_FOOT_POUNDS: ChannelInt32AttributeValues.ValueType  # 15884
CHANNEL_INT32_TORQUE_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLIVOLTS_PER_MILLIMETER_PER_SECOND: ChannelInt32AttributeValues.ValueType  # 15963
CHANNEL_INT32_VELOCITY_IEPE_SENSOR_SENSITIVITY_UNITS_MILLI_VOLTS_PER_INCH_PER_SECOND: ChannelInt32AttributeValues.ValueType  # 15964
CHANNEL_INT32_VELOCITY_UNITS_METERS_PER_SECOND: ChannelInt32AttributeValues.ValueType  # 15959
CHANNEL_INT32_VELOCITY_UNITS_INCHES_PER_SECOND: ChannelInt32AttributeValues.ValueType  # 15960
CHANNEL_INT32_VELOCITY_UNITS_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_VELOCITY_UNITS2_METERS_PER_SECOND: ChannelInt32AttributeValues.ValueType  # 15959
CHANNEL_INT32_VELOCITY_UNITS2_KILOMETERS_PER_HOUR: ChannelInt32AttributeValues.ValueType  # 16007
CHANNEL_INT32_VELOCITY_UNITS2_FEET_PER_SECOND: ChannelInt32AttributeValues.ValueType  # 16008
CHANNEL_INT32_VELOCITY_UNITS2_MILES_PER_HOUR: ChannelInt32AttributeValues.ValueType  # 16009
CHANNEL_INT32_VELOCITY_UNITS2_KNOTS: ChannelInt32AttributeValues.ValueType  # 16010
CHANNEL_INT32_VELOCITY_UNITS2_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_VOLTAGE_UNITS1_VOLTS: ChannelInt32AttributeValues.ValueType  # 10348
CHANNEL_INT32_VOLTAGE_UNITS1_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
CHANNEL_INT32_VOLTAGE_UNITS1_FROM_TEDS: ChannelInt32AttributeValues.ValueType  # 12516
CHANNEL_INT32_VOLTAGE_UNITS2_VOLTS: ChannelInt32AttributeValues.ValueType  # 10348
CHANNEL_INT32_VOLTAGE_UNITS2_FROM_CUSTOM_SCALE: ChannelInt32AttributeValues.ValueType  # 10065
global___ChannelInt32AttributeValues = ChannelInt32AttributeValues

class _DeviceInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_INT32_UNSPECIFIED: _DeviceInt32AttributeValues.ValueType  # 0
    DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE: _DeviceInt32AttributeValues.ValueType  # 10322
    DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS: _DeviceInt32AttributeValues.ValueType  # 10350
    DEVICE_INT32_AI_MEASUREMENT_TYPE_CURRENT: _DeviceInt32AttributeValues.ValueType  # 10134
    DEVICE_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS: _DeviceInt32AttributeValues.ValueType  # 10351
    DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION: _DeviceInt32AttributeValues.ValueType  # 10323
    DEVICE_INT32_AI_MEASUREMENT_TYPE_BRIDGE: _DeviceInt32AttributeValues.ValueType  # 15908
    DEVICE_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE: _DeviceInt32AttributeValues.ValueType  # 10181
    DEVICE_INT32_AI_MEASUREMENT_TYPE_RESISTANCE: _DeviceInt32AttributeValues.ValueType  # 10278
    DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_TC: _DeviceInt32AttributeValues.ValueType  # 10303
    DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR: _DeviceInt32AttributeValues.ValueType  # 10302
    DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD: _DeviceInt32AttributeValues.ValueType  # 10301
    DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR: _DeviceInt32AttributeValues.ValueType  # 10311
    DEVICE_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE: _DeviceInt32AttributeValues.ValueType  # 10300
    DEVICE_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE: _DeviceInt32AttributeValues.ValueType  # 15980
    DEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT: _DeviceInt32AttributeValues.ValueType  # 10352
    DEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT: _DeviceInt32AttributeValues.ValueType  # 10353
    DEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE: _DeviceInt32AttributeValues.ValueType  # 14835
    DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER: _DeviceInt32AttributeValues.ValueType  # 10356
    DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE: _DeviceInt32AttributeValues.ValueType  # 16104
    DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE: _DeviceInt32AttributeValues.ValueType  # 16106
    DEVICE_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR: _DeviceInt32AttributeValues.ValueType  # 15966
    DEVICE_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE: _DeviceInt32AttributeValues.ValueType  # 15899
    DEVICE_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR: _DeviceInt32AttributeValues.ValueType  # 15895
    DEVICE_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE: _DeviceInt32AttributeValues.ValueType  # 15902
    DEVICE_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE: _DeviceInt32AttributeValues.ValueType  # 10354
    DEVICE_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE: _DeviceInt32AttributeValues.ValueType  # 15905
    DEVICE_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR: _DeviceInt32AttributeValues.ValueType  # 12531
    DEVICE_INT32_AI_MEASUREMENT_TYPE_CHARGE: _DeviceInt32AttributeValues.ValueType  # 16105
    DEVICE_INT32_AI_MEASUREMENT_TYPE_POWER: _DeviceInt32AttributeValues.ValueType  # 16201
    DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE: _DeviceInt32AttributeValues.ValueType  # 10322
    DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT: _DeviceInt32AttributeValues.ValueType  # 10134
    DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN: _DeviceInt32AttributeValues.ValueType  # 14750
    DEVICE_INT32_ACQUISITION_TYPE_FINITE_SAMPS: _DeviceInt32AttributeValues.ValueType  # 10178
    DEVICE_INT32_ACQUISITION_TYPE_CONT_SAMPS: _DeviceInt32AttributeValues.ValueType  # 10123
    DEVICE_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT: _DeviceInt32AttributeValues.ValueType  # 12522
    DEVICE_INT32_ALT_REF_MSL: _DeviceInt32AttributeValues.ValueType  # 16005
    DEVICE_INT32_ALT_REF_HAE: _DeviceInt32AttributeValues.ValueType  # 16006
    DEVICE_INT32_ANT_STATUS_UNKNOWN: _DeviceInt32AttributeValues.ValueType  # 12588
    DEVICE_INT32_ANT_STATUS_NORMAL: _DeviceInt32AttributeValues.ValueType  # 10459
    DEVICE_INT32_ANT_STATUS_ABSENT: _DeviceInt32AttributeValues.ValueType  # 15994
    DEVICE_INT32_ANT_STATUS_OVERCURRENT: _DeviceInt32AttributeValues.ValueType  # 15995
    DEVICE_INT32_BUS_TYPE_PCI: _DeviceInt32AttributeValues.ValueType  # 12582
    DEVICE_INT32_BUS_TYPE_PCIE: _DeviceInt32AttributeValues.ValueType  # 13612
    DEVICE_INT32_BUS_TYPE_PXI: _DeviceInt32AttributeValues.ValueType  # 12583
    DEVICE_INT32_BUS_TYPE_PXIE: _DeviceInt32AttributeValues.ValueType  # 14706
    DEVICE_INT32_BUS_TYPE_SCXI: _DeviceInt32AttributeValues.ValueType  # 12584
    DEVICE_INT32_BUS_TYPE_SCC: _DeviceInt32AttributeValues.ValueType  # 14707
    DEVICE_INT32_BUS_TYPE_PC_CARD: _DeviceInt32AttributeValues.ValueType  # 12585
    DEVICE_INT32_BUS_TYPE_USB: _DeviceInt32AttributeValues.ValueType  # 12586
    DEVICE_INT32_BUS_TYPE_COMPACT_DAQ: _DeviceInt32AttributeValues.ValueType  # 14637
    DEVICE_INT32_BUS_TYPE_COMPACT_RIO: _DeviceInt32AttributeValues.ValueType  # 16143
    DEVICE_INT32_BUS_TYPE_TCPIP: _DeviceInt32AttributeValues.ValueType  # 14828
    DEVICE_INT32_BUS_TYPE_UNKNOWN: _DeviceInt32AttributeValues.ValueType  # 12588
    DEVICE_INT32_BUS_TYPE_SWITCH_BLOCK: _DeviceInt32AttributeValues.ValueType  # 15870
    DEVICE_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES: _DeviceInt32AttributeValues.ValueType  # 10125
    DEVICE_INT32_CI_MEASUREMENT_TYPE_FREQ: _DeviceInt32AttributeValues.ValueType  # 10179
    DEVICE_INT32_CI_MEASUREMENT_TYPE_PERIOD: _DeviceInt32AttributeValues.ValueType  # 10256
    DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH: _DeviceInt32AttributeValues.ValueType  # 10359
    DEVICE_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD: _DeviceInt32AttributeValues.ValueType  # 10289
    DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY: _DeviceInt32AttributeValues.ValueType  # 15864
    DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME: _DeviceInt32AttributeValues.ValueType  # 15865
    DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS: _DeviceInt32AttributeValues.ValueType  # 15866
    DEVICE_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE: _DeviceInt32AttributeValues.ValueType  # 16070
    DEVICE_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER: _DeviceInt32AttributeValues.ValueType  # 10360
    DEVICE_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER: _DeviceInt32AttributeValues.ValueType  # 10361
    DEVICE_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER: _DeviceInt32AttributeValues.ValueType  # 16078
    DEVICE_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER: _DeviceInt32AttributeValues.ValueType  # 16079
    DEVICE_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP: _DeviceInt32AttributeValues.ValueType  # 10267
    DEVICE_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP: _DeviceInt32AttributeValues.ValueType  # 10362
    DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_TIME: _DeviceInt32AttributeValues.ValueType  # 10269
    DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_FREQ: _DeviceInt32AttributeValues.ValueType  # 10119
    DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_TICKS: _DeviceInt32AttributeValues.ValueType  # 10268
    DEVICE_INT32_COUPLING_TYPES_AC: _DeviceInt32AttributeValues.ValueType  # 1
    DEVICE_INT32_COUPLING_TYPES_DC: _DeviceInt32AttributeValues.ValueType  # 2
    DEVICE_INT32_COUPLING_TYPES_GROUND: _DeviceInt32AttributeValues.ValueType  # 4
    DEVICE_INT32_COUPLING_TYPES_HF_REJECT: _DeviceInt32AttributeValues.ValueType  # 8
    DEVICE_INT32_COUPLING_TYPES_LF_REJECT: _DeviceInt32AttributeValues.ValueType  # 16
    DEVICE_INT32_COUPLING_TYPES_NOISE_REJECT: _DeviceInt32AttributeValues.ValueType  # 32
    DEVICE_INT32_FILTER_TYPE2_LOWPASS: _DeviceInt32AttributeValues.ValueType  # 16071
    DEVICE_INT32_FILTER_TYPE2_HIGHPASS: _DeviceInt32AttributeValues.ValueType  # 16072
    DEVICE_INT32_FILTER_TYPE2_BANDPASS: _DeviceInt32AttributeValues.ValueType  # 16073
    DEVICE_INT32_FILTER_TYPE2_NOTCH: _DeviceInt32AttributeValues.ValueType  # 16074
    DEVICE_INT32_FILTER_TYPE2_CUSTOM: _DeviceInt32AttributeValues.ValueType  # 10137
    DEVICE_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE: _DeviceInt32AttributeValues.ValueType  # 15997
    DEVICE_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE: _DeviceInt32AttributeValues.ValueType  # 15998
    DEVICE_INT32_NAV_MEASUREMENT_TYPE_LATITUDE: _DeviceInt32AttributeValues.ValueType  # 15999
    DEVICE_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND: _DeviceInt32AttributeValues.ValueType  # 16000
    DEVICE_INT32_NAV_MEASUREMENT_TYPE_TRACK: _DeviceInt32AttributeValues.ValueType  # 16001
    DEVICE_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP: _DeviceInt32AttributeValues.ValueType  # 15986
    DEVICE_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY: _DeviceInt32AttributeValues.ValueType  # 16003
    DEVICE_INT32_NAV_MODE_MOBILE: _DeviceInt32AttributeValues.ValueType  # 15989
    DEVICE_INT32_NAV_MODE_STATIONARY_WITH_SURVEY: _DeviceInt32AttributeValues.ValueType  # 15990
    DEVICE_INT32_NAV_MODE_STATIONARY_WITH_PRESET_LOCATION: _DeviceInt32AttributeValues.ValueType  # 15991
    DEVICE_INT32_PRODUCT_CATEGORY_M_SERIES_DAQ: _DeviceInt32AttributeValues.ValueType  # 14643
    DEVICE_INT32_PRODUCT_CATEGORY_X_SERIES_DAQ: _DeviceInt32AttributeValues.ValueType  # 15858
    DEVICE_INT32_PRODUCT_CATEGORY_E_SERIES_DAQ: _DeviceInt32AttributeValues.ValueType  # 14642
    DEVICE_INT32_PRODUCT_CATEGORY_S_SERIES_DAQ: _DeviceInt32AttributeValues.ValueType  # 14644
    DEVICE_INT32_PRODUCT_CATEGORY_B_SERIES_DAQ: _DeviceInt32AttributeValues.ValueType  # 14662
    DEVICE_INT32_PRODUCT_CATEGORY_SC_SERIES_DAQ: _DeviceInt32AttributeValues.ValueType  # 14645
    DEVICE_INT32_PRODUCT_CATEGORY_USBDAQ: _DeviceInt32AttributeValues.ValueType  # 14646
    DEVICE_INT32_PRODUCT_CATEGORY_AO_SERIES: _DeviceInt32AttributeValues.ValueType  # 14647
    DEVICE_INT32_PRODUCT_CATEGORY_DIGITAL_IO: _DeviceInt32AttributeValues.ValueType  # 14648
    DEVICE_INT32_PRODUCT_CATEGORY_TIO_SERIES: _DeviceInt32AttributeValues.ValueType  # 14661
    DEVICE_INT32_PRODUCT_CATEGORY_DYNAMIC_SIGNAL_ACQUISITION: _DeviceInt32AttributeValues.ValueType  # 14649
    DEVICE_INT32_PRODUCT_CATEGORY_SWITCHES: _DeviceInt32AttributeValues.ValueType  # 14650
    DEVICE_INT32_PRODUCT_CATEGORY_COMPACT_DAQ_CHASSIS: _DeviceInt32AttributeValues.ValueType  # 14658
    DEVICE_INT32_PRODUCT_CATEGORY_COMPACT_RIO_CHASSIS: _DeviceInt32AttributeValues.ValueType  # 16144
    DEVICE_INT32_PRODUCT_CATEGORY_C_SERIES_MODULE: _DeviceInt32AttributeValues.ValueType  # 14659
    DEVICE_INT32_PRODUCT_CATEGORY_SCXI_MODULE: _DeviceInt32AttributeValues.ValueType  # 14660
    DEVICE_INT32_PRODUCT_CATEGORY_SCC_CONNECTOR_BLOCK: _DeviceInt32AttributeValues.ValueType  # 14704
    DEVICE_INT32_PRODUCT_CATEGORY_SCC_MODULE: _DeviceInt32AttributeValues.ValueType  # 14705
    DEVICE_INT32_PRODUCT_CATEGORY_NIELVIS: _DeviceInt32AttributeValues.ValueType  # 14755
    DEVICE_INT32_PRODUCT_CATEGORY_NETWORK_DAQ: _DeviceInt32AttributeValues.ValueType  # 14829
    DEVICE_INT32_PRODUCT_CATEGORY_SC_EXPRESS: _DeviceInt32AttributeValues.ValueType  # 15886
    DEVICE_INT32_PRODUCT_CATEGORY_FIELD_DAQ: _DeviceInt32AttributeValues.ValueType  # 16151
    DEVICE_INT32_PRODUCT_CATEGORY_TEST_SCALE_CHASSIS: _DeviceInt32AttributeValues.ValueType  # 16180
    DEVICE_INT32_PRODUCT_CATEGORY_TEST_SCALE_MODULE: _DeviceInt32AttributeValues.ValueType  # 16181
    DEVICE_INT32_PRODUCT_CATEGORY_UNKNOWN: _DeviceInt32AttributeValues.ValueType  # 12588
    DEVICE_INT32_TRIGGER_USAGE_ADVANCE: _DeviceInt32AttributeValues.ValueType  # 12488
    DEVICE_INT32_TRIGGER_USAGE_PAUSE: _DeviceInt32AttributeValues.ValueType  # 12489
    DEVICE_INT32_TRIGGER_USAGE_REFERENCE: _DeviceInt32AttributeValues.ValueType  # 12490
    DEVICE_INT32_TRIGGER_USAGE_START: _DeviceInt32AttributeValues.ValueType  # 12491
    DEVICE_INT32_TRIGGER_USAGE_HANDSHAKE: _DeviceInt32AttributeValues.ValueType  # 10389
    DEVICE_INT32_TRIGGER_USAGE_ARM_START: _DeviceInt32AttributeValues.ValueType  # 14641
    DEVICE_INT32_TRIGGER_USAGE_TYPES_ADVANCE: _DeviceInt32AttributeValues.ValueType  # 1
    DEVICE_INT32_TRIGGER_USAGE_TYPES_PAUSE: _DeviceInt32AttributeValues.ValueType  # 2
    DEVICE_INT32_TRIGGER_USAGE_TYPES_REFERENCE: _DeviceInt32AttributeValues.ValueType  # 4
    DEVICE_INT32_TRIGGER_USAGE_TYPES_START: _DeviceInt32AttributeValues.ValueType  # 8
    DEVICE_INT32_TRIGGER_USAGE_TYPES_HANDSHAKE: _DeviceInt32AttributeValues.ValueType  # 16
    DEVICE_INT32_TRIGGER_USAGE_TYPES_ARM_START: _DeviceInt32AttributeValues.ValueType  # 32

class DeviceInt32AttributeValues(_DeviceInt32AttributeValues, metaclass=_DeviceInt32AttributeValuesEnumTypeWrapper): ...

DEVICE_INT32_UNSPECIFIED: DeviceInt32AttributeValues.ValueType  # 0
DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE: DeviceInt32AttributeValues.ValueType  # 10322
DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS: DeviceInt32AttributeValues.ValueType  # 10350
DEVICE_INT32_AI_MEASUREMENT_TYPE_CURRENT: DeviceInt32AttributeValues.ValueType  # 10134
DEVICE_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS: DeviceInt32AttributeValues.ValueType  # 10351
DEVICE_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION: DeviceInt32AttributeValues.ValueType  # 10323
DEVICE_INT32_AI_MEASUREMENT_TYPE_BRIDGE: DeviceInt32AttributeValues.ValueType  # 15908
DEVICE_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE: DeviceInt32AttributeValues.ValueType  # 10181
DEVICE_INT32_AI_MEASUREMENT_TYPE_RESISTANCE: DeviceInt32AttributeValues.ValueType  # 10278
DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_TC: DeviceInt32AttributeValues.ValueType  # 10303
DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR: DeviceInt32AttributeValues.ValueType  # 10302
DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD: DeviceInt32AttributeValues.ValueType  # 10301
DEVICE_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR: DeviceInt32AttributeValues.ValueType  # 10311
DEVICE_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE: DeviceInt32AttributeValues.ValueType  # 10300
DEVICE_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE: DeviceInt32AttributeValues.ValueType  # 15980
DEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT: DeviceInt32AttributeValues.ValueType  # 10352
DEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT: DeviceInt32AttributeValues.ValueType  # 10353
DEVICE_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE: DeviceInt32AttributeValues.ValueType  # 14835
DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER: DeviceInt32AttributeValues.ValueType  # 10356
DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE: DeviceInt32AttributeValues.ValueType  # 16104
DEVICE_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE: DeviceInt32AttributeValues.ValueType  # 16106
DEVICE_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR: DeviceInt32AttributeValues.ValueType  # 15966
DEVICE_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE: DeviceInt32AttributeValues.ValueType  # 15899
DEVICE_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR: DeviceInt32AttributeValues.ValueType  # 15895
DEVICE_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE: DeviceInt32AttributeValues.ValueType  # 15902
DEVICE_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE: DeviceInt32AttributeValues.ValueType  # 10354
DEVICE_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE: DeviceInt32AttributeValues.ValueType  # 15905
DEVICE_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR: DeviceInt32AttributeValues.ValueType  # 12531
DEVICE_INT32_AI_MEASUREMENT_TYPE_CHARGE: DeviceInt32AttributeValues.ValueType  # 16105
DEVICE_INT32_AI_MEASUREMENT_TYPE_POWER: DeviceInt32AttributeValues.ValueType  # 16201
DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE: DeviceInt32AttributeValues.ValueType  # 10322
DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT: DeviceInt32AttributeValues.ValueType  # 10134
DEVICE_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN: DeviceInt32AttributeValues.ValueType  # 14750
DEVICE_INT32_ACQUISITION_TYPE_FINITE_SAMPS: DeviceInt32AttributeValues.ValueType  # 10178
DEVICE_INT32_ACQUISITION_TYPE_CONT_SAMPS: DeviceInt32AttributeValues.ValueType  # 10123
DEVICE_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT: DeviceInt32AttributeValues.ValueType  # 12522
DEVICE_INT32_ALT_REF_MSL: DeviceInt32AttributeValues.ValueType  # 16005
DEVICE_INT32_ALT_REF_HAE: DeviceInt32AttributeValues.ValueType  # 16006
DEVICE_INT32_ANT_STATUS_UNKNOWN: DeviceInt32AttributeValues.ValueType  # 12588
DEVICE_INT32_ANT_STATUS_NORMAL: DeviceInt32AttributeValues.ValueType  # 10459
DEVICE_INT32_ANT_STATUS_ABSENT: DeviceInt32AttributeValues.ValueType  # 15994
DEVICE_INT32_ANT_STATUS_OVERCURRENT: DeviceInt32AttributeValues.ValueType  # 15995
DEVICE_INT32_BUS_TYPE_PCI: DeviceInt32AttributeValues.ValueType  # 12582
DEVICE_INT32_BUS_TYPE_PCIE: DeviceInt32AttributeValues.ValueType  # 13612
DEVICE_INT32_BUS_TYPE_PXI: DeviceInt32AttributeValues.ValueType  # 12583
DEVICE_INT32_BUS_TYPE_PXIE: DeviceInt32AttributeValues.ValueType  # 14706
DEVICE_INT32_BUS_TYPE_SCXI: DeviceInt32AttributeValues.ValueType  # 12584
DEVICE_INT32_BUS_TYPE_SCC: DeviceInt32AttributeValues.ValueType  # 14707
DEVICE_INT32_BUS_TYPE_PC_CARD: DeviceInt32AttributeValues.ValueType  # 12585
DEVICE_INT32_BUS_TYPE_USB: DeviceInt32AttributeValues.ValueType  # 12586
DEVICE_INT32_BUS_TYPE_COMPACT_DAQ: DeviceInt32AttributeValues.ValueType  # 14637
DEVICE_INT32_BUS_TYPE_COMPACT_RIO: DeviceInt32AttributeValues.ValueType  # 16143
DEVICE_INT32_BUS_TYPE_TCPIP: DeviceInt32AttributeValues.ValueType  # 14828
DEVICE_INT32_BUS_TYPE_UNKNOWN: DeviceInt32AttributeValues.ValueType  # 12588
DEVICE_INT32_BUS_TYPE_SWITCH_BLOCK: DeviceInt32AttributeValues.ValueType  # 15870
DEVICE_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES: DeviceInt32AttributeValues.ValueType  # 10125
DEVICE_INT32_CI_MEASUREMENT_TYPE_FREQ: DeviceInt32AttributeValues.ValueType  # 10179
DEVICE_INT32_CI_MEASUREMENT_TYPE_PERIOD: DeviceInt32AttributeValues.ValueType  # 10256
DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH: DeviceInt32AttributeValues.ValueType  # 10359
DEVICE_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD: DeviceInt32AttributeValues.ValueType  # 10289
DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY: DeviceInt32AttributeValues.ValueType  # 15864
DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME: DeviceInt32AttributeValues.ValueType  # 15865
DEVICE_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS: DeviceInt32AttributeValues.ValueType  # 15866
DEVICE_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE: DeviceInt32AttributeValues.ValueType  # 16070
DEVICE_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER: DeviceInt32AttributeValues.ValueType  # 10360
DEVICE_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER: DeviceInt32AttributeValues.ValueType  # 10361
DEVICE_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER: DeviceInt32AttributeValues.ValueType  # 16078
DEVICE_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER: DeviceInt32AttributeValues.ValueType  # 16079
DEVICE_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP: DeviceInt32AttributeValues.ValueType  # 10267
DEVICE_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP: DeviceInt32AttributeValues.ValueType  # 10362
DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_TIME: DeviceInt32AttributeValues.ValueType  # 10269
DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_FREQ: DeviceInt32AttributeValues.ValueType  # 10119
DEVICE_INT32_CO_OUTPUT_TYPE_PULSE_TICKS: DeviceInt32AttributeValues.ValueType  # 10268
DEVICE_INT32_COUPLING_TYPES_AC: DeviceInt32AttributeValues.ValueType  # 1
DEVICE_INT32_COUPLING_TYPES_DC: DeviceInt32AttributeValues.ValueType  # 2
DEVICE_INT32_COUPLING_TYPES_GROUND: DeviceInt32AttributeValues.ValueType  # 4
DEVICE_INT32_COUPLING_TYPES_HF_REJECT: DeviceInt32AttributeValues.ValueType  # 8
DEVICE_INT32_COUPLING_TYPES_LF_REJECT: DeviceInt32AttributeValues.ValueType  # 16
DEVICE_INT32_COUPLING_TYPES_NOISE_REJECT: DeviceInt32AttributeValues.ValueType  # 32
DEVICE_INT32_FILTER_TYPE2_LOWPASS: DeviceInt32AttributeValues.ValueType  # 16071
DEVICE_INT32_FILTER_TYPE2_HIGHPASS: DeviceInt32AttributeValues.ValueType  # 16072
DEVICE_INT32_FILTER_TYPE2_BANDPASS: DeviceInt32AttributeValues.ValueType  # 16073
DEVICE_INT32_FILTER_TYPE2_NOTCH: DeviceInt32AttributeValues.ValueType  # 16074
DEVICE_INT32_FILTER_TYPE2_CUSTOM: DeviceInt32AttributeValues.ValueType  # 10137
DEVICE_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE: DeviceInt32AttributeValues.ValueType  # 15997
DEVICE_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE: DeviceInt32AttributeValues.ValueType  # 15998
DEVICE_INT32_NAV_MEASUREMENT_TYPE_LATITUDE: DeviceInt32AttributeValues.ValueType  # 15999
DEVICE_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND: DeviceInt32AttributeValues.ValueType  # 16000
DEVICE_INT32_NAV_MEASUREMENT_TYPE_TRACK: DeviceInt32AttributeValues.ValueType  # 16001
DEVICE_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP: DeviceInt32AttributeValues.ValueType  # 15986
DEVICE_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY: DeviceInt32AttributeValues.ValueType  # 16003
DEVICE_INT32_NAV_MODE_MOBILE: DeviceInt32AttributeValues.ValueType  # 15989
DEVICE_INT32_NAV_MODE_STATIONARY_WITH_SURVEY: DeviceInt32AttributeValues.ValueType  # 15990
DEVICE_INT32_NAV_MODE_STATIONARY_WITH_PRESET_LOCATION: DeviceInt32AttributeValues.ValueType  # 15991
DEVICE_INT32_PRODUCT_CATEGORY_M_SERIES_DAQ: DeviceInt32AttributeValues.ValueType  # 14643
DEVICE_INT32_PRODUCT_CATEGORY_X_SERIES_DAQ: DeviceInt32AttributeValues.ValueType  # 15858
DEVICE_INT32_PRODUCT_CATEGORY_E_SERIES_DAQ: DeviceInt32AttributeValues.ValueType  # 14642
DEVICE_INT32_PRODUCT_CATEGORY_S_SERIES_DAQ: DeviceInt32AttributeValues.ValueType  # 14644
DEVICE_INT32_PRODUCT_CATEGORY_B_SERIES_DAQ: DeviceInt32AttributeValues.ValueType  # 14662
DEVICE_INT32_PRODUCT_CATEGORY_SC_SERIES_DAQ: DeviceInt32AttributeValues.ValueType  # 14645
DEVICE_INT32_PRODUCT_CATEGORY_USBDAQ: DeviceInt32AttributeValues.ValueType  # 14646
DEVICE_INT32_PRODUCT_CATEGORY_AO_SERIES: DeviceInt32AttributeValues.ValueType  # 14647
DEVICE_INT32_PRODUCT_CATEGORY_DIGITAL_IO: DeviceInt32AttributeValues.ValueType  # 14648
DEVICE_INT32_PRODUCT_CATEGORY_TIO_SERIES: DeviceInt32AttributeValues.ValueType  # 14661
DEVICE_INT32_PRODUCT_CATEGORY_DYNAMIC_SIGNAL_ACQUISITION: DeviceInt32AttributeValues.ValueType  # 14649
DEVICE_INT32_PRODUCT_CATEGORY_SWITCHES: DeviceInt32AttributeValues.ValueType  # 14650
DEVICE_INT32_PRODUCT_CATEGORY_COMPACT_DAQ_CHASSIS: DeviceInt32AttributeValues.ValueType  # 14658
DEVICE_INT32_PRODUCT_CATEGORY_COMPACT_RIO_CHASSIS: DeviceInt32AttributeValues.ValueType  # 16144
DEVICE_INT32_PRODUCT_CATEGORY_C_SERIES_MODULE: DeviceInt32AttributeValues.ValueType  # 14659
DEVICE_INT32_PRODUCT_CATEGORY_SCXI_MODULE: DeviceInt32AttributeValues.ValueType  # 14660
DEVICE_INT32_PRODUCT_CATEGORY_SCC_CONNECTOR_BLOCK: DeviceInt32AttributeValues.ValueType  # 14704
DEVICE_INT32_PRODUCT_CATEGORY_SCC_MODULE: DeviceInt32AttributeValues.ValueType  # 14705
DEVICE_INT32_PRODUCT_CATEGORY_NIELVIS: DeviceInt32AttributeValues.ValueType  # 14755
DEVICE_INT32_PRODUCT_CATEGORY_NETWORK_DAQ: DeviceInt32AttributeValues.ValueType  # 14829
DEVICE_INT32_PRODUCT_CATEGORY_SC_EXPRESS: DeviceInt32AttributeValues.ValueType  # 15886
DEVICE_INT32_PRODUCT_CATEGORY_FIELD_DAQ: DeviceInt32AttributeValues.ValueType  # 16151
DEVICE_INT32_PRODUCT_CATEGORY_TEST_SCALE_CHASSIS: DeviceInt32AttributeValues.ValueType  # 16180
DEVICE_INT32_PRODUCT_CATEGORY_TEST_SCALE_MODULE: DeviceInt32AttributeValues.ValueType  # 16181
DEVICE_INT32_PRODUCT_CATEGORY_UNKNOWN: DeviceInt32AttributeValues.ValueType  # 12588
DEVICE_INT32_TRIGGER_USAGE_ADVANCE: DeviceInt32AttributeValues.ValueType  # 12488
DEVICE_INT32_TRIGGER_USAGE_PAUSE: DeviceInt32AttributeValues.ValueType  # 12489
DEVICE_INT32_TRIGGER_USAGE_REFERENCE: DeviceInt32AttributeValues.ValueType  # 12490
DEVICE_INT32_TRIGGER_USAGE_START: DeviceInt32AttributeValues.ValueType  # 12491
DEVICE_INT32_TRIGGER_USAGE_HANDSHAKE: DeviceInt32AttributeValues.ValueType  # 10389
DEVICE_INT32_TRIGGER_USAGE_ARM_START: DeviceInt32AttributeValues.ValueType  # 14641
DEVICE_INT32_TRIGGER_USAGE_TYPES_ADVANCE: DeviceInt32AttributeValues.ValueType  # 1
DEVICE_INT32_TRIGGER_USAGE_TYPES_PAUSE: DeviceInt32AttributeValues.ValueType  # 2
DEVICE_INT32_TRIGGER_USAGE_TYPES_REFERENCE: DeviceInt32AttributeValues.ValueType  # 4
DEVICE_INT32_TRIGGER_USAGE_TYPES_START: DeviceInt32AttributeValues.ValueType  # 8
DEVICE_INT32_TRIGGER_USAGE_TYPES_HANDSHAKE: DeviceInt32AttributeValues.ValueType  # 16
DEVICE_INT32_TRIGGER_USAGE_TYPES_ARM_START: DeviceInt32AttributeValues.ValueType  # 32
global___DeviceInt32AttributeValues = DeviceInt32AttributeValues

class _ExportSignalInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExportSignalInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExportSignalInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXPORTSIGNAL_INT32_UNSPECIFIED: _ExportSignalInt32AttributeValues.ValueType  # 0
    EXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_MORE_THAN_HALF_FULL: _ExportSignalInt32AttributeValues.ValueType  # 10237
    EXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_FULL: _ExportSignalInt32AttributeValues.ValueType  # 10236
    EXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_CUSTOM_THRESHOLD: _ExportSignalInt32AttributeValues.ValueType  # 12577
    EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_SAMP_CLK_PERIODS: _ExportSignalInt32AttributeValues.ValueType  # 10286
    EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_SECONDS: _ExportSignalInt32AttributeValues.ValueType  # 10364
    EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_TICKS: _ExportSignalInt32AttributeValues.ValueType  # 10304
    EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS3_SECONDS: _ExportSignalInt32AttributeValues.ValueType  # 10364
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS_PULSE: _ExportSignalInt32AttributeValues.ValueType  # 10265
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS_TOGGLE: _ExportSignalInt32AttributeValues.ValueType  # 10307
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS_LVL: _ExportSignalInt32AttributeValues.ValueType  # 10210
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS2_PULSE: _ExportSignalInt32AttributeValues.ValueType  # 10265
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS2_TOGGLE: _ExportSignalInt32AttributeValues.ValueType  # 10307
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS3_PULSE: _ExportSignalInt32AttributeValues.ValueType  # 10265
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS3_LVL: _ExportSignalInt32AttributeValues.ValueType  # 10210
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS5_INTERLOCKED: _ExportSignalInt32AttributeValues.ValueType  # 12549
    EXPORTSIGNAL_INT32_EXPORT_ACTIONS5_PULSE: _ExportSignalInt32AttributeValues.ValueType  # 10265
    EXPORTSIGNAL_INT32_LEVEL1_HIGH: _ExportSignalInt32AttributeValues.ValueType  # 10192
    EXPORTSIGNAL_INT32_LEVEL1_LOW: _ExportSignalInt32AttributeValues.ValueType  # 10214
    EXPORTSIGNAL_INT32_POLARITY2_ACTIVE_HIGH: _ExportSignalInt32AttributeValues.ValueType  # 10095
    EXPORTSIGNAL_INT32_POLARITY2_ACTIVE_LOW: _ExportSignalInt32AttributeValues.ValueType  # 10096

class ExportSignalInt32AttributeValues(_ExportSignalInt32AttributeValues, metaclass=_ExportSignalInt32AttributeValuesEnumTypeWrapper): ...

EXPORTSIGNAL_INT32_UNSPECIFIED: ExportSignalInt32AttributeValues.ValueType  # 0
EXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_MORE_THAN_HALF_FULL: ExportSignalInt32AttributeValues.ValueType  # 10237
EXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_FULL: ExportSignalInt32AttributeValues.ValueType  # 10236
EXPORTSIGNAL_INT32_DEASSERT_CONDITION_ONBRD_MEM_CUSTOM_THRESHOLD: ExportSignalInt32AttributeValues.ValueType  # 12577
EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_SAMP_CLK_PERIODS: ExportSignalInt32AttributeValues.ValueType  # 10286
EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_SECONDS: ExportSignalInt32AttributeValues.ValueType  # 10364
EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS1_TICKS: ExportSignalInt32AttributeValues.ValueType  # 10304
EXPORTSIGNAL_INT32_DIGITAL_WIDTH_UNITS3_SECONDS: ExportSignalInt32AttributeValues.ValueType  # 10364
EXPORTSIGNAL_INT32_EXPORT_ACTIONS_PULSE: ExportSignalInt32AttributeValues.ValueType  # 10265
EXPORTSIGNAL_INT32_EXPORT_ACTIONS_TOGGLE: ExportSignalInt32AttributeValues.ValueType  # 10307
EXPORTSIGNAL_INT32_EXPORT_ACTIONS_LVL: ExportSignalInt32AttributeValues.ValueType  # 10210
EXPORTSIGNAL_INT32_EXPORT_ACTIONS2_PULSE: ExportSignalInt32AttributeValues.ValueType  # 10265
EXPORTSIGNAL_INT32_EXPORT_ACTIONS2_TOGGLE: ExportSignalInt32AttributeValues.ValueType  # 10307
EXPORTSIGNAL_INT32_EXPORT_ACTIONS3_PULSE: ExportSignalInt32AttributeValues.ValueType  # 10265
EXPORTSIGNAL_INT32_EXPORT_ACTIONS3_LVL: ExportSignalInt32AttributeValues.ValueType  # 10210
EXPORTSIGNAL_INT32_EXPORT_ACTIONS5_INTERLOCKED: ExportSignalInt32AttributeValues.ValueType  # 12549
EXPORTSIGNAL_INT32_EXPORT_ACTIONS5_PULSE: ExportSignalInt32AttributeValues.ValueType  # 10265
EXPORTSIGNAL_INT32_LEVEL1_HIGH: ExportSignalInt32AttributeValues.ValueType  # 10192
EXPORTSIGNAL_INT32_LEVEL1_LOW: ExportSignalInt32AttributeValues.ValueType  # 10214
EXPORTSIGNAL_INT32_POLARITY2_ACTIVE_HIGH: ExportSignalInt32AttributeValues.ValueType  # 10095
EXPORTSIGNAL_INT32_POLARITY2_ACTIVE_LOW: ExportSignalInt32AttributeValues.ValueType  # 10096
global___ExportSignalInt32AttributeValues = ExportSignalInt32AttributeValues

class _PhysicalChannelInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PhysicalChannelInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PhysicalChannelInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PHYSICALCHANNEL_INT32_UNSPECIFIED: _PhysicalChannelInt32AttributeValues.ValueType  # 0
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE: _PhysicalChannelInt32AttributeValues.ValueType  # 10322
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS: _PhysicalChannelInt32AttributeValues.ValueType  # 10350
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT: _PhysicalChannelInt32AttributeValues.ValueType  # 10134
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS: _PhysicalChannelInt32AttributeValues.ValueType  # 10351
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION: _PhysicalChannelInt32AttributeValues.ValueType  # 10323
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_BRIDGE: _PhysicalChannelInt32AttributeValues.ValueType  # 15908
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE: _PhysicalChannelInt32AttributeValues.ValueType  # 10181
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_RESISTANCE: _PhysicalChannelInt32AttributeValues.ValueType  # 10278
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_TC: _PhysicalChannelInt32AttributeValues.ValueType  # 10303
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR: _PhysicalChannelInt32AttributeValues.ValueType  # 10302
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD: _PhysicalChannelInt32AttributeValues.ValueType  # 10301
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR: _PhysicalChannelInt32AttributeValues.ValueType  # 10311
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE: _PhysicalChannelInt32AttributeValues.ValueType  # 10300
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE: _PhysicalChannelInt32AttributeValues.ValueType  # 15980
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT: _PhysicalChannelInt32AttributeValues.ValueType  # 10352
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT: _PhysicalChannelInt32AttributeValues.ValueType  # 10353
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE: _PhysicalChannelInt32AttributeValues.ValueType  # 14835
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER: _PhysicalChannelInt32AttributeValues.ValueType  # 10356
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE: _PhysicalChannelInt32AttributeValues.ValueType  # 16104
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE: _PhysicalChannelInt32AttributeValues.ValueType  # 16106
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR: _PhysicalChannelInt32AttributeValues.ValueType  # 15966
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE: _PhysicalChannelInt32AttributeValues.ValueType  # 15899
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR: _PhysicalChannelInt32AttributeValues.ValueType  # 15895
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE: _PhysicalChannelInt32AttributeValues.ValueType  # 15902
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE: _PhysicalChannelInt32AttributeValues.ValueType  # 10354
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE: _PhysicalChannelInt32AttributeValues.ValueType  # 15905
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR: _PhysicalChannelInt32AttributeValues.ValueType  # 12531
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CHARGE: _PhysicalChannelInt32AttributeValues.ValueType  # 16105
    PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POWER: _PhysicalChannelInt32AttributeValues.ValueType  # 16201
    PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE: _PhysicalChannelInt32AttributeValues.ValueType  # 10322
    PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT: _PhysicalChannelInt32AttributeValues.ValueType  # 10134
    PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN: _PhysicalChannelInt32AttributeValues.ValueType  # 14750
    PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_VOLTAGE: _PhysicalChannelInt32AttributeValues.ValueType  # 10322
    PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_CURRENT: _PhysicalChannelInt32AttributeValues.ValueType  # 10134
    PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_HIGH_IMPEDANCE: _PhysicalChannelInt32AttributeValues.ValueType  # 12527
    PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_FINITE_SAMPS: _PhysicalChannelInt32AttributeValues.ValueType  # 10178
    PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_CONT_SAMPS: _PhysicalChannelInt32AttributeValues.ValueType  # 10123
    PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT: _PhysicalChannelInt32AttributeValues.ValueType  # 12522
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES: _PhysicalChannelInt32AttributeValues.ValueType  # 10125
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_FREQ: _PhysicalChannelInt32AttributeValues.ValueType  # 10179
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PERIOD: _PhysicalChannelInt32AttributeValues.ValueType  # 10256
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH: _PhysicalChannelInt32AttributeValues.ValueType  # 10359
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD: _PhysicalChannelInt32AttributeValues.ValueType  # 10289
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY: _PhysicalChannelInt32AttributeValues.ValueType  # 15864
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME: _PhysicalChannelInt32AttributeValues.ValueType  # 15865
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS: _PhysicalChannelInt32AttributeValues.ValueType  # 15866
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE: _PhysicalChannelInt32AttributeValues.ValueType  # 16070
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER: _PhysicalChannelInt32AttributeValues.ValueType  # 10360
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER: _PhysicalChannelInt32AttributeValues.ValueType  # 10361
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER: _PhysicalChannelInt32AttributeValues.ValueType  # 16078
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER: _PhysicalChannelInt32AttributeValues.ValueType  # 16079
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP: _PhysicalChannelInt32AttributeValues.ValueType  # 10267
    PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP: _PhysicalChannelInt32AttributeValues.ValueType  # 10362
    PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TIME: _PhysicalChannelInt32AttributeValues.ValueType  # 10269
    PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_FREQ: _PhysicalChannelInt32AttributeValues.ValueType  # 10119
    PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TICKS: _PhysicalChannelInt32AttributeValues.ValueType  # 10268
    PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE: _PhysicalChannelInt32AttributeValues.ValueType  # 15997
    PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE: _PhysicalChannelInt32AttributeValues.ValueType  # 15998
    PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_LATITUDE: _PhysicalChannelInt32AttributeValues.ValueType  # 15999
    PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND: _PhysicalChannelInt32AttributeValues.ValueType  # 16000
    PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_TRACK: _PhysicalChannelInt32AttributeValues.ValueType  # 16001
    PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP: _PhysicalChannelInt32AttributeValues.ValueType  # 15986
    PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY: _PhysicalChannelInt32AttributeValues.ValueType  # 16003
    PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_DC: _PhysicalChannelInt32AttributeValues.ValueType  # 10050
    PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_AC: _PhysicalChannelInt32AttributeValues.ValueType  # 10045
    PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_BIPOLAR_DC: _PhysicalChannelInt32AttributeValues.ValueType  # 16147
    PHYSICALCHANNEL_INT32_TERM_CFG_RSE: _PhysicalChannelInt32AttributeValues.ValueType  # 1
    PHYSICALCHANNEL_INT32_TERM_CFG_NRSE: _PhysicalChannelInt32AttributeValues.ValueType  # 2
    PHYSICALCHANNEL_INT32_TERM_CFG_DIFF: _PhysicalChannelInt32AttributeValues.ValueType  # 4
    PHYSICALCHANNEL_INT32_TERM_CFG_PSEUDO_DIFF: _PhysicalChannelInt32AttributeValues.ValueType  # 8

class PhysicalChannelInt32AttributeValues(_PhysicalChannelInt32AttributeValues, metaclass=_PhysicalChannelInt32AttributeValuesEnumTypeWrapper): ...

PHYSICALCHANNEL_INT32_UNSPECIFIED: PhysicalChannelInt32AttributeValues.ValueType  # 0
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE: PhysicalChannelInt32AttributeValues.ValueType  # 10322
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_RMS: PhysicalChannelInt32AttributeValues.ValueType  # 10350
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT: PhysicalChannelInt32AttributeValues.ValueType  # 10134
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CURRENT_RMS: PhysicalChannelInt32AttributeValues.ValueType  # 10351
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VOLTAGE_CUSTOM_WITH_EXCITATION: PhysicalChannelInt32AttributeValues.ValueType  # 10323
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_BRIDGE: PhysicalChannelInt32AttributeValues.ValueType  # 15908
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FREQ_VOLTAGE: PhysicalChannelInt32AttributeValues.ValueType  # 10181
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_RESISTANCE: PhysicalChannelInt32AttributeValues.ValueType  # 10278
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_TC: PhysicalChannelInt32AttributeValues.ValueType  # 10303
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_THRMSTR: PhysicalChannelInt32AttributeValues.ValueType  # 10302
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_RTD: PhysicalChannelInt32AttributeValues.ValueType  # 10301
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEMP_BUILT_IN_SENSOR: PhysicalChannelInt32AttributeValues.ValueType  # 10311
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_STRAIN_GAGE: PhysicalChannelInt32AttributeValues.ValueType  # 10300
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ROSETTE_STRAIN_GAGE: PhysicalChannelInt32AttributeValues.ValueType  # 15980
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_LVDT: PhysicalChannelInt32AttributeValues.ValueType  # 10352
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_RVDT: PhysicalChannelInt32AttributeValues.ValueType  # 10353
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POSITION_EDDY_CURRENT_PROXIMITY_PROBE: PhysicalChannelInt32AttributeValues.ValueType  # 14835
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELEROMETER: PhysicalChannelInt32AttributeValues.ValueType  # 10356
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_CHARGE: PhysicalChannelInt32AttributeValues.ValueType  # 16104
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_ACCELERATION_4_WIRE_DC_VOLTAGE: PhysicalChannelInt32AttributeValues.ValueType  # 16106
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_VELOCITY_IEPE_SENSOR: PhysicalChannelInt32AttributeValues.ValueType  # 15966
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_BRIDGE: PhysicalChannelInt32AttributeValues.ValueType  # 15899
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_FORCE_IEPE_SENSOR: PhysicalChannelInt32AttributeValues.ValueType  # 15895
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_PRESSURE_BRIDGE: PhysicalChannelInt32AttributeValues.ValueType  # 15902
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_SOUND_PRESSURE_MICROPHONE: PhysicalChannelInt32AttributeValues.ValueType  # 10354
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TORQUE_BRIDGE: PhysicalChannelInt32AttributeValues.ValueType  # 15905
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_TEDS_SENSOR: PhysicalChannelInt32AttributeValues.ValueType  # 12531
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_CHARGE: PhysicalChannelInt32AttributeValues.ValueType  # 16105
PHYSICALCHANNEL_INT32_AI_MEASUREMENT_TYPE_POWER: PhysicalChannelInt32AttributeValues.ValueType  # 16201
PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_VOLTAGE: PhysicalChannelInt32AttributeValues.ValueType  # 10322
PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_CURRENT: PhysicalChannelInt32AttributeValues.ValueType  # 10134
PHYSICALCHANNEL_INT32_AO_OUTPUT_CHANNEL_TYPE_FUNC_GEN: PhysicalChannelInt32AttributeValues.ValueType  # 14750
PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_VOLTAGE: PhysicalChannelInt32AttributeValues.ValueType  # 10322
PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_CURRENT: PhysicalChannelInt32AttributeValues.ValueType  # 10134
PHYSICALCHANNEL_INT32_AO_POWER_UP_OUTPUT_BEHAVIOR_HIGH_IMPEDANCE: PhysicalChannelInt32AttributeValues.ValueType  # 12527
PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_FINITE_SAMPS: PhysicalChannelInt32AttributeValues.ValueType  # 10178
PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_CONT_SAMPS: PhysicalChannelInt32AttributeValues.ValueType  # 10123
PHYSICALCHANNEL_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT: PhysicalChannelInt32AttributeValues.ValueType  # 12522
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_COUNT_EDGES: PhysicalChannelInt32AttributeValues.ValueType  # 10125
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_FREQ: PhysicalChannelInt32AttributeValues.ValueType  # 10179
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PERIOD: PhysicalChannelInt32AttributeValues.ValueType  # 10256
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_WIDTH: PhysicalChannelInt32AttributeValues.ValueType  # 10359
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_SEMI_PERIOD: PhysicalChannelInt32AttributeValues.ValueType  # 10289
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_FREQUENCY: PhysicalChannelInt32AttributeValues.ValueType  # 15864
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TIME: PhysicalChannelInt32AttributeValues.ValueType  # 15865
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_PULSE_TICKS: PhysicalChannelInt32AttributeValues.ValueType  # 15866
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_DUTY_CYCLE: PhysicalChannelInt32AttributeValues.ValueType  # 16070
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_ANG_ENCODER: PhysicalChannelInt32AttributeValues.ValueType  # 10360
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_POSITION_LIN_ENCODER: PhysicalChannelInt32AttributeValues.ValueType  # 10361
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_ANG_ENCODER: PhysicalChannelInt32AttributeValues.ValueType  # 16078
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_VELOCITY_LIN_ENCODER: PhysicalChannelInt32AttributeValues.ValueType  # 16079
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_TWO_EDGE_SEP: PhysicalChannelInt32AttributeValues.ValueType  # 10267
PHYSICALCHANNEL_INT32_CI_MEASUREMENT_TYPE_GPS_TIMESTAMP: PhysicalChannelInt32AttributeValues.ValueType  # 10362
PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TIME: PhysicalChannelInt32AttributeValues.ValueType  # 10269
PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_FREQ: PhysicalChannelInt32AttributeValues.ValueType  # 10119
PHYSICALCHANNEL_INT32_CO_OUTPUT_TYPE_PULSE_TICKS: PhysicalChannelInt32AttributeValues.ValueType  # 10268
PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_ALTITUDE: PhysicalChannelInt32AttributeValues.ValueType  # 15997
PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_LONGITUDE: PhysicalChannelInt32AttributeValues.ValueType  # 15998
PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_LATITUDE: PhysicalChannelInt32AttributeValues.ValueType  # 15999
PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_SPEED_OVER_GROUND: PhysicalChannelInt32AttributeValues.ValueType  # 16000
PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_TRACK: PhysicalChannelInt32AttributeValues.ValueType  # 16001
PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_TIMESTAMP: PhysicalChannelInt32AttributeValues.ValueType  # 15986
PHYSICALCHANNEL_INT32_NAV_MEASUREMENT_TYPE_VERT_VELOCITY: PhysicalChannelInt32AttributeValues.ValueType  # 16003
PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_DC: PhysicalChannelInt32AttributeValues.ValueType  # 10050
PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_AC: PhysicalChannelInt32AttributeValues.ValueType  # 10045
PHYSICALCHANNEL_INT32_SENSOR_POWER_TYPE_BIPOLAR_DC: PhysicalChannelInt32AttributeValues.ValueType  # 16147
PHYSICALCHANNEL_INT32_TERM_CFG_RSE: PhysicalChannelInt32AttributeValues.ValueType  # 1
PHYSICALCHANNEL_INT32_TERM_CFG_NRSE: PhysicalChannelInt32AttributeValues.ValueType  # 2
PHYSICALCHANNEL_INT32_TERM_CFG_DIFF: PhysicalChannelInt32AttributeValues.ValueType  # 4
PHYSICALCHANNEL_INT32_TERM_CFG_PSEUDO_DIFF: PhysicalChannelInt32AttributeValues.ValueType  # 8
global___PhysicalChannelInt32AttributeValues = PhysicalChannelInt32AttributeValues

class _ReadInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReadInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReadInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    READ_INT32_UNSPECIFIED: _ReadInt32AttributeValues.ValueType  # 0
    READ_INT32_LOGGING_MODE_OFF: _ReadInt32AttributeValues.ValueType  # 10231
    READ_INT32_LOGGING_MODE_LOG: _ReadInt32AttributeValues.ValueType  # 15844
    READ_INT32_LOGGING_MODE_LOG_AND_READ: _ReadInt32AttributeValues.ValueType  # 15842
    READ_INT32_LOGGING_OPERATION_OPEN: _ReadInt32AttributeValues.ValueType  # 10437
    READ_INT32_LOGGING_OPERATION_OPEN_OR_CREATE: _ReadInt32AttributeValues.ValueType  # 15846
    READ_INT32_LOGGING_OPERATION_CREATE_OR_REPLACE: _ReadInt32AttributeValues.ValueType  # 15847
    READ_INT32_LOGGING_OPERATION_CREATE: _ReadInt32AttributeValues.ValueType  # 15848
    READ_INT32_OVERWRITE_MODE1_OVERWRITE_UNREAD_SAMPS: _ReadInt32AttributeValues.ValueType  # 10252
    READ_INT32_OVERWRITE_MODE1_DO_NOT_OVERWRITE_UNREAD_SAMPS: _ReadInt32AttributeValues.ValueType  # 10159
    READ_INT32_READ_RELATIVE_TO_FIRST_SAMPLE: _ReadInt32AttributeValues.ValueType  # 10424
    READ_INT32_READ_RELATIVE_TO_CURR_READ_POS: _ReadInt32AttributeValues.ValueType  # 10425
    READ_INT32_READ_RELATIVE_TO_REF_TRIG: _ReadInt32AttributeValues.ValueType  # 10426
    READ_INT32_READ_RELATIVE_TO_FIRST_PRETRIG_SAMP: _ReadInt32AttributeValues.ValueType  # 10427
    READ_INT32_READ_RELATIVE_TO_MOST_RECENT_SAMP: _ReadInt32AttributeValues.ValueType  # 10428
    READ_INT32_WAIT_MODE_WAIT_FOR_INTERRUPT: _ReadInt32AttributeValues.ValueType  # 12523
    READ_INT32_WAIT_MODE_POLL: _ReadInt32AttributeValues.ValueType  # 12524
    READ_INT32_WAIT_MODE_YIELD: _ReadInt32AttributeValues.ValueType  # 12525
    READ_INT32_WAIT_MODE_SLEEP: _ReadInt32AttributeValues.ValueType  # 12547

class ReadInt32AttributeValues(_ReadInt32AttributeValues, metaclass=_ReadInt32AttributeValuesEnumTypeWrapper): ...

READ_INT32_UNSPECIFIED: ReadInt32AttributeValues.ValueType  # 0
READ_INT32_LOGGING_MODE_OFF: ReadInt32AttributeValues.ValueType  # 10231
READ_INT32_LOGGING_MODE_LOG: ReadInt32AttributeValues.ValueType  # 15844
READ_INT32_LOGGING_MODE_LOG_AND_READ: ReadInt32AttributeValues.ValueType  # 15842
READ_INT32_LOGGING_OPERATION_OPEN: ReadInt32AttributeValues.ValueType  # 10437
READ_INT32_LOGGING_OPERATION_OPEN_OR_CREATE: ReadInt32AttributeValues.ValueType  # 15846
READ_INT32_LOGGING_OPERATION_CREATE_OR_REPLACE: ReadInt32AttributeValues.ValueType  # 15847
READ_INT32_LOGGING_OPERATION_CREATE: ReadInt32AttributeValues.ValueType  # 15848
READ_INT32_OVERWRITE_MODE1_OVERWRITE_UNREAD_SAMPS: ReadInt32AttributeValues.ValueType  # 10252
READ_INT32_OVERWRITE_MODE1_DO_NOT_OVERWRITE_UNREAD_SAMPS: ReadInt32AttributeValues.ValueType  # 10159
READ_INT32_READ_RELATIVE_TO_FIRST_SAMPLE: ReadInt32AttributeValues.ValueType  # 10424
READ_INT32_READ_RELATIVE_TO_CURR_READ_POS: ReadInt32AttributeValues.ValueType  # 10425
READ_INT32_READ_RELATIVE_TO_REF_TRIG: ReadInt32AttributeValues.ValueType  # 10426
READ_INT32_READ_RELATIVE_TO_FIRST_PRETRIG_SAMP: ReadInt32AttributeValues.ValueType  # 10427
READ_INT32_READ_RELATIVE_TO_MOST_RECENT_SAMP: ReadInt32AttributeValues.ValueType  # 10428
READ_INT32_WAIT_MODE_WAIT_FOR_INTERRUPT: ReadInt32AttributeValues.ValueType  # 12523
READ_INT32_WAIT_MODE_POLL: ReadInt32AttributeValues.ValueType  # 12524
READ_INT32_WAIT_MODE_YIELD: ReadInt32AttributeValues.ValueType  # 12525
READ_INT32_WAIT_MODE_SLEEP: ReadInt32AttributeValues.ValueType  # 12547
global___ReadInt32AttributeValues = ReadInt32AttributeValues

class _RealTimeInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RealTimeInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RealTimeInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REALTIME_INT32_UNSPECIFIED: _RealTimeInt32AttributeValues.ValueType  # 0
    REALTIME_INT32_WAIT_MODE3_WAIT_FOR_INTERRUPT: _RealTimeInt32AttributeValues.ValueType  # 12523
    REALTIME_INT32_WAIT_MODE3_POLL: _RealTimeInt32AttributeValues.ValueType  # 12524
    REALTIME_INT32_WAIT_MODE4_WAIT_FOR_INTERRUPT: _RealTimeInt32AttributeValues.ValueType  # 12523
    REALTIME_INT32_WAIT_MODE4_POLL: _RealTimeInt32AttributeValues.ValueType  # 12524

class RealTimeInt32AttributeValues(_RealTimeInt32AttributeValues, metaclass=_RealTimeInt32AttributeValuesEnumTypeWrapper): ...

REALTIME_INT32_UNSPECIFIED: RealTimeInt32AttributeValues.ValueType  # 0
REALTIME_INT32_WAIT_MODE3_WAIT_FOR_INTERRUPT: RealTimeInt32AttributeValues.ValueType  # 12523
REALTIME_INT32_WAIT_MODE3_POLL: RealTimeInt32AttributeValues.ValueType  # 12524
REALTIME_INT32_WAIT_MODE4_WAIT_FOR_INTERRUPT: RealTimeInt32AttributeValues.ValueType  # 12523
REALTIME_INT32_WAIT_MODE4_POLL: RealTimeInt32AttributeValues.ValueType  # 12524
global___RealTimeInt32AttributeValues = RealTimeInt32AttributeValues

class _ScaleInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ScaleInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ScaleInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SCALE_INT32_UNSPECIFIED: _ScaleInt32AttributeValues.ValueType  # 0
    SCALE_INT32_SCALE_TYPE_LINEAR: _ScaleInt32AttributeValues.ValueType  # 10447
    SCALE_INT32_SCALE_TYPE_MAP_RANGES: _ScaleInt32AttributeValues.ValueType  # 10448
    SCALE_INT32_SCALE_TYPE_POLYNOMIAL: _ScaleInt32AttributeValues.ValueType  # 10449
    SCALE_INT32_SCALE_TYPE_TABLE: _ScaleInt32AttributeValues.ValueType  # 10450
    SCALE_INT32_UNITS_PRE_SCALED_VOLTS: _ScaleInt32AttributeValues.ValueType  # 10348
    SCALE_INT32_UNITS_PRE_SCALED_AMPS: _ScaleInt32AttributeValues.ValueType  # 10342
    SCALE_INT32_UNITS_PRE_SCALED_DEG_F: _ScaleInt32AttributeValues.ValueType  # 10144
    SCALE_INT32_UNITS_PRE_SCALED_DEG_C: _ScaleInt32AttributeValues.ValueType  # 10143
    SCALE_INT32_UNITS_PRE_SCALED_DEG_R: _ScaleInt32AttributeValues.ValueType  # 10145
    SCALE_INT32_UNITS_PRE_SCALED_KELVINS: _ScaleInt32AttributeValues.ValueType  # 10325
    SCALE_INT32_UNITS_PRE_SCALED_STRAIN: _ScaleInt32AttributeValues.ValueType  # 10299
    SCALE_INT32_UNITS_PRE_SCALED_OHMS: _ScaleInt32AttributeValues.ValueType  # 10384
    SCALE_INT32_UNITS_PRE_SCALED_HZ: _ScaleInt32AttributeValues.ValueType  # 10373
    SCALE_INT32_UNITS_PRE_SCALED_SECONDS: _ScaleInt32AttributeValues.ValueType  # 10364
    SCALE_INT32_UNITS_PRE_SCALED_METERS: _ScaleInt32AttributeValues.ValueType  # 10219
    SCALE_INT32_UNITS_PRE_SCALED_INCHES: _ScaleInt32AttributeValues.ValueType  # 10379
    SCALE_INT32_UNITS_PRE_SCALED_DEGREES: _ScaleInt32AttributeValues.ValueType  # 10146
    SCALE_INT32_UNITS_PRE_SCALED_RADIANS: _ScaleInt32AttributeValues.ValueType  # 10273
    SCALE_INT32_UNITS_PRE_SCALED_TICKS: _ScaleInt32AttributeValues.ValueType  # 10304
    SCALE_INT32_UNITS_PRE_SCALED_RPM: _ScaleInt32AttributeValues.ValueType  # 16080
    SCALE_INT32_UNITS_PRE_SCALED_RADIANS_PER_SECOND: _ScaleInt32AttributeValues.ValueType  # 16081
    SCALE_INT32_UNITS_PRE_SCALED_DEGREES_PER_SECOND: _ScaleInt32AttributeValues.ValueType  # 16082
    SCALE_INT32_UNITS_PRE_SCALED_G: _ScaleInt32AttributeValues.ValueType  # 10186
    SCALE_INT32_UNITS_PRE_SCALED_METERS_PER_SECOND_SQUARED: _ScaleInt32AttributeValues.ValueType  # 12470
    SCALE_INT32_UNITS_PRE_SCALED_INCHES_PER_SECOND_SQUARED: _ScaleInt32AttributeValues.ValueType  # 12471
    SCALE_INT32_UNITS_PRE_SCALED_METERS_PER_SECOND: _ScaleInt32AttributeValues.ValueType  # 15959
    SCALE_INT32_UNITS_PRE_SCALED_INCHES_PER_SECOND: _ScaleInt32AttributeValues.ValueType  # 15960
    SCALE_INT32_UNITS_PRE_SCALED_PASCALS: _ScaleInt32AttributeValues.ValueType  # 10081
    SCALE_INT32_UNITS_PRE_SCALED_NEWTONS: _ScaleInt32AttributeValues.ValueType  # 15875
    SCALE_INT32_UNITS_PRE_SCALED_POUNDS: _ScaleInt32AttributeValues.ValueType  # 15876
    SCALE_INT32_UNITS_PRE_SCALED_KILOGRAM_FORCE: _ScaleInt32AttributeValues.ValueType  # 15877
    SCALE_INT32_UNITS_PRE_SCALED_POUNDS_PER_SQUARE_INCH: _ScaleInt32AttributeValues.ValueType  # 15879
    SCALE_INT32_UNITS_PRE_SCALED_BAR: _ScaleInt32AttributeValues.ValueType  # 15880
    SCALE_INT32_UNITS_PRE_SCALED_NEWTON_METERS: _ScaleInt32AttributeValues.ValueType  # 15881
    SCALE_INT32_UNITS_PRE_SCALED_INCH_OUNCES: _ScaleInt32AttributeValues.ValueType  # 15882
    SCALE_INT32_UNITS_PRE_SCALED_INCH_POUNDS: _ScaleInt32AttributeValues.ValueType  # 15883
    SCALE_INT32_UNITS_PRE_SCALED_FOOT_POUNDS: _ScaleInt32AttributeValues.ValueType  # 15884
    SCALE_INT32_UNITS_PRE_SCALED_VOLTS_PER_VOLT: _ScaleInt32AttributeValues.ValueType  # 15896
    SCALE_INT32_UNITS_PRE_SCALED_M_VOLTS_PER_VOLT: _ScaleInt32AttributeValues.ValueType  # 15897
    SCALE_INT32_UNITS_PRE_SCALED_COULOMBS: _ScaleInt32AttributeValues.ValueType  # 16102
    SCALE_INT32_UNITS_PRE_SCALED_PICO_COULOMBS: _ScaleInt32AttributeValues.ValueType  # 16103
    SCALE_INT32_UNITS_PRE_SCALED_FROM_TEDS: _ScaleInt32AttributeValues.ValueType  # 12516

class ScaleInt32AttributeValues(_ScaleInt32AttributeValues, metaclass=_ScaleInt32AttributeValuesEnumTypeWrapper): ...

SCALE_INT32_UNSPECIFIED: ScaleInt32AttributeValues.ValueType  # 0
SCALE_INT32_SCALE_TYPE_LINEAR: ScaleInt32AttributeValues.ValueType  # 10447
SCALE_INT32_SCALE_TYPE_MAP_RANGES: ScaleInt32AttributeValues.ValueType  # 10448
SCALE_INT32_SCALE_TYPE_POLYNOMIAL: ScaleInt32AttributeValues.ValueType  # 10449
SCALE_INT32_SCALE_TYPE_TABLE: ScaleInt32AttributeValues.ValueType  # 10450
SCALE_INT32_UNITS_PRE_SCALED_VOLTS: ScaleInt32AttributeValues.ValueType  # 10348
SCALE_INT32_UNITS_PRE_SCALED_AMPS: ScaleInt32AttributeValues.ValueType  # 10342
SCALE_INT32_UNITS_PRE_SCALED_DEG_F: ScaleInt32AttributeValues.ValueType  # 10144
SCALE_INT32_UNITS_PRE_SCALED_DEG_C: ScaleInt32AttributeValues.ValueType  # 10143
SCALE_INT32_UNITS_PRE_SCALED_DEG_R: ScaleInt32AttributeValues.ValueType  # 10145
SCALE_INT32_UNITS_PRE_SCALED_KELVINS: ScaleInt32AttributeValues.ValueType  # 10325
SCALE_INT32_UNITS_PRE_SCALED_STRAIN: ScaleInt32AttributeValues.ValueType  # 10299
SCALE_INT32_UNITS_PRE_SCALED_OHMS: ScaleInt32AttributeValues.ValueType  # 10384
SCALE_INT32_UNITS_PRE_SCALED_HZ: ScaleInt32AttributeValues.ValueType  # 10373
SCALE_INT32_UNITS_PRE_SCALED_SECONDS: ScaleInt32AttributeValues.ValueType  # 10364
SCALE_INT32_UNITS_PRE_SCALED_METERS: ScaleInt32AttributeValues.ValueType  # 10219
SCALE_INT32_UNITS_PRE_SCALED_INCHES: ScaleInt32AttributeValues.ValueType  # 10379
SCALE_INT32_UNITS_PRE_SCALED_DEGREES: ScaleInt32AttributeValues.ValueType  # 10146
SCALE_INT32_UNITS_PRE_SCALED_RADIANS: ScaleInt32AttributeValues.ValueType  # 10273
SCALE_INT32_UNITS_PRE_SCALED_TICKS: ScaleInt32AttributeValues.ValueType  # 10304
SCALE_INT32_UNITS_PRE_SCALED_RPM: ScaleInt32AttributeValues.ValueType  # 16080
SCALE_INT32_UNITS_PRE_SCALED_RADIANS_PER_SECOND: ScaleInt32AttributeValues.ValueType  # 16081
SCALE_INT32_UNITS_PRE_SCALED_DEGREES_PER_SECOND: ScaleInt32AttributeValues.ValueType  # 16082
SCALE_INT32_UNITS_PRE_SCALED_G: ScaleInt32AttributeValues.ValueType  # 10186
SCALE_INT32_UNITS_PRE_SCALED_METERS_PER_SECOND_SQUARED: ScaleInt32AttributeValues.ValueType  # 12470
SCALE_INT32_UNITS_PRE_SCALED_INCHES_PER_SECOND_SQUARED: ScaleInt32AttributeValues.ValueType  # 12471
SCALE_INT32_UNITS_PRE_SCALED_METERS_PER_SECOND: ScaleInt32AttributeValues.ValueType  # 15959
SCALE_INT32_UNITS_PRE_SCALED_INCHES_PER_SECOND: ScaleInt32AttributeValues.ValueType  # 15960
SCALE_INT32_UNITS_PRE_SCALED_PASCALS: ScaleInt32AttributeValues.ValueType  # 10081
SCALE_INT32_UNITS_PRE_SCALED_NEWTONS: ScaleInt32AttributeValues.ValueType  # 15875
SCALE_INT32_UNITS_PRE_SCALED_POUNDS: ScaleInt32AttributeValues.ValueType  # 15876
SCALE_INT32_UNITS_PRE_SCALED_KILOGRAM_FORCE: ScaleInt32AttributeValues.ValueType  # 15877
SCALE_INT32_UNITS_PRE_SCALED_POUNDS_PER_SQUARE_INCH: ScaleInt32AttributeValues.ValueType  # 15879
SCALE_INT32_UNITS_PRE_SCALED_BAR: ScaleInt32AttributeValues.ValueType  # 15880
SCALE_INT32_UNITS_PRE_SCALED_NEWTON_METERS: ScaleInt32AttributeValues.ValueType  # 15881
SCALE_INT32_UNITS_PRE_SCALED_INCH_OUNCES: ScaleInt32AttributeValues.ValueType  # 15882
SCALE_INT32_UNITS_PRE_SCALED_INCH_POUNDS: ScaleInt32AttributeValues.ValueType  # 15883
SCALE_INT32_UNITS_PRE_SCALED_FOOT_POUNDS: ScaleInt32AttributeValues.ValueType  # 15884
SCALE_INT32_UNITS_PRE_SCALED_VOLTS_PER_VOLT: ScaleInt32AttributeValues.ValueType  # 15896
SCALE_INT32_UNITS_PRE_SCALED_M_VOLTS_PER_VOLT: ScaleInt32AttributeValues.ValueType  # 15897
SCALE_INT32_UNITS_PRE_SCALED_COULOMBS: ScaleInt32AttributeValues.ValueType  # 16102
SCALE_INT32_UNITS_PRE_SCALED_PICO_COULOMBS: ScaleInt32AttributeValues.ValueType  # 16103
SCALE_INT32_UNITS_PRE_SCALED_FROM_TEDS: ScaleInt32AttributeValues.ValueType  # 12516
global___ScaleInt32AttributeValues = ScaleInt32AttributeValues

class _TimingInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimingInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimingInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIMING_INT32_UNSPECIFIED: _TimingInt32AttributeValues.ValueType  # 0
    TIMING_INT32_ACQUISITION_TYPE_FINITE_SAMPS: _TimingInt32AttributeValues.ValueType  # 10178
    TIMING_INT32_ACQUISITION_TYPE_CONT_SAMPS: _TimingInt32AttributeValues.ValueType  # 10123
    TIMING_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT: _TimingInt32AttributeValues.ValueType  # 12522
    TIMING_INT32_DIGITAL_WIDTH_UNITS2_SECONDS: _TimingInt32AttributeValues.ValueType  # 10364
    TIMING_INT32_DIGITAL_WIDTH_UNITS2_TICKS: _TimingInt32AttributeValues.ValueType  # 10304
    TIMING_INT32_EDGE1_RISING: _TimingInt32AttributeValues.ValueType  # 10280
    TIMING_INT32_EDGE1_FALLING: _TimingInt32AttributeValues.ValueType  # 10171
    TIMING_INT32_HANDSHAKE_START_CONDITION_IMMEDIATE: _TimingInt32AttributeValues.ValueType  # 10198
    TIMING_INT32_HANDSHAKE_START_CONDITION_WAIT_FOR_HANDSHAKE_TRIGGER_ASSERT: _TimingInt32AttributeValues.ValueType  # 12550
    TIMING_INT32_HANDSHAKE_START_CONDITION_WAIT_FOR_HANDSHAKE_TRIGGER_DEASSERT: _TimingInt32AttributeValues.ValueType  # 12551
    TIMING_INT32_MIOAI_CONVERT_TB_SRC_SAME_AS_SAMP_TIMEBASE: _TimingInt32AttributeValues.ValueType  # 10284
    TIMING_INT32_MIOAI_CONVERT_TB_SRC_SAME_AS_MASTER_TIMEBASE: _TimingInt32AttributeValues.ValueType  # 10282
    TIMING_INT32_MIOAI_CONVERT_TB_SRC_100_MHZ_TIMEBASE: _TimingInt32AttributeValues.ValueType  # 15857
    TIMING_INT32_MIOAI_CONVERT_TB_SRC_80_MHZ_TIMEBASE: _TimingInt32AttributeValues.ValueType  # 14636
    TIMING_INT32_MIOAI_CONVERT_TB_SRC_20_MHZ_TIMEBASE: _TimingInt32AttributeValues.ValueType  # 12537
    TIMING_INT32_MIOAI_CONVERT_TB_SRC_8_MHZ_TIMEBASE: _TimingInt32AttributeValues.ValueType  # 16023
    TIMING_INT32_OVERFLOW_BEHAVIOR_STOP_TASK_AND_ERROR: _TimingInt32AttributeValues.ValueType  # 15862
    TIMING_INT32_OVERFLOW_BEHAVIOR_IGNORE_OVERRUNS: _TimingInt32AttributeValues.ValueType  # 15863
    TIMING_INT32_SAMPLE_INPUT_DATA_WHEN_HANDSHAKE_TRIGGER_ASSERTS: _TimingInt32AttributeValues.ValueType  # 12552
    TIMING_INT32_SAMPLE_INPUT_DATA_WHEN_HANDSHAKE_TRIGGER_DEASSERTS: _TimingInt32AttributeValues.ValueType  # 12553
    TIMING_INT32_SAMPLE_TIMING_TYPE_SAMP_CLK: _TimingInt32AttributeValues.ValueType  # 10388
    TIMING_INT32_SAMPLE_TIMING_TYPE_BURST_HANDSHAKE: _TimingInt32AttributeValues.ValueType  # 12548
    TIMING_INT32_SAMPLE_TIMING_TYPE_HANDSHAKE: _TimingInt32AttributeValues.ValueType  # 10389
    TIMING_INT32_SAMPLE_TIMING_TYPE_IMPLICIT: _TimingInt32AttributeValues.ValueType  # 10451
    TIMING_INT32_SAMPLE_TIMING_TYPE_ON_DEMAND: _TimingInt32AttributeValues.ValueType  # 10390
    TIMING_INT32_SAMPLE_TIMING_TYPE_CHANGE_DETECTION: _TimingInt32AttributeValues.ValueType  # 12504
    TIMING_INT32_SAMPLE_TIMING_TYPE_PIPELINED_SAMP_CLK: _TimingInt32AttributeValues.ValueType  # 14668
    TIMING_INT32_SYNC_PULSE_TYPE_ONBOARD: _TimingInt32AttributeValues.ValueType  # 16128
    TIMING_INT32_SYNC_PULSE_TYPE_DIG_EDGE: _TimingInt32AttributeValues.ValueType  # 10150
    TIMING_INT32_SYNC_PULSE_TYPE_TIME: _TimingInt32AttributeValues.ValueType  # 15996
    TIMING_INT32_TIMESCALE2_HOST_TIME: _TimingInt32AttributeValues.ValueType  # 16126
    TIMING_INT32_TIMESCALE2_IO_DEVICE_TIME: _TimingInt32AttributeValues.ValueType  # 16127
    TIMING_INT32_UNDERFLOW_BEHAVIOR_HALT_OUTPUT_AND_ERROR: _TimingInt32AttributeValues.ValueType  # 14615
    TIMING_INT32_UNDERFLOW_BEHAVIOR_PAUSE_UNTIL_DATA_AVAILABLE: _TimingInt32AttributeValues.ValueType  # 14616

class TimingInt32AttributeValues(_TimingInt32AttributeValues, metaclass=_TimingInt32AttributeValuesEnumTypeWrapper): ...

TIMING_INT32_UNSPECIFIED: TimingInt32AttributeValues.ValueType  # 0
TIMING_INT32_ACQUISITION_TYPE_FINITE_SAMPS: TimingInt32AttributeValues.ValueType  # 10178
TIMING_INT32_ACQUISITION_TYPE_CONT_SAMPS: TimingInt32AttributeValues.ValueType  # 10123
TIMING_INT32_ACQUISITION_TYPE_HW_TIMED_SINGLE_POINT: TimingInt32AttributeValues.ValueType  # 12522
TIMING_INT32_DIGITAL_WIDTH_UNITS2_SECONDS: TimingInt32AttributeValues.ValueType  # 10364
TIMING_INT32_DIGITAL_WIDTH_UNITS2_TICKS: TimingInt32AttributeValues.ValueType  # 10304
TIMING_INT32_EDGE1_RISING: TimingInt32AttributeValues.ValueType  # 10280
TIMING_INT32_EDGE1_FALLING: TimingInt32AttributeValues.ValueType  # 10171
TIMING_INT32_HANDSHAKE_START_CONDITION_IMMEDIATE: TimingInt32AttributeValues.ValueType  # 10198
TIMING_INT32_HANDSHAKE_START_CONDITION_WAIT_FOR_HANDSHAKE_TRIGGER_ASSERT: TimingInt32AttributeValues.ValueType  # 12550
TIMING_INT32_HANDSHAKE_START_CONDITION_WAIT_FOR_HANDSHAKE_TRIGGER_DEASSERT: TimingInt32AttributeValues.ValueType  # 12551
TIMING_INT32_MIOAI_CONVERT_TB_SRC_SAME_AS_SAMP_TIMEBASE: TimingInt32AttributeValues.ValueType  # 10284
TIMING_INT32_MIOAI_CONVERT_TB_SRC_SAME_AS_MASTER_TIMEBASE: TimingInt32AttributeValues.ValueType  # 10282
TIMING_INT32_MIOAI_CONVERT_TB_SRC_100_MHZ_TIMEBASE: TimingInt32AttributeValues.ValueType  # 15857
TIMING_INT32_MIOAI_CONVERT_TB_SRC_80_MHZ_TIMEBASE: TimingInt32AttributeValues.ValueType  # 14636
TIMING_INT32_MIOAI_CONVERT_TB_SRC_20_MHZ_TIMEBASE: TimingInt32AttributeValues.ValueType  # 12537
TIMING_INT32_MIOAI_CONVERT_TB_SRC_8_MHZ_TIMEBASE: TimingInt32AttributeValues.ValueType  # 16023
TIMING_INT32_OVERFLOW_BEHAVIOR_STOP_TASK_AND_ERROR: TimingInt32AttributeValues.ValueType  # 15862
TIMING_INT32_OVERFLOW_BEHAVIOR_IGNORE_OVERRUNS: TimingInt32AttributeValues.ValueType  # 15863
TIMING_INT32_SAMPLE_INPUT_DATA_WHEN_HANDSHAKE_TRIGGER_ASSERTS: TimingInt32AttributeValues.ValueType  # 12552
TIMING_INT32_SAMPLE_INPUT_DATA_WHEN_HANDSHAKE_TRIGGER_DEASSERTS: TimingInt32AttributeValues.ValueType  # 12553
TIMING_INT32_SAMPLE_TIMING_TYPE_SAMP_CLK: TimingInt32AttributeValues.ValueType  # 10388
TIMING_INT32_SAMPLE_TIMING_TYPE_BURST_HANDSHAKE: TimingInt32AttributeValues.ValueType  # 12548
TIMING_INT32_SAMPLE_TIMING_TYPE_HANDSHAKE: TimingInt32AttributeValues.ValueType  # 10389
TIMING_INT32_SAMPLE_TIMING_TYPE_IMPLICIT: TimingInt32AttributeValues.ValueType  # 10451
TIMING_INT32_SAMPLE_TIMING_TYPE_ON_DEMAND: TimingInt32AttributeValues.ValueType  # 10390
TIMING_INT32_SAMPLE_TIMING_TYPE_CHANGE_DETECTION: TimingInt32AttributeValues.ValueType  # 12504
TIMING_INT32_SAMPLE_TIMING_TYPE_PIPELINED_SAMP_CLK: TimingInt32AttributeValues.ValueType  # 14668
TIMING_INT32_SYNC_PULSE_TYPE_ONBOARD: TimingInt32AttributeValues.ValueType  # 16128
TIMING_INT32_SYNC_PULSE_TYPE_DIG_EDGE: TimingInt32AttributeValues.ValueType  # 10150
TIMING_INT32_SYNC_PULSE_TYPE_TIME: TimingInt32AttributeValues.ValueType  # 15996
TIMING_INT32_TIMESCALE2_HOST_TIME: TimingInt32AttributeValues.ValueType  # 16126
TIMING_INT32_TIMESCALE2_IO_DEVICE_TIME: TimingInt32AttributeValues.ValueType  # 16127
TIMING_INT32_UNDERFLOW_BEHAVIOR_HALT_OUTPUT_AND_ERROR: TimingInt32AttributeValues.ValueType  # 14615
TIMING_INT32_UNDERFLOW_BEHAVIOR_PAUSE_UNTIL_DATA_AVAILABLE: TimingInt32AttributeValues.ValueType  # 14616
global___TimingInt32AttributeValues = TimingInt32AttributeValues

class _TriggerInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_INT32_UNSPECIFIED: _TriggerInt32AttributeValues.ValueType  # 0
    TRIGGER_INT32_ACTIVE_LEVEL_ABOVE_LVL: _TriggerInt32AttributeValues.ValueType  # 10093
    TRIGGER_INT32_ACTIVE_LEVEL_BELOW_LVL: _TriggerInt32AttributeValues.ValueType  # 10107
    TRIGGER_INT32_COUPLING2_AC: _TriggerInt32AttributeValues.ValueType  # 10045
    TRIGGER_INT32_COUPLING2_DC: _TriggerInt32AttributeValues.ValueType  # 10050
    TRIGGER_INT32_DIGITAL_PATTERN_CONDITION1_PATTERN_MATCHES: _TriggerInt32AttributeValues.ValueType  # 10254
    TRIGGER_INT32_DIGITAL_PATTERN_CONDITION1_PATTERN_DOES_NOT_MATCH: _TriggerInt32AttributeValues.ValueType  # 10253
    TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_SAMP_CLK_PERIODS: _TriggerInt32AttributeValues.ValueType  # 10286
    TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_SECONDS: _TriggerInt32AttributeValues.ValueType  # 10364
    TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_TICKS: _TriggerInt32AttributeValues.ValueType  # 10304
    TRIGGER_INT32_EDGE1_RISING: _TriggerInt32AttributeValues.ValueType  # 10280
    TRIGGER_INT32_EDGE1_FALLING: _TriggerInt32AttributeValues.ValueType  # 10171
    TRIGGER_INT32_LEVEL1_HIGH: _TriggerInt32AttributeValues.ValueType  # 10192
    TRIGGER_INT32_LEVEL1_LOW: _TriggerInt32AttributeValues.ValueType  # 10214
    TRIGGER_INT32_SLOPE1_RISING_SLOPE: _TriggerInt32AttributeValues.ValueType  # 10280
    TRIGGER_INT32_SLOPE1_FALLING_SLOPE: _TriggerInt32AttributeValues.ValueType  # 10171
    TRIGGER_INT32_SYNC_TYPE_NONE: _TriggerInt32AttributeValues.ValueType  # 10230
    TRIGGER_INT32_SYNC_TYPE_MASTER: _TriggerInt32AttributeValues.ValueType  # 15888
    TRIGGER_INT32_SYNC_TYPE_SLAVE: _TriggerInt32AttributeValues.ValueType  # 15889
    TRIGGER_INT32_TIMESCALE2_HOST_TIME: _TriggerInt32AttributeValues.ValueType  # 16126
    TRIGGER_INT32_TIMESCALE2_IO_DEVICE_TIME: _TriggerInt32AttributeValues.ValueType  # 16127
    TRIGGER_INT32_TRIGGER_TYPE10_ANLG_EDGE: _TriggerInt32AttributeValues.ValueType  # 10099
    TRIGGER_INT32_TRIGGER_TYPE10_ANLG_MULTI_EDGE: _TriggerInt32AttributeValues.ValueType  # 16108
    TRIGGER_INT32_TRIGGER_TYPE10_DIG_EDGE: _TriggerInt32AttributeValues.ValueType  # 10150
    TRIGGER_INT32_TRIGGER_TYPE10_DIG_PATTERN: _TriggerInt32AttributeValues.ValueType  # 10398
    TRIGGER_INT32_TRIGGER_TYPE10_ANLG_WIN: _TriggerInt32AttributeValues.ValueType  # 10103
    TRIGGER_INT32_TRIGGER_TYPE10_TIME: _TriggerInt32AttributeValues.ValueType  # 15996
    TRIGGER_INT32_TRIGGER_TYPE10_NONE: _TriggerInt32AttributeValues.ValueType  # 10230
    TRIGGER_INT32_TRIGGER_TYPE4_DIG_EDGE: _TriggerInt32AttributeValues.ValueType  # 10150
    TRIGGER_INT32_TRIGGER_TYPE4_TIME: _TriggerInt32AttributeValues.ValueType  # 15996
    TRIGGER_INT32_TRIGGER_TYPE4_NONE: _TriggerInt32AttributeValues.ValueType  # 10230
    TRIGGER_INT32_TRIGGER_TYPE5_DIG_EDGE: _TriggerInt32AttributeValues.ValueType  # 10150
    TRIGGER_INT32_TRIGGER_TYPE5_SOFTWARE: _TriggerInt32AttributeValues.ValueType  # 10292
    TRIGGER_INT32_TRIGGER_TYPE5_NONE: _TriggerInt32AttributeValues.ValueType  # 10230
    TRIGGER_INT32_TRIGGER_TYPE6_ANLG_LVL: _TriggerInt32AttributeValues.ValueType  # 10101
    TRIGGER_INT32_TRIGGER_TYPE6_ANLG_WIN: _TriggerInt32AttributeValues.ValueType  # 10103
    TRIGGER_INT32_TRIGGER_TYPE6_DIG_LVL: _TriggerInt32AttributeValues.ValueType  # 10152
    TRIGGER_INT32_TRIGGER_TYPE6_DIG_PATTERN: _TriggerInt32AttributeValues.ValueType  # 10398
    TRIGGER_INT32_TRIGGER_TYPE6_NONE: _TriggerInt32AttributeValues.ValueType  # 10230
    TRIGGER_INT32_TRIGGER_TYPE8_ANLG_EDGE: _TriggerInt32AttributeValues.ValueType  # 10099
    TRIGGER_INT32_TRIGGER_TYPE8_ANLG_MULTI_EDGE: _TriggerInt32AttributeValues.ValueType  # 16108
    TRIGGER_INT32_TRIGGER_TYPE8_DIG_EDGE: _TriggerInt32AttributeValues.ValueType  # 10150
    TRIGGER_INT32_TRIGGER_TYPE8_DIG_PATTERN: _TriggerInt32AttributeValues.ValueType  # 10398
    TRIGGER_INT32_TRIGGER_TYPE8_ANLG_WIN: _TriggerInt32AttributeValues.ValueType  # 10103
    TRIGGER_INT32_TRIGGER_TYPE8_TIME: _TriggerInt32AttributeValues.ValueType  # 15996
    TRIGGER_INT32_TRIGGER_TYPE8_NONE: _TriggerInt32AttributeValues.ValueType  # 10230
    TRIGGER_INT32_TRIGGER_TYPE9_INTERLOCKED: _TriggerInt32AttributeValues.ValueType  # 12549
    TRIGGER_INT32_TRIGGER_TYPE9_NONE: _TriggerInt32AttributeValues.ValueType  # 10230
    TRIGGER_INT32_WINDOW_TRIGGER_CONDITION1_ENTERING_WIN: _TriggerInt32AttributeValues.ValueType  # 10163
    TRIGGER_INT32_WINDOW_TRIGGER_CONDITION1_LEAVING_WIN: _TriggerInt32AttributeValues.ValueType  # 10208
    TRIGGER_INT32_WINDOW_TRIGGER_CONDITION2_INSIDE_WIN: _TriggerInt32AttributeValues.ValueType  # 10199
    TRIGGER_INT32_WINDOW_TRIGGER_CONDITION2_OUTSIDE_WIN: _TriggerInt32AttributeValues.ValueType  # 10251

class TriggerInt32AttributeValues(_TriggerInt32AttributeValues, metaclass=_TriggerInt32AttributeValuesEnumTypeWrapper): ...

TRIGGER_INT32_UNSPECIFIED: TriggerInt32AttributeValues.ValueType  # 0
TRIGGER_INT32_ACTIVE_LEVEL_ABOVE_LVL: TriggerInt32AttributeValues.ValueType  # 10093
TRIGGER_INT32_ACTIVE_LEVEL_BELOW_LVL: TriggerInt32AttributeValues.ValueType  # 10107
TRIGGER_INT32_COUPLING2_AC: TriggerInt32AttributeValues.ValueType  # 10045
TRIGGER_INT32_COUPLING2_DC: TriggerInt32AttributeValues.ValueType  # 10050
TRIGGER_INT32_DIGITAL_PATTERN_CONDITION1_PATTERN_MATCHES: TriggerInt32AttributeValues.ValueType  # 10254
TRIGGER_INT32_DIGITAL_PATTERN_CONDITION1_PATTERN_DOES_NOT_MATCH: TriggerInt32AttributeValues.ValueType  # 10253
TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_SAMP_CLK_PERIODS: TriggerInt32AttributeValues.ValueType  # 10286
TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_SECONDS: TriggerInt32AttributeValues.ValueType  # 10364
TRIGGER_INT32_DIGITAL_WIDTH_UNITS1_TICKS: TriggerInt32AttributeValues.ValueType  # 10304
TRIGGER_INT32_EDGE1_RISING: TriggerInt32AttributeValues.ValueType  # 10280
TRIGGER_INT32_EDGE1_FALLING: TriggerInt32AttributeValues.ValueType  # 10171
TRIGGER_INT32_LEVEL1_HIGH: TriggerInt32AttributeValues.ValueType  # 10192
TRIGGER_INT32_LEVEL1_LOW: TriggerInt32AttributeValues.ValueType  # 10214
TRIGGER_INT32_SLOPE1_RISING_SLOPE: TriggerInt32AttributeValues.ValueType  # 10280
TRIGGER_INT32_SLOPE1_FALLING_SLOPE: TriggerInt32AttributeValues.ValueType  # 10171
TRIGGER_INT32_SYNC_TYPE_NONE: TriggerInt32AttributeValues.ValueType  # 10230
TRIGGER_INT32_SYNC_TYPE_MASTER: TriggerInt32AttributeValues.ValueType  # 15888
TRIGGER_INT32_SYNC_TYPE_SLAVE: TriggerInt32AttributeValues.ValueType  # 15889
TRIGGER_INT32_TIMESCALE2_HOST_TIME: TriggerInt32AttributeValues.ValueType  # 16126
TRIGGER_INT32_TIMESCALE2_IO_DEVICE_TIME: TriggerInt32AttributeValues.ValueType  # 16127
TRIGGER_INT32_TRIGGER_TYPE10_ANLG_EDGE: TriggerInt32AttributeValues.ValueType  # 10099
TRIGGER_INT32_TRIGGER_TYPE10_ANLG_MULTI_EDGE: TriggerInt32AttributeValues.ValueType  # 16108
TRIGGER_INT32_TRIGGER_TYPE10_DIG_EDGE: TriggerInt32AttributeValues.ValueType  # 10150
TRIGGER_INT32_TRIGGER_TYPE10_DIG_PATTERN: TriggerInt32AttributeValues.ValueType  # 10398
TRIGGER_INT32_TRIGGER_TYPE10_ANLG_WIN: TriggerInt32AttributeValues.ValueType  # 10103
TRIGGER_INT32_TRIGGER_TYPE10_TIME: TriggerInt32AttributeValues.ValueType  # 15996
TRIGGER_INT32_TRIGGER_TYPE10_NONE: TriggerInt32AttributeValues.ValueType  # 10230
TRIGGER_INT32_TRIGGER_TYPE4_DIG_EDGE: TriggerInt32AttributeValues.ValueType  # 10150
TRIGGER_INT32_TRIGGER_TYPE4_TIME: TriggerInt32AttributeValues.ValueType  # 15996
TRIGGER_INT32_TRIGGER_TYPE4_NONE: TriggerInt32AttributeValues.ValueType  # 10230
TRIGGER_INT32_TRIGGER_TYPE5_DIG_EDGE: TriggerInt32AttributeValues.ValueType  # 10150
TRIGGER_INT32_TRIGGER_TYPE5_SOFTWARE: TriggerInt32AttributeValues.ValueType  # 10292
TRIGGER_INT32_TRIGGER_TYPE5_NONE: TriggerInt32AttributeValues.ValueType  # 10230
TRIGGER_INT32_TRIGGER_TYPE6_ANLG_LVL: TriggerInt32AttributeValues.ValueType  # 10101
TRIGGER_INT32_TRIGGER_TYPE6_ANLG_WIN: TriggerInt32AttributeValues.ValueType  # 10103
TRIGGER_INT32_TRIGGER_TYPE6_DIG_LVL: TriggerInt32AttributeValues.ValueType  # 10152
TRIGGER_INT32_TRIGGER_TYPE6_DIG_PATTERN: TriggerInt32AttributeValues.ValueType  # 10398
TRIGGER_INT32_TRIGGER_TYPE6_NONE: TriggerInt32AttributeValues.ValueType  # 10230
TRIGGER_INT32_TRIGGER_TYPE8_ANLG_EDGE: TriggerInt32AttributeValues.ValueType  # 10099
TRIGGER_INT32_TRIGGER_TYPE8_ANLG_MULTI_EDGE: TriggerInt32AttributeValues.ValueType  # 16108
TRIGGER_INT32_TRIGGER_TYPE8_DIG_EDGE: TriggerInt32AttributeValues.ValueType  # 10150
TRIGGER_INT32_TRIGGER_TYPE8_DIG_PATTERN: TriggerInt32AttributeValues.ValueType  # 10398
TRIGGER_INT32_TRIGGER_TYPE8_ANLG_WIN: TriggerInt32AttributeValues.ValueType  # 10103
TRIGGER_INT32_TRIGGER_TYPE8_TIME: TriggerInt32AttributeValues.ValueType  # 15996
TRIGGER_INT32_TRIGGER_TYPE8_NONE: TriggerInt32AttributeValues.ValueType  # 10230
TRIGGER_INT32_TRIGGER_TYPE9_INTERLOCKED: TriggerInt32AttributeValues.ValueType  # 12549
TRIGGER_INT32_TRIGGER_TYPE9_NONE: TriggerInt32AttributeValues.ValueType  # 10230
TRIGGER_INT32_WINDOW_TRIGGER_CONDITION1_ENTERING_WIN: TriggerInt32AttributeValues.ValueType  # 10163
TRIGGER_INT32_WINDOW_TRIGGER_CONDITION1_LEAVING_WIN: TriggerInt32AttributeValues.ValueType  # 10208
TRIGGER_INT32_WINDOW_TRIGGER_CONDITION2_INSIDE_WIN: TriggerInt32AttributeValues.ValueType  # 10199
TRIGGER_INT32_WINDOW_TRIGGER_CONDITION2_OUTSIDE_WIN: TriggerInt32AttributeValues.ValueType  # 10251
global___TriggerInt32AttributeValues = TriggerInt32AttributeValues

class _WatchdogInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WatchdogInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WatchdogInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WATCHDOG_INT32_UNSPECIFIED: _WatchdogInt32AttributeValues.ValueType  # 0
    WATCHDOG_INT32_DIGITAL_LINE_STATE_HIGH: _WatchdogInt32AttributeValues.ValueType  # 10192
    WATCHDOG_INT32_DIGITAL_LINE_STATE_LOW: _WatchdogInt32AttributeValues.ValueType  # 10214
    WATCHDOG_INT32_DIGITAL_LINE_STATE_TRISTATE: _WatchdogInt32AttributeValues.ValueType  # 10310
    WATCHDOG_INT32_DIGITAL_LINE_STATE_NO_CHANGE: _WatchdogInt32AttributeValues.ValueType  # 10160
    WATCHDOG_INT32_EDGE1_RISING: _WatchdogInt32AttributeValues.ValueType  # 10280
    WATCHDOG_INT32_EDGE1_FALLING: _WatchdogInt32AttributeValues.ValueType  # 10171
    WATCHDOG_INT32_TRIGGER_TYPE4_DIG_EDGE: _WatchdogInt32AttributeValues.ValueType  # 10150
    WATCHDOG_INT32_TRIGGER_TYPE4_TIME: _WatchdogInt32AttributeValues.ValueType  # 15996
    WATCHDOG_INT32_TRIGGER_TYPE4_NONE: _WatchdogInt32AttributeValues.ValueType  # 10230
    WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_VOLTAGE: _WatchdogInt32AttributeValues.ValueType  # 10322
    WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_CURRENT: _WatchdogInt32AttributeValues.ValueType  # 10134
    WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_NO_CHANGE: _WatchdogInt32AttributeValues.ValueType  # 10160
    WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_LOW: _WatchdogInt32AttributeValues.ValueType  # 10214
    WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_HIGH: _WatchdogInt32AttributeValues.ValueType  # 10192
    WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_NO_CHANGE: _WatchdogInt32AttributeValues.ValueType  # 10160

class WatchdogInt32AttributeValues(_WatchdogInt32AttributeValues, metaclass=_WatchdogInt32AttributeValuesEnumTypeWrapper): ...

WATCHDOG_INT32_UNSPECIFIED: WatchdogInt32AttributeValues.ValueType  # 0
WATCHDOG_INT32_DIGITAL_LINE_STATE_HIGH: WatchdogInt32AttributeValues.ValueType  # 10192
WATCHDOG_INT32_DIGITAL_LINE_STATE_LOW: WatchdogInt32AttributeValues.ValueType  # 10214
WATCHDOG_INT32_DIGITAL_LINE_STATE_TRISTATE: WatchdogInt32AttributeValues.ValueType  # 10310
WATCHDOG_INT32_DIGITAL_LINE_STATE_NO_CHANGE: WatchdogInt32AttributeValues.ValueType  # 10160
WATCHDOG_INT32_EDGE1_RISING: WatchdogInt32AttributeValues.ValueType  # 10280
WATCHDOG_INT32_EDGE1_FALLING: WatchdogInt32AttributeValues.ValueType  # 10171
WATCHDOG_INT32_TRIGGER_TYPE4_DIG_EDGE: WatchdogInt32AttributeValues.ValueType  # 10150
WATCHDOG_INT32_TRIGGER_TYPE4_TIME: WatchdogInt32AttributeValues.ValueType  # 15996
WATCHDOG_INT32_TRIGGER_TYPE4_NONE: WatchdogInt32AttributeValues.ValueType  # 10230
WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_VOLTAGE: WatchdogInt32AttributeValues.ValueType  # 10322
WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_CURRENT: WatchdogInt32AttributeValues.ValueType  # 10134
WATCHDOG_INT32_WATCHDOG_AO_EXPIR_STATE_NO_CHANGE: WatchdogInt32AttributeValues.ValueType  # 10160
WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_LOW: WatchdogInt32AttributeValues.ValueType  # 10214
WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_HIGH: WatchdogInt32AttributeValues.ValueType  # 10192
WATCHDOG_INT32_WATCHDOG_CO_EXPIR_STATE_NO_CHANGE: WatchdogInt32AttributeValues.ValueType  # 10160
global___WatchdogInt32AttributeValues = WatchdogInt32AttributeValues

class _WriteInt32AttributeValues:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WriteInt32AttributeValuesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WriteInt32AttributeValues.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WRITE_INT32_UNSPECIFIED: _WriteInt32AttributeValues.ValueType  # 0
    WRITE_INT32_REGENERATION_MODE1_ALLOW_REGEN: _WriteInt32AttributeValues.ValueType  # 10097
    WRITE_INT32_REGENERATION_MODE1_DO_NOT_ALLOW_REGEN: _WriteInt32AttributeValues.ValueType  # 10158
    WRITE_INT32_WAIT_MODE2_POLL: _WriteInt32AttributeValues.ValueType  # 12524
    WRITE_INT32_WAIT_MODE2_YIELD: _WriteInt32AttributeValues.ValueType  # 12525
    WRITE_INT32_WAIT_MODE2_SLEEP: _WriteInt32AttributeValues.ValueType  # 12547
    WRITE_INT32_WRITE_RELATIVE_TO_FIRST_SAMPLE: _WriteInt32AttributeValues.ValueType  # 10424
    WRITE_INT32_WRITE_RELATIVE_TO_CURR_WRITE_POS: _WriteInt32AttributeValues.ValueType  # 10430

class WriteInt32AttributeValues(_WriteInt32AttributeValues, metaclass=_WriteInt32AttributeValuesEnumTypeWrapper): ...

WRITE_INT32_UNSPECIFIED: WriteInt32AttributeValues.ValueType  # 0
WRITE_INT32_REGENERATION_MODE1_ALLOW_REGEN: WriteInt32AttributeValues.ValueType  # 10097
WRITE_INT32_REGENERATION_MODE1_DO_NOT_ALLOW_REGEN: WriteInt32AttributeValues.ValueType  # 10158
WRITE_INT32_WAIT_MODE2_POLL: WriteInt32AttributeValues.ValueType  # 12524
WRITE_INT32_WAIT_MODE2_YIELD: WriteInt32AttributeValues.ValueType  # 12525
WRITE_INT32_WAIT_MODE2_SLEEP: WriteInt32AttributeValues.ValueType  # 12547
WRITE_INT32_WRITE_RELATIVE_TO_FIRST_SAMPLE: WriteInt32AttributeValues.ValueType  # 10424
WRITE_INT32_WRITE_RELATIVE_TO_CURR_WRITE_POS: WriteInt32AttributeValues.ValueType  # 10430
global___WriteInt32AttributeValues = WriteInt32AttributeValues

@typing.final
class AnalogPowerUpChannelsAndState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    state: builtins.float
    channel_type: global___PowerUpChannelType.ValueType
    def __init__(
        self,
        *,
        channel_names: builtins.str = ...,
        state: builtins.float = ...,
        channel_type: global___PowerUpChannelType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_names", b"channel_names", "channel_type", b"channel_type", "state", b"state"]) -> None: ...

global___AnalogPowerUpChannelsAndState = AnalogPowerUpChannelsAndState

@typing.final
class WatchdogExpChannelsAndState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINES_FIELD_NUMBER: builtins.int
    EXP_STATE_FIELD_NUMBER: builtins.int
    lines: builtins.str
    exp_state: global___DigitalLineState.ValueType
    def __init__(
        self,
        *,
        lines: builtins.str = ...,
        exp_state: global___DigitalLineState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exp_state", b"exp_state", "lines", b"lines"]) -> None: ...

global___WatchdogExpChannelsAndState = WatchdogExpChannelsAndState

@typing.final
class DigitalPowerUpTypeAndChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    channel_name: builtins.str
    state: global___PowerUpStates.ValueType
    def __init__(
        self,
        *,
        channel_name: builtins.str = ...,
        state: global___PowerUpStates.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name", "state", b"state"]) -> None: ...

global___DigitalPowerUpTypeAndChannel = DigitalPowerUpTypeAndChannel

@typing.final
class DigitalPowerUpChannelsAndState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    state: global___PowerUpStates.ValueType
    def __init__(
        self,
        *,
        channel_names: builtins.str = ...,
        state: global___PowerUpStates.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_names", b"channel_names", "state", b"state"]) -> None: ...

global___DigitalPowerUpChannelsAndState = DigitalPowerUpChannelsAndState

@typing.final
class DigitalPullUpPullDownChannelsAndState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    state: global___ResistorState.ValueType
    def __init__(
        self,
        *,
        channel_names: builtins.str = ...,
        state: global___ResistorState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_names", b"channel_names", "state", b"state"]) -> None: ...

global___DigitalPullUpPullDownChannelsAndState = DigitalPullUpPullDownChannelsAndState

@typing.final
class AnalogPowerUpChannelAndType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    channel_name: builtins.str
    channel_type: global___PowerUpChannelType.ValueType
    def __init__(
        self,
        *,
        channel_name: builtins.str = ...,
        channel_type: global___PowerUpChannelType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name", "channel_type", b"channel_type"]) -> None: ...

global___AnalogPowerUpChannelAndType = AnalogPowerUpChannelAndType

@typing.final
class AddCDAQSyncConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_LIST_FIELD_NUMBER: builtins.int
    port_list: builtins.str
    def __init__(
        self,
        *,
        port_list: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["port_list", b"port_list"]) -> None: ...

global___AddCDAQSyncConnectionRequest = AddCDAQSyncConnectionRequest

@typing.final
class AddCDAQSyncConnectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___AddCDAQSyncConnectionResponse = AddCDAQSyncConnectionResponse

@typing.final
class AddGlobalChansToTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_names: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_names", b"channel_names", "task", b"task"]) -> None: ...

global___AddGlobalChansToTaskRequest = AddGlobalChansToTaskRequest

@typing.final
class AddGlobalChansToTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___AddGlobalChansToTaskResponse = AddGlobalChansToTaskResponse

@typing.final
class AddNetworkDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_ADDRESS_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTEMPT_RESERVATION_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    ip_address: builtins.str
    device_name: builtins.str
    attempt_reservation: builtins.bool
    timeout: builtins.float
    def __init__(
        self,
        *,
        ip_address: builtins.str = ...,
        device_name: builtins.str = ...,
        attempt_reservation: builtins.bool = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["attempt_reservation", b"attempt_reservation", "device_name", b"device_name", "ip_address", b"ip_address", "timeout", b"timeout"]) -> None: ...

global___AddNetworkDeviceRequest = AddNetworkDeviceRequest

@typing.final
class AddNetworkDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DEVICE_NAME_OUT_FIELD_NUMBER: builtins.int
    status: builtins.int
    device_name_out: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        device_name_out: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name_out", b"device_name_out", "status", b"status"]) -> None: ...

global___AddNetworkDeviceResponse = AddNetworkDeviceResponse

@typing.final
class AreConfiguredCDAQSyncPortsDisconnectedRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHASSIS_DEVICES_PORTS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    chassis_devices_ports: builtins.str
    timeout: builtins.float
    def __init__(
        self,
        *,
        chassis_devices_ports: builtins.str = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chassis_devices_ports", b"chassis_devices_ports", "timeout", b"timeout"]) -> None: ...

global___AreConfiguredCDAQSyncPortsDisconnectedRequest = AreConfiguredCDAQSyncPortsDisconnectedRequest

@typing.final
class AreConfiguredCDAQSyncPortsDisconnectedResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DISCONNECTED_PORTS_EXIST_FIELD_NUMBER: builtins.int
    status: builtins.int
    disconnected_ports_exist: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        disconnected_ports_exist: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disconnected_ports_exist", b"disconnected_ports_exist", "status", b"status"]) -> None: ...

global___AreConfiguredCDAQSyncPortsDisconnectedResponse = AreConfiguredCDAQSyncPortsDisconnectedResponse

@typing.final
class AutoConfigureCDAQSyncConnectionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHASSIS_DEVICES_PORTS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    chassis_devices_ports: builtins.str
    timeout: builtins.float
    def __init__(
        self,
        *,
        chassis_devices_ports: builtins.str = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chassis_devices_ports", b"chassis_devices_ports", "timeout", b"timeout"]) -> None: ...

global___AutoConfigureCDAQSyncConnectionsRequest = AutoConfigureCDAQSyncConnectionsRequest

@typing.final
class AutoConfigureCDAQSyncConnectionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___AutoConfigureCDAQSyncConnectionsResponse = AutoConfigureCDAQSyncConnectionsResponse

@typing.final
class CalculateReversePolyCoeffRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORWARD_COEFFS_FIELD_NUMBER: builtins.int
    MIN_VAL_X_FIELD_NUMBER: builtins.int
    MAX_VAL_X_FIELD_NUMBER: builtins.int
    NUM_POINTS_TO_COMPUTE_FIELD_NUMBER: builtins.int
    REVERSE_POLY_ORDER_FIELD_NUMBER: builtins.int
    min_val_x: builtins.float
    max_val_x: builtins.float
    num_points_to_compute: builtins.int
    reverse_poly_order: builtins.int
    @property
    def forward_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        forward_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        min_val_x: builtins.float = ...,
        max_val_x: builtins.float = ...,
        num_points_to_compute: builtins.int = ...,
        reverse_poly_order: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["forward_coeffs", b"forward_coeffs", "max_val_x", b"max_val_x", "min_val_x", b"min_val_x", "num_points_to_compute", b"num_points_to_compute", "reverse_poly_order", b"reverse_poly_order"]) -> None: ...

global___CalculateReversePolyCoeffRequest = CalculateReversePolyCoeffRequest

@typing.final
class CalculateReversePolyCoeffResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    REVERSE_COEFFS_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def reverse_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        reverse_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reverse_coeffs", b"reverse_coeffs", "status", b"status"]) -> None: ...

global___CalculateReversePolyCoeffResponse = CalculateReversePolyCoeffResponse

@typing.final
class CfgAnlgEdgeRefTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_SLOPE_FIELD_NUMBER: builtins.int
    TRIGGER_SLOPE_RAW_FIELD_NUMBER: builtins.int
    TRIGGER_LEVEL_FIELD_NUMBER: builtins.int
    PRETRIGGER_SAMPLES_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    trigger_slope: global___Slope1.ValueType
    trigger_slope_raw: builtins.int
    trigger_level: builtins.float
    pretrigger_samples: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_source: builtins.str = ...,
        trigger_slope: global___Slope1.ValueType = ...,
        trigger_slope_raw: builtins.int = ...,
        trigger_level: builtins.float = ...,
        pretrigger_samples: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "trigger_slope", b"trigger_slope", "trigger_slope_enum", b"trigger_slope_enum", "trigger_slope_raw", b"trigger_slope_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pretrigger_samples", b"pretrigger_samples", "task", b"task", "trigger_level", b"trigger_level", "trigger_slope", b"trigger_slope", "trigger_slope_enum", b"trigger_slope_enum", "trigger_slope_raw", b"trigger_slope_raw", "trigger_source", b"trigger_source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trigger_slope_enum", b"trigger_slope_enum"]) -> typing.Literal["trigger_slope", "trigger_slope_raw"] | None: ...

global___CfgAnlgEdgeRefTrigRequest = CfgAnlgEdgeRefTrigRequest

@typing.final
class CfgAnlgEdgeRefTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgAnlgEdgeRefTrigResponse = CfgAnlgEdgeRefTrigResponse

@typing.final
class CfgAnlgEdgeStartTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_SLOPE_FIELD_NUMBER: builtins.int
    TRIGGER_SLOPE_RAW_FIELD_NUMBER: builtins.int
    TRIGGER_LEVEL_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    trigger_slope: global___Slope1.ValueType
    trigger_slope_raw: builtins.int
    trigger_level: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_source: builtins.str = ...,
        trigger_slope: global___Slope1.ValueType = ...,
        trigger_slope_raw: builtins.int = ...,
        trigger_level: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "trigger_slope", b"trigger_slope", "trigger_slope_enum", b"trigger_slope_enum", "trigger_slope_raw", b"trigger_slope_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "trigger_level", b"trigger_level", "trigger_slope", b"trigger_slope", "trigger_slope_enum", b"trigger_slope_enum", "trigger_slope_raw", b"trigger_slope_raw", "trigger_source", b"trigger_source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trigger_slope_enum", b"trigger_slope_enum"]) -> typing.Literal["trigger_slope", "trigger_slope_raw"] | None: ...

global___CfgAnlgEdgeStartTrigRequest = CfgAnlgEdgeStartTrigRequest

@typing.final
class CfgAnlgEdgeStartTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgAnlgEdgeStartTrigResponse = CfgAnlgEdgeStartTrigResponse

@typing.final
class CfgAnlgMultiEdgeRefTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCES_FIELD_NUMBER: builtins.int
    TRIGGER_SLOPE_ARRAY_FIELD_NUMBER: builtins.int
    TRIGGER_LEVEL_ARRAY_FIELD_NUMBER: builtins.int
    PRETRIGGER_SAMPLES_FIELD_NUMBER: builtins.int
    trigger_sources: builtins.str
    pretrigger_samples: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def trigger_slope_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def trigger_level_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_sources: builtins.str = ...,
        trigger_slope_array: collections.abc.Iterable[builtins.int] | None = ...,
        trigger_level_array: collections.abc.Iterable[builtins.float] | None = ...,
        pretrigger_samples: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pretrigger_samples", b"pretrigger_samples", "task", b"task", "trigger_level_array", b"trigger_level_array", "trigger_slope_array", b"trigger_slope_array", "trigger_sources", b"trigger_sources"]) -> None: ...

global___CfgAnlgMultiEdgeRefTrigRequest = CfgAnlgMultiEdgeRefTrigRequest

@typing.final
class CfgAnlgMultiEdgeRefTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgAnlgMultiEdgeRefTrigResponse = CfgAnlgMultiEdgeRefTrigResponse

@typing.final
class CfgAnlgMultiEdgeStartTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCES_FIELD_NUMBER: builtins.int
    TRIGGER_SLOPE_ARRAY_FIELD_NUMBER: builtins.int
    TRIGGER_LEVEL_ARRAY_FIELD_NUMBER: builtins.int
    trigger_sources: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def trigger_slope_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def trigger_level_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_sources: builtins.str = ...,
        trigger_slope_array: collections.abc.Iterable[builtins.int] | None = ...,
        trigger_level_array: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "trigger_level_array", b"trigger_level_array", "trigger_slope_array", b"trigger_slope_array", "trigger_sources", b"trigger_sources"]) -> None: ...

global___CfgAnlgMultiEdgeStartTrigRequest = CfgAnlgMultiEdgeStartTrigRequest

@typing.final
class CfgAnlgMultiEdgeStartTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgAnlgMultiEdgeStartTrigResponse = CfgAnlgMultiEdgeStartTrigResponse

@typing.final
class CfgAnlgWindowRefTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_WHEN_FIELD_NUMBER: builtins.int
    TRIGGER_WHEN_RAW_FIELD_NUMBER: builtins.int
    WINDOW_TOP_FIELD_NUMBER: builtins.int
    WINDOW_BOTTOM_FIELD_NUMBER: builtins.int
    PRETRIGGER_SAMPLES_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    trigger_when: global___WindowTriggerCondition1.ValueType
    trigger_when_raw: builtins.int
    window_top: builtins.float
    window_bottom: builtins.float
    pretrigger_samples: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_source: builtins.str = ...,
        trigger_when: global___WindowTriggerCondition1.ValueType = ...,
        trigger_when_raw: builtins.int = ...,
        window_top: builtins.float = ...,
        window_bottom: builtins.float = ...,
        pretrigger_samples: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "trigger_when", b"trigger_when", "trigger_when_enum", b"trigger_when_enum", "trigger_when_raw", b"trigger_when_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pretrigger_samples", b"pretrigger_samples", "task", b"task", "trigger_source", b"trigger_source", "trigger_when", b"trigger_when", "trigger_when_enum", b"trigger_when_enum", "trigger_when_raw", b"trigger_when_raw", "window_bottom", b"window_bottom", "window_top", b"window_top"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trigger_when_enum", b"trigger_when_enum"]) -> typing.Literal["trigger_when", "trigger_when_raw"] | None: ...

global___CfgAnlgWindowRefTrigRequest = CfgAnlgWindowRefTrigRequest

@typing.final
class CfgAnlgWindowRefTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgAnlgWindowRefTrigResponse = CfgAnlgWindowRefTrigResponse

@typing.final
class CfgAnlgWindowStartTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_WHEN_FIELD_NUMBER: builtins.int
    TRIGGER_WHEN_RAW_FIELD_NUMBER: builtins.int
    WINDOW_TOP_FIELD_NUMBER: builtins.int
    WINDOW_BOTTOM_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    trigger_when: global___WindowTriggerCondition1.ValueType
    trigger_when_raw: builtins.int
    window_top: builtins.float
    window_bottom: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_source: builtins.str = ...,
        trigger_when: global___WindowTriggerCondition1.ValueType = ...,
        trigger_when_raw: builtins.int = ...,
        window_top: builtins.float = ...,
        window_bottom: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "trigger_when", b"trigger_when", "trigger_when_enum", b"trigger_when_enum", "trigger_when_raw", b"trigger_when_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "trigger_source", b"trigger_source", "trigger_when", b"trigger_when", "trigger_when_enum", b"trigger_when_enum", "trigger_when_raw", b"trigger_when_raw", "window_bottom", b"window_bottom", "window_top", b"window_top"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trigger_when_enum", b"trigger_when_enum"]) -> typing.Literal["trigger_when", "trigger_when_raw"] | None: ...

global___CfgAnlgWindowStartTrigRequest = CfgAnlgWindowStartTrigRequest

@typing.final
class CfgAnlgWindowStartTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgAnlgWindowStartTrigResponse = CfgAnlgWindowStartTrigResponse

@typing.final
class CfgBurstHandshakingTimingExportClockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_RAW_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    SAMPLE_CLK_RATE_FIELD_NUMBER: builtins.int
    SAMPLE_CLK_OUTP_TERM_FIELD_NUMBER: builtins.int
    SAMPLE_CLK_PULSE_POLARITY_FIELD_NUMBER: builtins.int
    SAMPLE_CLK_PULSE_POLARITY_RAW_FIELD_NUMBER: builtins.int
    PAUSE_WHEN_FIELD_NUMBER: builtins.int
    PAUSE_WHEN_RAW_FIELD_NUMBER: builtins.int
    READY_EVENT_ACTIVE_LEVEL_FIELD_NUMBER: builtins.int
    READY_EVENT_ACTIVE_LEVEL_RAW_FIELD_NUMBER: builtins.int
    sample_mode: global___AcquisitionType.ValueType
    sample_mode_raw: builtins.int
    samps_per_chan: builtins.int
    sample_clk_rate: builtins.float
    sample_clk_outp_term: builtins.str
    sample_clk_pulse_polarity: global___Polarity2.ValueType
    sample_clk_pulse_polarity_raw: builtins.int
    pause_when: global___Level1.ValueType
    pause_when_raw: builtins.int
    ready_event_active_level: global___Polarity2.ValueType
    ready_event_active_level_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        sample_mode: global___AcquisitionType.ValueType = ...,
        sample_mode_raw: builtins.int = ...,
        samps_per_chan: builtins.int = ...,
        sample_clk_rate: builtins.float = ...,
        sample_clk_outp_term: builtins.str = ...,
        sample_clk_pulse_polarity: global___Polarity2.ValueType = ...,
        sample_clk_pulse_polarity_raw: builtins.int = ...,
        pause_when: global___Level1.ValueType = ...,
        pause_when_raw: builtins.int = ...,
        ready_event_active_level: global___Polarity2.ValueType = ...,
        ready_event_active_level_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pause_when", b"pause_when", "pause_when_enum", b"pause_when_enum", "pause_when_raw", b"pause_when_raw", "ready_event_active_level", b"ready_event_active_level", "ready_event_active_level_enum", b"ready_event_active_level_enum", "ready_event_active_level_raw", b"ready_event_active_level_raw", "sample_clk_pulse_polarity", b"sample_clk_pulse_polarity", "sample_clk_pulse_polarity_enum", b"sample_clk_pulse_polarity_enum", "sample_clk_pulse_polarity_raw", b"sample_clk_pulse_polarity_raw", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pause_when", b"pause_when", "pause_when_enum", b"pause_when_enum", "pause_when_raw", b"pause_when_raw", "ready_event_active_level", b"ready_event_active_level", "ready_event_active_level_enum", b"ready_event_active_level_enum", "ready_event_active_level_raw", b"ready_event_active_level_raw", "sample_clk_outp_term", b"sample_clk_outp_term", "sample_clk_pulse_polarity", b"sample_clk_pulse_polarity", "sample_clk_pulse_polarity_enum", b"sample_clk_pulse_polarity_enum", "sample_clk_pulse_polarity_raw", b"sample_clk_pulse_polarity_raw", "sample_clk_rate", b"sample_clk_rate", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "samps_per_chan", b"samps_per_chan", "task", b"task"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["pause_when_enum", b"pause_when_enum"]) -> typing.Literal["pause_when", "pause_when_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["ready_event_active_level_enum", b"ready_event_active_level_enum"]) -> typing.Literal["ready_event_active_level", "ready_event_active_level_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sample_clk_pulse_polarity_enum", b"sample_clk_pulse_polarity_enum"]) -> typing.Literal["sample_clk_pulse_polarity", "sample_clk_pulse_polarity_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sample_mode_enum", b"sample_mode_enum"]) -> typing.Literal["sample_mode", "sample_mode_raw"] | None: ...

global___CfgBurstHandshakingTimingExportClockRequest = CfgBurstHandshakingTimingExportClockRequest

@typing.final
class CfgBurstHandshakingTimingExportClockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgBurstHandshakingTimingExportClockResponse = CfgBurstHandshakingTimingExportClockResponse

@typing.final
class CfgBurstHandshakingTimingImportClockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_RAW_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    SAMPLE_CLK_RATE_FIELD_NUMBER: builtins.int
    SAMPLE_CLK_SRC_FIELD_NUMBER: builtins.int
    SAMPLE_CLK_ACTIVE_EDGE_FIELD_NUMBER: builtins.int
    SAMPLE_CLK_ACTIVE_EDGE_RAW_FIELD_NUMBER: builtins.int
    PAUSE_WHEN_FIELD_NUMBER: builtins.int
    PAUSE_WHEN_RAW_FIELD_NUMBER: builtins.int
    READY_EVENT_ACTIVE_LEVEL_FIELD_NUMBER: builtins.int
    READY_EVENT_ACTIVE_LEVEL_RAW_FIELD_NUMBER: builtins.int
    sample_mode: global___AcquisitionType.ValueType
    sample_mode_raw: builtins.int
    samps_per_chan: builtins.int
    sample_clk_rate: builtins.float
    sample_clk_src: builtins.str
    sample_clk_active_edge: global___Edge1.ValueType
    sample_clk_active_edge_raw: builtins.int
    pause_when: global___Level1.ValueType
    pause_when_raw: builtins.int
    ready_event_active_level: global___Polarity2.ValueType
    ready_event_active_level_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        sample_mode: global___AcquisitionType.ValueType = ...,
        sample_mode_raw: builtins.int = ...,
        samps_per_chan: builtins.int = ...,
        sample_clk_rate: builtins.float = ...,
        sample_clk_src: builtins.str = ...,
        sample_clk_active_edge: global___Edge1.ValueType = ...,
        sample_clk_active_edge_raw: builtins.int = ...,
        pause_when: global___Level1.ValueType = ...,
        pause_when_raw: builtins.int = ...,
        ready_event_active_level: global___Polarity2.ValueType = ...,
        ready_event_active_level_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pause_when", b"pause_when", "pause_when_enum", b"pause_when_enum", "pause_when_raw", b"pause_when_raw", "ready_event_active_level", b"ready_event_active_level", "ready_event_active_level_enum", b"ready_event_active_level_enum", "ready_event_active_level_raw", b"ready_event_active_level_raw", "sample_clk_active_edge", b"sample_clk_active_edge", "sample_clk_active_edge_enum", b"sample_clk_active_edge_enum", "sample_clk_active_edge_raw", b"sample_clk_active_edge_raw", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pause_when", b"pause_when", "pause_when_enum", b"pause_when_enum", "pause_when_raw", b"pause_when_raw", "ready_event_active_level", b"ready_event_active_level", "ready_event_active_level_enum", b"ready_event_active_level_enum", "ready_event_active_level_raw", b"ready_event_active_level_raw", "sample_clk_active_edge", b"sample_clk_active_edge", "sample_clk_active_edge_enum", b"sample_clk_active_edge_enum", "sample_clk_active_edge_raw", b"sample_clk_active_edge_raw", "sample_clk_rate", b"sample_clk_rate", "sample_clk_src", b"sample_clk_src", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "samps_per_chan", b"samps_per_chan", "task", b"task"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["pause_when_enum", b"pause_when_enum"]) -> typing.Literal["pause_when", "pause_when_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["ready_event_active_level_enum", b"ready_event_active_level_enum"]) -> typing.Literal["ready_event_active_level", "ready_event_active_level_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sample_clk_active_edge_enum", b"sample_clk_active_edge_enum"]) -> typing.Literal["sample_clk_active_edge", "sample_clk_active_edge_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sample_mode_enum", b"sample_mode_enum"]) -> typing.Literal["sample_mode", "sample_mode_raw"] | None: ...

global___CfgBurstHandshakingTimingImportClockRequest = CfgBurstHandshakingTimingImportClockRequest

@typing.final
class CfgBurstHandshakingTimingImportClockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgBurstHandshakingTimingImportClockResponse = CfgBurstHandshakingTimingImportClockResponse

@typing.final
class CfgChangeDetectionTimingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    RISING_EDGE_CHAN_FIELD_NUMBER: builtins.int
    FALLING_EDGE_CHAN_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_RAW_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    rising_edge_chan: builtins.str
    falling_edge_chan: builtins.str
    sample_mode: global___AcquisitionType.ValueType
    sample_mode_raw: builtins.int
    samps_per_chan: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        rising_edge_chan: builtins.str = ...,
        falling_edge_chan: builtins.str = ...,
        sample_mode: global___AcquisitionType.ValueType = ...,
        sample_mode_raw: builtins.int = ...,
        samps_per_chan: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["falling_edge_chan", b"falling_edge_chan", "rising_edge_chan", b"rising_edge_chan", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "samps_per_chan", b"samps_per_chan", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["sample_mode_enum", b"sample_mode_enum"]) -> typing.Literal["sample_mode", "sample_mode_raw"] | None: ...

global___CfgChangeDetectionTimingRequest = CfgChangeDetectionTimingRequest

@typing.final
class CfgChangeDetectionTimingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgChangeDetectionTimingResponse = CfgChangeDetectionTimingResponse

@typing.final
class CfgDigEdgeRefTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_EDGE_FIELD_NUMBER: builtins.int
    TRIGGER_EDGE_RAW_FIELD_NUMBER: builtins.int
    PRETRIGGER_SAMPLES_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    trigger_edge: global___Edge1.ValueType
    trigger_edge_raw: builtins.int
    pretrigger_samples: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_source: builtins.str = ...,
        trigger_edge: global___Edge1.ValueType = ...,
        trigger_edge_raw: builtins.int = ...,
        pretrigger_samples: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "trigger_edge", b"trigger_edge", "trigger_edge_enum", b"trigger_edge_enum", "trigger_edge_raw", b"trigger_edge_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pretrigger_samples", b"pretrigger_samples", "task", b"task", "trigger_edge", b"trigger_edge", "trigger_edge_enum", b"trigger_edge_enum", "trigger_edge_raw", b"trigger_edge_raw", "trigger_source", b"trigger_source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trigger_edge_enum", b"trigger_edge_enum"]) -> typing.Literal["trigger_edge", "trigger_edge_raw"] | None: ...

global___CfgDigEdgeRefTrigRequest = CfgDigEdgeRefTrigRequest

@typing.final
class CfgDigEdgeRefTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgDigEdgeRefTrigResponse = CfgDigEdgeRefTrigResponse

@typing.final
class CfgDigEdgeStartTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_EDGE_FIELD_NUMBER: builtins.int
    TRIGGER_EDGE_RAW_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    trigger_edge: global___Edge1.ValueType
    trigger_edge_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_source: builtins.str = ...,
        trigger_edge: global___Edge1.ValueType = ...,
        trigger_edge_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "trigger_edge", b"trigger_edge", "trigger_edge_enum", b"trigger_edge_enum", "trigger_edge_raw", b"trigger_edge_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "trigger_edge", b"trigger_edge", "trigger_edge_enum", b"trigger_edge_enum", "trigger_edge_raw", b"trigger_edge_raw", "trigger_source", b"trigger_source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trigger_edge_enum", b"trigger_edge_enum"]) -> typing.Literal["trigger_edge", "trigger_edge_raw"] | None: ...

global___CfgDigEdgeStartTrigRequest = CfgDigEdgeStartTrigRequest

@typing.final
class CfgDigEdgeStartTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgDigEdgeStartTrigResponse = CfgDigEdgeStartTrigResponse

@typing.final
class CfgDigPatternRefTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_PATTERN_FIELD_NUMBER: builtins.int
    TRIGGER_WHEN_FIELD_NUMBER: builtins.int
    TRIGGER_WHEN_RAW_FIELD_NUMBER: builtins.int
    PRETRIGGER_SAMPLES_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    trigger_pattern: builtins.str
    trigger_when: global___DigitalPatternCondition1.ValueType
    trigger_when_raw: builtins.int
    pretrigger_samples: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_source: builtins.str = ...,
        trigger_pattern: builtins.str = ...,
        trigger_when: global___DigitalPatternCondition1.ValueType = ...,
        trigger_when_raw: builtins.int = ...,
        pretrigger_samples: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "trigger_when", b"trigger_when", "trigger_when_enum", b"trigger_when_enum", "trigger_when_raw", b"trigger_when_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pretrigger_samples", b"pretrigger_samples", "task", b"task", "trigger_pattern", b"trigger_pattern", "trigger_source", b"trigger_source", "trigger_when", b"trigger_when", "trigger_when_enum", b"trigger_when_enum", "trigger_when_raw", b"trigger_when_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trigger_when_enum", b"trigger_when_enum"]) -> typing.Literal["trigger_when", "trigger_when_raw"] | None: ...

global___CfgDigPatternRefTrigRequest = CfgDigPatternRefTrigRequest

@typing.final
class CfgDigPatternRefTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgDigPatternRefTrigResponse = CfgDigPatternRefTrigResponse

@typing.final
class CfgDigPatternStartTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TRIGGER_SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_PATTERN_FIELD_NUMBER: builtins.int
    TRIGGER_WHEN_FIELD_NUMBER: builtins.int
    TRIGGER_WHEN_RAW_FIELD_NUMBER: builtins.int
    trigger_source: builtins.str
    trigger_pattern: builtins.str
    trigger_when: global___DigitalPatternCondition1.ValueType
    trigger_when_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        trigger_source: builtins.str = ...,
        trigger_pattern: builtins.str = ...,
        trigger_when: global___DigitalPatternCondition1.ValueType = ...,
        trigger_when_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "trigger_when", b"trigger_when", "trigger_when_enum", b"trigger_when_enum", "trigger_when_raw", b"trigger_when_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "trigger_pattern", b"trigger_pattern", "trigger_source", b"trigger_source", "trigger_when", b"trigger_when", "trigger_when_enum", b"trigger_when_enum", "trigger_when_raw", b"trigger_when_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trigger_when_enum", b"trigger_when_enum"]) -> typing.Literal["trigger_when", "trigger_when_raw"] | None: ...

global___CfgDigPatternStartTrigRequest = CfgDigPatternStartTrigRequest

@typing.final
class CfgDigPatternStartTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgDigPatternStartTrigResponse = CfgDigPatternStartTrigResponse

@typing.final
class CfgHandshakingTimingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_RAW_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    sample_mode: global___AcquisitionType.ValueType
    sample_mode_raw: builtins.int
    samps_per_chan: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        sample_mode: global___AcquisitionType.ValueType = ...,
        sample_mode_raw: builtins.int = ...,
        samps_per_chan: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "samps_per_chan", b"samps_per_chan", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["sample_mode_enum", b"sample_mode_enum"]) -> typing.Literal["sample_mode", "sample_mode_raw"] | None: ...

global___CfgHandshakingTimingRequest = CfgHandshakingTimingRequest

@typing.final
class CfgHandshakingTimingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgHandshakingTimingResponse = CfgHandshakingTimingResponse

@typing.final
class CfgImplicitTimingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_RAW_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    sample_mode: global___AcquisitionType.ValueType
    sample_mode_raw: builtins.int
    samps_per_chan: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        sample_mode: global___AcquisitionType.ValueType = ...,
        sample_mode_raw: builtins.int = ...,
        samps_per_chan: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "samps_per_chan", b"samps_per_chan", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["sample_mode_enum", b"sample_mode_enum"]) -> typing.Literal["sample_mode", "sample_mode_raw"] | None: ...

global___CfgImplicitTimingRequest = CfgImplicitTimingRequest

@typing.final
class CfgImplicitTimingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgImplicitTimingResponse = CfgImplicitTimingResponse

@typing.final
class CfgInputBufferRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["num_samps_per_chan", b"num_samps_per_chan", "task", b"task"]) -> None: ...

global___CfgInputBufferRequest = CfgInputBufferRequest

@typing.final
class CfgInputBufferResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgInputBufferResponse = CfgInputBufferResponse

@typing.final
class CfgOutputBufferRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["num_samps_per_chan", b"num_samps_per_chan", "task", b"task"]) -> None: ...

global___CfgOutputBufferRequest = CfgOutputBufferRequest

@typing.final
class CfgOutputBufferResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgOutputBufferResponse = CfgOutputBufferResponse

@typing.final
class CfgPipelinedSampClkTimingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    RATE_FIELD_NUMBER: builtins.int
    ACTIVE_EDGE_FIELD_NUMBER: builtins.int
    ACTIVE_EDGE_RAW_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_RAW_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    source: builtins.str
    rate: builtins.float
    active_edge: global___Edge1.ValueType
    active_edge_raw: builtins.int
    sample_mode: global___AcquisitionType.ValueType
    sample_mode_raw: builtins.int
    samps_per_chan: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        source: builtins.str = ...,
        rate: builtins.float = ...,
        active_edge: global___Edge1.ValueType = ...,
        active_edge_raw: builtins.int = ...,
        sample_mode: global___AcquisitionType.ValueType = ...,
        sample_mode_raw: builtins.int = ...,
        samps_per_chan: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["active_edge", b"active_edge", "active_edge_enum", b"active_edge_enum", "active_edge_raw", b"active_edge_raw", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["active_edge", b"active_edge", "active_edge_enum", b"active_edge_enum", "active_edge_raw", b"active_edge_raw", "rate", b"rate", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "samps_per_chan", b"samps_per_chan", "source", b"source", "task", b"task"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["active_edge_enum", b"active_edge_enum"]) -> typing.Literal["active_edge", "active_edge_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sample_mode_enum", b"sample_mode_enum"]) -> typing.Literal["sample_mode", "sample_mode_raw"] | None: ...

global___CfgPipelinedSampClkTimingRequest = CfgPipelinedSampClkTimingRequest

@typing.final
class CfgPipelinedSampClkTimingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgPipelinedSampClkTimingResponse = CfgPipelinedSampClkTimingResponse

@typing.final
class CfgSampClkTimingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    RATE_FIELD_NUMBER: builtins.int
    ACTIVE_EDGE_FIELD_NUMBER: builtins.int
    ACTIVE_EDGE_RAW_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_FIELD_NUMBER: builtins.int
    SAMPLE_MODE_RAW_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    source: builtins.str
    rate: builtins.float
    active_edge: global___Edge1.ValueType
    active_edge_raw: builtins.int
    sample_mode: global___AcquisitionType.ValueType
    sample_mode_raw: builtins.int
    samps_per_chan: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        source: builtins.str = ...,
        rate: builtins.float = ...,
        active_edge: global___Edge1.ValueType = ...,
        active_edge_raw: builtins.int = ...,
        sample_mode: global___AcquisitionType.ValueType = ...,
        sample_mode_raw: builtins.int = ...,
        samps_per_chan: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["active_edge", b"active_edge", "active_edge_enum", b"active_edge_enum", "active_edge_raw", b"active_edge_raw", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["active_edge", b"active_edge", "active_edge_enum", b"active_edge_enum", "active_edge_raw", b"active_edge_raw", "rate", b"rate", "sample_mode", b"sample_mode", "sample_mode_enum", b"sample_mode_enum", "sample_mode_raw", b"sample_mode_raw", "samps_per_chan", b"samps_per_chan", "source", b"source", "task", b"task"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["active_edge_enum", b"active_edge_enum"]) -> typing.Literal["active_edge", "active_edge_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sample_mode_enum", b"sample_mode_enum"]) -> typing.Literal["sample_mode", "sample_mode_raw"] | None: ...

global___CfgSampClkTimingRequest = CfgSampClkTimingRequest

@typing.final
class CfgSampClkTimingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgSampClkTimingResponse = CfgSampClkTimingResponse

@typing.final
class CfgTimeStartTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    WHEN_FIELD_NUMBER: builtins.int
    TIMESCALE_FIELD_NUMBER: builtins.int
    TIMESCALE_RAW_FIELD_NUMBER: builtins.int
    timescale: global___Timescale2.ValueType
    timescale_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def when(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        when: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        timescale: global___Timescale2.ValueType = ...,
        timescale_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "timescale", b"timescale", "timescale_enum", b"timescale_enum", "timescale_raw", b"timescale_raw", "when", b"when"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timescale", b"timescale", "timescale_enum", b"timescale_enum", "timescale_raw", b"timescale_raw", "when", b"when"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["timescale_enum", b"timescale_enum"]) -> typing.Literal["timescale", "timescale_raw"] | None: ...

global___CfgTimeStartTrigRequest = CfgTimeStartTrigRequest

@typing.final
class CfgTimeStartTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgTimeStartTrigResponse = CfgTimeStartTrigResponse

@typing.final
class CfgWatchdogAOExpirStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    EXPIR_STATE_ARRAY_FIELD_NUMBER: builtins.int
    OUTPUT_TYPE_ARRAY_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def expir_state_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def output_type_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___WatchdogAOOutputType.ValueType]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_names: builtins.str = ...,
        expir_state_array: collections.abc.Iterable[builtins.float] | None = ...,
        output_type_array: collections.abc.Iterable[global___WatchdogAOOutputType.ValueType] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_names", b"channel_names", "expir_state_array", b"expir_state_array", "output_type_array", b"output_type_array", "task", b"task"]) -> None: ...

global___CfgWatchdogAOExpirStatesRequest = CfgWatchdogAOExpirStatesRequest

@typing.final
class CfgWatchdogAOExpirStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgWatchdogAOExpirStatesResponse = CfgWatchdogAOExpirStatesResponse

@typing.final
class CfgWatchdogCOExpirStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    EXPIR_STATE_ARRAY_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def expir_state_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___WatchdogCOExpirState.ValueType]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_names: builtins.str = ...,
        expir_state_array: collections.abc.Iterable[global___WatchdogCOExpirState.ValueType] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_names", b"channel_names", "expir_state_array", b"expir_state_array", "task", b"task"]) -> None: ...

global___CfgWatchdogCOExpirStatesRequest = CfgWatchdogCOExpirStatesRequest

@typing.final
class CfgWatchdogCOExpirStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgWatchdogCOExpirStatesResponse = CfgWatchdogCOExpirStatesResponse

@typing.final
class CfgWatchdogDOExpirStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    EXPIR_STATE_ARRAY_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def expir_state_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___DigitalLineState.ValueType]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_names: builtins.str = ...,
        expir_state_array: collections.abc.Iterable[global___DigitalLineState.ValueType] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_names", b"channel_names", "expir_state_array", b"expir_state_array", "task", b"task"]) -> None: ...

global___CfgWatchdogDOExpirStatesRequest = CfgWatchdogDOExpirStatesRequest

@typing.final
class CfgWatchdogDOExpirStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CfgWatchdogDOExpirStatesResponse = CfgWatchdogDOExpirStatesResponse

@typing.final
class ClearTEDSRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["physical_channel", b"physical_channel"]) -> None: ...

global___ClearTEDSRequest = ClearTEDSRequest

@typing.final
class ClearTEDSResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ClearTEDSResponse = ClearTEDSResponse

@typing.final
class ClearTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___ClearTaskRequest = ClearTaskRequest

@typing.final
class ClearTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ClearTaskResponse = ClearTaskResponse

@typing.final
class ConfigureLoggingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    LOGGING_MODE_FIELD_NUMBER: builtins.int
    LOGGING_MODE_RAW_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    OPERATION_RAW_FIELD_NUMBER: builtins.int
    file_path: builtins.str
    logging_mode: global___LoggingMode.ValueType
    logging_mode_raw: builtins.int
    group_name: builtins.str
    operation: global___LoggingOperation.ValueType
    operation_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        file_path: builtins.str = ...,
        logging_mode: global___LoggingMode.ValueType = ...,
        logging_mode_raw: builtins.int = ...,
        group_name: builtins.str = ...,
        operation: global___LoggingOperation.ValueType = ...,
        operation_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["logging_mode", b"logging_mode", "logging_mode_enum", b"logging_mode_enum", "logging_mode_raw", b"logging_mode_raw", "operation", b"operation", "operation_enum", b"operation_enum", "operation_raw", b"operation_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["file_path", b"file_path", "group_name", b"group_name", "logging_mode", b"logging_mode", "logging_mode_enum", b"logging_mode_enum", "logging_mode_raw", b"logging_mode_raw", "operation", b"operation", "operation_enum", b"operation_enum", "operation_raw", b"operation_raw", "task", b"task"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["logging_mode_enum", b"logging_mode_enum"]) -> typing.Literal["logging_mode", "logging_mode_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["operation_enum", b"operation_enum"]) -> typing.Literal["operation", "operation_raw"] | None: ...

global___ConfigureLoggingRequest = ConfigureLoggingRequest

@typing.final
class ConfigureLoggingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ConfigureLoggingResponse = ConfigureLoggingResponse

@typing.final
class ConfigureTEDSRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    file_path: builtins.str
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_path", b"file_path", "physical_channel", b"physical_channel"]) -> None: ...

global___ConfigureTEDSRequest = ConfigureTEDSRequest

@typing.final
class ConfigureTEDSResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ConfigureTEDSResponse = ConfigureTEDSResponse

@typing.final
class ConnectTermsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_TERMINAL_FIELD_NUMBER: builtins.int
    DESTINATION_TERMINAL_FIELD_NUMBER: builtins.int
    SIGNAL_MODIFIERS_FIELD_NUMBER: builtins.int
    SIGNAL_MODIFIERS_RAW_FIELD_NUMBER: builtins.int
    source_terminal: builtins.str
    destination_terminal: builtins.str
    signal_modifiers: global___InvertPolarity.ValueType
    signal_modifiers_raw: builtins.int
    def __init__(
        self,
        *,
        source_terminal: builtins.str = ...,
        destination_terminal: builtins.str = ...,
        signal_modifiers: global___InvertPolarity.ValueType = ...,
        signal_modifiers_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["signal_modifiers", b"signal_modifiers", "signal_modifiers_enum", b"signal_modifiers_enum", "signal_modifiers_raw", b"signal_modifiers_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination_terminal", b"destination_terminal", "signal_modifiers", b"signal_modifiers", "signal_modifiers_enum", b"signal_modifiers_enum", "signal_modifiers_raw", b"signal_modifiers_raw", "source_terminal", b"source_terminal"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["signal_modifiers_enum", b"signal_modifiers_enum"]) -> typing.Literal["signal_modifiers", "signal_modifiers_raw"] | None: ...

global___ConnectTermsRequest = ConnectTermsRequest

@typing.final
class ConnectTermsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ConnectTermsResponse = ConnectTermsResponse

@typing.final
class ControlWatchdogTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    ACTION_RAW_FIELD_NUMBER: builtins.int
    action: global___WatchdogControlAction.ValueType
    action_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        action: global___WatchdogControlAction.ValueType = ...,
        action_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "action_enum", b"action_enum", "action_raw", b"action_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "action_enum", b"action_enum", "action_raw", b"action_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action_enum", b"action_enum"]) -> typing.Literal["action", "action_raw"] | None: ...

global___ControlWatchdogTaskRequest = ControlWatchdogTaskRequest

@typing.final
class ControlWatchdogTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ControlWatchdogTaskResponse = ControlWatchdogTaskResponse

@typing.final
class CreateAIAccel4WireDCVoltageChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SENSITIVITY_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    USE_EXCIT_FOR_SCALING_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___AccelUnits2.ValueType
    units_raw: builtins.int
    sensitivity: builtins.float
    sensitivity_units: global___AccelSensitivityUnits1.ValueType
    sensitivity_units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    use_excit_for_scaling: builtins.bool
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___AccelUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        sensitivity: builtins.float = ...,
        sensitivity_units: global___AccelSensitivityUnits1.ValueType = ...,
        sensitivity_units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        use_excit_for_scaling: builtins.bool = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "sensitivity", b"sensitivity", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "use_excit_for_scaling", b"use_excit_for_scaling", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sensitivity_units_enum", b"sensitivity_units_enum"]) -> typing.Literal["sensitivity_units", "sensitivity_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIAccel4WireDCVoltageChanRequest = CreateAIAccel4WireDCVoltageChanRequest

@typing.final
class CreateAIAccel4WireDCVoltageChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIAccel4WireDCVoltageChanResponse = CreateAIAccel4WireDCVoltageChanResponse

@typing.final
class CreateAIAccelChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SENSITIVITY_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___AccelUnits2.ValueType
    units_raw: builtins.int
    sensitivity: builtins.float
    sensitivity_units: global___AccelSensitivityUnits1.ValueType
    sensitivity_units_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___AccelUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        sensitivity: builtins.float = ...,
        sensitivity_units: global___AccelSensitivityUnits1.ValueType = ...,
        sensitivity_units_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "sensitivity", b"sensitivity", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sensitivity_units_enum", b"sensitivity_units_enum"]) -> typing.Literal["sensitivity_units", "sensitivity_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIAccelChanRequest = CreateAIAccelChanRequest

@typing.final
class CreateAIAccelChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIAccelChanResponse = CreateAIAccelChanResponse

@typing.final
class CreateAIAccelChargeChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SENSITIVITY_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___AccelUnits2.ValueType
    units_raw: builtins.int
    sensitivity: builtins.float
    sensitivity_units: global___AccelChargeSensitivityUnits.ValueType
    sensitivity_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___AccelUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        sensitivity: builtins.float = ...,
        sensitivity_units: global___AccelChargeSensitivityUnits.ValueType = ...,
        sensitivity_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "sensitivity", b"sensitivity", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sensitivity_units_enum", b"sensitivity_units_enum"]) -> typing.Literal["sensitivity_units", "sensitivity_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIAccelChargeChanRequest = CreateAIAccelChargeChanRequest

@typing.final
class CreateAIAccelChargeChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIAccelChargeChanResponse = CreateAIAccelChargeChanResponse

@typing.final
class CreateAIBridgeChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___BridgeUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___BridgeUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIBridgeChanRequest = CreateAIBridgeChanRequest

@typing.final
class CreateAIBridgeChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIBridgeChanResponse = CreateAIBridgeChanResponse

@typing.final
class CreateAIChargeChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___ChargeUnits.ValueType
    units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___ChargeUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIChargeChanRequest = CreateAIChargeChanRequest

@typing.final
class CreateAIChargeChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIChargeChanResponse = CreateAIChargeChanResponse

@typing.final
class CreateAICurrentChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOC_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOC_RAW_FIELD_NUMBER: builtins.int
    EXT_SHUNT_RESISTOR_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___CurrentUnits2.ValueType
    units_raw: builtins.int
    shunt_resistor_loc: global___CurrentShuntResistorLocationWithDefault.ValueType
    shunt_resistor_loc_raw: builtins.int
    ext_shunt_resistor_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___CurrentUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        shunt_resistor_loc: global___CurrentShuntResistorLocationWithDefault.ValueType = ...,
        shunt_resistor_loc_raw: builtins.int = ...,
        ext_shunt_resistor_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["shunt_resistor_loc", b"shunt_resistor_loc", "shunt_resistor_loc_enum", b"shunt_resistor_loc_enum", "shunt_resistor_loc_raw", b"shunt_resistor_loc_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "ext_shunt_resistor_val", b"ext_shunt_resistor_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "shunt_resistor_loc", b"shunt_resistor_loc", "shunt_resistor_loc_enum", b"shunt_resistor_loc_enum", "shunt_resistor_loc_raw", b"shunt_resistor_loc_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_loc_enum", b"shunt_resistor_loc_enum"]) -> typing.Literal["shunt_resistor_loc", "shunt_resistor_loc_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAICurrentChanRequest = CreateAICurrentChanRequest

@typing.final
class CreateAICurrentChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAICurrentChanResponse = CreateAICurrentChanResponse

@typing.final
class CreateAICurrentRMSChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOC_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOC_RAW_FIELD_NUMBER: builtins.int
    EXT_SHUNT_RESISTOR_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___CurrentUnits2.ValueType
    units_raw: builtins.int
    shunt_resistor_loc: global___CurrentShuntResistorLocationWithDefault.ValueType
    shunt_resistor_loc_raw: builtins.int
    ext_shunt_resistor_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___CurrentUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        shunt_resistor_loc: global___CurrentShuntResistorLocationWithDefault.ValueType = ...,
        shunt_resistor_loc_raw: builtins.int = ...,
        ext_shunt_resistor_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["shunt_resistor_loc", b"shunt_resistor_loc", "shunt_resistor_loc_enum", b"shunt_resistor_loc_enum", "shunt_resistor_loc_raw", b"shunt_resistor_loc_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "ext_shunt_resistor_val", b"ext_shunt_resistor_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "shunt_resistor_loc", b"shunt_resistor_loc", "shunt_resistor_loc_enum", b"shunt_resistor_loc_enum", "shunt_resistor_loc_raw", b"shunt_resistor_loc_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_loc_enum", b"shunt_resistor_loc_enum"]) -> typing.Literal["shunt_resistor_loc", "shunt_resistor_loc_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAICurrentRMSChanRequest = CreateAICurrentRMSChanRequest

@typing.final
class CreateAICurrentRMSChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAICurrentRMSChanResponse = CreateAICurrentRMSChanResponse

@typing.final
class CreateAIForceBridgePolynomialChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    FORWARD_COEFFS_FIELD_NUMBER: builtins.int
    REVERSE_COEFFS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___ForceUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def forward_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def reverse_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___ForceUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        forward_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        reverse_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "forward_coeffs", b"forward_coeffs", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "reverse_coeffs", b"reverse_coeffs", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIForceBridgePolynomialChanRequest = CreateAIForceBridgePolynomialChanRequest

@typing.final
class CreateAIForceBridgePolynomialChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIForceBridgePolynomialChanResponse = CreateAIForceBridgePolynomialChanResponse

@typing.final
class CreateAIForceBridgeTableChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    ELECTRICAL_VALS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    PHYSICAL_VALS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___ForceUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def electrical_vals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def physical_vals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___ForceUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        electrical_vals: collections.abc.Iterable[builtins.float] | None = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        physical_vals: collections.abc.Iterable[builtins.float] | None = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "electrical_vals", b"electrical_vals", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "physical_vals", b"physical_vals", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIForceBridgeTableChanRequest = CreateAIForceBridgeTableChanRequest

@typing.final
class CreateAIForceBridgeTableChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIForceBridgeTableChanResponse = CreateAIForceBridgeTableChanResponse

@typing.final
class CreateAIForceBridgeTwoPointLinChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    FIRST_ELECTRICAL_VAL_FIELD_NUMBER: builtins.int
    SECOND_ELECTRICAL_VAL_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    FIRST_PHYSICAL_VAL_FIELD_NUMBER: builtins.int
    SECOND_PHYSICAL_VAL_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___ForceUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    first_electrical_val: builtins.float
    second_electrical_val: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    first_physical_val: builtins.float
    second_physical_val: builtins.float
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___ForceUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        first_electrical_val: builtins.float = ...,
        second_electrical_val: builtins.float = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        first_physical_val: builtins.float = ...,
        second_physical_val: builtins.float = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "first_electrical_val", b"first_electrical_val", "first_physical_val", b"first_physical_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "second_electrical_val", b"second_electrical_val", "second_physical_val", b"second_physical_val", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIForceBridgeTwoPointLinChanRequest = CreateAIForceBridgeTwoPointLinChanRequest

@typing.final
class CreateAIForceBridgeTwoPointLinChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIForceBridgeTwoPointLinChanResponse = CreateAIForceBridgeTwoPointLinChanResponse

@typing.final
class CreateAIForceIEPEChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SENSITIVITY_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___ForceIEPEUnits.ValueType
    units_raw: builtins.int
    sensitivity: builtins.float
    sensitivity_units: global___ForceIEPESensorSensitivityUnits.ValueType
    sensitivity_units_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___ForceIEPEUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        sensitivity: builtins.float = ...,
        sensitivity_units: global___ForceIEPESensorSensitivityUnits.ValueType = ...,
        sensitivity_units_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "sensitivity", b"sensitivity", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sensitivity_units_enum", b"sensitivity_units_enum"]) -> typing.Literal["sensitivity_units", "sensitivity_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIForceIEPEChanRequest = CreateAIForceIEPEChanRequest

@typing.final
class CreateAIForceIEPEChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIForceIEPEChanResponse = CreateAIForceIEPEChanResponse

@typing.final
class CreateAIFreqVoltageChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    THRESHOLD_LEVEL_FIELD_NUMBER: builtins.int
    HYSTERESIS_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___FrequencyUnits.ValueType
    units_raw: builtins.int
    threshold_level: builtins.float
    hysteresis: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___FrequencyUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        threshold_level: builtins.float = ...,
        hysteresis: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "hysteresis", b"hysteresis", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "threshold_level", b"threshold_level", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIFreqVoltageChanRequest = CreateAIFreqVoltageChanRequest

@typing.final
class CreateAIFreqVoltageChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIFreqVoltageChanResponse = CreateAIFreqVoltageChanResponse

@typing.final
class CreateAIMicrophoneChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    MIC_SENSITIVITY_FIELD_NUMBER: builtins.int
    MAX_SND_PRESS_LEVEL_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    units: global___SoundPressureUnits1.ValueType
    units_raw: builtins.int
    mic_sensitivity: builtins.float
    max_snd_press_level: builtins.float
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        units: global___SoundPressureUnits1.ValueType = ...,
        units_raw: builtins.int = ...,
        mic_sensitivity: builtins.float = ...,
        max_snd_press_level: builtins.float = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_snd_press_level", b"max_snd_press_level", "mic_sensitivity", b"mic_sensitivity", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIMicrophoneChanRequest = CreateAIMicrophoneChanRequest

@typing.final
class CreateAIMicrophoneChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIMicrophoneChanResponse = CreateAIMicrophoneChanResponse

@typing.final
class CreateAIPosEddyCurrProxProbeChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SENSITIVITY_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___LengthUnits2.ValueType
    units_raw: builtins.int
    sensitivity: builtins.float
    sensitivity_units: global___EddyCurrentProxProbeSensitivityUnits.ValueType
    sensitivity_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___LengthUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        sensitivity: builtins.float = ...,
        sensitivity_units: global___EddyCurrentProxProbeSensitivityUnits.ValueType = ...,
        sensitivity_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "sensitivity", b"sensitivity", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sensitivity_units_enum", b"sensitivity_units_enum"]) -> typing.Literal["sensitivity_units", "sensitivity_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIPosEddyCurrProxProbeChanRequest = CreateAIPosEddyCurrProxProbeChanRequest

@typing.final
class CreateAIPosEddyCurrProxProbeChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIPosEddyCurrProxProbeChanResponse = CreateAIPosEddyCurrProxProbeChanResponse

@typing.final
class CreateAIPosLVDTChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SENSITIVITY_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_FREQ_FIELD_NUMBER: builtins.int
    AC_EXCIT_WIRE_MODE_FIELD_NUMBER: builtins.int
    AC_EXCIT_WIRE_MODE_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___LengthUnits2.ValueType
    units_raw: builtins.int
    sensitivity: builtins.float
    sensitivity_units: global___LVDTSensitivityUnits1.ValueType
    sensitivity_units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    voltage_excit_freq: builtins.float
    ac_excit_wire_mode: global___ACExcitWireMode.ValueType
    ac_excit_wire_mode_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___LengthUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        sensitivity: builtins.float = ...,
        sensitivity_units: global___LVDTSensitivityUnits1.ValueType = ...,
        sensitivity_units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        voltage_excit_freq: builtins.float = ...,
        ac_excit_wire_mode: global___ACExcitWireMode.ValueType = ...,
        ac_excit_wire_mode_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ac_excit_wire_mode", b"ac_excit_wire_mode", "ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum", "ac_excit_wire_mode_raw", b"ac_excit_wire_mode_raw", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ac_excit_wire_mode", b"ac_excit_wire_mode", "ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum", "ac_excit_wire_mode_raw", b"ac_excit_wire_mode_raw", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "sensitivity", b"sensitivity", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_freq", b"voltage_excit_freq", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum"]) -> typing.Literal["ac_excit_wire_mode", "ac_excit_wire_mode_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sensitivity_units_enum", b"sensitivity_units_enum"]) -> typing.Literal["sensitivity_units", "sensitivity_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIPosLVDTChanRequest = CreateAIPosLVDTChanRequest

@typing.final
class CreateAIPosLVDTChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIPosLVDTChanResponse = CreateAIPosLVDTChanResponse

@typing.final
class CreateAIPosRVDTChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SENSITIVITY_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_FREQ_FIELD_NUMBER: builtins.int
    AC_EXCIT_WIRE_MODE_FIELD_NUMBER: builtins.int
    AC_EXCIT_WIRE_MODE_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___AngleUnits1.ValueType
    units_raw: builtins.int
    sensitivity: builtins.float
    sensitivity_units: global___RVDTSensitivityUnits1.ValueType
    sensitivity_units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    voltage_excit_freq: builtins.float
    ac_excit_wire_mode: global___ACExcitWireMode.ValueType
    ac_excit_wire_mode_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___AngleUnits1.ValueType = ...,
        units_raw: builtins.int = ...,
        sensitivity: builtins.float = ...,
        sensitivity_units: global___RVDTSensitivityUnits1.ValueType = ...,
        sensitivity_units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        voltage_excit_freq: builtins.float = ...,
        ac_excit_wire_mode: global___ACExcitWireMode.ValueType = ...,
        ac_excit_wire_mode_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ac_excit_wire_mode", b"ac_excit_wire_mode", "ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum", "ac_excit_wire_mode_raw", b"ac_excit_wire_mode_raw", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ac_excit_wire_mode", b"ac_excit_wire_mode", "ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum", "ac_excit_wire_mode_raw", b"ac_excit_wire_mode_raw", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "sensitivity", b"sensitivity", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_freq", b"voltage_excit_freq", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum"]) -> typing.Literal["ac_excit_wire_mode", "ac_excit_wire_mode_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sensitivity_units_enum", b"sensitivity_units_enum"]) -> typing.Literal["sensitivity_units", "sensitivity_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIPosRVDTChanRequest = CreateAIPosRVDTChanRequest

@typing.final
class CreateAIPosRVDTChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIPosRVDTChanResponse = CreateAIPosRVDTChanResponse

@typing.final
class CreateAIPowerChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    VOLTAGE_SETPOINT_FIELD_NUMBER: builtins.int
    CURRENT_SETPOINT_FIELD_NUMBER: builtins.int
    OUTPUT_ENABLE_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    voltage_setpoint: builtins.float
    current_setpoint: builtins.float
    output_enable: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        voltage_setpoint: builtins.float = ...,
        current_setpoint: builtins.float = ...,
        output_enable: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_setpoint", b"current_setpoint", "name_to_assign_to_channel", b"name_to_assign_to_channel", "output_enable", b"output_enable", "physical_channel", b"physical_channel", "task", b"task", "voltage_setpoint", b"voltage_setpoint"]) -> None: ...

global___CreateAIPowerChanRequest = CreateAIPowerChanRequest

@typing.final
class CreateAIPowerChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIPowerChanResponse = CreateAIPowerChanResponse

@typing.final
class CreateAIPressureBridgePolynomialChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    FORWARD_COEFFS_FIELD_NUMBER: builtins.int
    REVERSE_COEFFS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___PressureUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def forward_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def reverse_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___PressureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        forward_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        reverse_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "forward_coeffs", b"forward_coeffs", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "reverse_coeffs", b"reverse_coeffs", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIPressureBridgePolynomialChanRequest = CreateAIPressureBridgePolynomialChanRequest

@typing.final
class CreateAIPressureBridgePolynomialChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIPressureBridgePolynomialChanResponse = CreateAIPressureBridgePolynomialChanResponse

@typing.final
class CreateAIPressureBridgeTableChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    ELECTRICAL_VALS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    PHYSICAL_VALS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___PressureUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def electrical_vals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def physical_vals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___PressureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        electrical_vals: collections.abc.Iterable[builtins.float] | None = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        physical_vals: collections.abc.Iterable[builtins.float] | None = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "electrical_vals", b"electrical_vals", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "physical_vals", b"physical_vals", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIPressureBridgeTableChanRequest = CreateAIPressureBridgeTableChanRequest

@typing.final
class CreateAIPressureBridgeTableChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIPressureBridgeTableChanResponse = CreateAIPressureBridgeTableChanResponse

@typing.final
class CreateAIPressureBridgeTwoPointLinChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    FIRST_ELECTRICAL_VAL_FIELD_NUMBER: builtins.int
    SECOND_ELECTRICAL_VAL_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    FIRST_PHYSICAL_VAL_FIELD_NUMBER: builtins.int
    SECOND_PHYSICAL_VAL_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___PressureUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    first_electrical_val: builtins.float
    second_electrical_val: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    first_physical_val: builtins.float
    second_physical_val: builtins.float
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___PressureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        first_electrical_val: builtins.float = ...,
        second_electrical_val: builtins.float = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        first_physical_val: builtins.float = ...,
        second_physical_val: builtins.float = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "first_electrical_val", b"first_electrical_val", "first_physical_val", b"first_physical_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "second_electrical_val", b"second_electrical_val", "second_physical_val", b"second_physical_val", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIPressureBridgeTwoPointLinChanRequest = CreateAIPressureBridgeTwoPointLinChanRequest

@typing.final
class CreateAIPressureBridgeTwoPointLinChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIPressureBridgeTwoPointLinChanResponse = CreateAIPressureBridgeTwoPointLinChanResponse

@typing.final
class CreateAIRTDChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    RTD_TYPE_FIELD_NUMBER: builtins.int
    RTD_TYPE_RAW_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    R0_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    rtd_type: global___RTDType1.ValueType
    rtd_type_raw: builtins.int
    resistance_config: global___ResistanceConfiguration.ValueType
    resistance_config_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    r0: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        rtd_type: global___RTDType1.ValueType = ...,
        rtd_type_raw: builtins.int = ...,
        resistance_config: global___ResistanceConfiguration.ValueType = ...,
        resistance_config_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        r0: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "rtd_type", b"rtd_type", "rtd_type_enum", b"rtd_type_enum", "rtd_type_raw", b"rtd_type_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "r0", b"r0", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "rtd_type", b"rtd_type", "rtd_type_enum", b"rtd_type_enum", "rtd_type_raw", b"rtd_type_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["resistance_config_enum", b"resistance_config_enum"]) -> typing.Literal["resistance_config", "resistance_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["rtd_type_enum", b"rtd_type_enum"]) -> typing.Literal["rtd_type", "rtd_type_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIRTDChanRequest = CreateAIRTDChanRequest

@typing.final
class CreateAIRTDChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIRTDChanResponse = CreateAIRTDChanResponse

@typing.final
class CreateAIResistanceChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___ResistanceUnits2.ValueType
    units_raw: builtins.int
    resistance_config: global___ResistanceConfiguration.ValueType
    resistance_config_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___ResistanceUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        resistance_config: global___ResistanceConfiguration.ValueType = ...,
        resistance_config_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["resistance_config_enum", b"resistance_config_enum"]) -> typing.Literal["resistance_config", "resistance_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIResistanceChanRequest = CreateAIResistanceChanRequest

@typing.final
class CreateAIResistanceChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIResistanceChanResponse = CreateAIResistanceChanResponse

@typing.final
class CreateAIRosetteStrainGageChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    ROSETTE_TYPE_FIELD_NUMBER: builtins.int
    ROSETTE_TYPE_RAW_FIELD_NUMBER: builtins.int
    GAGE_ORIENTATION_FIELD_NUMBER: builtins.int
    ROSETTE_MEAS_TYPES_FIELD_NUMBER: builtins.int
    STRAIN_CONFIG_FIELD_NUMBER: builtins.int
    STRAIN_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    GAGE_FACTOR_FIELD_NUMBER: builtins.int
    NOMINAL_GAGE_RESISTANCE_FIELD_NUMBER: builtins.int
    POISSON_RATIO_FIELD_NUMBER: builtins.int
    LEAD_WIRE_RESISTANCE_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    rosette_type: global___StrainGageRosetteType.ValueType
    rosette_type_raw: builtins.int
    gage_orientation: builtins.float
    strain_config: global___StrainGageBridgeType1.ValueType
    strain_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    gage_factor: builtins.float
    nominal_gage_resistance: builtins.float
    poisson_ratio: builtins.float
    lead_wire_resistance: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def rosette_meas_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        rosette_type: global___StrainGageRosetteType.ValueType = ...,
        rosette_type_raw: builtins.int = ...,
        gage_orientation: builtins.float = ...,
        rosette_meas_types: collections.abc.Iterable[builtins.int] | None = ...,
        strain_config: global___StrainGageBridgeType1.ValueType = ...,
        strain_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        gage_factor: builtins.float = ...,
        nominal_gage_resistance: builtins.float = ...,
        poisson_ratio: builtins.float = ...,
        lead_wire_resistance: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rosette_type", b"rosette_type", "rosette_type_enum", b"rosette_type_enum", "rosette_type_raw", b"rosette_type_raw", "strain_config", b"strain_config", "strain_config_enum", b"strain_config_enum", "strain_config_raw", b"strain_config_raw", "task", b"task", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gage_factor", b"gage_factor", "gage_orientation", b"gage_orientation", "lead_wire_resistance", b"lead_wire_resistance", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_gage_resistance", b"nominal_gage_resistance", "physical_channel", b"physical_channel", "poisson_ratio", b"poisson_ratio", "rosette_meas_types", b"rosette_meas_types", "rosette_type", b"rosette_type", "rosette_type_enum", b"rosette_type_enum", "rosette_type_raw", b"rosette_type_raw", "strain_config", b"strain_config", "strain_config_enum", b"strain_config_enum", "strain_config_raw", b"strain_config_raw", "task", b"task", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["rosette_type_enum", b"rosette_type_enum"]) -> typing.Literal["rosette_type", "rosette_type_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["strain_config_enum", b"strain_config_enum"]) -> typing.Literal["strain_config", "strain_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIRosetteStrainGageChanRequest = CreateAIRosetteStrainGageChanRequest

@typing.final
class CreateAIRosetteStrainGageChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIRosetteStrainGageChanResponse = CreateAIRosetteStrainGageChanResponse

@typing.final
class CreateAIStrainGageChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    STRAIN_CONFIG_FIELD_NUMBER: builtins.int
    STRAIN_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    GAGE_FACTOR_FIELD_NUMBER: builtins.int
    INITIAL_BRIDGE_VOLTAGE_FIELD_NUMBER: builtins.int
    NOMINAL_GAGE_RESISTANCE_FIELD_NUMBER: builtins.int
    POISSON_RATIO_FIELD_NUMBER: builtins.int
    LEAD_WIRE_RESISTANCE_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___StrainUnits1.ValueType
    units_raw: builtins.int
    strain_config: global___StrainGageBridgeType1.ValueType
    strain_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    gage_factor: builtins.float
    initial_bridge_voltage: builtins.float
    nominal_gage_resistance: builtins.float
    poisson_ratio: builtins.float
    lead_wire_resistance: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___StrainUnits1.ValueType = ...,
        units_raw: builtins.int = ...,
        strain_config: global___StrainGageBridgeType1.ValueType = ...,
        strain_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        gage_factor: builtins.float = ...,
        initial_bridge_voltage: builtins.float = ...,
        nominal_gage_resistance: builtins.float = ...,
        poisson_ratio: builtins.float = ...,
        lead_wire_resistance: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["strain_config", b"strain_config", "strain_config_enum", b"strain_config_enum", "strain_config_raw", b"strain_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "gage_factor", b"gage_factor", "initial_bridge_voltage", b"initial_bridge_voltage", "lead_wire_resistance", b"lead_wire_resistance", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_gage_resistance", b"nominal_gage_resistance", "physical_channel", b"physical_channel", "poisson_ratio", b"poisson_ratio", "strain_config", b"strain_config", "strain_config_enum", b"strain_config_enum", "strain_config_raw", b"strain_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["strain_config_enum", b"strain_config_enum"]) -> typing.Literal["strain_config", "strain_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIStrainGageChanRequest = CreateAIStrainGageChanRequest

@typing.final
class CreateAIStrainGageChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIStrainGageChanResponse = CreateAIStrainGageChanResponse

@typing.final
class CreateAITempBuiltInSensorChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAITempBuiltInSensorChanRequest = CreateAITempBuiltInSensorChanRequest

@typing.final
class CreateAITempBuiltInSensorChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAITempBuiltInSensorChanResponse = CreateAITempBuiltInSensorChanResponse

@typing.final
class CreateAIThrmcplChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    THERMOCOUPLE_TYPE_FIELD_NUMBER: builtins.int
    THERMOCOUPLE_TYPE_RAW_FIELD_NUMBER: builtins.int
    CJC_SOURCE_FIELD_NUMBER: builtins.int
    CJC_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CJC_VAL_FIELD_NUMBER: builtins.int
    CJC_CHANNEL_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    thermocouple_type: global___ThermocoupleType1.ValueType
    thermocouple_type_raw: builtins.int
    cjc_source: global___CJCSource1.ValueType
    cjc_source_raw: builtins.int
    cjc_val: builtins.float
    cjc_channel: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        thermocouple_type: global___ThermocoupleType1.ValueType = ...,
        thermocouple_type_raw: builtins.int = ...,
        cjc_source: global___CJCSource1.ValueType = ...,
        cjc_source_raw: builtins.int = ...,
        cjc_val: builtins.float = ...,
        cjc_channel: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cjc_source", b"cjc_source", "cjc_source_enum", b"cjc_source_enum", "cjc_source_raw", b"cjc_source_raw", "task", b"task", "thermocouple_type", b"thermocouple_type", "thermocouple_type_enum", b"thermocouple_type_enum", "thermocouple_type_raw", b"thermocouple_type_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cjc_channel", b"cjc_channel", "cjc_source", b"cjc_source", "cjc_source_enum", b"cjc_source_enum", "cjc_source_raw", b"cjc_source_raw", "cjc_val", b"cjc_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "thermocouple_type", b"thermocouple_type", "thermocouple_type_enum", b"thermocouple_type_enum", "thermocouple_type_raw", b"thermocouple_type_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["cjc_source_enum", b"cjc_source_enum"]) -> typing.Literal["cjc_source", "cjc_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["thermocouple_type_enum", b"thermocouple_type_enum"]) -> typing.Literal["thermocouple_type", "thermocouple_type_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIThrmcplChanRequest = CreateAIThrmcplChanRequest

@typing.final
class CreateAIThrmcplChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIThrmcplChanResponse = CreateAIThrmcplChanResponse

@typing.final
class CreateAIThrmstrChanIexRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    A_FIELD_NUMBER: builtins.int
    B_FIELD_NUMBER: builtins.int
    C_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    resistance_config: global___ResistanceConfiguration.ValueType
    resistance_config_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    a: builtins.float
    b: builtins.float
    c: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        resistance_config: global___ResistanceConfiguration.ValueType = ...,
        resistance_config_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        a: builtins.float = ...,
        b: builtins.float = ...,
        c: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["a", b"a", "b", b"b", "c", b"c", "current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["resistance_config_enum", b"resistance_config_enum"]) -> typing.Literal["resistance_config", "resistance_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIThrmstrChanIexRequest = CreateAIThrmstrChanIexRequest

@typing.final
class CreateAIThrmstrChanIexResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIThrmstrChanIexResponse = CreateAIThrmstrChanIexResponse

@typing.final
class CreateAIThrmstrChanVexRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    A_FIELD_NUMBER: builtins.int
    B_FIELD_NUMBER: builtins.int
    C_FIELD_NUMBER: builtins.int
    R1_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    resistance_config: global___ResistanceConfiguration.ValueType
    resistance_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    a: builtins.float
    b: builtins.float
    c: builtins.float
    r1: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        resistance_config: global___ResistanceConfiguration.ValueType = ...,
        resistance_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        a: builtins.float = ...,
        b: builtins.float = ...,
        c: builtins.float = ...,
        r1: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["a", b"a", "b", b"b", "c", b"c", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "r1", b"r1", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["resistance_config_enum", b"resistance_config_enum"]) -> typing.Literal["resistance_config", "resistance_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIThrmstrChanVexRequest = CreateAIThrmstrChanVexRequest

@typing.final
class CreateAIThrmstrChanVexResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIThrmstrChanVexResponse = CreateAIThrmstrChanVexResponse

@typing.final
class CreateAITorqueBridgePolynomialChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    FORWARD_COEFFS_FIELD_NUMBER: builtins.int
    REVERSE_COEFFS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TorqueUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def forward_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def reverse_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TorqueUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        forward_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        reverse_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "forward_coeffs", b"forward_coeffs", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "reverse_coeffs", b"reverse_coeffs", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAITorqueBridgePolynomialChanRequest = CreateAITorqueBridgePolynomialChanRequest

@typing.final
class CreateAITorqueBridgePolynomialChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAITorqueBridgePolynomialChanResponse = CreateAITorqueBridgePolynomialChanResponse

@typing.final
class CreateAITorqueBridgeTableChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    ELECTRICAL_VALS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    PHYSICAL_VALS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TorqueUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def electrical_vals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def physical_vals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TorqueUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        electrical_vals: collections.abc.Iterable[builtins.float] | None = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        physical_vals: collections.abc.Iterable[builtins.float] | None = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "electrical_vals", b"electrical_vals", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "physical_vals", b"physical_vals", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAITorqueBridgeTableChanRequest = CreateAITorqueBridgeTableChanRequest

@typing.final
class CreateAITorqueBridgeTableChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAITorqueBridgeTableChanResponse = CreateAITorqueBridgeTableChanResponse

@typing.final
class CreateAITorqueBridgeTwoPointLinChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    NOMINAL_BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    FIRST_ELECTRICAL_VAL_FIELD_NUMBER: builtins.int
    SECOND_ELECTRICAL_VAL_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_FIELD_NUMBER: builtins.int
    ELECTRICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    FIRST_PHYSICAL_VAL_FIELD_NUMBER: builtins.int
    SECOND_PHYSICAL_VAL_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_FIELD_NUMBER: builtins.int
    PHYSICAL_UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TorqueUnits.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    nominal_bridge_resistance: builtins.float
    first_electrical_val: builtins.float
    second_electrical_val: builtins.float
    electrical_units: global___BridgeElectricalUnits.ValueType
    electrical_units_raw: builtins.int
    first_physical_val: builtins.float
    second_physical_val: builtins.float
    physical_units: global___BridgePhysicalUnits.ValueType
    physical_units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TorqueUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        nominal_bridge_resistance: builtins.float = ...,
        first_electrical_val: builtins.float = ...,
        second_electrical_val: builtins.float = ...,
        electrical_units: global___BridgeElectricalUnits.ValueType = ...,
        electrical_units_raw: builtins.int = ...,
        first_physical_val: builtins.float = ...,
        second_physical_val: builtins.float = ...,
        physical_units: global___BridgePhysicalUnits.ValueType = ...,
        physical_units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "electrical_units", b"electrical_units", "electrical_units_enum", b"electrical_units_enum", "electrical_units_raw", b"electrical_units_raw", "first_electrical_val", b"first_electrical_val", "first_physical_val", b"first_physical_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "nominal_bridge_resistance", b"nominal_bridge_resistance", "physical_channel", b"physical_channel", "physical_units", b"physical_units", "physical_units_enum", b"physical_units_enum", "physical_units_raw", b"physical_units_raw", "second_electrical_val", b"second_electrical_val", "second_physical_val", b"second_physical_val", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["electrical_units_enum", b"electrical_units_enum"]) -> typing.Literal["electrical_units", "electrical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["physical_units_enum", b"physical_units_enum"]) -> typing.Literal["physical_units", "physical_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAITorqueBridgeTwoPointLinChanRequest = CreateAITorqueBridgeTwoPointLinChanRequest

@typing.final
class CreateAITorqueBridgeTwoPointLinChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAITorqueBridgeTwoPointLinChanResponse = CreateAITorqueBridgeTwoPointLinChanResponse

@typing.final
class CreateAIVelocityIEPEChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SENSITIVITY_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_FIELD_NUMBER: builtins.int
    SENSITIVITY_UNITS_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___VelocityUnits.ValueType
    units_raw: builtins.int
    sensitivity: builtins.float
    sensitivity_units: global___VelocityIEPESensorSensitivityUnits.ValueType
    sensitivity_units_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___VelocityUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        sensitivity: builtins.float = ...,
        sensitivity_units: global___VelocityIEPESensorSensitivityUnits.ValueType = ...,
        sensitivity_units_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "sensitivity", b"sensitivity", "sensitivity_units", b"sensitivity_units", "sensitivity_units_enum", b"sensitivity_units_enum", "sensitivity_units_raw", b"sensitivity_units_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sensitivity_units_enum", b"sensitivity_units_enum"]) -> typing.Literal["sensitivity_units", "sensitivity_units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIVelocityIEPEChanRequest = CreateAIVelocityIEPEChanRequest

@typing.final
class CreateAIVelocityIEPEChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIVelocityIEPEChanResponse = CreateAIVelocityIEPEChanResponse

@typing.final
class CreateAIVoltageChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___VoltageUnits2.ValueType
    units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___VoltageUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIVoltageChanRequest = CreateAIVoltageChanRequest

@typing.final
class CreateAIVoltageChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIVoltageChanResponse = CreateAIVoltageChanResponse

@typing.final
class CreateAIVoltageChanWithExcitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_FIELD_NUMBER: builtins.int
    BRIDGE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    USE_EXCIT_FOR_SCALING_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___VoltageUnits2.ValueType
    units_raw: builtins.int
    bridge_config: global___BridgeConfiguration1.ValueType
    bridge_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    use_excit_for_scaling: builtins.bool
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___VoltageUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        bridge_config: global___BridgeConfiguration1.ValueType = ...,
        bridge_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        use_excit_for_scaling: builtins.bool = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_config", b"bridge_config", "bridge_config_enum", b"bridge_config_enum", "bridge_config_raw", b"bridge_config_raw", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "use_excit_for_scaling", b"use_excit_for_scaling", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["bridge_config_enum", b"bridge_config_enum"]) -> typing.Literal["bridge_config", "bridge_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateAIVoltageChanWithExcitRequest = CreateAIVoltageChanWithExcitRequest

@typing.final
class CreateAIVoltageChanWithExcitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIVoltageChanWithExcitResponse = CreateAIVoltageChanWithExcitResponse

@typing.final
class CreateAIVoltageRMSChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___VoltageUnits2.ValueType
    units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___VoltageUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAIVoltageRMSChanRequest = CreateAIVoltageRMSChanRequest

@typing.final
class CreateAIVoltageRMSChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAIVoltageRMSChanResponse = CreateAIVoltageRMSChanResponse

@typing.final
class CreateAOCurrentChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___CurrentUnits2.ValueType
    units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___CurrentUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAOCurrentChanRequest = CreateAOCurrentChanRequest

@typing.final
class CreateAOCurrentChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAOCurrentChanResponse = CreateAOCurrentChanResponse

@typing.final
class CreateAOFuncGenChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TYPE_RAW_FIELD_NUMBER: builtins.int
    FREQ_FIELD_NUMBER: builtins.int
    AMPLITUDE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    type: global___FuncGenType.ValueType
    type_raw: builtins.int
    freq: builtins.float
    amplitude: builtins.float
    offset: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        type: global___FuncGenType.ValueType = ...,
        type_raw: builtins.int = ...,
        freq: builtins.float = ...,
        amplitude: builtins.float = ...,
        offset: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "type", b"type", "type_enum", b"type_enum", "type_raw", b"type_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["amplitude", b"amplitude", "freq", b"freq", "name_to_assign_to_channel", b"name_to_assign_to_channel", "offset", b"offset", "physical_channel", b"physical_channel", "task", b"task", "type", b"type", "type_enum", b"type_enum", "type_raw", b"type_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type_enum", b"type_enum"]) -> typing.Literal["type", "type_raw"] | None: ...

global___CreateAOFuncGenChanRequest = CreateAOFuncGenChanRequest

@typing.final
class CreateAOFuncGenChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAOFuncGenChanResponse = CreateAOFuncGenChanResponse

@typing.final
class CreateAOVoltageChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___VoltageUnits2.ValueType
    units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___VoltageUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateAOVoltageChanRequest = CreateAOVoltageChanRequest

@typing.final
class CreateAOVoltageChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateAOVoltageChanResponse = CreateAOVoltageChanResponse

@typing.final
class CreateCIAngEncoderChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    DECODING_TYPE_FIELD_NUMBER: builtins.int
    DECODING_TYPE_RAW_FIELD_NUMBER: builtins.int
    ZIDX_ENABLE_FIELD_NUMBER: builtins.int
    ZIDX_VAL_FIELD_NUMBER: builtins.int
    ZIDX_PHASE_FIELD_NUMBER: builtins.int
    ZIDX_PHASE_RAW_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    PULSES_PER_REV_FIELD_NUMBER: builtins.int
    INITIAL_ANGLE_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    decoding_type: global___EncoderType2.ValueType
    decoding_type_raw: builtins.int
    zidx_enable: builtins.bool
    zidx_val: builtins.float
    zidx_phase: global___EncoderZIndexPhase1.ValueType
    zidx_phase_raw: builtins.int
    units: global___AngleUnits2.ValueType
    units_raw: builtins.int
    pulses_per_rev: builtins.int
    initial_angle: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        decoding_type: global___EncoderType2.ValueType = ...,
        decoding_type_raw: builtins.int = ...,
        zidx_enable: builtins.bool = ...,
        zidx_val: builtins.float = ...,
        zidx_phase: global___EncoderZIndexPhase1.ValueType = ...,
        zidx_phase_raw: builtins.int = ...,
        units: global___AngleUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        pulses_per_rev: builtins.int = ...,
        initial_angle: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["decoding_type", b"decoding_type", "decoding_type_enum", b"decoding_type_enum", "decoding_type_raw", b"decoding_type_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "zidx_phase", b"zidx_phase", "zidx_phase_enum", b"zidx_phase_enum", "zidx_phase_raw", b"zidx_phase_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "decoding_type", b"decoding_type", "decoding_type_enum", b"decoding_type_enum", "decoding_type_raw", b"decoding_type_raw", "initial_angle", b"initial_angle", "name_to_assign_to_channel", b"name_to_assign_to_channel", "pulses_per_rev", b"pulses_per_rev", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "zidx_enable", b"zidx_enable", "zidx_phase", b"zidx_phase", "zidx_phase_enum", b"zidx_phase_enum", "zidx_phase_raw", b"zidx_phase_raw", "zidx_val", b"zidx_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["decoding_type_enum", b"decoding_type_enum"]) -> typing.Literal["decoding_type", "decoding_type_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["zidx_phase_enum", b"zidx_phase_enum"]) -> typing.Literal["zidx_phase", "zidx_phase_raw"] | None: ...

global___CreateCIAngEncoderChanRequest = CreateCIAngEncoderChanRequest

@typing.final
class CreateCIAngEncoderChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIAngEncoderChanResponse = CreateCIAngEncoderChanResponse

@typing.final
class CreateCIAngVelocityChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    DECODING_TYPE_FIELD_NUMBER: builtins.int
    DECODING_TYPE_RAW_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    PULSES_PER_REV_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    decoding_type: global___EncoderType2.ValueType
    decoding_type_raw: builtins.int
    units: global___AngularVelocityUnits.ValueType
    units_raw: builtins.int
    pulses_per_rev: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        decoding_type: global___EncoderType2.ValueType = ...,
        decoding_type_raw: builtins.int = ...,
        units: global___AngularVelocityUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        pulses_per_rev: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["decoding_type", b"decoding_type", "decoding_type_enum", b"decoding_type_enum", "decoding_type_raw", b"decoding_type_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "decoding_type", b"decoding_type", "decoding_type_enum", b"decoding_type_enum", "decoding_type_raw", b"decoding_type_raw", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "pulses_per_rev", b"pulses_per_rev", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["decoding_type_enum", b"decoding_type_enum"]) -> typing.Literal["decoding_type", "decoding_type_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCIAngVelocityChanRequest = CreateCIAngVelocityChanRequest

@typing.final
class CreateCIAngVelocityChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIAngVelocityChanResponse = CreateCIAngVelocityChanResponse

@typing.final
class CreateCICountEdgesChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    EDGE_FIELD_NUMBER: builtins.int
    EDGE_RAW_FIELD_NUMBER: builtins.int
    INITIAL_COUNT_FIELD_NUMBER: builtins.int
    COUNT_DIRECTION_FIELD_NUMBER: builtins.int
    COUNT_DIRECTION_RAW_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    edge: global___Edge1.ValueType
    edge_raw: builtins.int
    initial_count: builtins.int
    count_direction: global___CountDirection1.ValueType
    count_direction_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        edge: global___Edge1.ValueType = ...,
        edge_raw: builtins.int = ...,
        initial_count: builtins.int = ...,
        count_direction: global___CountDirection1.ValueType = ...,
        count_direction_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["count_direction", b"count_direction", "count_direction_enum", b"count_direction_enum", "count_direction_raw", b"count_direction_raw", "edge", b"edge", "edge_enum", b"edge_enum", "edge_raw", b"edge_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["count_direction", b"count_direction", "count_direction_enum", b"count_direction_enum", "count_direction_raw", b"count_direction_raw", "counter", b"counter", "edge", b"edge", "edge_enum", b"edge_enum", "edge_raw", b"edge_raw", "initial_count", b"initial_count", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["count_direction_enum", b"count_direction_enum"]) -> typing.Literal["count_direction", "count_direction_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["edge_enum", b"edge_enum"]) -> typing.Literal["edge", "edge_raw"] | None: ...

global___CreateCICountEdgesChanRequest = CreateCICountEdgesChanRequest

@typing.final
class CreateCICountEdgesChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCICountEdgesChanResponse = CreateCICountEdgesChanResponse

@typing.final
class CreateCIDutyCycleChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_FREQ_FIELD_NUMBER: builtins.int
    MAX_FREQ_FIELD_NUMBER: builtins.int
    EDGE_FIELD_NUMBER: builtins.int
    EDGE_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_freq: builtins.float
    max_freq: builtins.float
    edge: global___Edge1.ValueType
    edge_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_freq: builtins.float = ...,
        max_freq: builtins.float = ...,
        edge: global___Edge1.ValueType = ...,
        edge_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["edge", b"edge", "edge_enum", b"edge_enum", "edge_raw", b"edge_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "edge", b"edge", "edge_enum", b"edge_enum", "edge_raw", b"edge_raw", "max_freq", b"max_freq", "min_freq", b"min_freq", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["edge_enum", b"edge_enum"]) -> typing.Literal["edge", "edge_raw"] | None: ...

global___CreateCIDutyCycleChanRequest = CreateCIDutyCycleChanRequest

@typing.final
class CreateCIDutyCycleChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIDutyCycleChanResponse = CreateCIDutyCycleChanResponse

@typing.final
class CreateCIFreqChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    EDGE_FIELD_NUMBER: builtins.int
    EDGE_RAW_FIELD_NUMBER: builtins.int
    MEAS_METHOD_FIELD_NUMBER: builtins.int
    MEAS_METHOD_RAW_FIELD_NUMBER: builtins.int
    MEAS_TIME_FIELD_NUMBER: builtins.int
    DIVISOR_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___FrequencyUnits3.ValueType
    units_raw: builtins.int
    edge: global___Edge1.ValueType
    edge_raw: builtins.int
    meas_method: global___CounterFrequencyMethod.ValueType
    meas_method_raw: builtins.int
    meas_time: builtins.float
    divisor: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___FrequencyUnits3.ValueType = ...,
        units_raw: builtins.int = ...,
        edge: global___Edge1.ValueType = ...,
        edge_raw: builtins.int = ...,
        meas_method: global___CounterFrequencyMethod.ValueType = ...,
        meas_method_raw: builtins.int = ...,
        meas_time: builtins.float = ...,
        divisor: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["edge", b"edge", "edge_enum", b"edge_enum", "edge_raw", b"edge_raw", "meas_method", b"meas_method", "meas_method_enum", b"meas_method_enum", "meas_method_raw", b"meas_method_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "divisor", b"divisor", "edge", b"edge", "edge_enum", b"edge_enum", "edge_raw", b"edge_raw", "max_val", b"max_val", "meas_method", b"meas_method", "meas_method_enum", b"meas_method_enum", "meas_method_raw", b"meas_method_raw", "meas_time", b"meas_time", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["edge_enum", b"edge_enum"]) -> typing.Literal["edge", "edge_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["meas_method_enum", b"meas_method_enum"]) -> typing.Literal["meas_method", "meas_method_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCIFreqChanRequest = CreateCIFreqChanRequest

@typing.final
class CreateCIFreqChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIFreqChanResponse = CreateCIFreqChanResponse

@typing.final
class CreateCIGPSTimestampChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SYNC_METHOD_FIELD_NUMBER: builtins.int
    SYNC_METHOD_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    units: global___TimeUnits.ValueType
    units_raw: builtins.int
    sync_method: global___GpsSignalType1.ValueType
    sync_method_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        units: global___TimeUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        sync_method: global___GpsSignalType1.ValueType = ...,
        sync_method_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["sync_method", b"sync_method", "sync_method_enum", b"sync_method_enum", "sync_method_raw", b"sync_method_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "name_to_assign_to_channel", b"name_to_assign_to_channel", "sync_method", b"sync_method", "sync_method_enum", b"sync_method_enum", "sync_method_raw", b"sync_method_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["sync_method_enum", b"sync_method_enum"]) -> typing.Literal["sync_method", "sync_method_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCIGPSTimestampChanRequest = CreateCIGPSTimestampChanRequest

@typing.final
class CreateCIGPSTimestampChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIGPSTimestampChanResponse = CreateCIGPSTimestampChanResponse

@typing.final
class CreateCILinEncoderChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    DECODING_TYPE_FIELD_NUMBER: builtins.int
    DECODING_TYPE_RAW_FIELD_NUMBER: builtins.int
    ZIDX_ENABLE_FIELD_NUMBER: builtins.int
    ZIDX_VAL_FIELD_NUMBER: builtins.int
    ZIDX_PHASE_FIELD_NUMBER: builtins.int
    ZIDX_PHASE_RAW_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    DIST_PER_PULSE_FIELD_NUMBER: builtins.int
    INITIAL_POS_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    decoding_type: global___EncoderType2.ValueType
    decoding_type_raw: builtins.int
    zidx_enable: builtins.bool
    zidx_val: builtins.float
    zidx_phase: global___EncoderZIndexPhase1.ValueType
    zidx_phase_raw: builtins.int
    units: global___LengthUnits3.ValueType
    units_raw: builtins.int
    dist_per_pulse: builtins.float
    initial_pos: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        decoding_type: global___EncoderType2.ValueType = ...,
        decoding_type_raw: builtins.int = ...,
        zidx_enable: builtins.bool = ...,
        zidx_val: builtins.float = ...,
        zidx_phase: global___EncoderZIndexPhase1.ValueType = ...,
        zidx_phase_raw: builtins.int = ...,
        units: global___LengthUnits3.ValueType = ...,
        units_raw: builtins.int = ...,
        dist_per_pulse: builtins.float = ...,
        initial_pos: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["decoding_type", b"decoding_type", "decoding_type_enum", b"decoding_type_enum", "decoding_type_raw", b"decoding_type_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "zidx_phase", b"zidx_phase", "zidx_phase_enum", b"zidx_phase_enum", "zidx_phase_raw", b"zidx_phase_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "decoding_type", b"decoding_type", "decoding_type_enum", b"decoding_type_enum", "decoding_type_raw", b"decoding_type_raw", "dist_per_pulse", b"dist_per_pulse", "initial_pos", b"initial_pos", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "zidx_enable", b"zidx_enable", "zidx_phase", b"zidx_phase", "zidx_phase_enum", b"zidx_phase_enum", "zidx_phase_raw", b"zidx_phase_raw", "zidx_val", b"zidx_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["decoding_type_enum", b"decoding_type_enum"]) -> typing.Literal["decoding_type", "decoding_type_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["zidx_phase_enum", b"zidx_phase_enum"]) -> typing.Literal["zidx_phase", "zidx_phase_raw"] | None: ...

global___CreateCILinEncoderChanRequest = CreateCILinEncoderChanRequest

@typing.final
class CreateCILinEncoderChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCILinEncoderChanResponse = CreateCILinEncoderChanResponse

@typing.final
class CreateCILinVelocityChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    DECODING_TYPE_FIELD_NUMBER: builtins.int
    DECODING_TYPE_RAW_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    DIST_PER_PULSE_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    decoding_type: global___EncoderType2.ValueType
    decoding_type_raw: builtins.int
    units: global___VelocityUnits.ValueType
    units_raw: builtins.int
    dist_per_pulse: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        decoding_type: global___EncoderType2.ValueType = ...,
        decoding_type_raw: builtins.int = ...,
        units: global___VelocityUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        dist_per_pulse: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["decoding_type", b"decoding_type", "decoding_type_enum", b"decoding_type_enum", "decoding_type_raw", b"decoding_type_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "decoding_type", b"decoding_type", "decoding_type_enum", b"decoding_type_enum", "decoding_type_raw", b"decoding_type_raw", "dist_per_pulse", b"dist_per_pulse", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["decoding_type_enum", b"decoding_type_enum"]) -> typing.Literal["decoding_type", "decoding_type_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCILinVelocityChanRequest = CreateCILinVelocityChanRequest

@typing.final
class CreateCILinVelocityChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCILinVelocityChanResponse = CreateCILinVelocityChanResponse

@typing.final
class CreateCIPeriodChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    EDGE_FIELD_NUMBER: builtins.int
    EDGE_RAW_FIELD_NUMBER: builtins.int
    MEAS_METHOD_FIELD_NUMBER: builtins.int
    MEAS_METHOD_RAW_FIELD_NUMBER: builtins.int
    MEAS_TIME_FIELD_NUMBER: builtins.int
    DIVISOR_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TimeUnits3.ValueType
    units_raw: builtins.int
    edge: global___Edge1.ValueType
    edge_raw: builtins.int
    meas_method: global___CounterFrequencyMethod.ValueType
    meas_method_raw: builtins.int
    meas_time: builtins.float
    divisor: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TimeUnits3.ValueType = ...,
        units_raw: builtins.int = ...,
        edge: global___Edge1.ValueType = ...,
        edge_raw: builtins.int = ...,
        meas_method: global___CounterFrequencyMethod.ValueType = ...,
        meas_method_raw: builtins.int = ...,
        meas_time: builtins.float = ...,
        divisor: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["edge", b"edge", "edge_enum", b"edge_enum", "edge_raw", b"edge_raw", "meas_method", b"meas_method", "meas_method_enum", b"meas_method_enum", "meas_method_raw", b"meas_method_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "divisor", b"divisor", "edge", b"edge", "edge_enum", b"edge_enum", "edge_raw", b"edge_raw", "max_val", b"max_val", "meas_method", b"meas_method", "meas_method_enum", b"meas_method_enum", "meas_method_raw", b"meas_method_raw", "meas_time", b"meas_time", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["edge_enum", b"edge_enum"]) -> typing.Literal["edge", "edge_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["meas_method_enum", b"meas_method_enum"]) -> typing.Literal["meas_method", "meas_method_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCIPeriodChanRequest = CreateCIPeriodChanRequest

@typing.final
class CreateCIPeriodChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIPeriodChanResponse = CreateCIPeriodChanResponse

@typing.final
class CreateCIPulseChanFreqRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___FrequencyUnits2.ValueType
    units_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___FrequencyUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCIPulseChanFreqRequest = CreateCIPulseChanFreqRequest

@typing.final
class CreateCIPulseChanFreqResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIPulseChanFreqResponse = CreateCIPulseChanFreqResponse

@typing.final
class CreateCIPulseChanTicksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    SOURCE_TERMINAL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    source_terminal: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        source_terminal: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "source_terminal", b"source_terminal", "task", b"task"]) -> None: ...

global___CreateCIPulseChanTicksRequest = CreateCIPulseChanTicksRequest

@typing.final
class CreateCIPulseChanTicksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIPulseChanTicksResponse = CreateCIPulseChanTicksResponse

@typing.final
class CreateCIPulseChanTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___DigitalWidthUnits3.ValueType
    units_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___DigitalWidthUnits3.ValueType = ...,
        units_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCIPulseChanTimeRequest = CreateCIPulseChanTimeRequest

@typing.final
class CreateCIPulseChanTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIPulseChanTimeResponse = CreateCIPulseChanTimeResponse

@typing.final
class CreateCIPulseWidthChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    STARTING_EDGE_FIELD_NUMBER: builtins.int
    STARTING_EDGE_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TimeUnits3.ValueType
    units_raw: builtins.int
    starting_edge: global___Edge1.ValueType
    starting_edge_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TimeUnits3.ValueType = ...,
        units_raw: builtins.int = ...,
        starting_edge: global___Edge1.ValueType = ...,
        starting_edge_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["starting_edge", b"starting_edge", "starting_edge_enum", b"starting_edge_enum", "starting_edge_raw", b"starting_edge_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "starting_edge", b"starting_edge", "starting_edge_enum", b"starting_edge_enum", "starting_edge_raw", b"starting_edge_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["starting_edge_enum", b"starting_edge_enum"]) -> typing.Literal["starting_edge", "starting_edge_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCIPulseWidthChanRequest = CreateCIPulseWidthChanRequest

@typing.final
class CreateCIPulseWidthChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCIPulseWidthChanResponse = CreateCIPulseWidthChanResponse

@typing.final
class CreateCISemiPeriodChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TimeUnits3.ValueType
    units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TimeUnits3.ValueType = ...,
        units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCISemiPeriodChanRequest = CreateCISemiPeriodChanRequest

@typing.final
class CreateCISemiPeriodChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCISemiPeriodChanResponse = CreateCISemiPeriodChanResponse

@typing.final
class CreateCITwoEdgeSepChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    FIRST_EDGE_FIELD_NUMBER: builtins.int
    FIRST_EDGE_RAW_FIELD_NUMBER: builtins.int
    SECOND_EDGE_FIELD_NUMBER: builtins.int
    SECOND_EDGE_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TimeUnits3.ValueType
    units_raw: builtins.int
    first_edge: global___Edge1.ValueType
    first_edge_raw: builtins.int
    second_edge: global___Edge1.ValueType
    second_edge_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TimeUnits3.ValueType = ...,
        units_raw: builtins.int = ...,
        first_edge: global___Edge1.ValueType = ...,
        first_edge_raw: builtins.int = ...,
        second_edge: global___Edge1.ValueType = ...,
        second_edge_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["first_edge", b"first_edge", "first_edge_enum", b"first_edge_enum", "first_edge_raw", b"first_edge_raw", "second_edge", b"second_edge", "second_edge_enum", b"second_edge_enum", "second_edge_raw", b"second_edge_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "custom_scale_name", b"custom_scale_name", "first_edge", b"first_edge", "first_edge_enum", b"first_edge_enum", "first_edge_raw", b"first_edge_raw", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "second_edge", b"second_edge", "second_edge_enum", b"second_edge_enum", "second_edge_raw", b"second_edge_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["first_edge_enum", b"first_edge_enum"]) -> typing.Literal["first_edge", "first_edge_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["second_edge_enum", b"second_edge_enum"]) -> typing.Literal["second_edge", "second_edge_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCITwoEdgeSepChanRequest = CreateCITwoEdgeSepChanRequest

@typing.final
class CreateCITwoEdgeSepChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCITwoEdgeSepChanResponse = CreateCITwoEdgeSepChanResponse

@typing.final
class CreateCOPulseChanFreqRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    IDLE_STATE_FIELD_NUMBER: builtins.int
    IDLE_STATE_RAW_FIELD_NUMBER: builtins.int
    INITIAL_DELAY_FIELD_NUMBER: builtins.int
    FREQ_FIELD_NUMBER: builtins.int
    DUTY_CYCLE_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    units: global___FrequencyUnits2.ValueType
    units_raw: builtins.int
    idle_state: global___Level1.ValueType
    idle_state_raw: builtins.int
    initial_delay: builtins.float
    freq: builtins.float
    duty_cycle: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        units: global___FrequencyUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        idle_state: global___Level1.ValueType = ...,
        idle_state_raw: builtins.int = ...,
        initial_delay: builtins.float = ...,
        freq: builtins.float = ...,
        duty_cycle: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["idle_state", b"idle_state", "idle_state_enum", b"idle_state_enum", "idle_state_raw", b"idle_state_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "duty_cycle", b"duty_cycle", "freq", b"freq", "idle_state", b"idle_state", "idle_state_enum", b"idle_state_enum", "idle_state_raw", b"idle_state_raw", "initial_delay", b"initial_delay", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["idle_state_enum", b"idle_state_enum"]) -> typing.Literal["idle_state", "idle_state_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCOPulseChanFreqRequest = CreateCOPulseChanFreqRequest

@typing.final
class CreateCOPulseChanFreqResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCOPulseChanFreqResponse = CreateCOPulseChanFreqResponse

@typing.final
class CreateCOPulseChanTicksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    SOURCE_TERMINAL_FIELD_NUMBER: builtins.int
    IDLE_STATE_FIELD_NUMBER: builtins.int
    IDLE_STATE_RAW_FIELD_NUMBER: builtins.int
    INITIAL_DELAY_FIELD_NUMBER: builtins.int
    LOW_TICKS_FIELD_NUMBER: builtins.int
    HIGH_TICKS_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    source_terminal: builtins.str
    idle_state: global___Level1.ValueType
    idle_state_raw: builtins.int
    initial_delay: builtins.int
    low_ticks: builtins.int
    high_ticks: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        source_terminal: builtins.str = ...,
        idle_state: global___Level1.ValueType = ...,
        idle_state_raw: builtins.int = ...,
        initial_delay: builtins.int = ...,
        low_ticks: builtins.int = ...,
        high_ticks: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["idle_state", b"idle_state", "idle_state_enum", b"idle_state_enum", "idle_state_raw", b"idle_state_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "high_ticks", b"high_ticks", "idle_state", b"idle_state", "idle_state_enum", b"idle_state_enum", "idle_state_raw", b"idle_state_raw", "initial_delay", b"initial_delay", "low_ticks", b"low_ticks", "name_to_assign_to_channel", b"name_to_assign_to_channel", "source_terminal", b"source_terminal", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["idle_state_enum", b"idle_state_enum"]) -> typing.Literal["idle_state", "idle_state_raw"] | None: ...

global___CreateCOPulseChanTicksRequest = CreateCOPulseChanTicksRequest

@typing.final
class CreateCOPulseChanTicksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCOPulseChanTicksResponse = CreateCOPulseChanTicksResponse

@typing.final
class CreateCOPulseChanTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    COUNTER_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    IDLE_STATE_FIELD_NUMBER: builtins.int
    IDLE_STATE_RAW_FIELD_NUMBER: builtins.int
    INITIAL_DELAY_FIELD_NUMBER: builtins.int
    LOW_TIME_FIELD_NUMBER: builtins.int
    HIGH_TIME_FIELD_NUMBER: builtins.int
    counter: builtins.str
    name_to_assign_to_channel: builtins.str
    units: global___DigitalWidthUnits3.ValueType
    units_raw: builtins.int
    idle_state: global___Level1.ValueType
    idle_state_raw: builtins.int
    initial_delay: builtins.float
    low_time: builtins.float
    high_time: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        counter: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        units: global___DigitalWidthUnits3.ValueType = ...,
        units_raw: builtins.int = ...,
        idle_state: global___Level1.ValueType = ...,
        idle_state_raw: builtins.int = ...,
        initial_delay: builtins.float = ...,
        low_time: builtins.float = ...,
        high_time: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["idle_state", b"idle_state", "idle_state_enum", b"idle_state_enum", "idle_state_raw", b"idle_state_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter", b"counter", "high_time", b"high_time", "idle_state", b"idle_state", "idle_state_enum", b"idle_state_enum", "idle_state_raw", b"idle_state_raw", "initial_delay", b"initial_delay", "low_time", b"low_time", "name_to_assign_to_channel", b"name_to_assign_to_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["idle_state_enum", b"idle_state_enum"]) -> typing.Literal["idle_state", "idle_state_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateCOPulseChanTimeRequest = CreateCOPulseChanTimeRequest

@typing.final
class CreateCOPulseChanTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateCOPulseChanTimeResponse = CreateCOPulseChanTimeResponse

@typing.final
class CreateDIChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_LINES_FIELD_NUMBER: builtins.int
    LINE_GROUPING_FIELD_NUMBER: builtins.int
    LINE_GROUPING_RAW_FIELD_NUMBER: builtins.int
    lines: builtins.str
    name_to_assign_to_lines: builtins.str
    line_grouping: global___LineGrouping.ValueType
    line_grouping_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        name_to_assign_to_lines: builtins.str = ...,
        line_grouping: global___LineGrouping.ValueType = ...,
        line_grouping_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["line_grouping", b"line_grouping", "line_grouping_enum", b"line_grouping_enum", "line_grouping_raw", b"line_grouping_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["line_grouping", b"line_grouping", "line_grouping_enum", b"line_grouping_enum", "line_grouping_raw", b"line_grouping_raw", "lines", b"lines", "name_to_assign_to_lines", b"name_to_assign_to_lines", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["line_grouping_enum", b"line_grouping_enum"]) -> typing.Literal["line_grouping", "line_grouping_raw"] | None: ...

global___CreateDIChanRequest = CreateDIChanRequest

@typing.final
class CreateDIChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateDIChanResponse = CreateDIChanResponse

@typing.final
class CreateDOChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_LINES_FIELD_NUMBER: builtins.int
    LINE_GROUPING_FIELD_NUMBER: builtins.int
    LINE_GROUPING_RAW_FIELD_NUMBER: builtins.int
    lines: builtins.str
    name_to_assign_to_lines: builtins.str
    line_grouping: global___LineGrouping.ValueType
    line_grouping_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        name_to_assign_to_lines: builtins.str = ...,
        line_grouping: global___LineGrouping.ValueType = ...,
        line_grouping_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["line_grouping", b"line_grouping", "line_grouping_enum", b"line_grouping_enum", "line_grouping_raw", b"line_grouping_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["line_grouping", b"line_grouping", "line_grouping_enum", b"line_grouping_enum", "line_grouping_raw", b"line_grouping_raw", "lines", b"lines", "name_to_assign_to_lines", b"name_to_assign_to_lines", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["line_grouping_enum", b"line_grouping_enum"]) -> typing.Literal["line_grouping", "line_grouping_raw"] | None: ...

global___CreateDOChanRequest = CreateDOChanRequest

@typing.final
class CreateDOChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateDOChanResponse = CreateDOChanResponse

@typing.final
class CreateLinScaleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SLOPE_FIELD_NUMBER: builtins.int
    Y_INTERCEPT_FIELD_NUMBER: builtins.int
    PRE_SCALED_UNITS_FIELD_NUMBER: builtins.int
    PRE_SCALED_UNITS_RAW_FIELD_NUMBER: builtins.int
    SCALED_UNITS_FIELD_NUMBER: builtins.int
    name: builtins.str
    slope: builtins.float
    y_intercept: builtins.float
    pre_scaled_units: global___UnitsPreScaled.ValueType
    pre_scaled_units_raw: builtins.int
    scaled_units: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        slope: builtins.float = ...,
        y_intercept: builtins.float = ...,
        pre_scaled_units: global___UnitsPreScaled.ValueType = ...,
        pre_scaled_units_raw: builtins.int = ...,
        scaled_units: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pre_scaled_units", b"pre_scaled_units", "pre_scaled_units_enum", b"pre_scaled_units_enum", "pre_scaled_units_raw", b"pre_scaled_units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "pre_scaled_units", b"pre_scaled_units", "pre_scaled_units_enum", b"pre_scaled_units_enum", "pre_scaled_units_raw", b"pre_scaled_units_raw", "scaled_units", b"scaled_units", "slope", b"slope", "y_intercept", b"y_intercept"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["pre_scaled_units_enum", b"pre_scaled_units_enum"]) -> typing.Literal["pre_scaled_units", "pre_scaled_units_raw"] | None: ...

global___CreateLinScaleRequest = CreateLinScaleRequest

@typing.final
class CreateLinScaleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateLinScaleResponse = CreateLinScaleResponse

@typing.final
class CreateMapScaleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRESCALED_MIN_FIELD_NUMBER: builtins.int
    PRESCALED_MAX_FIELD_NUMBER: builtins.int
    SCALED_MIN_FIELD_NUMBER: builtins.int
    SCALED_MAX_FIELD_NUMBER: builtins.int
    PRE_SCALED_UNITS_FIELD_NUMBER: builtins.int
    PRE_SCALED_UNITS_RAW_FIELD_NUMBER: builtins.int
    SCALED_UNITS_FIELD_NUMBER: builtins.int
    name: builtins.str
    prescaled_min: builtins.float
    prescaled_max: builtins.float
    scaled_min: builtins.float
    scaled_max: builtins.float
    pre_scaled_units: global___UnitsPreScaled.ValueType
    pre_scaled_units_raw: builtins.int
    scaled_units: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        prescaled_min: builtins.float = ...,
        prescaled_max: builtins.float = ...,
        scaled_min: builtins.float = ...,
        scaled_max: builtins.float = ...,
        pre_scaled_units: global___UnitsPreScaled.ValueType = ...,
        pre_scaled_units_raw: builtins.int = ...,
        scaled_units: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pre_scaled_units", b"pre_scaled_units", "pre_scaled_units_enum", b"pre_scaled_units_enum", "pre_scaled_units_raw", b"pre_scaled_units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "pre_scaled_units", b"pre_scaled_units", "pre_scaled_units_enum", b"pre_scaled_units_enum", "pre_scaled_units_raw", b"pre_scaled_units_raw", "prescaled_max", b"prescaled_max", "prescaled_min", b"prescaled_min", "scaled_max", b"scaled_max", "scaled_min", b"scaled_min", "scaled_units", b"scaled_units"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["pre_scaled_units_enum", b"pre_scaled_units_enum"]) -> typing.Literal["pre_scaled_units", "pre_scaled_units_raw"] | None: ...

global___CreateMapScaleRequest = CreateMapScaleRequest

@typing.final
class CreateMapScaleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateMapScaleResponse = CreateMapScaleResponse

@typing.final
class CreatePolynomialScaleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    FORWARD_COEFFS_FIELD_NUMBER: builtins.int
    REVERSE_COEFFS_FIELD_NUMBER: builtins.int
    PRE_SCALED_UNITS_FIELD_NUMBER: builtins.int
    PRE_SCALED_UNITS_RAW_FIELD_NUMBER: builtins.int
    SCALED_UNITS_FIELD_NUMBER: builtins.int
    name: builtins.str
    pre_scaled_units: global___UnitsPreScaled.ValueType
    pre_scaled_units_raw: builtins.int
    scaled_units: builtins.str
    @property
    def forward_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def reverse_coeffs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        forward_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        reverse_coeffs: collections.abc.Iterable[builtins.float] | None = ...,
        pre_scaled_units: global___UnitsPreScaled.ValueType = ...,
        pre_scaled_units_raw: builtins.int = ...,
        scaled_units: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pre_scaled_units", b"pre_scaled_units", "pre_scaled_units_enum", b"pre_scaled_units_enum", "pre_scaled_units_raw", b"pre_scaled_units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["forward_coeffs", b"forward_coeffs", "name", b"name", "pre_scaled_units", b"pre_scaled_units", "pre_scaled_units_enum", b"pre_scaled_units_enum", "pre_scaled_units_raw", b"pre_scaled_units_raw", "reverse_coeffs", b"reverse_coeffs", "scaled_units", b"scaled_units"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["pre_scaled_units_enum", b"pre_scaled_units_enum"]) -> typing.Literal["pre_scaled_units", "pre_scaled_units_raw"] | None: ...

global___CreatePolynomialScaleRequest = CreatePolynomialScaleRequest

@typing.final
class CreatePolynomialScaleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreatePolynomialScaleResponse = CreatePolynomialScaleResponse

@typing.final
class CreateTEDSAIAccelChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___AccelUnits2.ValueType
    units_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___AccelUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAIAccelChanRequest = CreateTEDSAIAccelChanRequest

@typing.final
class CreateTEDSAIAccelChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIAccelChanResponse = CreateTEDSAIAccelChanResponse

@typing.final
class CreateTEDSAIBridgeChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TEDSUnits.ValueType
    units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TEDSUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAIBridgeChanRequest = CreateTEDSAIBridgeChanRequest

@typing.final
class CreateTEDSAIBridgeChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIBridgeChanResponse = CreateTEDSAIBridgeChanResponse

@typing.final
class CreateTEDSAICurrentChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOC_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOC_RAW_FIELD_NUMBER: builtins.int
    EXT_SHUNT_RESISTOR_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___TEDSUnits.ValueType
    units_raw: builtins.int
    shunt_resistor_loc: global___CurrentShuntResistorLocationWithDefault.ValueType
    shunt_resistor_loc_raw: builtins.int
    ext_shunt_resistor_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TEDSUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        shunt_resistor_loc: global___CurrentShuntResistorLocationWithDefault.ValueType = ...,
        shunt_resistor_loc_raw: builtins.int = ...,
        ext_shunt_resistor_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["shunt_resistor_loc", b"shunt_resistor_loc", "shunt_resistor_loc_enum", b"shunt_resistor_loc_enum", "shunt_resistor_loc_raw", b"shunt_resistor_loc_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "ext_shunt_resistor_val", b"ext_shunt_resistor_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "shunt_resistor_loc", b"shunt_resistor_loc", "shunt_resistor_loc_enum", b"shunt_resistor_loc_enum", "shunt_resistor_loc_raw", b"shunt_resistor_loc_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_loc_enum", b"shunt_resistor_loc_enum"]) -> typing.Literal["shunt_resistor_loc", "shunt_resistor_loc_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAICurrentChanRequest = CreateTEDSAICurrentChanRequest

@typing.final
class CreateTEDSAICurrentChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAICurrentChanResponse = CreateTEDSAICurrentChanResponse

@typing.final
class CreateTEDSAIForceBridgeChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___ForceUnits.ValueType
    units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___ForceUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAIForceBridgeChanRequest = CreateTEDSAIForceBridgeChanRequest

@typing.final
class CreateTEDSAIForceBridgeChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIForceBridgeChanResponse = CreateTEDSAIForceBridgeChanResponse

@typing.final
class CreateTEDSAIForceIEPEChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___ForceIEPEUnits.ValueType
    units_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___ForceIEPEUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAIForceIEPEChanRequest = CreateTEDSAIForceIEPEChanRequest

@typing.final
class CreateTEDSAIForceIEPEChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIForceIEPEChanResponse = CreateTEDSAIForceIEPEChanResponse

@typing.final
class CreateTEDSAIMicrophoneChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    MAX_SND_PRESS_LEVEL_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    units: global___SoundPressureUnits1.ValueType
    units_raw: builtins.int
    max_snd_press_level: builtins.float
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        units: global___SoundPressureUnits1.ValueType = ...,
        units_raw: builtins.int = ...,
        max_snd_press_level: builtins.float = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_snd_press_level", b"max_snd_press_level", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAIMicrophoneChanRequest = CreateTEDSAIMicrophoneChanRequest

@typing.final
class CreateTEDSAIMicrophoneChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIMicrophoneChanResponse = CreateTEDSAIMicrophoneChanResponse

@typing.final
class CreateTEDSAIPosLVDTChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_FREQ_FIELD_NUMBER: builtins.int
    AC_EXCIT_WIRE_MODE_FIELD_NUMBER: builtins.int
    AC_EXCIT_WIRE_MODE_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___LengthUnits2.ValueType
    units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    voltage_excit_freq: builtins.float
    ac_excit_wire_mode: global___ACExcitWireMode.ValueType
    ac_excit_wire_mode_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___LengthUnits2.ValueType = ...,
        units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        voltage_excit_freq: builtins.float = ...,
        ac_excit_wire_mode: global___ACExcitWireMode.ValueType = ...,
        ac_excit_wire_mode_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ac_excit_wire_mode", b"ac_excit_wire_mode", "ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum", "ac_excit_wire_mode_raw", b"ac_excit_wire_mode_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ac_excit_wire_mode", b"ac_excit_wire_mode", "ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum", "ac_excit_wire_mode_raw", b"ac_excit_wire_mode_raw", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_freq", b"voltage_excit_freq", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum"]) -> typing.Literal["ac_excit_wire_mode", "ac_excit_wire_mode_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAIPosLVDTChanRequest = CreateTEDSAIPosLVDTChanRequest

@typing.final
class CreateTEDSAIPosLVDTChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIPosLVDTChanResponse = CreateTEDSAIPosLVDTChanResponse

@typing.final
class CreateTEDSAIPosRVDTChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_FREQ_FIELD_NUMBER: builtins.int
    AC_EXCIT_WIRE_MODE_FIELD_NUMBER: builtins.int
    AC_EXCIT_WIRE_MODE_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___AngleUnits1.ValueType
    units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    voltage_excit_freq: builtins.float
    ac_excit_wire_mode: global___ACExcitWireMode.ValueType
    ac_excit_wire_mode_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___AngleUnits1.ValueType = ...,
        units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        voltage_excit_freq: builtins.float = ...,
        ac_excit_wire_mode: global___ACExcitWireMode.ValueType = ...,
        ac_excit_wire_mode_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ac_excit_wire_mode", b"ac_excit_wire_mode", "ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum", "ac_excit_wire_mode_raw", b"ac_excit_wire_mode_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ac_excit_wire_mode", b"ac_excit_wire_mode", "ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum", "ac_excit_wire_mode_raw", b"ac_excit_wire_mode_raw", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_freq", b"voltage_excit_freq", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["ac_excit_wire_mode_enum", b"ac_excit_wire_mode_enum"]) -> typing.Literal["ac_excit_wire_mode", "ac_excit_wire_mode_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAIPosRVDTChanRequest = CreateTEDSAIPosRVDTChanRequest

@typing.final
class CreateTEDSAIPosRVDTChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIPosRVDTChanResponse = CreateTEDSAIPosRVDTChanResponse

@typing.final
class CreateTEDSAIPressureBridgeChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___PressureUnits.ValueType
    units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___PressureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAIPressureBridgeChanRequest = CreateTEDSAIPressureBridgeChanRequest

@typing.final
class CreateTEDSAIPressureBridgeChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIPressureBridgeChanResponse = CreateTEDSAIPressureBridgeChanResponse

@typing.final
class CreateTEDSAIRTDChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    resistance_config: global___ResistanceConfiguration.ValueType
    resistance_config_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        resistance_config: global___ResistanceConfiguration.ValueType = ...,
        resistance_config_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["resistance_config_enum", b"resistance_config_enum"]) -> typing.Literal["resistance_config", "resistance_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAIRTDChanRequest = CreateTEDSAIRTDChanRequest

@typing.final
class CreateTEDSAIRTDChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIRTDChanResponse = CreateTEDSAIRTDChanResponse

@typing.final
class CreateTEDSAIResistanceChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TEDSUnits.ValueType
    units_raw: builtins.int
    resistance_config: global___ResistanceConfiguration.ValueType
    resistance_config_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TEDSUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        resistance_config: global___ResistanceConfiguration.ValueType = ...,
        resistance_config_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["resistance_config_enum", b"resistance_config_enum"]) -> typing.Literal["resistance_config", "resistance_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAIResistanceChanRequest = CreateTEDSAIResistanceChanRequest

@typing.final
class CreateTEDSAIResistanceChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIResistanceChanResponse = CreateTEDSAIResistanceChanResponse

@typing.final
class CreateTEDSAIStrainGageChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    INITIAL_BRIDGE_VOLTAGE_FIELD_NUMBER: builtins.int
    LEAD_WIRE_RESISTANCE_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___StrainUnits1.ValueType
    units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    initial_bridge_voltage: builtins.float
    lead_wire_resistance: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___StrainUnits1.ValueType = ...,
        units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        initial_bridge_voltage: builtins.float = ...,
        lead_wire_resistance: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "initial_bridge_voltage", b"initial_bridge_voltage", "lead_wire_resistance", b"lead_wire_resistance", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAIStrainGageChanRequest = CreateTEDSAIStrainGageChanRequest

@typing.final
class CreateTEDSAIStrainGageChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIStrainGageChanResponse = CreateTEDSAIStrainGageChanResponse

@typing.final
class CreateTEDSAIThrmcplChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CJC_SOURCE_FIELD_NUMBER: builtins.int
    CJC_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CJC_VAL_FIELD_NUMBER: builtins.int
    CJC_CHANNEL_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    cjc_source: global___CJCSource1.ValueType
    cjc_source_raw: builtins.int
    cjc_val: builtins.float
    cjc_channel: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        cjc_source: global___CJCSource1.ValueType = ...,
        cjc_source_raw: builtins.int = ...,
        cjc_val: builtins.float = ...,
        cjc_channel: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cjc_source", b"cjc_source", "cjc_source_enum", b"cjc_source_enum", "cjc_source_raw", b"cjc_source_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cjc_channel", b"cjc_channel", "cjc_source", b"cjc_source", "cjc_source_enum", b"cjc_source_enum", "cjc_source_raw", b"cjc_source_raw", "cjc_val", b"cjc_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["cjc_source_enum", b"cjc_source_enum"]) -> typing.Literal["cjc_source", "cjc_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAIThrmcplChanRequest = CreateTEDSAIThrmcplChanRequest

@typing.final
class CreateTEDSAIThrmcplChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIThrmcplChanResponse = CreateTEDSAIThrmcplChanResponse

@typing.final
class CreateTEDSAIThrmstrChanIexRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    CURRENT_EXCIT_VAL_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    resistance_config: global___ResistanceConfiguration.ValueType
    resistance_config_raw: builtins.int
    current_excit_source: global___ExcitationSource.ValueType
    current_excit_source_raw: builtins.int
    current_excit_val: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        resistance_config: global___ResistanceConfiguration.ValueType = ...,
        resistance_config_raw: builtins.int = ...,
        current_excit_source: global___ExcitationSource.ValueType = ...,
        current_excit_source_raw: builtins.int = ...,
        current_excit_val: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["current_excit_source", b"current_excit_source", "current_excit_source_enum", b"current_excit_source_enum", "current_excit_source_raw", b"current_excit_source_raw", "current_excit_val", b"current_excit_val", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["current_excit_source_enum", b"current_excit_source_enum"]) -> typing.Literal["current_excit_source", "current_excit_source_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["resistance_config_enum", b"resistance_config_enum"]) -> typing.Literal["resistance_config", "resistance_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAIThrmstrChanIexRequest = CreateTEDSAIThrmstrChanIexRequest

@typing.final
class CreateTEDSAIThrmstrChanIexResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIThrmstrChanIexResponse = CreateTEDSAIThrmstrChanIexResponse

@typing.final
class CreateTEDSAIThrmstrChanVexRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_FIELD_NUMBER: builtins.int
    RESISTANCE_CONFIG_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    R1_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TemperatureUnits.ValueType
    units_raw: builtins.int
    resistance_config: global___ResistanceConfiguration.ValueType
    resistance_config_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    r1: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TemperatureUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        resistance_config: global___ResistanceConfiguration.ValueType = ...,
        resistance_config_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        r1: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "r1", b"r1", "resistance_config", b"resistance_config", "resistance_config_enum", b"resistance_config_enum", "resistance_config_raw", b"resistance_config_raw", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["resistance_config_enum", b"resistance_config_enum"]) -> typing.Literal["resistance_config", "resistance_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAIThrmstrChanVexRequest = CreateTEDSAIThrmstrChanVexRequest

@typing.final
class CreateTEDSAIThrmstrChanVexResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIThrmstrChanVexResponse = CreateTEDSAIThrmstrChanVexResponse

@typing.final
class CreateTEDSAITorqueBridgeChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    min_val: builtins.float
    max_val: builtins.float
    units: global___TorqueUnits.ValueType
    units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TorqueUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAITorqueBridgeChanRequest = CreateTEDSAITorqueBridgeChanRequest

@typing.final
class CreateTEDSAITorqueBridgeChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAITorqueBridgeChanResponse = CreateTEDSAITorqueBridgeChanResponse

@typing.final
class CreateTEDSAIVoltageChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___TEDSUnits.ValueType
    units_raw: builtins.int
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TEDSUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...

global___CreateTEDSAIVoltageChanRequest = CreateTEDSAIVoltageChanRequest

@typing.final
class CreateTEDSAIVoltageChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIVoltageChanResponse = CreateTEDSAIVoltageChanResponse

@typing.final
class CreateTEDSAIVoltageChanWithExcitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    NAME_TO_ASSIGN_TO_CHANNEL_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_FIELD_NUMBER: builtins.int
    TERMINAL_CONFIG_RAW_FIELD_NUMBER: builtins.int
    MIN_VAL_FIELD_NUMBER: builtins.int
    MAX_VAL_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    UNITS_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_SOURCE_RAW_FIELD_NUMBER: builtins.int
    VOLTAGE_EXCIT_VAL_FIELD_NUMBER: builtins.int
    CUSTOM_SCALE_NAME_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    name_to_assign_to_channel: builtins.str
    terminal_config: global___InputTermCfgWithDefault.ValueType
    terminal_config_raw: builtins.int
    min_val: builtins.float
    max_val: builtins.float
    units: global___TEDSUnits.ValueType
    units_raw: builtins.int
    voltage_excit_source: global___ExcitationSource.ValueType
    voltage_excit_source_raw: builtins.int
    voltage_excit_val: builtins.float
    custom_scale_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        physical_channel: builtins.str = ...,
        name_to_assign_to_channel: builtins.str = ...,
        terminal_config: global___InputTermCfgWithDefault.ValueType = ...,
        terminal_config_raw: builtins.int = ...,
        min_val: builtins.float = ...,
        max_val: builtins.float = ...,
        units: global___TEDSUnits.ValueType = ...,
        units_raw: builtins.int = ...,
        voltage_excit_source: global___ExcitationSource.ValueType = ...,
        voltage_excit_source_raw: builtins.int = ...,
        voltage_excit_val: builtins.float = ...,
        custom_scale_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom_scale_name", b"custom_scale_name", "max_val", b"max_val", "min_val", b"min_val", "name_to_assign_to_channel", b"name_to_assign_to_channel", "physical_channel", b"physical_channel", "task", b"task", "terminal_config", b"terminal_config", "terminal_config_enum", b"terminal_config_enum", "terminal_config_raw", b"terminal_config_raw", "units", b"units", "units_enum", b"units_enum", "units_raw", b"units_raw", "voltage_excit_source", b"voltage_excit_source", "voltage_excit_source_enum", b"voltage_excit_source_enum", "voltage_excit_source_raw", b"voltage_excit_source_raw", "voltage_excit_val", b"voltage_excit_val"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["terminal_config_enum", b"terminal_config_enum"]) -> typing.Literal["terminal_config", "terminal_config_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["units_enum", b"units_enum"]) -> typing.Literal["units", "units_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["voltage_excit_source_enum", b"voltage_excit_source_enum"]) -> typing.Literal["voltage_excit_source", "voltage_excit_source_raw"] | None: ...

global___CreateTEDSAIVoltageChanWithExcitRequest = CreateTEDSAIVoltageChanWithExcitRequest

@typing.final
class CreateTEDSAIVoltageChanWithExcitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTEDSAIVoltageChanWithExcitResponse = CreateTEDSAIVoltageChanWithExcitResponse

@typing.final
class CreateTableScaleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRESCALED_VALS_FIELD_NUMBER: builtins.int
    SCALED_VALS_FIELD_NUMBER: builtins.int
    PRE_SCALED_UNITS_FIELD_NUMBER: builtins.int
    PRE_SCALED_UNITS_RAW_FIELD_NUMBER: builtins.int
    SCALED_UNITS_FIELD_NUMBER: builtins.int
    name: builtins.str
    pre_scaled_units: global___UnitsPreScaled.ValueType
    pre_scaled_units_raw: builtins.int
    scaled_units: builtins.str
    @property
    def prescaled_vals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def scaled_vals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        prescaled_vals: collections.abc.Iterable[builtins.float] | None = ...,
        scaled_vals: collections.abc.Iterable[builtins.float] | None = ...,
        pre_scaled_units: global___UnitsPreScaled.ValueType = ...,
        pre_scaled_units_raw: builtins.int = ...,
        scaled_units: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pre_scaled_units", b"pre_scaled_units", "pre_scaled_units_enum", b"pre_scaled_units_enum", "pre_scaled_units_raw", b"pre_scaled_units_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "pre_scaled_units", b"pre_scaled_units", "pre_scaled_units_enum", b"pre_scaled_units_enum", "pre_scaled_units_raw", b"pre_scaled_units_raw", "prescaled_vals", b"prescaled_vals", "scaled_units", b"scaled_units", "scaled_vals", b"scaled_vals"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["pre_scaled_units_enum", b"pre_scaled_units_enum"]) -> typing.Literal["pre_scaled_units", "pre_scaled_units_raw"] | None: ...

global___CreateTableScaleRequest = CreateTableScaleRequest

@typing.final
class CreateTableScaleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___CreateTableScaleResponse = CreateTableScaleResponse

@typing.final
class CreateTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_NAME_FIELD_NUMBER: builtins.int
    INITIALIZATION_BEHAVIOR_FIELD_NUMBER: builtins.int
    session_name: builtins.str
    initialization_behavior: session_pb2.SessionInitializationBehavior.ValueType
    def __init__(
        self,
        *,
        session_name: builtins.str = ...,
        initialization_behavior: session_pb2.SessionInitializationBehavior.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["initialization_behavior", b"initialization_behavior", "session_name", b"session_name"]) -> None: ...

global___CreateTaskRequest = CreateTaskRequest

@typing.final
class CreateTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    NEW_SESSION_INITIALIZED_FIELD_NUMBER: builtins.int
    status: builtins.int
    new_session_initialized: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        task: session_pb2.Session | None = ...,
        new_session_initialized: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["new_session_initialized", b"new_session_initialized", "status", b"status", "task", b"task"]) -> None: ...

global___CreateTaskResponse = CreateTaskResponse

@typing.final
class CreateWatchdogTimerTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    SESSION_NAME_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    EXP_STATES_FIELD_NUMBER: builtins.int
    INITIALIZATION_BEHAVIOR_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    session_name: builtins.str
    timeout: builtins.float
    initialization_behavior: session_pb2.SessionInitializationBehavior.ValueType
    @property
    def exp_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WatchdogExpChannelsAndState]: ...
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        session_name: builtins.str = ...,
        timeout: builtins.float = ...,
        exp_states: collections.abc.Iterable[global___WatchdogExpChannelsAndState] | None = ...,
        initialization_behavior: session_pb2.SessionInitializationBehavior.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "exp_states", b"exp_states", "initialization_behavior", b"initialization_behavior", "session_name", b"session_name", "timeout", b"timeout"]) -> None: ...

global___CreateWatchdogTimerTaskRequest = CreateWatchdogTimerTaskRequest

@typing.final
class CreateWatchdogTimerTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    NEW_SESSION_INITIALIZED_FIELD_NUMBER: builtins.int
    status: builtins.int
    new_session_initialized: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        task: session_pb2.Session | None = ...,
        new_session_initialized: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["new_session_initialized", b"new_session_initialized", "status", b"status", "task", b"task"]) -> None: ...

global___CreateWatchdogTimerTaskResponse = CreateWatchdogTimerTaskResponse

@typing.final
class CreateWatchdogTimerTaskExRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    SESSION_NAME_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    INITIALIZATION_BEHAVIOR_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    session_name: builtins.str
    timeout: builtins.float
    initialization_behavior: session_pb2.SessionInitializationBehavior.ValueType
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        session_name: builtins.str = ...,
        timeout: builtins.float = ...,
        initialization_behavior: session_pb2.SessionInitializationBehavior.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "initialization_behavior", b"initialization_behavior", "session_name", b"session_name", "timeout", b"timeout"]) -> None: ...

global___CreateWatchdogTimerTaskExRequest = CreateWatchdogTimerTaskExRequest

@typing.final
class CreateWatchdogTimerTaskExResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    NEW_SESSION_INITIALIZED_FIELD_NUMBER: builtins.int
    status: builtins.int
    new_session_initialized: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        task: session_pb2.Session | None = ...,
        new_session_initialized: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["new_session_initialized", b"new_session_initialized", "status", b"status", "task", b"task"]) -> None: ...

global___CreateWatchdogTimerTaskExResponse = CreateWatchdogTimerTaskExResponse

@typing.final
class DeleteNetworkDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___DeleteNetworkDeviceRequest = DeleteNetworkDeviceRequest

@typing.final
class DeleteNetworkDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___DeleteNetworkDeviceResponse = DeleteNetworkDeviceResponse

@typing.final
class DeleteSavedGlobalChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    channel_name: builtins.str
    def __init__(
        self,
        *,
        channel_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name"]) -> None: ...

global___DeleteSavedGlobalChanRequest = DeleteSavedGlobalChanRequest

@typing.final
class DeleteSavedGlobalChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___DeleteSavedGlobalChanResponse = DeleteSavedGlobalChanResponse

@typing.final
class DeleteSavedScaleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["scale_name", b"scale_name"]) -> None: ...

global___DeleteSavedScaleRequest = DeleteSavedScaleRequest

@typing.final
class DeleteSavedScaleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___DeleteSavedScaleResponse = DeleteSavedScaleResponse

@typing.final
class DeleteSavedTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_NAME_FIELD_NUMBER: builtins.int
    task_name: builtins.str
    def __init__(
        self,
        *,
        task_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_name", b"task_name"]) -> None: ...

global___DeleteSavedTaskRequest = DeleteSavedTaskRequest

@typing.final
class DeleteSavedTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___DeleteSavedTaskResponse = DeleteSavedTaskResponse

@typing.final
class DeviceSupportsCalRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___DeviceSupportsCalRequest = DeviceSupportsCalRequest

@typing.final
class DeviceSupportsCalResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    CAL_SUPPORTED_FIELD_NUMBER: builtins.int
    status: builtins.int
    cal_supported: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        cal_supported: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cal_supported", b"cal_supported", "status", b"status"]) -> None: ...

global___DeviceSupportsCalResponse = DeviceSupportsCalResponse

@typing.final
class DisableRefTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___DisableRefTrigRequest = DisableRefTrigRequest

@typing.final
class DisableRefTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___DisableRefTrigResponse = DisableRefTrigResponse

@typing.final
class DisableStartTrigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___DisableStartTrigRequest = DisableStartTrigRequest

@typing.final
class DisableStartTrigResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___DisableStartTrigResponse = DisableStartTrigResponse

@typing.final
class DisconnectTermsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_TERMINAL_FIELD_NUMBER: builtins.int
    DESTINATION_TERMINAL_FIELD_NUMBER: builtins.int
    source_terminal: builtins.str
    destination_terminal: builtins.str
    def __init__(
        self,
        *,
        source_terminal: builtins.str = ...,
        destination_terminal: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_terminal", b"destination_terminal", "source_terminal", b"source_terminal"]) -> None: ...

global___DisconnectTermsRequest = DisconnectTermsRequest

@typing.final
class DisconnectTermsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___DisconnectTermsResponse = DisconnectTermsResponse

@typing.final
class ExportSignalRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SIGNAL_ID_FIELD_NUMBER: builtins.int
    SIGNAL_ID_RAW_FIELD_NUMBER: builtins.int
    OUTPUT_TERMINAL_FIELD_NUMBER: builtins.int
    signal_id: global___Signal.ValueType
    signal_id_raw: builtins.int
    output_terminal: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        signal_id: global___Signal.ValueType = ...,
        signal_id_raw: builtins.int = ...,
        output_terminal: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["signal_id", b"signal_id", "signal_id_enum", b"signal_id_enum", "signal_id_raw", b"signal_id_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["output_terminal", b"output_terminal", "signal_id", b"signal_id", "signal_id_enum", b"signal_id_enum", "signal_id_raw", b"signal_id_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["signal_id_enum", b"signal_id_enum"]) -> typing.Literal["signal_id", "signal_id_raw"] | None: ...

global___ExportSignalRequest = ExportSignalRequest

@typing.final
class ExportSignalResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ExportSignalResponse = ExportSignalResponse

@typing.final
class GetAIChanCalCalDateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    channel_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name", "task", b"task"]) -> None: ...

global___GetAIChanCalCalDateRequest = GetAIChanCalCalDateRequest

@typing.final
class GetAIChanCalCalDateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    MINUTE_FIELD_NUMBER: builtins.int
    status: builtins.int
    year: builtins.int
    month: builtins.int
    day: builtins.int
    hour: builtins.int
    minute: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        year: builtins.int = ...,
        month: builtins.int = ...,
        day: builtins.int = ...,
        hour: builtins.int = ...,
        minute: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["day", b"day", "hour", b"hour", "minute", b"minute", "month", b"month", "status", b"status", "year", b"year"]) -> None: ...

global___GetAIChanCalCalDateResponse = GetAIChanCalCalDateResponse

@typing.final
class GetAIChanCalExpDateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    channel_name: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name", "task", b"task"]) -> None: ...

global___GetAIChanCalExpDateRequest = GetAIChanCalExpDateRequest

@typing.final
class GetAIChanCalExpDateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    MINUTE_FIELD_NUMBER: builtins.int
    status: builtins.int
    year: builtins.int
    month: builtins.int
    day: builtins.int
    hour: builtins.int
    minute: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        year: builtins.int = ...,
        month: builtins.int = ...,
        day: builtins.int = ...,
        hour: builtins.int = ...,
        minute: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["day", b"day", "hour", b"hour", "minute", b"minute", "month", b"month", "status", b"status", "year", b"year"]) -> None: ...

global___GetAIChanCalExpDateResponse = GetAIChanCalExpDateResponse

@typing.final
class GetAnalogPowerUpStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    CHANNELS_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnalogPowerUpChannelAndType]: ...
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        channels: collections.abc.Iterable[global___AnalogPowerUpChannelAndType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channels", b"channels", "device_name", b"device_name"]) -> None: ...

global___GetAnalogPowerUpStatesRequest = GetAnalogPowerUpStatesRequest

@typing.final
class GetAnalogPowerUpStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    POWER_UP_STATES_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def power_up_states(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        power_up_states: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["power_up_states", b"power_up_states", "status", b"status"]) -> None: ...

global___GetAnalogPowerUpStatesResponse = GetAnalogPowerUpStatesResponse

@typing.final
class GetAnalogPowerUpStatesWithOutputTypeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    array_size: builtins.int
    def __init__(
        self,
        *,
        channel_names: builtins.str = ...,
        array_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["array_size", b"array_size", "channel_names", b"channel_names"]) -> None: ...

global___GetAnalogPowerUpStatesWithOutputTypeRequest = GetAnalogPowerUpStatesWithOutputTypeRequest

@typing.final
class GetAnalogPowerUpStatesWithOutputTypeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    STATE_ARRAY_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_ARRAY_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_ARRAY_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def state_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def channel_type_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PowerUpChannelType.ValueType]: ...
    @property
    def channel_type_array_raw(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        state_array: collections.abc.Iterable[builtins.float] | None = ...,
        channel_type_array: collections.abc.Iterable[global___PowerUpChannelType.ValueType] | None = ...,
        channel_type_array_raw: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_type_array", b"channel_type_array", "channel_type_array_raw", b"channel_type_array_raw", "state_array", b"state_array", "status", b"status"]) -> None: ...

global___GetAnalogPowerUpStatesWithOutputTypeResponse = GetAnalogPowerUpStatesWithOutputTypeResponse

@typing.final
class GetArmStartTrigTimestampValRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___GetArmStartTrigTimestampValRequest = GetArmStartTrigTimestampValRequest

@typing.final
class GetArmStartTrigTimestampValResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status"]) -> None: ...

global___GetArmStartTrigTimestampValResponse = GetArmStartTrigTimestampValResponse

@typing.final
class GetArmStartTrigTrigWhenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___GetArmStartTrigTrigWhenRequest = GetArmStartTrigTrigWhenRequest

@typing.final
class GetArmStartTrigTrigWhenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status"]) -> None: ...

global___GetArmStartTrigTrigWhenResponse = GetArmStartTrigTrigWhenResponse

@typing.final
class GetAutoConfiguredCDAQSyncConnectionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAutoConfiguredCDAQSyncConnectionsRequest = GetAutoConfiguredCDAQSyncConnectionsRequest

@typing.final
class GetAutoConfiguredCDAQSyncConnectionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    PORT_LIST_FIELD_NUMBER: builtins.int
    status: builtins.int
    port_list: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        port_list: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["port_list", b"port_list", "status", b"status"]) -> None: ...

global___GetAutoConfiguredCDAQSyncConnectionsResponse = GetAutoConfiguredCDAQSyncConnectionsResponse

@typing.final
class GetBufferAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___BufferUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___BufferUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetBufferAttributeUInt32Request = GetBufferAttributeUInt32Request

@typing.final
class GetBufferAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetBufferAttributeUInt32Response = GetBufferAttributeUInt32Response

@typing.final
class GetCalInfoAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___CalibrationInfoBoolAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___CalibrationInfoBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetCalInfoAttributeBoolRequest = GetCalInfoAttributeBoolRequest

@typing.final
class GetCalInfoAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetCalInfoAttributeBoolResponse = GetCalInfoAttributeBoolResponse

@typing.final
class GetCalInfoAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___CalibrationInfoDoubleAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___CalibrationInfoDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetCalInfoAttributeDoubleRequest = GetCalInfoAttributeDoubleRequest

@typing.final
class GetCalInfoAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetCalInfoAttributeDoubleResponse = GetCalInfoAttributeDoubleResponse

@typing.final
class GetCalInfoAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___CalibrationInfoStringAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___CalibrationInfoStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetCalInfoAttributeStringRequest = GetCalInfoAttributeStringRequest

@typing.final
class GetCalInfoAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetCalInfoAttributeStringResponse = GetCalInfoAttributeStringResponse

@typing.final
class GetCalInfoAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___CalibrationInfoUInt32Attribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___CalibrationInfoUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetCalInfoAttributeUInt32Request = GetCalInfoAttributeUInt32Request

@typing.final
class GetCalInfoAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetCalInfoAttributeUInt32Response = GetCalInfoAttributeUInt32Response

@typing.final
class GetChanAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetChanAttributeBoolRequest = GetChanAttributeBoolRequest

@typing.final
class GetChanAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetChanAttributeBoolResponse = GetChanAttributeBoolResponse

@typing.final
class GetChanAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelDoubleAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetChanAttributeDoubleRequest = GetChanAttributeDoubleRequest

@typing.final
class GetChanAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetChanAttributeDoubleResponse = GetChanAttributeDoubleResponse

@typing.final
class GetChanAttributeDoubleArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelDoubleArrayAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelDoubleArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetChanAttributeDoubleArrayRequest = GetChanAttributeDoubleArrayRequest

@typing.final
class GetChanAttributeDoubleArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetChanAttributeDoubleArrayResponse = GetChanAttributeDoubleArrayResponse

@typing.final
class GetChanAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetChanAttributeInt32Request = GetChanAttributeInt32Request

@typing.final
class GetChanAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___ChannelInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___ChannelInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetChanAttributeInt32Response = GetChanAttributeInt32Response

@typing.final
class GetChanAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetChanAttributeStringRequest = GetChanAttributeStringRequest

@typing.final
class GetChanAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetChanAttributeStringResponse = GetChanAttributeStringResponse

@typing.final
class GetChanAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetChanAttributeUInt32Request = GetChanAttributeUInt32Request

@typing.final
class GetChanAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetChanAttributeUInt32Response = GetChanAttributeUInt32Response

@typing.final
class GetDeviceAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___DeviceBoolAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___DeviceBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetDeviceAttributeBoolRequest = GetDeviceAttributeBoolRequest

@typing.final
class GetDeviceAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetDeviceAttributeBoolResponse = GetDeviceAttributeBoolResponse

@typing.final
class GetDeviceAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___DeviceDoubleAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___DeviceDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetDeviceAttributeDoubleRequest = GetDeviceAttributeDoubleRequest

@typing.final
class GetDeviceAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetDeviceAttributeDoubleResponse = GetDeviceAttributeDoubleResponse

@typing.final
class GetDeviceAttributeDoubleArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___DeviceDoubleArrayAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___DeviceDoubleArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetDeviceAttributeDoubleArrayRequest = GetDeviceAttributeDoubleArrayRequest

@typing.final
class GetDeviceAttributeDoubleArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetDeviceAttributeDoubleArrayResponse = GetDeviceAttributeDoubleArrayResponse

@typing.final
class GetDeviceAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___DeviceInt32Attribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___DeviceInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetDeviceAttributeInt32Request = GetDeviceAttributeInt32Request

@typing.final
class GetDeviceAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___DeviceInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___DeviceInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetDeviceAttributeInt32Response = GetDeviceAttributeInt32Response

@typing.final
class GetDeviceAttributeInt32ArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___DeviceInt32ArrayAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___DeviceInt32ArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetDeviceAttributeInt32ArrayRequest = GetDeviceAttributeInt32ArrayRequest

@typing.final
class GetDeviceAttributeInt32ArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___DeviceInt32AttributeValues.ValueType]: ...
    @property
    def value_raw(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[global___DeviceInt32AttributeValues.ValueType] | None = ...,
        value_raw: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetDeviceAttributeInt32ArrayResponse = GetDeviceAttributeInt32ArrayResponse

@typing.final
class GetDeviceAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___DeviceStringAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___DeviceStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetDeviceAttributeStringRequest = GetDeviceAttributeStringRequest

@typing.final
class GetDeviceAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetDeviceAttributeStringResponse = GetDeviceAttributeStringResponse

@typing.final
class GetDeviceAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___DeviceUInt32Attribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___DeviceUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetDeviceAttributeUInt32Request = GetDeviceAttributeUInt32Request

@typing.final
class GetDeviceAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetDeviceAttributeUInt32Response = GetDeviceAttributeUInt32Response

@typing.final
class GetDeviceAttributeUInt32ArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___DeviceUInt32ArrayAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___DeviceUInt32ArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetDeviceAttributeUInt32ArrayRequest = GetDeviceAttributeUInt32ArrayRequest

@typing.final
class GetDeviceAttributeUInt32ArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetDeviceAttributeUInt32ArrayResponse = GetDeviceAttributeUInt32ArrayResponse

@typing.final
class GetDigitalLogicFamilyPowerUpStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___GetDigitalLogicFamilyPowerUpStateRequest = GetDigitalLogicFamilyPowerUpStateRequest

@typing.final
class GetDigitalLogicFamilyPowerUpStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    LOGIC_FAMILY_FIELD_NUMBER: builtins.int
    status: builtins.int
    logic_family: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        logic_family: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["logic_family", b"logic_family", "status", b"status"]) -> None: ...

global___GetDigitalLogicFamilyPowerUpStateResponse = GetDigitalLogicFamilyPowerUpStateResponse

@typing.final
class GetDigitalPowerUpStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    @property
    def channel_name(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        channel_name: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name", "device_name", b"device_name"]) -> None: ...

global___GetDigitalPowerUpStatesRequest = GetDigitalPowerUpStatesRequest

@typing.final
class GetDigitalPowerUpStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    POWER_UP_STATES_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def power_up_states(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PowerUpStates.ValueType]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        power_up_states: collections.abc.Iterable[global___PowerUpStates.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["power_up_states", b"power_up_states", "status", b"status"]) -> None: ...

global___GetDigitalPowerUpStatesResponse = GetDigitalPowerUpStatesResponse

@typing.final
class GetDigitalPullUpPullDownStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    @property
    def channel_name(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        channel_name: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name", "device_name", b"device_name"]) -> None: ...

global___GetDigitalPullUpPullDownStatesRequest = GetDigitalPullUpPullDownStatesRequest

@typing.final
class GetDigitalPullUpPullDownStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    PULL_UP_PULL_DOWN_STATES_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def pull_up_pull_down_states(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___ResistorState.ValueType]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        pull_up_pull_down_states: collections.abc.Iterable[global___ResistorState.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["pull_up_pull_down_states", b"pull_up_pull_down_states", "status", b"status"]) -> None: ...

global___GetDigitalPullUpPullDownStatesResponse = GetDigitalPullUpPullDownStatesResponse

@typing.final
class GetDisconnectedCDAQSyncPortsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetDisconnectedCDAQSyncPortsRequest = GetDisconnectedCDAQSyncPortsRequest

@typing.final
class GetDisconnectedCDAQSyncPortsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    PORT_LIST_FIELD_NUMBER: builtins.int
    status: builtins.int
    port_list: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        port_list: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["port_list", b"port_list", "status", b"status"]) -> None: ...

global___GetDisconnectedCDAQSyncPortsResponse = GetDisconnectedCDAQSyncPortsResponse

@typing.final
class GetErrorStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_CODE_FIELD_NUMBER: builtins.int
    error_code: builtins.int
    def __init__(
        self,
        *,
        error_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["error_code", b"error_code"]) -> None: ...

global___GetErrorStringRequest = GetErrorStringRequest

@typing.final
class GetErrorStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    ERROR_STRING_FIELD_NUMBER: builtins.int
    status: builtins.int
    error_string: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        error_string: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["error_string", b"error_string", "status", b"status"]) -> None: ...

global___GetErrorStringResponse = GetErrorStringResponse

@typing.final
class GetExportedSignalAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetExportedSignalAttributeBoolRequest = GetExportedSignalAttributeBoolRequest

@typing.final
class GetExportedSignalAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetExportedSignalAttributeBoolResponse = GetExportedSignalAttributeBoolResponse

@typing.final
class GetExportedSignalAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalDoubleAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetExportedSignalAttributeDoubleRequest = GetExportedSignalAttributeDoubleRequest

@typing.final
class GetExportedSignalAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetExportedSignalAttributeDoubleResponse = GetExportedSignalAttributeDoubleResponse

@typing.final
class GetExportedSignalAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetExportedSignalAttributeInt32Request = GetExportedSignalAttributeInt32Request

@typing.final
class GetExportedSignalAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___ExportSignalInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___ExportSignalInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetExportedSignalAttributeInt32Response = GetExportedSignalAttributeInt32Response

@typing.final
class GetExportedSignalAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetExportedSignalAttributeStringRequest = GetExportedSignalAttributeStringRequest

@typing.final
class GetExportedSignalAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetExportedSignalAttributeStringResponse = GetExportedSignalAttributeStringResponse

@typing.final
class GetExportedSignalAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetExportedSignalAttributeUInt32Request = GetExportedSignalAttributeUInt32Request

@typing.final
class GetExportedSignalAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetExportedSignalAttributeUInt32Response = GetExportedSignalAttributeUInt32Response

@typing.final
class GetExtCalLastDateAndTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___GetExtCalLastDateAndTimeRequest = GetExtCalLastDateAndTimeRequest

@typing.final
class GetExtCalLastDateAndTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    MINUTE_FIELD_NUMBER: builtins.int
    status: builtins.int
    year: builtins.int
    month: builtins.int
    day: builtins.int
    hour: builtins.int
    minute: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        year: builtins.int = ...,
        month: builtins.int = ...,
        day: builtins.int = ...,
        hour: builtins.int = ...,
        minute: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["day", b"day", "hour", b"hour", "minute", b"minute", "month", b"month", "status", b"status", "year", b"year"]) -> None: ...

global___GetExtCalLastDateAndTimeResponse = GetExtCalLastDateAndTimeResponse

@typing.final
class GetFirstSampClkWhenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___GetFirstSampClkWhenRequest = GetFirstSampClkWhenRequest

@typing.final
class GetFirstSampClkWhenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status"]) -> None: ...

global___GetFirstSampClkWhenResponse = GetFirstSampClkWhenResponse

@typing.final
class GetFirstSampTimestampValRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___GetFirstSampTimestampValRequest = GetFirstSampTimestampValRequest

@typing.final
class GetFirstSampTimestampValResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status"]) -> None: ...

global___GetFirstSampTimestampValResponse = GetFirstSampTimestampValResponse

@typing.final
class GetNthTaskChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    index: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        index: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "task", b"task"]) -> None: ...

global___GetNthTaskChannelRequest = GetNthTaskChannelRequest

@typing.final
class GetNthTaskChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    BUFFER_FIELD_NUMBER: builtins.int
    status: builtins.int
    buffer: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        buffer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "status", b"status"]) -> None: ...

global___GetNthTaskChannelResponse = GetNthTaskChannelResponse

@typing.final
class GetNthTaskDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    index: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        index: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "task", b"task"]) -> None: ...

global___GetNthTaskDeviceRequest = GetNthTaskDeviceRequest

@typing.final
class GetNthTaskDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    BUFFER_FIELD_NUMBER: builtins.int
    status: builtins.int
    buffer: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        buffer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "status", b"status"]) -> None: ...

global___GetNthTaskDeviceResponse = GetNthTaskDeviceResponse

@typing.final
class GetNthTaskReadChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    index: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        index: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "task", b"task"]) -> None: ...

global___GetNthTaskReadChannelRequest = GetNthTaskReadChannelRequest

@typing.final
class GetNthTaskReadChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    BUFFER_FIELD_NUMBER: builtins.int
    status: builtins.int
    buffer: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        buffer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["buffer", b"buffer", "status", b"status"]) -> None: ...

global___GetNthTaskReadChannelResponse = GetNthTaskReadChannelResponse

@typing.final
class GetPersistedChanAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___PersistedChannelBoolAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        channel: builtins.str = ...,
        attribute: global___PersistedChannelBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPersistedChanAttributeBoolRequest = GetPersistedChanAttributeBoolRequest

@typing.final
class GetPersistedChanAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPersistedChanAttributeBoolResponse = GetPersistedChanAttributeBoolResponse

@typing.final
class GetPersistedChanAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___PersistedChannelStringAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        channel: builtins.str = ...,
        attribute: global___PersistedChannelStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPersistedChanAttributeStringRequest = GetPersistedChanAttributeStringRequest

@typing.final
class GetPersistedChanAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPersistedChanAttributeStringResponse = GetPersistedChanAttributeStringResponse

@typing.final
class GetPersistedScaleAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___PersistedScaleBoolAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___PersistedScaleBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPersistedScaleAttributeBoolRequest = GetPersistedScaleAttributeBoolRequest

@typing.final
class GetPersistedScaleAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPersistedScaleAttributeBoolResponse = GetPersistedScaleAttributeBoolResponse

@typing.final
class GetPersistedScaleAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___PersistedScaleStringAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___PersistedScaleStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPersistedScaleAttributeStringRequest = GetPersistedScaleAttributeStringRequest

@typing.final
class GetPersistedScaleAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPersistedScaleAttributeStringResponse = GetPersistedScaleAttributeStringResponse

@typing.final
class GetPersistedTaskAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    task_name: builtins.str
    attribute: global___PersistedTaskBoolAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        task_name: builtins.str = ...,
        attribute: global___PersistedTaskBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task_name", b"task_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPersistedTaskAttributeBoolRequest = GetPersistedTaskAttributeBoolRequest

@typing.final
class GetPersistedTaskAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPersistedTaskAttributeBoolResponse = GetPersistedTaskAttributeBoolResponse

@typing.final
class GetPersistedTaskAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    task_name: builtins.str
    attribute: global___PersistedTaskStringAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        task_name: builtins.str = ...,
        attribute: global___PersistedTaskStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task_name", b"task_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPersistedTaskAttributeStringRequest = GetPersistedTaskAttributeStringRequest

@typing.final
class GetPersistedTaskAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPersistedTaskAttributeStringResponse = GetPersistedTaskAttributeStringResponse

@typing.final
class GetPhysicalChanAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelBoolAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeBoolRequest = GetPhysicalChanAttributeBoolRequest

@typing.final
class GetPhysicalChanAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPhysicalChanAttributeBoolResponse = GetPhysicalChanAttributeBoolResponse

@typing.final
class GetPhysicalChanAttributeBytesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelBytesAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelBytesAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeBytesRequest = GetPhysicalChanAttributeBytesRequest

@typing.final
class GetPhysicalChanAttributeBytesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bytes
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPhysicalChanAttributeBytesResponse = GetPhysicalChanAttributeBytesResponse

@typing.final
class GetPhysicalChanAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelDoubleAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeDoubleRequest = GetPhysicalChanAttributeDoubleRequest

@typing.final
class GetPhysicalChanAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPhysicalChanAttributeDoubleResponse = GetPhysicalChanAttributeDoubleResponse

@typing.final
class GetPhysicalChanAttributeDoubleArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelDoubleArrayAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelDoubleArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeDoubleArrayRequest = GetPhysicalChanAttributeDoubleArrayRequest

@typing.final
class GetPhysicalChanAttributeDoubleArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPhysicalChanAttributeDoubleArrayResponse = GetPhysicalChanAttributeDoubleArrayResponse

@typing.final
class GetPhysicalChanAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelInt32Attribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeInt32Request = GetPhysicalChanAttributeInt32Request

@typing.final
class GetPhysicalChanAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___PhysicalChannelInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___PhysicalChannelInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetPhysicalChanAttributeInt32Response = GetPhysicalChanAttributeInt32Response

@typing.final
class GetPhysicalChanAttributeInt32ArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelInt32ArrayAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelInt32ArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeInt32ArrayRequest = GetPhysicalChanAttributeInt32ArrayRequest

@typing.final
class GetPhysicalChanAttributeInt32ArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PhysicalChannelInt32AttributeValues.ValueType]: ...
    @property
    def value_raw(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[global___PhysicalChannelInt32AttributeValues.ValueType] | None = ...,
        value_raw: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetPhysicalChanAttributeInt32ArrayResponse = GetPhysicalChanAttributeInt32ArrayResponse

@typing.final
class GetPhysicalChanAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelStringAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeStringRequest = GetPhysicalChanAttributeStringRequest

@typing.final
class GetPhysicalChanAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPhysicalChanAttributeStringResponse = GetPhysicalChanAttributeStringResponse

@typing.final
class GetPhysicalChanAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelUInt32Attribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeUInt32Request = GetPhysicalChanAttributeUInt32Request

@typing.final
class GetPhysicalChanAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPhysicalChanAttributeUInt32Response = GetPhysicalChanAttributeUInt32Response

@typing.final
class GetPhysicalChanAttributeUInt32ArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    attribute: global___PhysicalChannelUInt32ArrayAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        attribute: global___PhysicalChannelUInt32ArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetPhysicalChanAttributeUInt32ArrayRequest = GetPhysicalChanAttributeUInt32ArrayRequest

@typing.final
class GetPhysicalChanAttributeUInt32ArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetPhysicalChanAttributeUInt32ArrayResponse = GetPhysicalChanAttributeUInt32ArrayResponse

@typing.final
class GetReadAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ReadBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetReadAttributeBoolRequest = GetReadAttributeBoolRequest

@typing.final
class GetReadAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetReadAttributeBoolResponse = GetReadAttributeBoolResponse

@typing.final
class GetReadAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ReadDoubleAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetReadAttributeDoubleRequest = GetReadAttributeDoubleRequest

@typing.final
class GetReadAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetReadAttributeDoubleResponse = GetReadAttributeDoubleResponse

@typing.final
class GetReadAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ReadInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetReadAttributeInt32Request = GetReadAttributeInt32Request

@typing.final
class GetReadAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___ReadInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___ReadInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetReadAttributeInt32Response = GetReadAttributeInt32Response

@typing.final
class GetReadAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ReadStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetReadAttributeStringRequest = GetReadAttributeStringRequest

@typing.final
class GetReadAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetReadAttributeStringResponse = GetReadAttributeStringResponse

@typing.final
class GetReadAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ReadUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetReadAttributeUInt32Request = GetReadAttributeUInt32Request

@typing.final
class GetReadAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetReadAttributeUInt32Response = GetReadAttributeUInt32Response

@typing.final
class GetReadAttributeUInt64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ReadUInt64Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadUInt64Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetReadAttributeUInt64Request = GetReadAttributeUInt64Request

@typing.final
class GetReadAttributeUInt64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetReadAttributeUInt64Response = GetReadAttributeUInt64Response

@typing.final
class GetRealTimeAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___RealTimeBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___RealTimeBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetRealTimeAttributeBoolRequest = GetRealTimeAttributeBoolRequest

@typing.final
class GetRealTimeAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetRealTimeAttributeBoolResponse = GetRealTimeAttributeBoolResponse

@typing.final
class GetRealTimeAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___RealTimeInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___RealTimeInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetRealTimeAttributeInt32Request = GetRealTimeAttributeInt32Request

@typing.final
class GetRealTimeAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___RealTimeInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___RealTimeInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetRealTimeAttributeInt32Response = GetRealTimeAttributeInt32Response

@typing.final
class GetRealTimeAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___RealTimeUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___RealTimeUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetRealTimeAttributeUInt32Request = GetRealTimeAttributeUInt32Request

@typing.final
class GetRealTimeAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetRealTimeAttributeUInt32Response = GetRealTimeAttributeUInt32Response

@typing.final
class GetRefTrigTimestampValRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___GetRefTrigTimestampValRequest = GetRefTrigTimestampValRequest

@typing.final
class GetRefTrigTimestampValResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status"]) -> None: ...

global___GetRefTrigTimestampValResponse = GetRefTrigTimestampValResponse

@typing.final
class GetScaleAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___ScaleDoubleAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___ScaleDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetScaleAttributeDoubleRequest = GetScaleAttributeDoubleRequest

@typing.final
class GetScaleAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetScaleAttributeDoubleResponse = GetScaleAttributeDoubleResponse

@typing.final
class GetScaleAttributeDoubleArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___ScaleDoubleArrayAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___ScaleDoubleArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetScaleAttributeDoubleArrayRequest = GetScaleAttributeDoubleArrayRequest

@typing.final
class GetScaleAttributeDoubleArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetScaleAttributeDoubleArrayResponse = GetScaleAttributeDoubleArrayResponse

@typing.final
class GetScaleAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___ScaleInt32Attribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___ScaleInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetScaleAttributeInt32Request = GetScaleAttributeInt32Request

@typing.final
class GetScaleAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___ScaleInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___ScaleInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetScaleAttributeInt32Response = GetScaleAttributeInt32Response

@typing.final
class GetScaleAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___ScaleStringAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___ScaleStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetScaleAttributeStringRequest = GetScaleAttributeStringRequest

@typing.final
class GetScaleAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetScaleAttributeStringResponse = GetScaleAttributeStringResponse

@typing.final
class GetSelfCalLastDateAndTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___GetSelfCalLastDateAndTimeRequest = GetSelfCalLastDateAndTimeRequest

@typing.final
class GetSelfCalLastDateAndTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    MINUTE_FIELD_NUMBER: builtins.int
    status: builtins.int
    year: builtins.int
    month: builtins.int
    day: builtins.int
    hour: builtins.int
    minute: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        year: builtins.int = ...,
        month: builtins.int = ...,
        day: builtins.int = ...,
        hour: builtins.int = ...,
        minute: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["day", b"day", "hour", b"hour", "minute", b"minute", "month", b"month", "status", b"status", "year", b"year"]) -> None: ...

global___GetSelfCalLastDateAndTimeResponse = GetSelfCalLastDateAndTimeResponse

@typing.final
class GetStartTrigTimestampValRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___GetStartTrigTimestampValRequest = GetStartTrigTimestampValRequest

@typing.final
class GetStartTrigTimestampValResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status"]) -> None: ...

global___GetStartTrigTimestampValResponse = GetStartTrigTimestampValResponse

@typing.final
class GetStartTrigTrigWhenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___GetStartTrigTrigWhenRequest = GetStartTrigTrigWhenRequest

@typing.final
class GetStartTrigTrigWhenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status"]) -> None: ...

global___GetStartTrigTrigWhenResponse = GetStartTrigTrigWhenResponse

@typing.final
class GetSyncPulseTimeWhenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___GetSyncPulseTimeWhenRequest = GetSyncPulseTimeWhenRequest

@typing.final
class GetSyncPulseTimeWhenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "status", b"status"]) -> None: ...

global___GetSyncPulseTimeWhenResponse = GetSyncPulseTimeWhenResponse

@typing.final
class GetSystemInfoAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___SystemStringAttribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        attribute: global___SystemStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetSystemInfoAttributeStringRequest = GetSystemInfoAttributeStringRequest

@typing.final
class GetSystemInfoAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetSystemInfoAttributeStringResponse = GetSystemInfoAttributeStringResponse

@typing.final
class GetSystemInfoAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___SystemUInt32Attribute.ValueType
    attribute_raw: builtins.int
    def __init__(
        self,
        *,
        attribute: global___SystemUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetSystemInfoAttributeUInt32Request = GetSystemInfoAttributeUInt32Request

@typing.final
class GetSystemInfoAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetSystemInfoAttributeUInt32Response = GetSystemInfoAttributeUInt32Response

@typing.final
class GetTaskAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TaskBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TaskBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTaskAttributeBoolRequest = GetTaskAttributeBoolRequest

@typing.final
class GetTaskAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTaskAttributeBoolResponse = GetTaskAttributeBoolResponse

@typing.final
class GetTaskAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TaskStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TaskStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTaskAttributeStringRequest = GetTaskAttributeStringRequest

@typing.final
class GetTaskAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTaskAttributeStringResponse = GetTaskAttributeStringResponse

@typing.final
class GetTaskAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TaskUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TaskUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTaskAttributeUInt32Request = GetTaskAttributeUInt32Request

@typing.final
class GetTaskAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTaskAttributeUInt32Response = GetTaskAttributeUInt32Response

@typing.final
class GetTimingAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeBoolRequest = GetTimingAttributeBoolRequest

@typing.final
class GetTimingAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeBoolResponse = GetTimingAttributeBoolResponse

@typing.final
class GetTimingAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingDoubleAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeDoubleRequest = GetTimingAttributeDoubleRequest

@typing.final
class GetTimingAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeDoubleResponse = GetTimingAttributeDoubleResponse

@typing.final
class GetTimingAttributeExBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeExBoolRequest = GetTimingAttributeExBoolRequest

@typing.final
class GetTimingAttributeExBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeExBoolResponse = GetTimingAttributeExBoolResponse

@typing.final
class GetTimingAttributeExDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingDoubleAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeExDoubleRequest = GetTimingAttributeExDoubleRequest

@typing.final
class GetTimingAttributeExDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeExDoubleResponse = GetTimingAttributeExDoubleResponse

@typing.final
class GetTimingAttributeExInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeExInt32Request = GetTimingAttributeExInt32Request

@typing.final
class GetTimingAttributeExInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___TimingInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___TimingInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetTimingAttributeExInt32Response = GetTimingAttributeExInt32Response

@typing.final
class GetTimingAttributeExStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeExStringRequest = GetTimingAttributeExStringRequest

@typing.final
class GetTimingAttributeExStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeExStringResponse = GetTimingAttributeExStringResponse

@typing.final
class GetTimingAttributeExTimestampRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingTimestampAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingTimestampAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeExTimestampRequest = GetTimingAttributeExTimestampRequest

@typing.final
class GetTimingAttributeExTimestampResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeExTimestampResponse = GetTimingAttributeExTimestampResponse

@typing.final
class GetTimingAttributeExUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeExUInt32Request = GetTimingAttributeExUInt32Request

@typing.final
class GetTimingAttributeExUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeExUInt32Response = GetTimingAttributeExUInt32Response

@typing.final
class GetTimingAttributeExUInt64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingUInt64Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingUInt64Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeExUInt64Request = GetTimingAttributeExUInt64Request

@typing.final
class GetTimingAttributeExUInt64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeExUInt64Response = GetTimingAttributeExUInt64Response

@typing.final
class GetTimingAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeInt32Request = GetTimingAttributeInt32Request

@typing.final
class GetTimingAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___TimingInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___TimingInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetTimingAttributeInt32Response = GetTimingAttributeInt32Response

@typing.final
class GetTimingAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeStringRequest = GetTimingAttributeStringRequest

@typing.final
class GetTimingAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeStringResponse = GetTimingAttributeStringResponse

@typing.final
class GetTimingAttributeTimestampRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingTimestampAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingTimestampAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeTimestampRequest = GetTimingAttributeTimestampRequest

@typing.final
class GetTimingAttributeTimestampResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeTimestampResponse = GetTimingAttributeTimestampResponse

@typing.final
class GetTimingAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeUInt32Request = GetTimingAttributeUInt32Request

@typing.final
class GetTimingAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeUInt32Response = GetTimingAttributeUInt32Response

@typing.final
class GetTimingAttributeUInt64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingUInt64Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingUInt64Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTimingAttributeUInt64Request = GetTimingAttributeUInt64Request

@typing.final
class GetTimingAttributeUInt64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTimingAttributeUInt64Response = GetTimingAttributeUInt64Response

@typing.final
class GetTrigAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTrigAttributeBoolRequest = GetTrigAttributeBoolRequest

@typing.final
class GetTrigAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTrigAttributeBoolResponse = GetTrigAttributeBoolResponse

@typing.final
class GetTrigAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerDoubleAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTrigAttributeDoubleRequest = GetTrigAttributeDoubleRequest

@typing.final
class GetTrigAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTrigAttributeDoubleResponse = GetTrigAttributeDoubleResponse

@typing.final
class GetTrigAttributeDoubleArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerDoubleArrayAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerDoubleArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTrigAttributeDoubleArrayRequest = GetTrigAttributeDoubleArrayRequest

@typing.final
class GetTrigAttributeDoubleArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTrigAttributeDoubleArrayResponse = GetTrigAttributeDoubleArrayResponse

@typing.final
class GetTrigAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTrigAttributeInt32Request = GetTrigAttributeInt32Request

@typing.final
class GetTrigAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___TriggerInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___TriggerInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetTrigAttributeInt32Response = GetTrigAttributeInt32Response

@typing.final
class GetTrigAttributeInt32ArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerInt32ArrayAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerInt32ArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTrigAttributeInt32ArrayRequest = GetTrigAttributeInt32ArrayRequest

@typing.final
class GetTrigAttributeInt32ArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___TriggerInt32AttributeValues.ValueType]: ...
    @property
    def value_raw(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: collections.abc.Iterable[global___TriggerInt32AttributeValues.ValueType] | None = ...,
        value_raw: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetTrigAttributeInt32ArrayResponse = GetTrigAttributeInt32ArrayResponse

@typing.final
class GetTrigAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTrigAttributeStringRequest = GetTrigAttributeStringRequest

@typing.final
class GetTrigAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTrigAttributeStringResponse = GetTrigAttributeStringResponse

@typing.final
class GetTrigAttributeTimestampRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerTimestampAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerTimestampAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTrigAttributeTimestampRequest = GetTrigAttributeTimestampRequest

@typing.final
class GetTrigAttributeTimestampResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTrigAttributeTimestampResponse = GetTrigAttributeTimestampResponse

@typing.final
class GetTrigAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetTrigAttributeUInt32Request = GetTrigAttributeUInt32Request

@typing.final
class GetTrigAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetTrigAttributeUInt32Response = GetTrigAttributeUInt32Response

@typing.final
class GetWatchdogAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWatchdogAttributeBoolRequest = GetWatchdogAttributeBoolRequest

@typing.final
class GetWatchdogAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetWatchdogAttributeBoolResponse = GetWatchdogAttributeBoolResponse

@typing.final
class GetWatchdogAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogDoubleAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWatchdogAttributeDoubleRequest = GetWatchdogAttributeDoubleRequest

@typing.final
class GetWatchdogAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetWatchdogAttributeDoubleResponse = GetWatchdogAttributeDoubleResponse

@typing.final
class GetWatchdogAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWatchdogAttributeInt32Request = GetWatchdogAttributeInt32Request

@typing.final
class GetWatchdogAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___WatchdogInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___WatchdogInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetWatchdogAttributeInt32Response = GetWatchdogAttributeInt32Response

@typing.final
class GetWatchdogAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWatchdogAttributeStringRequest = GetWatchdogAttributeStringRequest

@typing.final
class GetWatchdogAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetWatchdogAttributeStringResponse = GetWatchdogAttributeStringResponse

@typing.final
class GetWriteAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___WriteBoolAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWriteAttributeBoolRequest = GetWriteAttributeBoolRequest

@typing.final
class GetWriteAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetWriteAttributeBoolResponse = GetWriteAttributeBoolResponse

@typing.final
class GetWriteAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___WriteDoubleAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWriteAttributeDoubleRequest = GetWriteAttributeDoubleRequest

@typing.final
class GetWriteAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetWriteAttributeDoubleResponse = GetWriteAttributeDoubleResponse

@typing.final
class GetWriteAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___WriteInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWriteAttributeInt32Request = GetWriteAttributeInt32Request

@typing.final
class GetWriteAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: global___WriteInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: global___WriteInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value", "value_raw", b"value_raw"]) -> None: ...

global___GetWriteAttributeInt32Response = GetWriteAttributeInt32Response

@typing.final
class GetWriteAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___WriteStringAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWriteAttributeStringRequest = GetWriteAttributeStringRequest

@typing.final
class GetWriteAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetWriteAttributeStringResponse = GetWriteAttributeStringResponse

@typing.final
class GetWriteAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___WriteUInt32Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWriteAttributeUInt32Request = GetWriteAttributeUInt32Request

@typing.final
class GetWriteAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetWriteAttributeUInt32Response = GetWriteAttributeUInt32Response

@typing.final
class GetWriteAttributeUInt64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___WriteUInt64Attribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteUInt64Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___GetWriteAttributeUInt64Request = GetWriteAttributeUInt64Request

@typing.final
class GetWriteAttributeUInt64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___GetWriteAttributeUInt64Response = GetWriteAttributeUInt64Response

@typing.final
class IsTaskDoneRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___IsTaskDoneRequest = IsTaskDoneRequest

@typing.final
class IsTaskDoneResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    IS_TASK_DONE_FIELD_NUMBER: builtins.int
    status: builtins.int
    is_task_done: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        is_task_done: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["is_task_done", b"is_task_done", "status", b"status"]) -> None: ...

global___IsTaskDoneResponse = IsTaskDoneResponse

@typing.final
class LoadTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_NAME_FIELD_NUMBER: builtins.int
    INITIALIZATION_BEHAVIOR_FIELD_NUMBER: builtins.int
    session_name: builtins.str
    initialization_behavior: session_pb2.SessionInitializationBehavior.ValueType
    def __init__(
        self,
        *,
        session_name: builtins.str = ...,
        initialization_behavior: session_pb2.SessionInitializationBehavior.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["initialization_behavior", b"initialization_behavior", "session_name", b"session_name"]) -> None: ...

global___LoadTaskRequest = LoadTaskRequest

@typing.final
class LoadTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    NEW_SESSION_INITIALIZED_FIELD_NUMBER: builtins.int
    status: builtins.int
    new_session_initialized: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        task: session_pb2.Session | None = ...,
        new_session_initialized: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["new_session_initialized", b"new_session_initialized", "status", b"status", "task", b"task"]) -> None: ...

global___LoadTaskResponse = LoadTaskResponse

@typing.final
class PerformBridgeOffsetNullingCalExRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    SKIP_UNSUPPORTED_CHANNELS_FIELD_NUMBER: builtins.int
    channel: builtins.str
    skip_unsupported_channels: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        skip_unsupported_channels: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel", b"channel", "skip_unsupported_channels", b"skip_unsupported_channels", "task", b"task"]) -> None: ...

global___PerformBridgeOffsetNullingCalExRequest = PerformBridgeOffsetNullingCalExRequest

@typing.final
class PerformBridgeOffsetNullingCalExResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___PerformBridgeOffsetNullingCalExResponse = PerformBridgeOffsetNullingCalExResponse

@typing.final
class PerformBridgeShuntCalExRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_VALUE_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOCATION_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOCATION_RAW_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_SELECT_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_SELECT_RAW_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_SOURCE_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_SOURCE_RAW_FIELD_NUMBER: builtins.int
    BRIDGE_RESISTANCE_FIELD_NUMBER: builtins.int
    SKIP_UNSUPPORTED_CHANNELS_FIELD_NUMBER: builtins.int
    channel: builtins.str
    shunt_resistor_value: builtins.float
    shunt_resistor_location: global___ShuntElementLocation.ValueType
    shunt_resistor_location_raw: builtins.int
    shunt_resistor_select: global___ShuntCalSelect.ValueType
    shunt_resistor_select_raw: builtins.int
    shunt_resistor_source: global___ShuntCalSource.ValueType
    shunt_resistor_source_raw: builtins.int
    bridge_resistance: builtins.float
    skip_unsupported_channels: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        shunt_resistor_value: builtins.float = ...,
        shunt_resistor_location: global___ShuntElementLocation.ValueType = ...,
        shunt_resistor_location_raw: builtins.int = ...,
        shunt_resistor_select: global___ShuntCalSelect.ValueType = ...,
        shunt_resistor_select_raw: builtins.int = ...,
        shunt_resistor_source: global___ShuntCalSource.ValueType = ...,
        shunt_resistor_source_raw: builtins.int = ...,
        bridge_resistance: builtins.float = ...,
        skip_unsupported_channels: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["shunt_resistor_location", b"shunt_resistor_location", "shunt_resistor_location_enum", b"shunt_resistor_location_enum", "shunt_resistor_location_raw", b"shunt_resistor_location_raw", "shunt_resistor_select", b"shunt_resistor_select", "shunt_resistor_select_enum", b"shunt_resistor_select_enum", "shunt_resistor_select_raw", b"shunt_resistor_select_raw", "shunt_resistor_source", b"shunt_resistor_source", "shunt_resistor_source_enum", b"shunt_resistor_source_enum", "shunt_resistor_source_raw", b"shunt_resistor_source_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bridge_resistance", b"bridge_resistance", "channel", b"channel", "shunt_resistor_location", b"shunt_resistor_location", "shunt_resistor_location_enum", b"shunt_resistor_location_enum", "shunt_resistor_location_raw", b"shunt_resistor_location_raw", "shunt_resistor_select", b"shunt_resistor_select", "shunt_resistor_select_enum", b"shunt_resistor_select_enum", "shunt_resistor_select_raw", b"shunt_resistor_select_raw", "shunt_resistor_source", b"shunt_resistor_source", "shunt_resistor_source_enum", b"shunt_resistor_source_enum", "shunt_resistor_source_raw", b"shunt_resistor_source_raw", "shunt_resistor_value", b"shunt_resistor_value", "skip_unsupported_channels", b"skip_unsupported_channels", "task", b"task"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_location_enum", b"shunt_resistor_location_enum"]) -> typing.Literal["shunt_resistor_location", "shunt_resistor_location_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_select_enum", b"shunt_resistor_select_enum"]) -> typing.Literal["shunt_resistor_select", "shunt_resistor_select_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_source_enum", b"shunt_resistor_source_enum"]) -> typing.Literal["shunt_resistor_source", "shunt_resistor_source_raw"] | None: ...

global___PerformBridgeShuntCalExRequest = PerformBridgeShuntCalExRequest

@typing.final
class PerformBridgeShuntCalExResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___PerformBridgeShuntCalExResponse = PerformBridgeShuntCalExResponse

@typing.final
class PerformStrainShuntCalExRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_VALUE_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOCATION_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_LOCATION_RAW_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_SELECT_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_SELECT_RAW_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_SOURCE_FIELD_NUMBER: builtins.int
    SHUNT_RESISTOR_SOURCE_RAW_FIELD_NUMBER: builtins.int
    SKIP_UNSUPPORTED_CHANNELS_FIELD_NUMBER: builtins.int
    channel: builtins.str
    shunt_resistor_value: builtins.float
    shunt_resistor_location: global___ShuntElementLocation.ValueType
    shunt_resistor_location_raw: builtins.int
    shunt_resistor_select: global___ShuntCalSelect.ValueType
    shunt_resistor_select_raw: builtins.int
    shunt_resistor_source: global___ShuntCalSource.ValueType
    shunt_resistor_source_raw: builtins.int
    skip_unsupported_channels: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        shunt_resistor_value: builtins.float = ...,
        shunt_resistor_location: global___ShuntElementLocation.ValueType = ...,
        shunt_resistor_location_raw: builtins.int = ...,
        shunt_resistor_select: global___ShuntCalSelect.ValueType = ...,
        shunt_resistor_select_raw: builtins.int = ...,
        shunt_resistor_source: global___ShuntCalSource.ValueType = ...,
        shunt_resistor_source_raw: builtins.int = ...,
        skip_unsupported_channels: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["shunt_resistor_location", b"shunt_resistor_location", "shunt_resistor_location_enum", b"shunt_resistor_location_enum", "shunt_resistor_location_raw", b"shunt_resistor_location_raw", "shunt_resistor_select", b"shunt_resistor_select", "shunt_resistor_select_enum", b"shunt_resistor_select_enum", "shunt_resistor_select_raw", b"shunt_resistor_select_raw", "shunt_resistor_source", b"shunt_resistor_source", "shunt_resistor_source_enum", b"shunt_resistor_source_enum", "shunt_resistor_source_raw", b"shunt_resistor_source_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel", b"channel", "shunt_resistor_location", b"shunt_resistor_location", "shunt_resistor_location_enum", b"shunt_resistor_location_enum", "shunt_resistor_location_raw", b"shunt_resistor_location_raw", "shunt_resistor_select", b"shunt_resistor_select", "shunt_resistor_select_enum", b"shunt_resistor_select_enum", "shunt_resistor_select_raw", b"shunt_resistor_select_raw", "shunt_resistor_source", b"shunt_resistor_source", "shunt_resistor_source_enum", b"shunt_resistor_source_enum", "shunt_resistor_source_raw", b"shunt_resistor_source_raw", "shunt_resistor_value", b"shunt_resistor_value", "skip_unsupported_channels", b"skip_unsupported_channels", "task", b"task"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_location_enum", b"shunt_resistor_location_enum"]) -> typing.Literal["shunt_resistor_location", "shunt_resistor_location_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_select_enum", b"shunt_resistor_select_enum"]) -> typing.Literal["shunt_resistor_select", "shunt_resistor_select_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["shunt_resistor_source_enum", b"shunt_resistor_source_enum"]) -> typing.Literal["shunt_resistor_source", "shunt_resistor_source_raw"] | None: ...

global___PerformStrainShuntCalExRequest = PerformStrainShuntCalExRequest

@typing.final
class PerformStrainShuntCalExResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___PerformStrainShuntCalExResponse = PerformStrainShuntCalExResponse

@typing.final
class PerformThrmcplLeadOffsetNullingCalRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    SKIP_UNSUPPORTED_CHANNELS_FIELD_NUMBER: builtins.int
    channel: builtins.str
    skip_unsupported_channels: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        skip_unsupported_channels: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel", b"channel", "skip_unsupported_channels", b"skip_unsupported_channels", "task", b"task"]) -> None: ...

global___PerformThrmcplLeadOffsetNullingCalRequest = PerformThrmcplLeadOffsetNullingCalRequest

@typing.final
class PerformThrmcplLeadOffsetNullingCalResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___PerformThrmcplLeadOffsetNullingCalResponse = PerformThrmcplLeadOffsetNullingCalResponse

@typing.final
class ReadAnalogF64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadAnalogF64Request = ReadAnalogF64Request

@typing.final
class ReadAnalogF64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.float] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadAnalogF64Response = ReadAnalogF64Response

@typing.final
class ReadAnalogScalarF64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadAnalogScalarF64Request = ReadAnalogScalarF64Request

@typing.final
class ReadAnalogScalarF64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___ReadAnalogScalarF64Response = ReadAnalogScalarF64Response

@typing.final
class ReadBinaryI16Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadBinaryI16Request = ReadBinaryI16Request

@typing.final
class ReadBinaryI16Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadBinaryI16Response = ReadBinaryI16Response

@typing.final
class ReadBinaryI32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadBinaryI32Request = ReadBinaryI32Request

@typing.final
class ReadBinaryI32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadBinaryI32Response = ReadBinaryI32Response

@typing.final
class ReadBinaryU16Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadBinaryU16Request = ReadBinaryU16Request

@typing.final
class ReadBinaryU16Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadBinaryU16Response = ReadBinaryU16Response

@typing.final
class ReadBinaryU32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadBinaryU32Request = ReadBinaryU32Request

@typing.final
class ReadBinaryU32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadBinaryU32Response = ReadBinaryU32Response

@typing.final
class ReadCounterF64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadCounterF64Request = ReadCounterF64Request

@typing.final
class ReadCounterF64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.float] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadCounterF64Response = ReadCounterF64Response

@typing.final
class ReadCounterF64ExRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadCounterF64ExRequest = ReadCounterF64ExRequest

@typing.final
class ReadCounterF64ExResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.float] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadCounterF64ExResponse = ReadCounterF64ExResponse

@typing.final
class ReadCounterScalarF64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadCounterScalarF64Request = ReadCounterScalarF64Request

@typing.final
class ReadCounterScalarF64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___ReadCounterScalarF64Response = ReadCounterScalarF64Response

@typing.final
class ReadCounterScalarU32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadCounterScalarU32Request = ReadCounterScalarU32Request

@typing.final
class ReadCounterScalarU32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___ReadCounterScalarU32Response = ReadCounterScalarU32Response

@typing.final
class ReadCounterU32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadCounterU32Request = ReadCounterU32Request

@typing.final
class ReadCounterU32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadCounterU32Response = ReadCounterU32Response

@typing.final
class ReadCounterU32ExRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadCounterU32ExRequest = ReadCounterU32ExRequest

@typing.final
class ReadCounterU32ExResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadCounterU32ExResponse = ReadCounterU32ExResponse

@typing.final
class ReadCtrFreqRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    INTERLEAVED_FIELD_NUMBER: builtins.int
    INTERLEAVED_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    interleaved: global___GroupBy.ValueType
    interleaved_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        interleaved: global___GroupBy.ValueType = ...,
        interleaved_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["interleaved", b"interleaved", "interleaved_enum", b"interleaved_enum", "interleaved_raw", b"interleaved_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "interleaved", b"interleaved", "interleaved_enum", b"interleaved_enum", "interleaved_raw", b"interleaved_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["interleaved_enum", b"interleaved_enum"]) -> typing.Literal["interleaved", "interleaved_raw"] | None: ...

global___ReadCtrFreqRequest = ReadCtrFreqRequest

@typing.final
class ReadCtrFreqResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FREQUENCY_FIELD_NUMBER: builtins.int
    READ_ARRAY_DUTY_CYCLE_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array_frequency(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def read_array_duty_cycle(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array_frequency: collections.abc.Iterable[builtins.float] | None = ...,
        read_array_duty_cycle: collections.abc.Iterable[builtins.float] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array_duty_cycle", b"read_array_duty_cycle", "read_array_frequency", b"read_array_frequency", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadCtrFreqResponse = ReadCtrFreqResponse

@typing.final
class ReadCtrFreqScalarRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadCtrFreqScalarRequest = ReadCtrFreqScalarRequest

@typing.final
class ReadCtrFreqScalarResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    FREQUENCY_FIELD_NUMBER: builtins.int
    DUTY_CYCLE_FIELD_NUMBER: builtins.int
    status: builtins.int
    frequency: builtins.float
    duty_cycle: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        frequency: builtins.float = ...,
        duty_cycle: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["duty_cycle", b"duty_cycle", "frequency", b"frequency", "status", b"status"]) -> None: ...

global___ReadCtrFreqScalarResponse = ReadCtrFreqScalarResponse

@typing.final
class ReadCtrTicksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    INTERLEAVED_FIELD_NUMBER: builtins.int
    INTERLEAVED_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    interleaved: global___GroupBy.ValueType
    interleaved_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        interleaved: global___GroupBy.ValueType = ...,
        interleaved_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["interleaved", b"interleaved", "interleaved_enum", b"interleaved_enum", "interleaved_raw", b"interleaved_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "interleaved", b"interleaved", "interleaved_enum", b"interleaved_enum", "interleaved_raw", b"interleaved_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["interleaved_enum", b"interleaved_enum"]) -> typing.Literal["interleaved", "interleaved_raw"] | None: ...

global___ReadCtrTicksRequest = ReadCtrTicksRequest

@typing.final
class ReadCtrTicksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_HIGH_TICKS_FIELD_NUMBER: builtins.int
    READ_ARRAY_LOW_TICKS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array_high_ticks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def read_array_low_ticks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array_high_ticks: collections.abc.Iterable[builtins.int] | None = ...,
        read_array_low_ticks: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array_high_ticks", b"read_array_high_ticks", "read_array_low_ticks", b"read_array_low_ticks", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadCtrTicksResponse = ReadCtrTicksResponse

@typing.final
class ReadCtrTicksScalarRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadCtrTicksScalarRequest = ReadCtrTicksScalarRequest

@typing.final
class ReadCtrTicksScalarResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    HIGH_TICKS_FIELD_NUMBER: builtins.int
    LOW_TICKS_FIELD_NUMBER: builtins.int
    status: builtins.int
    high_ticks: builtins.int
    low_ticks: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        high_ticks: builtins.int = ...,
        low_ticks: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["high_ticks", b"high_ticks", "low_ticks", b"low_ticks", "status", b"status"]) -> None: ...

global___ReadCtrTicksScalarResponse = ReadCtrTicksScalarResponse

@typing.final
class ReadCtrTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    INTERLEAVED_FIELD_NUMBER: builtins.int
    INTERLEAVED_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    interleaved: global___GroupBy.ValueType
    interleaved_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        interleaved: global___GroupBy.ValueType = ...,
        interleaved_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["interleaved", b"interleaved", "interleaved_enum", b"interleaved_enum", "interleaved_raw", b"interleaved_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "interleaved", b"interleaved", "interleaved_enum", b"interleaved_enum", "interleaved_raw", b"interleaved_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["interleaved_enum", b"interleaved_enum"]) -> typing.Literal["interleaved", "interleaved_raw"] | None: ...

global___ReadCtrTimeRequest = ReadCtrTimeRequest

@typing.final
class ReadCtrTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_HIGH_TIME_FIELD_NUMBER: builtins.int
    READ_ARRAY_LOW_TIME_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array_high_time(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def read_array_low_time(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array_high_time: collections.abc.Iterable[builtins.float] | None = ...,
        read_array_low_time: collections.abc.Iterable[builtins.float] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array_high_time", b"read_array_high_time", "read_array_low_time", b"read_array_low_time", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadCtrTimeResponse = ReadCtrTimeResponse

@typing.final
class ReadCtrTimeScalarRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadCtrTimeScalarRequest = ReadCtrTimeScalarRequest

@typing.final
class ReadCtrTimeScalarResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    HIGH_TIME_FIELD_NUMBER: builtins.int
    LOW_TIME_FIELD_NUMBER: builtins.int
    status: builtins.int
    high_time: builtins.float
    low_time: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        high_time: builtins.float = ...,
        low_time: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["high_time", b"high_time", "low_time", b"low_time", "status", b"status"]) -> None: ...

global___ReadCtrTimeScalarResponse = ReadCtrTimeScalarResponse

@typing.final
class ReadDigitalLinesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_BYTES_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_bytes: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_bytes", b"array_size_in_bytes", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadDigitalLinesRequest = ReadDigitalLinesRequest

@typing.final
class ReadDigitalLinesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    NUM_BYTES_PER_SAMP_FIELD_NUMBER: builtins.int
    status: builtins.int
    read_array: builtins.bytes
    samps_per_chan_read: builtins.int
    num_bytes_per_samp: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: builtins.bytes = ...,
        samps_per_chan_read: builtins.int = ...,
        num_bytes_per_samp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_bytes_per_samp", b"num_bytes_per_samp", "read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadDigitalLinesResponse = ReadDigitalLinesResponse

@typing.final
class ReadDigitalScalarU32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadDigitalScalarU32Request = ReadDigitalScalarU32Request

@typing.final
class ReadDigitalScalarU32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    status: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "value", b"value"]) -> None: ...

global___ReadDigitalScalarU32Response = ReadDigitalScalarU32Response

@typing.final
class ReadDigitalU16Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadDigitalU16Request = ReadDigitalU16Request

@typing.final
class ReadDigitalU16Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadDigitalU16Response = ReadDigitalU16Response

@typing.final
class ReadDigitalU32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadDigitalU32Request = ReadDigitalU32Request

@typing.final
class ReadDigitalU32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadDigitalU32Response = ReadDigitalU32Response

@typing.final
class ReadDigitalU8Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadDigitalU8Request = ReadDigitalU8Request

@typing.final
class ReadDigitalU8Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    read_array: builtins.bytes
    samps_per_chan_read: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: builtins.bytes = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array", b"read_array", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadDigitalU8Response = ReadDigitalU8Response

@typing.final
class ReadPowerBinaryI16Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadPowerBinaryI16Request = ReadPowerBinaryI16Request

@typing.final
class ReadPowerBinaryI16Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_VOLTAGE_FIELD_NUMBER: builtins.int
    READ_ARRAY_CURRENT_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array_voltage(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def read_array_current(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array_voltage: collections.abc.Iterable[builtins.int] | None = ...,
        read_array_current: collections.abc.Iterable[builtins.int] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array_current", b"read_array_current", "read_array_voltage", b"read_array_voltage", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadPowerBinaryI16Response = ReadPowerBinaryI16Response

@typing.final
class ReadPowerF64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FILL_MODE_FIELD_NUMBER: builtins.int
    FILL_MODE_RAW_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_SAMPS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    fill_mode: global___GroupBy.ValueType
    fill_mode_raw: builtins.int
    array_size_in_samps: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        fill_mode: global___GroupBy.ValueType = ...,
        fill_mode_raw: builtins.int = ...,
        array_size_in_samps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_samps", b"array_size_in_samps", "fill_mode", b"fill_mode", "fill_mode_enum", b"fill_mode_enum", "fill_mode_raw", b"fill_mode_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["fill_mode_enum", b"fill_mode_enum"]) -> typing.Literal["fill_mode", "fill_mode_raw"] | None: ...

global___ReadPowerF64Request = ReadPowerF64Request

@typing.final
class ReadPowerF64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_VOLTAGE_FIELD_NUMBER: builtins.int
    READ_ARRAY_CURRENT_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_READ_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_read: builtins.int
    @property
    def read_array_voltage(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def read_array_current(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array_voltage: collections.abc.Iterable[builtins.float] | None = ...,
        read_array_current: collections.abc.Iterable[builtins.float] | None = ...,
        samps_per_chan_read: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["read_array_current", b"read_array_current", "read_array_voltage", b"read_array_voltage", "samps_per_chan_read", b"samps_per_chan_read", "status", b"status"]) -> None: ...

global___ReadPowerF64Response = ReadPowerF64Response

@typing.final
class ReadPowerScalarF64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadPowerScalarF64Request = ReadPowerScalarF64Request

@typing.final
class ReadPowerScalarF64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    VOLTAGE_FIELD_NUMBER: builtins.int
    CURRENT_FIELD_NUMBER: builtins.int
    status: builtins.int
    voltage: builtins.float
    current: builtins.float
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        voltage: builtins.float = ...,
        current: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["current", b"current", "status", b"status", "voltage", b"voltage"]) -> None: ...

global___ReadPowerScalarF64Response = ReadPowerScalarF64Response

@typing.final
class ReadRawRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    ARRAY_SIZE_IN_BYTES_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    timeout: builtins.float
    array_size_in_bytes: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        timeout: builtins.float = ...,
        array_size_in_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_size_in_bytes", b"array_size_in_bytes", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...

global___ReadRawRequest = ReadRawRequest

@typing.final
class ReadRawResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    READ_ARRAY_FIELD_NUMBER: builtins.int
    SAMPS_READ_FIELD_NUMBER: builtins.int
    NUM_BYTES_PER_SAMP_FIELD_NUMBER: builtins.int
    status: builtins.int
    read_array: builtins.bytes
    samps_read: builtins.int
    num_bytes_per_samp: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        read_array: builtins.bytes = ...,
        samps_read: builtins.int = ...,
        num_bytes_per_samp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_bytes_per_samp", b"num_bytes_per_samp", "read_array", b"read_array", "samps_read", b"samps_read", "status", b"status"]) -> None: ...

global___ReadRawResponse = ReadRawResponse

@typing.final
class RegisterDoneEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___RegisterDoneEventRequest = RegisterDoneEventRequest

@typing.final
class RegisterDoneEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___RegisterDoneEventResponse = RegisterDoneEventResponse

@typing.final
class RegisterEveryNSamplesEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    EVERY_N_SAMPLES_EVENT_TYPE_FIELD_NUMBER: builtins.int
    EVERY_N_SAMPLES_EVENT_TYPE_RAW_FIELD_NUMBER: builtins.int
    N_SAMPLES_FIELD_NUMBER: builtins.int
    every_n_samples_event_type: global___EveryNSamplesEventType.ValueType
    every_n_samples_event_type_raw: builtins.int
    n_samples: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        every_n_samples_event_type: global___EveryNSamplesEventType.ValueType = ...,
        every_n_samples_event_type_raw: builtins.int = ...,
        n_samples: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["every_n_samples_event_type", b"every_n_samples_event_type", "every_n_samples_event_type_enum", b"every_n_samples_event_type_enum", "every_n_samples_event_type_raw", b"every_n_samples_event_type_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["every_n_samples_event_type", b"every_n_samples_event_type", "every_n_samples_event_type_enum", b"every_n_samples_event_type_enum", "every_n_samples_event_type_raw", b"every_n_samples_event_type_raw", "n_samples", b"n_samples", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["every_n_samples_event_type_enum", b"every_n_samples_event_type_enum"]) -> typing.Literal["every_n_samples_event_type", "every_n_samples_event_type_raw"] | None: ...

global___RegisterEveryNSamplesEventRequest = RegisterEveryNSamplesEventRequest

@typing.final
class RegisterEveryNSamplesEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    EVERY_N_SAMPLES_EVENT_TYPE_FIELD_NUMBER: builtins.int
    EVERY_N_SAMPLES_EVENT_TYPE_RAW_FIELD_NUMBER: builtins.int
    N_SAMPLES_FIELD_NUMBER: builtins.int
    status: builtins.int
    every_n_samples_event_type: global___EveryNSamplesEventType.ValueType
    every_n_samples_event_type_raw: builtins.int
    n_samples: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        every_n_samples_event_type: global___EveryNSamplesEventType.ValueType = ...,
        every_n_samples_event_type_raw: builtins.int = ...,
        n_samples: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["every_n_samples_event_type", b"every_n_samples_event_type", "every_n_samples_event_type_raw", b"every_n_samples_event_type_raw", "n_samples", b"n_samples", "status", b"status"]) -> None: ...

global___RegisterEveryNSamplesEventResponse = RegisterEveryNSamplesEventResponse

@typing.final
class RegisterSignalEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SIGNAL_ID_FIELD_NUMBER: builtins.int
    SIGNAL_ID_RAW_FIELD_NUMBER: builtins.int
    signal_id: global___Signal2.ValueType
    signal_id_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        signal_id: global___Signal2.ValueType = ...,
        signal_id_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["signal_id", b"signal_id", "signal_id_enum", b"signal_id_enum", "signal_id_raw", b"signal_id_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["signal_id", b"signal_id", "signal_id_enum", b"signal_id_enum", "signal_id_raw", b"signal_id_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["signal_id_enum", b"signal_id_enum"]) -> typing.Literal["signal_id", "signal_id_raw"] | None: ...

global___RegisterSignalEventRequest = RegisterSignalEventRequest

@typing.final
class RegisterSignalEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SIGNAL_ID_FIELD_NUMBER: builtins.int
    status: builtins.int
    signal_id: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        signal_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signal_id", b"signal_id", "status", b"status"]) -> None: ...

global___RegisterSignalEventResponse = RegisterSignalEventResponse

@typing.final
class RemoveCDAQSyncConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_LIST_FIELD_NUMBER: builtins.int
    port_list: builtins.str
    def __init__(
        self,
        *,
        port_list: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["port_list", b"port_list"]) -> None: ...

global___RemoveCDAQSyncConnectionRequest = RemoveCDAQSyncConnectionRequest

@typing.final
class RemoveCDAQSyncConnectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___RemoveCDAQSyncConnectionResponse = RemoveCDAQSyncConnectionResponse

@typing.final
class ReserveNetworkDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    OVERRIDE_RESERVATION_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    override_reservation: builtins.bool
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        override_reservation: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "override_reservation", b"override_reservation"]) -> None: ...

global___ReserveNetworkDeviceRequest = ReserveNetworkDeviceRequest

@typing.final
class ReserveNetworkDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ReserveNetworkDeviceResponse = ReserveNetworkDeviceResponse

@typing.final
class ResetBufferAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___BufferResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___BufferResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetBufferAttributeRequest = ResetBufferAttributeRequest

@typing.final
class ResetBufferAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetBufferAttributeResponse = ResetBufferAttributeResponse

@typing.final
class ResetChanAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetChanAttributeRequest = ResetChanAttributeRequest

@typing.final
class ResetChanAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetChanAttributeResponse = ResetChanAttributeResponse

@typing.final
class ResetDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___ResetDeviceRequest = ResetDeviceRequest

@typing.final
class ResetDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetDeviceResponse = ResetDeviceResponse

@typing.final
class ResetExportedSignalAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetExportedSignalAttributeRequest = ResetExportedSignalAttributeRequest

@typing.final
class ResetExportedSignalAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetExportedSignalAttributeResponse = ResetExportedSignalAttributeResponse

@typing.final
class ResetReadAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ReadResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetReadAttributeRequest = ResetReadAttributeRequest

@typing.final
class ResetReadAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetReadAttributeResponse = ResetReadAttributeResponse

@typing.final
class ResetRealTimeAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___RealTimeResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___RealTimeResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetRealTimeAttributeRequest = ResetRealTimeAttributeRequest

@typing.final
class ResetRealTimeAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetRealTimeAttributeResponse = ResetRealTimeAttributeResponse

@typing.final
class ResetTimingAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetTimingAttributeRequest = ResetTimingAttributeRequest

@typing.final
class ResetTimingAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetTimingAttributeResponse = ResetTimingAttributeResponse

@typing.final
class ResetTimingAttributeExRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetTimingAttributeExRequest = ResetTimingAttributeExRequest

@typing.final
class ResetTimingAttributeExResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetTimingAttributeExResponse = ResetTimingAttributeExResponse

@typing.final
class ResetTrigAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetTrigAttributeRequest = ResetTrigAttributeRequest

@typing.final
class ResetTrigAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetTrigAttributeResponse = ResetTrigAttributeResponse

@typing.final
class ResetWatchdogAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetWatchdogAttributeRequest = ResetWatchdogAttributeRequest

@typing.final
class ResetWatchdogAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetWatchdogAttributeResponse = ResetWatchdogAttributeResponse

@typing.final
class ResetWriteAttributeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___WriteResetAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteResetAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___ResetWriteAttributeRequest = ResetWriteAttributeRequest

@typing.final
class ResetWriteAttributeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ResetWriteAttributeResponse = ResetWriteAttributeResponse

@typing.final
class RestoreLastExtCalConstRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___RestoreLastExtCalConstRequest = RestoreLastExtCalConstRequest

@typing.final
class RestoreLastExtCalConstResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___RestoreLastExtCalConstResponse = RestoreLastExtCalConstResponse

@typing.final
class SaveGlobalChanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    SAVE_AS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    OPTIONS_RAW_FIELD_NUMBER: builtins.int
    channel_name: builtins.str
    save_as: builtins.str
    author: builtins.str
    options: global___SaveOptions.ValueType
    options_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_name: builtins.str = ...,
        save_as: builtins.str = ...,
        author: builtins.str = ...,
        options: global___SaveOptions.ValueType = ...,
        options_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["options", b"options", "options_enum", b"options_enum", "options_raw", b"options_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "channel_name", b"channel_name", "options", b"options", "options_enum", b"options_enum", "options_raw", b"options_raw", "save_as", b"save_as", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["options_enum", b"options_enum"]) -> typing.Literal["options", "options_raw"] | None: ...

global___SaveGlobalChanRequest = SaveGlobalChanRequest

@typing.final
class SaveGlobalChanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SaveGlobalChanResponse = SaveGlobalChanResponse

@typing.final
class SaveScaleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    SAVE_AS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    OPTIONS_RAW_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    save_as: builtins.str
    author: builtins.str
    options: global___SaveOptions.ValueType
    options_raw: builtins.int
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        save_as: builtins.str = ...,
        author: builtins.str = ...,
        options: global___SaveOptions.ValueType = ...,
        options_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["options", b"options", "options_enum", b"options_enum", "options_raw", b"options_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "options", b"options", "options_enum", b"options_enum", "options_raw", b"options_raw", "save_as", b"save_as", "scale_name", b"scale_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["options_enum", b"options_enum"]) -> typing.Literal["options", "options_raw"] | None: ...

global___SaveScaleRequest = SaveScaleRequest

@typing.final
class SaveScaleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SaveScaleResponse = SaveScaleResponse

@typing.final
class SaveTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SAVE_AS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    OPTIONS_RAW_FIELD_NUMBER: builtins.int
    save_as: builtins.str
    author: builtins.str
    options: global___SaveOptions.ValueType
    options_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        save_as: builtins.str = ...,
        author: builtins.str = ...,
        options: global___SaveOptions.ValueType = ...,
        options_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["options", b"options", "options_enum", b"options_enum", "options_raw", b"options_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "options", b"options", "options_enum", b"options_enum", "options_raw", b"options_raw", "save_as", b"save_as", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["options_enum", b"options_enum"]) -> typing.Literal["options", "options_raw"] | None: ...

global___SaveTaskRequest = SaveTaskRequest

@typing.final
class SaveTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SaveTaskResponse = SaveTaskResponse

@typing.final
class SelfCalRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___SelfCalRequest = SelfCalRequest

@typing.final
class SelfCalResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SelfCalResponse = SelfCalResponse

@typing.final
class SelfTestDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___SelfTestDeviceRequest = SelfTestDeviceRequest

@typing.final
class SelfTestDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SelfTestDeviceResponse = SelfTestDeviceResponse

@typing.final
class SetAIChanCalCalDateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    MINUTE_FIELD_NUMBER: builtins.int
    channel_name: builtins.str
    year: builtins.int
    month: builtins.int
    day: builtins.int
    hour: builtins.int
    minute: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_name: builtins.str = ...,
        year: builtins.int = ...,
        month: builtins.int = ...,
        day: builtins.int = ...,
        hour: builtins.int = ...,
        minute: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name", "day", b"day", "hour", b"hour", "minute", b"minute", "month", b"month", "task", b"task", "year", b"year"]) -> None: ...

global___SetAIChanCalCalDateRequest = SetAIChanCalCalDateRequest

@typing.final
class SetAIChanCalCalDateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetAIChanCalCalDateResponse = SetAIChanCalCalDateResponse

@typing.final
class SetAIChanCalExpDateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    MINUTE_FIELD_NUMBER: builtins.int
    channel_name: builtins.str
    year: builtins.int
    month: builtins.int
    day: builtins.int
    hour: builtins.int
    minute: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel_name: builtins.str = ...,
        year: builtins.int = ...,
        month: builtins.int = ...,
        day: builtins.int = ...,
        hour: builtins.int = ...,
        minute: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_name", b"channel_name", "day", b"day", "hour", b"hour", "minute", b"minute", "month", b"month", "task", b"task", "year", b"year"]) -> None: ...

global___SetAIChanCalExpDateRequest = SetAIChanCalExpDateRequest

@typing.final
class SetAIChanCalExpDateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetAIChanCalExpDateResponse = SetAIChanCalExpDateResponse

@typing.final
class SetAnalogPowerUpStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    POWER_UP_STATES_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    @property
    def power_up_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnalogPowerUpChannelsAndState]: ...
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        power_up_states: collections.abc.Iterable[global___AnalogPowerUpChannelsAndState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "power_up_states", b"power_up_states"]) -> None: ...

global___SetAnalogPowerUpStatesRequest = SetAnalogPowerUpStatesRequest

@typing.final
class SetAnalogPowerUpStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetAnalogPowerUpStatesResponse = SetAnalogPowerUpStatesResponse

@typing.final
class SetAnalogPowerUpStatesWithOutputTypeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_NAMES_FIELD_NUMBER: builtins.int
    STATE_ARRAY_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_ARRAY_FIELD_NUMBER: builtins.int
    channel_names: builtins.str
    @property
    def state_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def channel_type_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PowerUpChannelType.ValueType]: ...
    def __init__(
        self,
        *,
        channel_names: builtins.str = ...,
        state_array: collections.abc.Iterable[builtins.float] | None = ...,
        channel_type_array: collections.abc.Iterable[global___PowerUpChannelType.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_names", b"channel_names", "channel_type_array", b"channel_type_array", "state_array", b"state_array"]) -> None: ...

global___SetAnalogPowerUpStatesWithOutputTypeRequest = SetAnalogPowerUpStatesWithOutputTypeRequest

@typing.final
class SetAnalogPowerUpStatesWithOutputTypeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetAnalogPowerUpStatesWithOutputTypeResponse = SetAnalogPowerUpStatesWithOutputTypeResponse

@typing.final
class SetArmStartTrigTrigWhenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "task", b"task"]) -> None: ...

global___SetArmStartTrigTrigWhenRequest = SetArmStartTrigTrigWhenRequest

@typing.final
class SetArmStartTrigTrigWhenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetArmStartTrigTrigWhenResponse = SetArmStartTrigTrigWhenResponse

@typing.final
class SetBufferAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___BufferUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___BufferUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetBufferAttributeUInt32Request = SetBufferAttributeUInt32Request

@typing.final
class SetBufferAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetBufferAttributeUInt32Response = SetBufferAttributeUInt32Response

@typing.final
class SetCalInfoAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___CalibrationInfoBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___CalibrationInfoBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetCalInfoAttributeBoolRequest = SetCalInfoAttributeBoolRequest

@typing.final
class SetCalInfoAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetCalInfoAttributeBoolResponse = SetCalInfoAttributeBoolResponse

@typing.final
class SetCalInfoAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___CalibrationInfoDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___CalibrationInfoDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetCalInfoAttributeDoubleRequest = SetCalInfoAttributeDoubleRequest

@typing.final
class SetCalInfoAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetCalInfoAttributeDoubleResponse = SetCalInfoAttributeDoubleResponse

@typing.final
class SetCalInfoAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___CalibrationInfoStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___CalibrationInfoStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetCalInfoAttributeStringRequest = SetCalInfoAttributeStringRequest

@typing.final
class SetCalInfoAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetCalInfoAttributeStringResponse = SetCalInfoAttributeStringResponse

@typing.final
class SetCalInfoAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    attribute: global___CalibrationInfoUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        attribute: global___CalibrationInfoUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_name", b"device_name", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetCalInfoAttributeUInt32Request = SetCalInfoAttributeUInt32Request

@typing.final
class SetCalInfoAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetCalInfoAttributeUInt32Response = SetCalInfoAttributeUInt32Response

@typing.final
class SetChanAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetChanAttributeBoolRequest = SetChanAttributeBoolRequest

@typing.final
class SetChanAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetChanAttributeBoolResponse = SetChanAttributeBoolResponse

@typing.final
class SetChanAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetChanAttributeDoubleRequest = SetChanAttributeDoubleRequest

@typing.final
class SetChanAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetChanAttributeDoubleResponse = SetChanAttributeDoubleResponse

@typing.final
class SetChanAttributeDoubleArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelDoubleArrayAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelDoubleArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetChanAttributeDoubleArrayRequest = SetChanAttributeDoubleArrayRequest

@typing.final
class SetChanAttributeDoubleArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetChanAttributeDoubleArrayResponse = SetChanAttributeDoubleArrayResponse

@typing.final
class SetChanAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___ChannelInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___ChannelInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetChanAttributeInt32Request = SetChanAttributeInt32Request

@typing.final
class SetChanAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetChanAttributeInt32Response = SetChanAttributeInt32Response

@typing.final
class SetChanAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetChanAttributeStringRequest = SetChanAttributeStringRequest

@typing.final
class SetChanAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetChanAttributeStringResponse = SetChanAttributeStringResponse

@typing.final
class SetChanAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    channel: builtins.str
    attribute: global___ChannelUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        channel: builtins.str = ...,
        attribute: global___ChannelUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "channel", b"channel", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetChanAttributeUInt32Request = SetChanAttributeUInt32Request

@typing.final
class SetChanAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetChanAttributeUInt32Response = SetChanAttributeUInt32Response

@typing.final
class SetDigitalLogicFamilyPowerUpStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    LOGIC_FAMILY_FIELD_NUMBER: builtins.int
    LOGIC_FAMILY_RAW_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    logic_family: global___LogicFamily.ValueType
    logic_family_raw: builtins.int
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        logic_family: global___LogicFamily.ValueType = ...,
        logic_family_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["logic_family", b"logic_family", "logic_family_enum", b"logic_family_enum", "logic_family_raw", b"logic_family_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "logic_family", b"logic_family", "logic_family_enum", b"logic_family_enum", "logic_family_raw", b"logic_family_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["logic_family_enum", b"logic_family_enum"]) -> typing.Literal["logic_family", "logic_family_raw"] | None: ...

global___SetDigitalLogicFamilyPowerUpStateRequest = SetDigitalLogicFamilyPowerUpStateRequest

@typing.final
class SetDigitalLogicFamilyPowerUpStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetDigitalLogicFamilyPowerUpStateResponse = SetDigitalLogicFamilyPowerUpStateResponse

@typing.final
class SetDigitalPowerUpStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    POWER_UP_STATES_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    @property
    def power_up_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DigitalPowerUpChannelsAndState]: ...
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        power_up_states: collections.abc.Iterable[global___DigitalPowerUpChannelsAndState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "power_up_states", b"power_up_states"]) -> None: ...

global___SetDigitalPowerUpStatesRequest = SetDigitalPowerUpStatesRequest

@typing.final
class SetDigitalPowerUpStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetDigitalPowerUpStatesResponse = SetDigitalPowerUpStatesResponse

@typing.final
class SetDigitalPullUpPullDownStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    PULL_UP_PULL_DOWN_STATES_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    @property
    def pull_up_pull_down_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DigitalPullUpPullDownChannelsAndState]: ...
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        pull_up_pull_down_states: collections.abc.Iterable[global___DigitalPullUpPullDownChannelsAndState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "pull_up_pull_down_states", b"pull_up_pull_down_states"]) -> None: ...

global___SetDigitalPullUpPullDownStatesRequest = SetDigitalPullUpPullDownStatesRequest

@typing.final
class SetDigitalPullUpPullDownStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetDigitalPullUpPullDownStatesResponse = SetDigitalPullUpPullDownStatesResponse

@typing.final
class SetExportedSignalAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetExportedSignalAttributeBoolRequest = SetExportedSignalAttributeBoolRequest

@typing.final
class SetExportedSignalAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetExportedSignalAttributeBoolResponse = SetExportedSignalAttributeBoolResponse

@typing.final
class SetExportedSignalAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetExportedSignalAttributeDoubleRequest = SetExportedSignalAttributeDoubleRequest

@typing.final
class SetExportedSignalAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetExportedSignalAttributeDoubleResponse = SetExportedSignalAttributeDoubleResponse

@typing.final
class SetExportedSignalAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___ExportSignalInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___ExportSignalInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetExportedSignalAttributeInt32Request = SetExportedSignalAttributeInt32Request

@typing.final
class SetExportedSignalAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetExportedSignalAttributeInt32Response = SetExportedSignalAttributeInt32Response

@typing.final
class SetExportedSignalAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetExportedSignalAttributeStringRequest = SetExportedSignalAttributeStringRequest

@typing.final
class SetExportedSignalAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetExportedSignalAttributeStringResponse = SetExportedSignalAttributeStringResponse

@typing.final
class SetExportedSignalAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ExportSignalUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ExportSignalUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetExportedSignalAttributeUInt32Request = SetExportedSignalAttributeUInt32Request

@typing.final
class SetExportedSignalAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetExportedSignalAttributeUInt32Response = SetExportedSignalAttributeUInt32Response

@typing.final
class SetFirstSampClkWhenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "task", b"task"]) -> None: ...

global___SetFirstSampClkWhenRequest = SetFirstSampClkWhenRequest

@typing.final
class SetFirstSampClkWhenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetFirstSampClkWhenResponse = SetFirstSampClkWhenResponse

@typing.final
class SetReadAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ReadBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetReadAttributeBoolRequest = SetReadAttributeBoolRequest

@typing.final
class SetReadAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetReadAttributeBoolResponse = SetReadAttributeBoolResponse

@typing.final
class SetReadAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ReadDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetReadAttributeDoubleRequest = SetReadAttributeDoubleRequest

@typing.final
class SetReadAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetReadAttributeDoubleResponse = SetReadAttributeDoubleResponse

@typing.final
class SetReadAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___ReadInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___ReadInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___ReadInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetReadAttributeInt32Request = SetReadAttributeInt32Request

@typing.final
class SetReadAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetReadAttributeInt32Response = SetReadAttributeInt32Response

@typing.final
class SetReadAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ReadStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetReadAttributeStringRequest = SetReadAttributeStringRequest

@typing.final
class SetReadAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetReadAttributeStringResponse = SetReadAttributeStringResponse

@typing.final
class SetReadAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ReadUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetReadAttributeUInt32Request = SetReadAttributeUInt32Request

@typing.final
class SetReadAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetReadAttributeUInt32Response = SetReadAttributeUInt32Response

@typing.final
class SetReadAttributeUInt64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___ReadUInt64Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___ReadUInt64Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetReadAttributeUInt64Request = SetReadAttributeUInt64Request

@typing.final
class SetReadAttributeUInt64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetReadAttributeUInt64Response = SetReadAttributeUInt64Response

@typing.final
class SetRealTimeAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___RealTimeBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___RealTimeBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetRealTimeAttributeBoolRequest = SetRealTimeAttributeBoolRequest

@typing.final
class SetRealTimeAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetRealTimeAttributeBoolResponse = SetRealTimeAttributeBoolResponse

@typing.final
class SetRealTimeAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___RealTimeInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___RealTimeInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___RealTimeInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___RealTimeInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetRealTimeAttributeInt32Request = SetRealTimeAttributeInt32Request

@typing.final
class SetRealTimeAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetRealTimeAttributeInt32Response = SetRealTimeAttributeInt32Response

@typing.final
class SetRealTimeAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___RealTimeUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___RealTimeUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetRealTimeAttributeUInt32Request = SetRealTimeAttributeUInt32Request

@typing.final
class SetRealTimeAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetRealTimeAttributeUInt32Response = SetRealTimeAttributeUInt32Response

@typing.final
class SetScaleAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___ScaleDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___ScaleDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetScaleAttributeDoubleRequest = SetScaleAttributeDoubleRequest

@typing.final
class SetScaleAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetScaleAttributeDoubleResponse = SetScaleAttributeDoubleResponse

@typing.final
class SetScaleAttributeDoubleArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___ScaleDoubleArrayAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___ScaleDoubleArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetScaleAttributeDoubleArrayRequest = SetScaleAttributeDoubleArrayRequest

@typing.final
class SetScaleAttributeDoubleArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetScaleAttributeDoubleArrayResponse = SetScaleAttributeDoubleArrayResponse

@typing.final
class SetScaleAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___ScaleInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___ScaleInt32AttributeValues.ValueType
    value_raw: builtins.int
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___ScaleInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___ScaleInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetScaleAttributeInt32Request = SetScaleAttributeInt32Request

@typing.final
class SetScaleAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetScaleAttributeInt32Response = SetScaleAttributeInt32Response

@typing.final
class SetScaleAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    scale_name: builtins.str
    attribute: global___ScaleStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        scale_name: builtins.str = ...,
        attribute: global___ScaleStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "scale_name", b"scale_name", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetScaleAttributeStringRequest = SetScaleAttributeStringRequest

@typing.final
class SetScaleAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetScaleAttributeStringResponse = SetScaleAttributeStringResponse

@typing.final
class SetStartTrigTrigWhenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "task", b"task"]) -> None: ...

global___SetStartTrigTrigWhenRequest = SetStartTrigTrigWhenRequest

@typing.final
class SetStartTrigTrigWhenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetStartTrigTrigWhenResponse = SetStartTrigTrigWhenResponse

@typing.final
class SetSyncPulseTimeWhenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def data(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        data: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "task", b"task"]) -> None: ...

global___SetSyncPulseTimeWhenRequest = SetSyncPulseTimeWhenRequest

@typing.final
class SetSyncPulseTimeWhenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetSyncPulseTimeWhenResponse = SetSyncPulseTimeWhenResponse

@typing.final
class SetTimingAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TimingBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeBoolRequest = SetTimingAttributeBoolRequest

@typing.final
class SetTimingAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeBoolResponse = SetTimingAttributeBoolResponse

@typing.final
class SetTimingAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TimingDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeDoubleRequest = SetTimingAttributeDoubleRequest

@typing.final
class SetTimingAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeDoubleResponse = SetTimingAttributeDoubleResponse

@typing.final
class SetTimingAttributeExBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeExBoolRequest = SetTimingAttributeExBoolRequest

@typing.final
class SetTimingAttributeExBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeExBoolResponse = SetTimingAttributeExBoolResponse

@typing.final
class SetTimingAttributeExDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeExDoubleRequest = SetTimingAttributeExDoubleRequest

@typing.final
class SetTimingAttributeExDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeExDoubleResponse = SetTimingAttributeExDoubleResponse

@typing.final
class SetTimingAttributeExInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___TimingInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___TimingInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetTimingAttributeExInt32Request = SetTimingAttributeExInt32Request

@typing.final
class SetTimingAttributeExInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeExInt32Response = SetTimingAttributeExInt32Response

@typing.final
class SetTimingAttributeExStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeExStringRequest = SetTimingAttributeExStringRequest

@typing.final
class SetTimingAttributeExStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeExStringResponse = SetTimingAttributeExStringResponse

@typing.final
class SetTimingAttributeExTimestampRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingTimestampAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingTimestampAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeExTimestampRequest = SetTimingAttributeExTimestampRequest

@typing.final
class SetTimingAttributeExTimestampResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeExTimestampResponse = SetTimingAttributeExTimestampResponse

@typing.final
class SetTimingAttributeExUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeExUInt32Request = SetTimingAttributeExUInt32Request

@typing.final
class SetTimingAttributeExUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeExUInt32Response = SetTimingAttributeExUInt32Response

@typing.final
class SetTimingAttributeExUInt64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    DEVICE_NAMES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    device_names: builtins.str
    attribute: global___TimingUInt64Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        device_names: builtins.str = ...,
        attribute: global___TimingUInt64Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "device_names", b"device_names", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeExUInt64Request = SetTimingAttributeExUInt64Request

@typing.final
class SetTimingAttributeExUInt64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeExUInt64Response = SetTimingAttributeExUInt64Response

@typing.final
class SetTimingAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TimingInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___TimingInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___TimingInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetTimingAttributeInt32Request = SetTimingAttributeInt32Request

@typing.final
class SetTimingAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeInt32Response = SetTimingAttributeInt32Response

@typing.final
class SetTimingAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TimingStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeStringRequest = SetTimingAttributeStringRequest

@typing.final
class SetTimingAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeStringResponse = SetTimingAttributeStringResponse

@typing.final
class SetTimingAttributeTimestampRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TimingTimestampAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingTimestampAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeTimestampRequest = SetTimingAttributeTimestampRequest

@typing.final
class SetTimingAttributeTimestampResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeTimestampResponse = SetTimingAttributeTimestampResponse

@typing.final
class SetTimingAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TimingUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeUInt32Request = SetTimingAttributeUInt32Request

@typing.final
class SetTimingAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeUInt32Response = SetTimingAttributeUInt32Response

@typing.final
class SetTimingAttributeUInt64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TimingUInt64Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TimingUInt64Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTimingAttributeUInt64Request = SetTimingAttributeUInt64Request

@typing.final
class SetTimingAttributeUInt64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTimingAttributeUInt64Response = SetTimingAttributeUInt64Response

@typing.final
class SetTrigAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TriggerBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTrigAttributeBoolRequest = SetTrigAttributeBoolRequest

@typing.final
class SetTrigAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTrigAttributeBoolResponse = SetTrigAttributeBoolResponse

@typing.final
class SetTrigAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TriggerDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTrigAttributeDoubleRequest = SetTrigAttributeDoubleRequest

@typing.final
class SetTrigAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTrigAttributeDoubleResponse = SetTrigAttributeDoubleResponse

@typing.final
class SetTrigAttributeDoubleArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TriggerDoubleArrayAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerDoubleArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTrigAttributeDoubleArrayRequest = SetTrigAttributeDoubleArrayRequest

@typing.final
class SetTrigAttributeDoubleArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTrigAttributeDoubleArrayResponse = SetTrigAttributeDoubleArrayResponse

@typing.final
class SetTrigAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___TriggerInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___TriggerInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___TriggerInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetTrigAttributeInt32Request = SetTrigAttributeInt32Request

@typing.final
class SetTrigAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTrigAttributeInt32Response = SetTrigAttributeInt32Response

@typing.final
class SetTrigAttributeInt32ArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TriggerInt32ArrayAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerInt32ArrayAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTrigAttributeInt32ArrayRequest = SetTrigAttributeInt32ArrayRequest

@typing.final
class SetTrigAttributeInt32ArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTrigAttributeInt32ArrayResponse = SetTrigAttributeInt32ArrayResponse

@typing.final
class SetTrigAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TriggerStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTrigAttributeStringRequest = SetTrigAttributeStringRequest

@typing.final
class SetTrigAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTrigAttributeStringResponse = SetTrigAttributeStringResponse

@typing.final
class SetTrigAttributeTimestampRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TriggerTimestampAttribute.ValueType
    attribute_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerTimestampAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTrigAttributeTimestampRequest = SetTrigAttributeTimestampRequest

@typing.final
class SetTrigAttributeTimestampResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTrigAttributeTimestampResponse = SetTrigAttributeTimestampResponse

@typing.final
class SetTrigAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___TriggerUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___TriggerUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetTrigAttributeUInt32Request = SetTrigAttributeUInt32Request

@typing.final
class SetTrigAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetTrigAttributeUInt32Response = SetTrigAttributeUInt32Response

@typing.final
class SetWatchdogAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetWatchdogAttributeBoolRequest = SetWatchdogAttributeBoolRequest

@typing.final
class SetWatchdogAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWatchdogAttributeBoolResponse = SetWatchdogAttributeBoolResponse

@typing.final
class SetWatchdogAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetWatchdogAttributeDoubleRequest = SetWatchdogAttributeDoubleRequest

@typing.final
class SetWatchdogAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWatchdogAttributeDoubleResponse = SetWatchdogAttributeDoubleResponse

@typing.final
class SetWatchdogAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___WatchdogInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___WatchdogInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetWatchdogAttributeInt32Request = SetWatchdogAttributeInt32Request

@typing.final
class SetWatchdogAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWatchdogAttributeInt32Response = SetWatchdogAttributeInt32Response

@typing.final
class SetWatchdogAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    lines: builtins.str
    attribute: global___WatchdogStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        lines: builtins.str = ...,
        attribute: global___WatchdogStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "lines", b"lines", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetWatchdogAttributeStringRequest = SetWatchdogAttributeStringRequest

@typing.final
class SetWatchdogAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWatchdogAttributeStringResponse = SetWatchdogAttributeStringResponse

@typing.final
class SetWriteAttributeBoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___WriteBoolAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.bool
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteBoolAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetWriteAttributeBoolRequest = SetWriteAttributeBoolRequest

@typing.final
class SetWriteAttributeBoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWriteAttributeBoolResponse = SetWriteAttributeBoolResponse

@typing.final
class SetWriteAttributeDoubleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___WriteDoubleAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteDoubleAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetWriteAttributeDoubleRequest = SetWriteAttributeDoubleRequest

@typing.final
class SetWriteAttributeDoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWriteAttributeDoubleResponse = SetWriteAttributeDoubleResponse

@typing.final
class SetWriteAttributeInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VALUE_RAW_FIELD_NUMBER: builtins.int
    attribute: global___WriteInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: global___WriteInt32AttributeValues.ValueType
    value_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: global___WriteInt32AttributeValues.ValueType = ...,
        value_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value", "value_enum", b"value_enum", "value_raw", b"value_raw"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["value_enum", b"value_enum"]) -> typing.Literal["value", "value_raw"] | None: ...

global___SetWriteAttributeInt32Request = SetWriteAttributeInt32Request

@typing.final
class SetWriteAttributeInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWriteAttributeInt32Response = SetWriteAttributeInt32Response

@typing.final
class SetWriteAttributeStringRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___WriteStringAttribute.ValueType
    attribute_raw: builtins.int
    value: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteStringAttribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetWriteAttributeStringRequest = SetWriteAttributeStringRequest

@typing.final
class SetWriteAttributeStringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWriteAttributeStringResponse = SetWriteAttributeStringResponse

@typing.final
class SetWriteAttributeUInt32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___WriteUInt32Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteUInt32Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetWriteAttributeUInt32Request = SetWriteAttributeUInt32Request

@typing.final
class SetWriteAttributeUInt32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWriteAttributeUInt32Response = SetWriteAttributeUInt32Response

@typing.final
class SetWriteAttributeUInt64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RAW_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: global___WriteUInt64Attribute.ValueType
    attribute_raw: builtins.int
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        attribute: global___WriteUInt64Attribute.ValueType = ...,
        attribute_raw: builtins.int = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attribute", b"attribute", "attribute_enum", b"attribute_enum", "attribute_raw", b"attribute_raw", "task", b"task", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["attribute_enum", b"attribute_enum"]) -> typing.Literal["attribute", "attribute_raw"] | None: ...

global___SetWriteAttributeUInt64Request = SetWriteAttributeUInt64Request

@typing.final
class SetWriteAttributeUInt64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___SetWriteAttributeUInt64Response = SetWriteAttributeUInt64Response

@typing.final
class StartNewFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    file_path: builtins.str
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        file_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["file_path", b"file_path", "task", b"task"]) -> None: ...

global___StartNewFileRequest = StartNewFileRequest

@typing.final
class StartNewFileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___StartNewFileResponse = StartNewFileResponse

@typing.final
class StartTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___StartTaskRequest = StartTaskRequest

@typing.final
class StartTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___StartTaskResponse = StartTaskResponse

@typing.final
class StopTaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___StopTaskRequest = StopTaskRequest

@typing.final
class StopTaskResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___StopTaskResponse = StopTaskResponse

@typing.final
class TaskControlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    ACTION_RAW_FIELD_NUMBER: builtins.int
    action: global___TaskControlAction.ValueType
    action_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        action: global___TaskControlAction.ValueType = ...,
        action_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "action_enum", b"action_enum", "action_raw", b"action_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "action_enum", b"action_enum", "action_raw", b"action_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action_enum", b"action_enum"]) -> typing.Literal["action", "action_raw"] | None: ...

global___TaskControlRequest = TaskControlRequest

@typing.final
class TaskControlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___TaskControlResponse = TaskControlResponse

@typing.final
class TristateOutputTermRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_TERMINAL_FIELD_NUMBER: builtins.int
    output_terminal: builtins.str
    def __init__(
        self,
        *,
        output_terminal: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["output_terminal", b"output_terminal"]) -> None: ...

global___TristateOutputTermRequest = TristateOutputTermRequest

@typing.final
class TristateOutputTermResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___TristateOutputTermResponse = TristateOutputTermResponse

@typing.final
class UnregisterDoneEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___UnregisterDoneEventRequest = UnregisterDoneEventRequest

@typing.final
class UnregisterDoneEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___UnregisterDoneEventResponse = UnregisterDoneEventResponse

@typing.final
class UnregisterEveryNSamplesEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    EVERY_N_SAMPLES_EVENT_TYPE_FIELD_NUMBER: builtins.int
    EVERY_N_SAMPLES_EVENT_TYPE_RAW_FIELD_NUMBER: builtins.int
    every_n_samples_event_type: global___EveryNSamplesEventType.ValueType
    every_n_samples_event_type_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        every_n_samples_event_type: global___EveryNSamplesEventType.ValueType = ...,
        every_n_samples_event_type_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["every_n_samples_event_type", b"every_n_samples_event_type", "every_n_samples_event_type_enum", b"every_n_samples_event_type_enum", "every_n_samples_event_type_raw", b"every_n_samples_event_type_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["every_n_samples_event_type", b"every_n_samples_event_type", "every_n_samples_event_type_enum", b"every_n_samples_event_type_enum", "every_n_samples_event_type_raw", b"every_n_samples_event_type_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["every_n_samples_event_type_enum", b"every_n_samples_event_type_enum"]) -> typing.Literal["every_n_samples_event_type", "every_n_samples_event_type_raw"] | None: ...

global___UnregisterEveryNSamplesEventRequest = UnregisterEveryNSamplesEventRequest

@typing.final
class UnregisterEveryNSamplesEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___UnregisterEveryNSamplesEventResponse = UnregisterEveryNSamplesEventResponse

@typing.final
class UnregisterSignalEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    SIGNAL_ID_FIELD_NUMBER: builtins.int
    SIGNAL_ID_RAW_FIELD_NUMBER: builtins.int
    signal_id: global___Signal2.ValueType
    signal_id_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        signal_id: global___Signal2.ValueType = ...,
        signal_id_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["signal_id", b"signal_id", "signal_id_enum", b"signal_id_enum", "signal_id_raw", b"signal_id_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["signal_id", b"signal_id", "signal_id_enum", b"signal_id_enum", "signal_id_raw", b"signal_id_raw", "task", b"task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["signal_id_enum", b"signal_id_enum"]) -> typing.Literal["signal_id", "signal_id_raw"] | None: ...

global___UnregisterSignalEventRequest = UnregisterSignalEventRequest

@typing.final
class UnregisterSignalEventResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___UnregisterSignalEventResponse = UnregisterSignalEventResponse

@typing.final
class UnreserveNetworkDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name"]) -> None: ...

global___UnreserveNetworkDeviceRequest = UnreserveNetworkDeviceRequest

@typing.final
class UnreserveNetworkDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___UnreserveNetworkDeviceResponse = UnreserveNetworkDeviceResponse

@typing.final
class WaitForNextSampleClockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout"]) -> None: ...

global___WaitForNextSampleClockRequest = WaitForNextSampleClockRequest

@typing.final
class WaitForNextSampleClockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    IS_LATE_FIELD_NUMBER: builtins.int
    status: builtins.int
    is_late: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        is_late: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["is_late", b"is_late", "status", b"status"]) -> None: ...

global___WaitForNextSampleClockResponse = WaitForNextSampleClockResponse

@typing.final
class WaitForValidTimestampRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIMESTAMP_EVENT_FIELD_NUMBER: builtins.int
    TIMESTAMP_EVENT_RAW_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    timestamp_event: global___TimestampEvent.ValueType
    timestamp_event_raw: builtins.int
    timeout: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        timestamp_event: global___TimestampEvent.ValueType = ...,
        timestamp_event_raw: builtins.int = ...,
        timeout: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task", "timestamp_event", b"timestamp_event", "timestamp_event_enum", b"timestamp_event_enum", "timestamp_event_raw", b"timestamp_event_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "timeout", b"timeout", "timestamp_event", b"timestamp_event", "timestamp_event_enum", b"timestamp_event_enum", "timestamp_event_raw", b"timestamp_event_raw"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["timestamp_event_enum", b"timestamp_event_enum"]) -> typing.Literal["timestamp_event", "timestamp_event_raw"] | None: ...

global___WaitForValidTimestampRequest = WaitForValidTimestampRequest

@typing.final
class WaitForValidTimestampResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    status: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "timestamp", b"timestamp"]) -> None: ...

global___WaitForValidTimestampResponse = WaitForValidTimestampResponse

@typing.final
class WaitUntilTaskDoneRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    TIME_TO_WAIT_FIELD_NUMBER: builtins.int
    time_to_wait: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        time_to_wait: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task", "time_to_wait", b"time_to_wait"]) -> None: ...

global___WaitUntilTaskDoneRequest = WaitUntilTaskDoneRequest

@typing.final
class WaitUntilTaskDoneResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___WaitUntilTaskDoneResponse = WaitUntilTaskDoneResponse

@typing.final
class WriteAnalogF64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def write_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteAnalogF64Request = WriteAnalogF64Request

@typing.final
class WriteAnalogF64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteAnalogF64Response = WriteAnalogF64Response

@typing.final
class WriteAnalogScalarF64Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    value: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "task", b"task", "timeout", b"timeout", "value", b"value"]) -> None: ...

global___WriteAnalogScalarF64Request = WriteAnalogScalarF64Request

@typing.final
class WriteAnalogScalarF64Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___WriteAnalogScalarF64Response = WriteAnalogScalarF64Response

@typing.final
class WriteBinaryI16Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def write_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteBinaryI16Request = WriteBinaryI16Request

@typing.final
class WriteBinaryI16Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteBinaryI16Response = WriteBinaryI16Response

@typing.final
class WriteBinaryI32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def write_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteBinaryI32Request = WriteBinaryI32Request

@typing.final
class WriteBinaryI32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteBinaryI32Response = WriteBinaryI32Response

@typing.final
class WriteBinaryU16Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def write_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteBinaryU16Request = WriteBinaryU16Request

@typing.final
class WriteBinaryU16Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteBinaryU16Response = WriteBinaryU16Response

@typing.final
class WriteBinaryU32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def write_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteBinaryU32Request = WriteBinaryU32Request

@typing.final
class WriteBinaryU32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteBinaryU32Response = WriteBinaryU32Response

@typing.final
class WriteCtrFreqRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    FREQUENCY_FIELD_NUMBER: builtins.int
    DUTY_CYCLE_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def frequency(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def duty_cycle(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        frequency: collections.abc.Iterable[builtins.float] | None = ...,
        duty_cycle: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "duty_cycle", b"duty_cycle", "frequency", b"frequency", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteCtrFreqRequest = WriteCtrFreqRequest

@typing.final
class WriteCtrFreqResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    num_samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        num_samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_samps_per_chan_written", b"num_samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteCtrFreqResponse = WriteCtrFreqResponse

@typing.final
class WriteCtrFreqScalarRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    FREQUENCY_FIELD_NUMBER: builtins.int
    DUTY_CYCLE_FIELD_NUMBER: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    frequency: builtins.float
    duty_cycle: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        frequency: builtins.float = ...,
        duty_cycle: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "duty_cycle", b"duty_cycle", "frequency", b"frequency", "task", b"task", "timeout", b"timeout"]) -> None: ...

global___WriteCtrFreqScalarRequest = WriteCtrFreqScalarRequest

@typing.final
class WriteCtrFreqScalarResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___WriteCtrFreqScalarResponse = WriteCtrFreqScalarResponse

@typing.final
class WriteCtrTicksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    HIGH_TICKS_FIELD_NUMBER: builtins.int
    LOW_TICKS_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def high_ticks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def low_ticks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        high_ticks: collections.abc.Iterable[builtins.int] | None = ...,
        low_ticks: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "high_ticks", b"high_ticks", "low_ticks", b"low_ticks", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteCtrTicksRequest = WriteCtrTicksRequest

@typing.final
class WriteCtrTicksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    num_samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        num_samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_samps_per_chan_written", b"num_samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteCtrTicksResponse = WriteCtrTicksResponse

@typing.final
class WriteCtrTicksScalarRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    HIGH_TICKS_FIELD_NUMBER: builtins.int
    LOW_TICKS_FIELD_NUMBER: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    high_ticks: builtins.int
    low_ticks: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        high_ticks: builtins.int = ...,
        low_ticks: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "high_ticks", b"high_ticks", "low_ticks", b"low_ticks", "task", b"task", "timeout", b"timeout"]) -> None: ...

global___WriteCtrTicksScalarRequest = WriteCtrTicksScalarRequest

@typing.final
class WriteCtrTicksScalarResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___WriteCtrTicksScalarResponse = WriteCtrTicksScalarResponse

@typing.final
class WriteCtrTimeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    HIGH_TIME_FIELD_NUMBER: builtins.int
    LOW_TIME_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def high_time(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def low_time(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        high_time: collections.abc.Iterable[builtins.float] | None = ...,
        low_time: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "high_time", b"high_time", "low_time", b"low_time", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteCtrTimeRequest = WriteCtrTimeRequest

@typing.final
class WriteCtrTimeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    num_samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        num_samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_samps_per_chan_written", b"num_samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteCtrTimeResponse = WriteCtrTimeResponse

@typing.final
class WriteCtrTimeScalarRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    HIGH_TIME_FIELD_NUMBER: builtins.int
    LOW_TIME_FIELD_NUMBER: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    high_time: builtins.float
    low_time: builtins.float
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        high_time: builtins.float = ...,
        low_time: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "high_time", b"high_time", "low_time", b"low_time", "task", b"task", "timeout", b"timeout"]) -> None: ...

global___WriteCtrTimeScalarRequest = WriteCtrTimeScalarRequest

@typing.final
class WriteCtrTimeScalarResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___WriteCtrTimeScalarResponse = WriteCtrTimeScalarResponse

@typing.final
class WriteDigitalLinesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    write_array: builtins.bytes
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteDigitalLinesRequest = WriteDigitalLinesRequest

@typing.final
class WriteDigitalLinesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteDigitalLinesResponse = WriteDigitalLinesResponse

@typing.final
class WriteDigitalScalarU32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    value: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "task", b"task", "timeout", b"timeout", "value", b"value"]) -> None: ...

global___WriteDigitalScalarU32Request = WriteDigitalScalarU32Request

@typing.final
class WriteDigitalScalarU32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___WriteDigitalScalarU32Response = WriteDigitalScalarU32Response

@typing.final
class WriteDigitalU16Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def write_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteDigitalU16Request = WriteDigitalU16Request

@typing.final
class WriteDigitalU16Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteDigitalU16Response = WriteDigitalU16Response

@typing.final
class WriteDigitalU32Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    @property
    def task(self) -> session_pb2.Session: ...
    @property
    def write_array(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteDigitalU32Request = WriteDigitalU32Request

@typing.final
class WriteDigitalU32Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteDigitalU32Response = WriteDigitalU32Response

@typing.final
class WriteDigitalU8Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_PER_CHAN_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_FIELD_NUMBER: builtins.int
    DATA_LAYOUT_RAW_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps_per_chan: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    data_layout: global___GroupBy.ValueType
    data_layout_raw: builtins.int
    write_array: builtins.bytes
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps_per_chan: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        data_layout: global___GroupBy.ValueType = ...,
        data_layout_raw: builtins.int = ...,
        write_array: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "data_layout", b"data_layout", "data_layout_enum", b"data_layout_enum", "data_layout_raw", b"data_layout_raw", "num_samps_per_chan", b"num_samps_per_chan", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data_layout_enum", b"data_layout_enum"]) -> typing.Literal["data_layout", "data_layout_raw"] | None: ...

global___WriteDigitalU8Request = WriteDigitalU8Request

@typing.final
class WriteDigitalU8Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteDigitalU8Response = WriteDigitalU8Response

@typing.final
class WriteRawRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    NUM_SAMPS_FIELD_NUMBER: builtins.int
    AUTO_START_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    WRITE_ARRAY_FIELD_NUMBER: builtins.int
    num_samps: builtins.int
    auto_start: builtins.bool
    timeout: builtins.float
    write_array: builtins.bytes
    @property
    def task(self) -> session_pb2.Session: ...
    def __init__(
        self,
        *,
        task: session_pb2.Session | None = ...,
        num_samps: builtins.int = ...,
        auto_start: builtins.bool = ...,
        timeout: builtins.float = ...,
        write_array: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_start", b"auto_start", "num_samps", b"num_samps", "task", b"task", "timeout", b"timeout", "write_array", b"write_array"]) -> None: ...

global___WriteRawRequest = WriteRawRequest

@typing.final
class WriteRawResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SAMPS_PER_CHAN_WRITTEN_FIELD_NUMBER: builtins.int
    status: builtins.int
    samps_per_chan_written: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        samps_per_chan_written: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["samps_per_chan_written", b"samps_per_chan_written", "status", b"status"]) -> None: ...

global___WriteRawResponse = WriteRawResponse

@typing.final
class WriteToTEDSFromArrayRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    BIT_STREAM_FIELD_NUMBER: builtins.int
    BASIC_TEDS_OPTIONS_FIELD_NUMBER: builtins.int
    BASIC_TEDS_OPTIONS_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    bit_stream: builtins.bytes
    basic_teds_options: global___WriteBasicTEDSOptions.ValueType
    basic_teds_options_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        bit_stream: builtins.bytes = ...,
        basic_teds_options: global___WriteBasicTEDSOptions.ValueType = ...,
        basic_teds_options_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["basic_teds_options", b"basic_teds_options", "basic_teds_options_enum", b"basic_teds_options_enum", "basic_teds_options_raw", b"basic_teds_options_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["basic_teds_options", b"basic_teds_options", "basic_teds_options_enum", b"basic_teds_options_enum", "basic_teds_options_raw", b"basic_teds_options_raw", "bit_stream", b"bit_stream", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["basic_teds_options_enum", b"basic_teds_options_enum"]) -> typing.Literal["basic_teds_options", "basic_teds_options_raw"] | None: ...

global___WriteToTEDSFromArrayRequest = WriteToTEDSFromArrayRequest

@typing.final
class WriteToTEDSFromArrayResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___WriteToTEDSFromArrayResponse = WriteToTEDSFromArrayResponse

@typing.final
class WriteToTEDSFromFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_CHANNEL_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    BASIC_TEDS_OPTIONS_FIELD_NUMBER: builtins.int
    BASIC_TEDS_OPTIONS_RAW_FIELD_NUMBER: builtins.int
    physical_channel: builtins.str
    file_path: builtins.str
    basic_teds_options: global___WriteBasicTEDSOptions.ValueType
    basic_teds_options_raw: builtins.int
    def __init__(
        self,
        *,
        physical_channel: builtins.str = ...,
        file_path: builtins.str = ...,
        basic_teds_options: global___WriteBasicTEDSOptions.ValueType = ...,
        basic_teds_options_raw: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["basic_teds_options", b"basic_teds_options", "basic_teds_options_enum", b"basic_teds_options_enum", "basic_teds_options_raw", b"basic_teds_options_raw"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["basic_teds_options", b"basic_teds_options", "basic_teds_options_enum", b"basic_teds_options_enum", "basic_teds_options_raw", b"basic_teds_options_raw", "file_path", b"file_path", "physical_channel", b"physical_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["basic_teds_options_enum", b"basic_teds_options_enum"]) -> typing.Literal["basic_teds_options", "basic_teds_options_raw"] | None: ...

global___WriteToTEDSFromFileRequest = WriteToTEDSFromFileRequest

@typing.final
class WriteToTEDSFromFileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___WriteToTEDSFromFileResponse = WriteToTEDSFromFileResponse
